{
 "cells": [
  {
   "cell_type": "markdown",
   "metadata": {
    "slideshow": {
     "slide_type": "slide"
    }
   },
   "source": [
    "# Compare to ANOVA and LMM: ROC curve"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 1,
   "metadata": {},
   "outputs": [],
   "source": [
    "\n",
    "import numpy as np\n",
    "\n",
    "from bayes_window import model_comparison, BayesWindow\n",
    "from bayes_window.generative_models import generate_fake_lfp\n"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Data plot\n",
    "- Intercept varies across mice, but not slope\n",
    "    - (Same response, different baseline)\n",
    "- We vary the number of trials and then test raw or log-transformed data"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "metadata": {
    "lines_to_next_cell": 2
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<div id=\"altair-viz-f631124762f746fc83f98f953b6d1e69\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-f631124762f746fc83f98f953b6d1e69\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-f631124762f746fc83f98f953b6d1e69\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm//vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm//vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm//vega-lite@4.8.1?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm//vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function loadScript(lib) {\n",
       "      return new Promise(function(resolve, reject) {\n",
       "        var s = document.createElement('script');\n",
       "        s.src = paths[lib];\n",
       "        s.async = true;\n",
       "        s.onload = () => resolve(paths[lib]);\n",
       "        s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "        document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "      });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else if (typeof vegaEmbed === \"function\") {\n",
       "      displayChart(vegaEmbed);\n",
       "    } else {\n",
       "      loadScript(\"vega\")\n",
       "        .then(() => loadScript(\"vega-lite\"))\n",
       "        .then(() => loadScript(\"vega-embed\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 400, \"continuousHeight\": 300}}, \"layer\": [{\"layer\": [{\"mark\": {\"type\": \"line\", \"clip\": true, \"fill\": null, \"opacity\": 0.8}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"ordinal\", \"field\": \"\"}, \"size\": {\"value\": 1.0}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\"}, \"field\": \"Power\", \"scale\": {\"domain\": [55.79511701986472, 629.7680046995029], \"zero\": false}, \"title\": \"Power\"}}}, {\"mark\": {\"type\": \"circle\", \"clip\": true, \"filled\": true, \"opacity\": 0}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"ordinal\", \"field\": \"\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"Power\", \"scale\": {\"domain\": [55.79511701986472, 629.7680046995029], \"zero\": false}}}}, {\"mark\": {\"type\": \"boxplot\", \"clip\": true, \"color\": \"black\", \"median\": {\"color\": \"red\", \"strokeWidth\": 20}, \"opacity\": 0.3, \"size\": 9}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"Power\", \"scale\": {\"domain\": [55.79511701986472, 629.7680046995029], \"zero\": false}}}}], \"width\": 60}, {\"mark\": {\"type\": \"line\", \"fill\": null}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"quantitative\", \"field\": \"i_trial\"}, \"opacity\": {\"value\": 0.5}, \"size\": {\"value\": 0.9}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"Power\", \"scale\": {\"clamp\": true, \"domain\": [55.79511701986472, 629.7680046995029], \"zero\": false}}}}], \"data\": {\"name\": \"data-64baf6555841c3bad0ba6097e6ff8585\"}, \"$schema\": \"https://vega.github.io/schema/vega-lite/v4.8.1.json\", \"datasets\": {\"data-64baf6555841c3bad0ba6097e6ff8585\": [{\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 0, \"stim\": 0, \"Log power\": 1.6625497755180054, \"Firing rate\": 45.977968194823, \"Power\": 45.977968194823, \"i_spike\": 47.5, \"isi\": 0.07354283633507393, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 0, \"stim\": 1, \"Log power\": 1.782475432512846, \"Firing rate\": 60.600391868556535, \"Power\": 60.600391868556535, \"i_spike\": 50.5, \"isi\": 0.06709212109537435, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 1, \"stim\": 0, \"Log power\": 1.6780165775152507, \"Firing rate\": 47.644917306616556, \"Power\": 47.644917306616556, \"i_spike\": 43.0, \"isi\": 0.07926214363259138, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 1, \"stim\": 1, \"Log power\": 1.8211077850924373, \"Firing rate\": 66.23808758688277, \"Power\": 66.23808758688277, \"i_spike\": 57.5, \"isi\": 0.058750136147541036, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 2, \"stim\": 0, \"Log power\": 2.0766150819706195, \"Firing rate\": 119.29303338504354, \"Power\": 119.29303338504354, \"i_spike\": 32.0, \"isi\": 0.10970724102139953, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 2, \"stim\": 1, \"Log power\": 1.9391979776076984, \"Firing rate\": 86.93566441404978, \"Power\": 86.93566441404978, \"i_spike\": 66.5, \"isi\": 0.04968085796225274, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 3, \"stim\": 0, \"Log power\": 1.6476537252223684, \"Firing rate\": 44.4276892187081, \"Power\": 44.4276892187081, \"i_spike\": 44.5, \"isi\": 0.07727660502735256, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 3, \"stim\": 1, \"Log power\": 2.009877408326617, \"Firing rate\": 102.3004180191958, \"Power\": 102.3004180191958, \"i_spike\": 50.0, \"isi\": 0.06874825391126772, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 4, \"stim\": 0, \"Log power\": 1.9957416381817628, \"Firing rate\": 99.02426741941034, \"Power\": 99.02426741941034, \"i_spike\": 45.5, \"isi\": 0.07620278604838457, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 4, \"stim\": 1, \"Log power\": 1.927856333796681, \"Firing rate\": 84.69471945641088, \"Power\": 84.69471945641088, \"i_spike\": 55.0, \"isi\": 0.0616251200000963, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 5, \"stim\": 0, \"Log power\": 1.9132809823976238, \"Firing rate\": 81.89944946339625, \"Power\": 81.89944946339625, \"i_spike\": 39.5, \"isi\": 0.08739212204242809, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 5, \"stim\": 1, \"Log power\": 2.3898214408114526, \"Firing rate\": 245.36998751434663, \"Power\": 245.36998751434663, \"i_spike\": 52.5, \"isi\": 0.06635568745876487, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 6, \"stim\": 0, \"Log power\": 1.9969983418381505, \"Firing rate\": 99.31122566527485, \"Power\": 99.31122566527485, \"i_spike\": 51.0, \"isi\": 0.0673386975882036, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 6, \"stim\": 1, \"Log power\": 1.7542980267354813, \"Firing rate\": 56.79342062949033, \"Power\": 56.79342062949033, \"i_spike\": 51.0, \"isi\": 0.06821465228737356, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 7, \"stim\": 0, \"Log power\": 1.8473378581898523, \"Firing rate\": 70.36194858541609, \"Power\": 70.36194858541609, \"i_spike\": 47.5, \"isi\": 0.07357355109764273, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 7, \"stim\": 1, \"Log power\": 1.8004488619718322, \"Firing rate\": 63.160980306830645, \"Power\": 63.160980306830645, \"i_spike\": 61.5, \"isi\": 0.05648394362971899, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 8, \"stim\": 0, \"Log power\": 1.7149420010583498, \"Firing rate\": 51.87307591077447, \"Power\": 51.87307591077447, \"i_spike\": 43.5, \"isi\": 0.08011524793269516, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 8, \"stim\": 1, \"Log power\": 2.641833120822674, \"Firing rate\": 438.3622231874032, \"Power\": 438.3622231874032, \"i_spike\": 62.5, \"isi\": 0.05363123023346108, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 9, \"stim\": 0, \"Log power\": 1.8379665875535347, \"Firing rate\": 68.85993169170796, \"Power\": 68.85993169170796, \"i_spike\": 45.0, \"isi\": 0.07837657942481951, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 9, \"stim\": 1, \"Log power\": 1.8859828114170158, \"Firing rate\": 76.91000001098662, \"Power\": 76.91000001098662, \"i_spike\": 57.0, \"isi\": 0.06042001776535927, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 10, \"stim\": 0, \"Log power\": 1.8077611512333742, \"Firing rate\": 64.23343557820496, \"Power\": 64.23343557820496, \"i_spike\": 42.0, \"isi\": 0.083046735898273, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 10, \"stim\": 1, \"Log power\": 2.3461271529189394, \"Firing rate\": 221.88459593516652, \"Power\": 221.88459593516652, \"i_spike\": 55.5, \"isi\": 0.06103085765500905, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 11, \"stim\": 0, \"Log power\": 1.7415319117614236, \"Firing rate\": 55.14827235932182, \"Power\": 55.14827235932182, \"i_spike\": 33.5, \"isi\": 0.10297915019077108, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 11, \"stim\": 1, \"Log power\": 2.1007648420307206, \"Firing rate\": 126.11444762226479, \"Power\": 126.11444762226479, \"i_spike\": 59.5, \"isi\": 0.0576395291856615, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 12, \"stim\": 0, \"Log power\": 2.0006701859195495, \"Firing rate\": 100.15443513921579, \"Power\": 100.15443513921579, \"i_spike\": 33.5, \"isi\": 0.10247731872421481, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 12, \"stim\": 1, \"Log power\": 2.500914066076398, \"Firing rate\": 316.8940362230377, \"Power\": 316.8940362230377, \"i_spike\": 54.5, \"isi\": 0.061916597674327487, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 13, \"stim\": 0, \"Log power\": 1.8816301513737979, \"Firing rate\": 76.14302937597942, \"Power\": 76.14302937597942, \"i_spike\": 37.0, \"isi\": 0.09351272470863202, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 13, \"stim\": 1, \"Log power\": 2.10938763550984, \"Firing rate\": 128.6434372347139, \"Power\": 128.6434372347139, \"i_spike\": 58.0, \"isi\": 0.06005302527969796, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 14, \"stim\": 0, \"Log power\": 2.2716052348133373, \"Firing rate\": 186.89824994890884, \"Power\": 186.89824994890884, \"i_spike\": 55.5, \"isi\": 0.06297327071513874, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 14, \"stim\": 1, \"Log power\": 1.9845826624506278, \"Firing rate\": 96.51229932546447, \"Power\": 96.51229932546447, \"i_spike\": 64.0, \"isi\": 0.05383194516091484, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 15, \"stim\": 0, \"Log power\": 2.250477990975017, \"Firing rate\": 178.02376883001423, \"Power\": 178.02376883001423, \"i_spike\": 31.5, \"isi\": 0.10816378961221756, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 15, \"stim\": 1, \"Log power\": 1.9057488929454696, \"Firing rate\": 80.49129097179582, \"Power\": 80.49129097179582, \"i_spike\": 55.5, \"isi\": 0.06271382662498402, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 16, \"stim\": 0, \"Log power\": 1.85309886906835, \"Firing rate\": 71.30153327597479, \"Power\": 71.30153327597479, \"i_spike\": 43.0, \"isi\": 0.08193823451241652, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 16, \"stim\": 1, \"Log power\": 2.2312550060163914, \"Firing rate\": 170.3158263487131, \"Power\": 170.3158263487131, \"i_spike\": 68.5, \"isi\": 0.05136776537701065, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 17, \"stim\": 0, \"Log power\": 2.3671270453085143, \"Firing rate\": 232.8772399955018, \"Power\": 232.8772399955018, \"i_spike\": 45.0, \"isi\": 0.07420621878282166, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 17, \"stim\": 1, \"Log power\": 2.312739155336508, \"Firing rate\": 205.46561638202544, \"Power\": 205.46561638202544, \"i_spike\": 50.5, \"isi\": 0.0687503819850757, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 18, \"stim\": 0, \"Log power\": 1.9427273969748382, \"Firing rate\": 87.64505077722241, \"Power\": 87.64505077722241, \"i_spike\": 49.5, \"isi\": 0.07008707305661183, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 18, \"stim\": 1, \"Log power\": 2.7684057930927617, \"Firing rate\": 586.6860922077974, \"Power\": 586.6860922077974, \"i_spike\": 42.5, \"isi\": 0.0780428505654008, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 19, \"stim\": 0, \"Log power\": 1.742783557903538, \"Firing rate\": 55.30744013197595, \"Power\": 55.30744013197595, \"i_spike\": 41.0, \"isi\": 0.08430000837937159, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 19, \"stim\": 1, \"Log power\": 1.5724192175144618, \"Firing rate\": 37.36106241490691, \"Power\": 37.36106241490691, \"i_spike\": 44.0, \"isi\": 0.07924970852204646, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 20, \"stim\": 0, \"Log power\": 1.6757122987665798, \"Firing rate\": 47.392792457798336, \"Power\": 47.392792457798336, \"i_spike\": 40.5, \"isi\": 0.08438587583548386, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 20, \"stim\": 1, \"Log power\": 1.8910718120342573, \"Firing rate\": 77.81652126032918, \"Power\": 77.81652126032918, \"i_spike\": 53.5, \"isi\": 0.06367926738304572, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 21, \"stim\": 0, \"Log power\": 1.571384669791069, \"Firing rate\": 37.27216927138806, \"Power\": 37.27216927138806, \"i_spike\": 39.5, \"isi\": 0.08672838699138857, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 21, \"stim\": 1, \"Log power\": 2.1544848415763638, \"Firing rate\": 142.72000149337688, \"Power\": 142.72000149337688, \"i_spike\": 57.5, \"isi\": 0.058690930111028224, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 22, \"stim\": 0, \"Log power\": 2.0990155569441233, \"Firing rate\": 125.60749569857214, \"Power\": 125.60749569857214, \"i_spike\": 42.5, \"isi\": 0.08142636059032474, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 22, \"stim\": 1, \"Log power\": 1.9671675230283032, \"Firing rate\": 92.71874039952, \"Power\": 92.71874039952, \"i_spike\": 68.5, \"isi\": 0.05080615403599393, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 23, \"stim\": 0, \"Log power\": 1.8915945580103632, \"Firing rate\": 77.91024283965878, \"Power\": 77.91024283965878, \"i_spike\": 40.5, \"isi\": 0.08723072421561726, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 23, \"stim\": 1, \"Log power\": 2.0138506338400366, \"Firing rate\": 103.2406270967658, \"Power\": 103.2406270967658, \"i_spike\": 61.0, \"isi\": 0.05603803867480305, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 24, \"stim\": 0, \"Log power\": 1.838615657540525, \"Firing rate\": 68.96292247934187, \"Power\": 68.96292247934187, \"i_spike\": 49.5, \"isi\": 0.07011998827474242, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 24, \"stim\": 1, \"Log power\": 2.0378266686393847, \"Firing rate\": 109.10048183856799, \"Power\": 109.10048183856799, \"i_spike\": 49.5, \"isi\": 0.07007645686923011, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 25, \"stim\": 0, \"Log power\": 2.160395765698059, \"Firing rate\": 144.6757577523293, \"Power\": 144.6757577523293, \"i_spike\": 37.5, \"isi\": 0.0911316621841269, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 25, \"stim\": 1, \"Log power\": 1.8370901904033095, \"Firing rate\": 68.72111390746909, \"Power\": 68.72111390746909, \"i_spike\": 65.0, \"isi\": 0.053356165398502436, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 26, \"stim\": 0, \"Log power\": 1.5792670047135864, \"Firing rate\": 37.954825993505, \"Power\": 37.954825993505, \"i_spike\": 38.5, \"isi\": 0.09106403685321714, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 26, \"stim\": 1, \"Log power\": 1.7660847171662621, \"Firing rate\": 58.355892712709014, \"Power\": 58.355892712709014, \"i_spike\": 47.0, \"isi\": 0.07402118305549837, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 27, \"stim\": 0, \"Log power\": 2.9950507930809986, \"Firing rate\": 988.6687180320453, \"Power\": 988.6687180320453, \"i_spike\": 44.5, \"isi\": 0.07735688495976953, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 27, \"stim\": 1, \"Log power\": 2.2143078512574506, \"Firing rate\": 163.79771962276013, \"Power\": 163.79771962276013, \"i_spike\": 53.5, \"isi\": 0.06225282994792721, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 28, \"stim\": 0, \"Log power\": 1.7959439115726101, \"Firing rate\": 62.509195795069836, \"Power\": 62.509195795069836, \"i_spike\": 42.5, \"isi\": 0.08128744285068623, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 28, \"stim\": 1, \"Log power\": 2.3013973109202865, \"Firing rate\": 200.16922648036277, \"Power\": 200.16922648036277, \"i_spike\": 52.5, \"isi\": 0.06516971434220052, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 29, \"stim\": 0, \"Log power\": 2.1946297973583544, \"Firing rate\": 156.54161043876903, \"Power\": 156.54161043876903, \"i_spike\": 44.5, \"isi\": 0.07727557206965738, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 29, \"stim\": 1, \"Log power\": 1.9558089784240185, \"Firing rate\": 90.32520968335054, \"Power\": 90.32520968335054, \"i_spike\": 59.0, \"isi\": 0.058649479068032195, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 30, \"stim\": 0, \"Log power\": 2.034248188304255, \"Firing rate\": 108.20521400524017, \"Power\": 108.20521400524017, \"i_spike\": 41.0, \"isi\": 0.08579087565424744, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 30, \"stim\": 1, \"Log power\": 2.5721986608468432, \"Firing rate\": 373.4209339798544, \"Power\": 373.4209339798544, \"i_spike\": 66.0, \"isi\": 0.05330483207625823, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 31, \"stim\": 0, \"Log power\": 2.0273796056901263, \"Firing rate\": 106.50735650223092, \"Power\": 106.50735650223092, \"i_spike\": 45.0, \"isi\": 0.07676633890225787, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 31, \"stim\": 1, \"Log power\": 2.286022654934577, \"Firing rate\": 193.2069100607903, \"Power\": 193.2069100607903, \"i_spike\": 56.0, \"isi\": 0.0613939932540251, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 32, \"stim\": 0, \"Log power\": 3.3280364641909714, \"Firing rate\": 2128.317736087387, \"Power\": 2128.317736087387, \"i_spike\": 47.5, \"isi\": 0.07322765281217154, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 32, \"stim\": 1, \"Log power\": 1.9083047527132848, \"Firing rate\": 80.96638564377915, \"Power\": 80.96638564377915, \"i_spike\": 52.5, \"isi\": 0.0632778022576872, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 33, \"stim\": 0, \"Log power\": 1.9016810185687205, \"Firing rate\": 79.7408789814844, \"Power\": 79.7408789814844, \"i_spike\": 40.0, \"isi\": 0.08782328408815572, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 33, \"stim\": 1, \"Log power\": 2.0296871276111905, \"Firing rate\": 107.07476443290204, \"Power\": 107.07476443290204, \"i_spike\": 63.5, \"isi\": 0.05487293151804296, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 34, \"stim\": 0, \"Log power\": 1.650726640690192, \"Firing rate\": 44.743158728629496, \"Power\": 44.743158728629496, \"i_spike\": 37.0, \"isi\": 0.09257067023090851, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 34, \"stim\": 1, \"Log power\": 2.031334590839408, \"Firing rate\": 107.48171582470553, \"Power\": 107.48171582470553, \"i_spike\": 64.0, \"isi\": 0.05462807637479468, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 35, \"stim\": 0, \"Log power\": 1.9781418238636843, \"Firing rate\": 95.09152752901628, \"Power\": 95.09152752901628, \"i_spike\": 42.0, \"isi\": 0.08276101154579588, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 35, \"stim\": 1, \"Log power\": 2.0520094239126423, \"Firing rate\": 112.72219159051606, \"Power\": 112.72219159051606, \"i_spike\": 75.5, \"isi\": 0.04415771856047787, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 36, \"stim\": 0, \"Log power\": 1.8060331458619012, \"Firing rate\": 63.97836626554339, \"Power\": 63.97836626554339, \"i_spike\": 51.0, \"isi\": 0.06650204153706461, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 36, \"stim\": 1, \"Log power\": 1.8623423129251562, \"Firing rate\": 72.8353670086671, \"Power\": 72.8353670086671, \"i_spike\": 53.0, \"isi\": 0.06572110225049307, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 37, \"stim\": 0, \"Log power\": 1.9532183819686684, \"Firing rate\": 89.78801738239333, \"Power\": 89.78801738239333, \"i_spike\": 33.5, \"isi\": 0.09955159917609266, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 37, \"stim\": 1, \"Log power\": 1.7973003649356576, \"Firing rate\": 62.70473906356686, \"Power\": 62.70473906356686, \"i_spike\": 59.5, \"isi\": 0.057688428183748225, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 38, \"stim\": 0, \"Log power\": 1.9476318198751157, \"Firing rate\": 88.64042299874271, \"Power\": 88.64042299874271, \"i_spike\": 43.5, \"isi\": 0.07973225992194521, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 38, \"stim\": 1, \"Log power\": 2.0979555122430877, \"Firing rate\": 125.30128136865821, \"Power\": 125.30128136865821, \"i_spike\": 66.0, \"isi\": 0.05281247759359185, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 39, \"stim\": 0, \"Log power\": 2.679786300644913, \"Firing rate\": 478.3946350794061, \"Power\": 478.3946350794061, \"i_spike\": 40.0, \"isi\": 0.0873890906244907, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 39, \"stim\": 1, \"Log power\": 1.8833105457337704, \"Firing rate\": 76.43821657722582, \"Power\": 76.43821657722582, \"i_spike\": 55.5, \"isi\": 0.0609562796143166, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 40, \"stim\": 0, \"Log power\": 1.673695178196339, \"Firing rate\": 47.1731826783389, \"Power\": 47.1731826783389, \"i_spike\": 46.5, \"isi\": 0.07329633431697158, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 40, \"stim\": 1, \"Log power\": 2.079308312644918, \"Firing rate\": 120.03511493507222, \"Power\": 120.03511493507222, \"i_spike\": 57.0, \"isi\": 0.05839535654311927, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 41, \"stim\": 0, \"Log power\": 1.9556957540470727, \"Firing rate\": 90.30166417910256, \"Power\": 90.30166417910256, \"i_spike\": 39.0, \"isi\": 0.08852862505917714, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 41, \"stim\": 1, \"Log power\": 2.059912145837366, \"Firing rate\": 114.7921383056625, \"Power\": 114.7921383056625, \"i_spike\": 49.0, \"isi\": 0.06835247186146068, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 42, \"stim\": 0, \"Log power\": 2.0507511848871642, \"Firing rate\": 112.3960852100619, \"Power\": 112.3960852100619, \"i_spike\": 41.0, \"isi\": 0.08601568296080994, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 42, \"stim\": 1, \"Log power\": 2.0748263042980017, \"Firing rate\": 118.8026982043569, \"Power\": 118.8026982043569, \"i_spike\": 48.0, \"isi\": 0.07172681228584546, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 43, \"stim\": 0, \"Log power\": 1.8359221100954841, \"Firing rate\": 68.53652964429995, \"Power\": 68.53652964429995, \"i_spike\": 46.0, \"isi\": 0.07597072035963864, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 43, \"stim\": 1, \"Log power\": 1.9937090050607151, \"Firing rate\": 98.56188596715207, \"Power\": 98.56188596715207, \"i_spike\": 68.0, \"isi\": 0.0513725347971293, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 44, \"stim\": 0, \"Log power\": 2.0293463061900066, \"Firing rate\": 106.99076829849588, \"Power\": 106.99076829849588, \"i_spike\": 44.0, \"isi\": 0.07882303495908782, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 44, \"stim\": 1, \"Log power\": 2.0196048170210186, \"Firing rate\": 104.61761547259218, \"Power\": 104.61761547259218, \"i_spike\": 58.5, \"isi\": 0.05958144841822776, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 45, \"stim\": 0, \"Log power\": 1.8377265654586405, \"Firing rate\": 68.82188529844396, \"Power\": 68.82188529844396, \"i_spike\": 41.0, \"isi\": 0.0807325683170197, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 45, \"stim\": 1, \"Log power\": 2.1682453616157247, \"Firing rate\": 147.31445439515846, \"Power\": 147.31445439515846, \"i_spike\": 56.0, \"isi\": 0.06217689188937558, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 46, \"stim\": 0, \"Log power\": 1.7205940818714955, \"Firing rate\": 52.552584824029516, \"Power\": 52.552584824029516, \"i_spike\": 51.0, \"isi\": 0.06645190302631439, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 46, \"stim\": 1, \"Log power\": 1.8710696912300562, \"Firing rate\": 74.31383797355485, \"Power\": 74.31383797355485, \"i_spike\": 58.5, \"isi\": 0.05891229914424447, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 47, \"stim\": 0, \"Log power\": 1.7039842864544466, \"Firing rate\": 50.5806360699715, \"Power\": 50.5806360699715, \"i_spike\": 27.5, \"isi\": 0.12400270581990115, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 47, \"stim\": 1, \"Log power\": 3.312638298459702, \"Firing rate\": 2054.1790632540356, \"Power\": 2054.1790632540356, \"i_spike\": 58.5, \"isi\": 0.059458853061755274, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 48, \"stim\": 0, \"Log power\": 1.6772508055992832, \"Firing rate\": 47.56098119016587, \"Power\": 47.56098119016587, \"i_spike\": 47.0, \"isi\": 0.0705228308378095, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 48, \"stim\": 1, \"Log power\": 2.232253611662001, \"Firing rate\": 170.70789679787646, \"Power\": 170.70789679787646, \"i_spike\": 53.5, \"isi\": 0.06344505318954197, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 49, \"stim\": 0, \"Log power\": 1.655062404256302, \"Firing rate\": 45.192087672225654, \"Power\": 45.192087672225654, \"i_spike\": 40.0, \"isi\": 0.08775481269360264, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 49, \"stim\": 1, \"Log power\": 2.085772014037125, \"Firing rate\": 121.83498496401806, \"Power\": 121.83498496401806, \"i_spike\": 64.5, \"isi\": 0.05425207715902479, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 50, \"stim\": 0, \"Log power\": 1.6266525026336474, \"Firing rate\": 42.330412698891415, \"Power\": 42.330412698891415, \"i_spike\": 41.5, \"isi\": 0.08370436160465566, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 50, \"stim\": 1, \"Log power\": 1.918969810182661, \"Firing rate\": 82.97930827558643, \"Power\": 82.97930827558643, \"i_spike\": 68.5, \"isi\": 0.05137691086662653, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 51, \"stim\": 0, \"Log power\": 1.8125656859069499, \"Firing rate\": 64.94798562811408, \"Power\": 64.94798562811408, \"i_spike\": 38.0, \"isi\": 0.09086928979593929, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 51, \"stim\": 1, \"Log power\": 1.8439844567083397, \"Firing rate\": 69.8207414959996, \"Power\": 69.8207414959996, \"i_spike\": 64.5, \"isi\": 0.05180500982536453, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 52, \"stim\": 0, \"Log power\": 1.6776999534416146, \"Firing rate\": 47.610194254196784, \"Power\": 47.610194254196784, \"i_spike\": 46.0, \"isi\": 0.0762207315983537, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 52, \"stim\": 1, \"Log power\": 2.1999947056869247, \"Firing rate\": 158.4873871769851, \"Power\": 158.4873871769851, \"i_spike\": 60.0, \"isi\": 0.05797460508991254, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 53, \"stim\": 0, \"Log power\": 1.6565284821536752, \"Firing rate\": 45.344903516262065, \"Power\": 45.344903516262065, \"i_spike\": 46.0, \"isi\": 0.07515393887896518, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 53, \"stim\": 1, \"Log power\": 2.1065073265681913, \"Firing rate\": 127.79307681361739, \"Power\": 127.79307681361739, \"i_spike\": 45.5, \"isi\": 0.07531185034790498, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 54, \"stim\": 0, \"Log power\": 1.932341365963057, \"Firing rate\": 85.57390802085132, \"Power\": 85.57390802085132, \"i_spike\": 46.5, \"isi\": 0.07504054660234809, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 54, \"stim\": 1, \"Log power\": 1.9947039553731538, \"Firing rate\": 98.7879459324626, \"Power\": 98.7879459324626, \"i_spike\": 59.0, \"isi\": 0.05931616360677708, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 55, \"stim\": 0, \"Log power\": 1.7616316370565803, \"Firing rate\": 57.76059217291501, \"Power\": 57.76059217291501, \"i_spike\": 35.0, \"isi\": 0.09882212944229501, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 55, \"stim\": 1, \"Log power\": 1.8491341909710781, \"Firing rate\": 70.65358303107308, \"Power\": 70.65358303107308, \"i_spike\": 54.0, \"isi\": 0.06396292039828358, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 56, \"stim\": 0, \"Log power\": 2.0847769811202665, \"Firing rate\": 121.55616252029836, \"Power\": 121.55616252029836, \"i_spike\": 36.5, \"isi\": 0.09620098339847712, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 56, \"stim\": 1, \"Log power\": 2.337404701680528, \"Firing rate\": 217.47267759474167, \"Power\": 217.47267759474167, \"i_spike\": 51.0, \"isi\": 0.06589074308543828, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 57, \"stim\": 0, \"Log power\": 1.6836821030312688, \"Firing rate\": 48.270533970919125, \"Power\": 48.270533970919125, \"i_spike\": 43.5, \"isi\": 0.08008582237911993, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 57, \"stim\": 1, \"Log power\": 2.3710565727711237, \"Firing rate\": 234.99389124598048, \"Power\": 234.99389124598048, \"i_spike\": 61.0, \"isi\": 0.056089999180668156, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 58, \"stim\": 0, \"Log power\": 1.8798793374432592, \"Firing rate\": 75.83668442940264, \"Power\": 75.83668442940264, \"i_spike\": 40.5, \"isi\": 0.08562695135109932, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 58, \"stim\": 1, \"Log power\": 2.008600214584485, \"Firing rate\": 102.00001005746722, \"Power\": 102.00001005746722, \"i_spike\": 50.0, \"isi\": 0.06849064602311145, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 59, \"stim\": 0, \"Log power\": 1.8378644867771181, \"Firing rate\": 68.843744918886, \"Power\": 68.843744918886, \"i_spike\": 44.5, \"isi\": 0.07615217690726388, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 59, \"stim\": 1, \"Log power\": 2.3442124438177028, \"Firing rate\": 220.90850868397348, \"Power\": 220.90850868397348, \"i_spike\": 58.5, \"isi\": 0.058405571923777766, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 60, \"stim\": 0, \"Log power\": 1.9434719738476816, \"Firing rate\": 87.79544285859512, \"Power\": 87.79544285859512, \"i_spike\": 40.5, \"isi\": 0.08584070225119106, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 60, \"stim\": 1, \"Log power\": 2.316164503886908, \"Firing rate\": 207.09256341490877, \"Power\": 207.09256341490877, \"i_spike\": 55.5, \"isi\": 0.06323412106138424, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 61, \"stim\": 0, \"Log power\": 1.7530151270124552, \"Firing rate\": 56.62590121945686, \"Power\": 56.62590121945686, \"i_spike\": 45.0, \"isi\": 0.07812840761067365, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 61, \"stim\": 1, \"Log power\": 1.9686998222743461, \"Firing rate\": 93.04645302586161, \"Power\": 93.04645302586161, \"i_spike\": 50.5, \"isi\": 0.06774657488528416, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 62, \"stim\": 0, \"Log power\": 1.7637851710770174, \"Firing rate\": 58.04772065472716, \"Power\": 58.04772065472716, \"i_spike\": 41.5, \"isi\": 0.0833785270374119, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 62, \"stim\": 1, \"Log power\": 2.0159295170988667, \"Firing rate\": 103.73600460089305, \"Power\": 103.73600460089305, \"i_spike\": 59.5, \"isi\": 0.05866318726774495, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 63, \"stim\": 0, \"Log power\": 1.4582398560956404, \"Firing rate\": 28.723665206713104, \"Power\": 28.723665206713104, \"i_spike\": 28.0, \"isi\": 0.11678930604740018, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 63, \"stim\": 1, \"Log power\": 1.8378189324404344, \"Firing rate\": 68.83652408879881, \"Power\": 68.83652408879881, \"i_spike\": 57.0, \"isi\": 0.0613482699561352, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 64, \"stim\": 0, \"Log power\": 1.7259416502256677, \"Firing rate\": 53.203677249347386, \"Power\": 53.203677249347386, \"i_spike\": 39.5, \"isi\": 0.08957622999624087, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 64, \"stim\": 1, \"Log power\": 2.1782772307373075, \"Firing rate\": 150.75691118615725, \"Power\": 150.75691118615725, \"i_spike\": 66.5, \"isi\": 0.05166655104038336, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 65, \"stim\": 0, \"Log power\": 1.588376096085825, \"Firing rate\": 38.75931526773088, \"Power\": 38.75931526773088, \"i_spike\": 33.5, \"isi\": 0.09652616577103539, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 65, \"stim\": 1, \"Log power\": 2.026607254930215, \"Firing rate\": 106.31811178961277, \"Power\": 106.31811178961277, \"i_spike\": 66.0, \"isi\": 0.052910628121811076, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 66, \"stim\": 0, \"Log power\": 1.9720315758493399, \"Firing rate\": 93.76301758622593, \"Power\": 93.76301758622593, \"i_spike\": 39.0, \"isi\": 0.08724811354150354, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 66, \"stim\": 1, \"Log power\": 2.038134329011705, \"Firing rate\": 109.1777975502512, \"Power\": 109.1777975502512, \"i_spike\": 52.0, \"isi\": 0.06683320213445922, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 67, \"stim\": 0, \"Log power\": 1.836084974166112, \"Firing rate\": 68.56223623712768, \"Power\": 68.56223623712768, \"i_spike\": 38.5, \"isi\": 0.0902314893192157, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 67, \"stim\": 1, \"Log power\": 1.8227859692521355, \"Firing rate\": 66.49453743935133, \"Power\": 66.49453743935133, \"i_spike\": 42.0, \"isi\": 0.08234930398597237, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 68, \"stim\": 0, \"Log power\": 1.632339131898025, \"Firing rate\": 42.888329608155786, \"Power\": 42.888329608155786, \"i_spike\": 40.5, \"isi\": 0.08650216056129542, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 68, \"stim\": 1, \"Log power\": 2.3205536004723557, \"Firing rate\": 209.19610802721925, \"Power\": 209.19610802721925, \"i_spike\": 71.5, \"isi\": 0.04782229208407432, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 69, \"stim\": 0, \"Log power\": 1.8767864116081252, \"Firing rate\": 75.29851504569253, \"Power\": 75.29851504569253, \"i_spike\": 51.5, \"isi\": 0.06771616734836566, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 69, \"stim\": 1, \"Log power\": 1.7421760508548234, \"Firing rate\": 55.23012814238975, \"Power\": 55.23012814238975, \"i_spike\": 59.5, \"isi\": 0.05879567455052462, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 0, \"stim\": 0, \"Log power\": 2.00520516503773, \"Firing rate\": 101.20574473623418, \"Power\": 101.20574473623418, \"i_spike\": 49.5, \"isi\": 0.06904948547500527, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 0, \"stim\": 1, \"Log power\": 2.626101753125223, \"Firing rate\": 422.76765510744195, \"Power\": 422.76765510744195, \"i_spike\": 72.0, \"isi\": 0.04790010526381386, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 1, \"stim\": 0, \"Log power\": 1.8756880718175075, \"Firing rate\": 75.10832413251623, \"Power\": 75.10832413251623, \"i_spike\": 40.5, \"isi\": 0.084983571214487, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 1, \"stim\": 1, \"Log power\": 2.2806503708815176, \"Firing rate\": 190.83163484080103, \"Power\": 190.83163484080103, \"i_spike\": 49.0, \"isi\": 0.0665926715195611, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 2, \"stim\": 0, \"Log power\": 1.8611592156038326, \"Firing rate\": 72.63722021081432, \"Power\": 72.63722021081432, \"i_spike\": 60.5, \"isi\": 0.05765868054822749, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 2, \"stim\": 1, \"Log power\": 1.9544841070398389, \"Firing rate\": 90.0500808416818, \"Power\": 90.0500808416818, \"i_spike\": 65.5, \"isi\": 0.05360725803483716, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 3, \"stim\": 0, \"Log power\": 1.7955485102399653, \"Firing rate\": 62.45231049631098, \"Power\": 62.45231049631098, \"i_spike\": 52.0, \"isi\": 0.06771236917900902, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 3, \"stim\": 1, \"Log power\": 2.0234617050041317, \"Firing rate\": 105.55084270321642, \"Power\": 105.55084270321642, \"i_spike\": 62.0, \"isi\": 0.05666229965325677, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 4, \"stim\": 0, \"Log power\": 1.860354134538902, \"Firing rate\": 72.50269241133196, \"Power\": 72.50269241133196, \"i_spike\": 57.5, \"isi\": 0.061064656757891606, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 4, \"stim\": 1, \"Log power\": 2.037876665515965, \"Firing rate\": 109.11304243406458, \"Power\": 109.11304243406458, \"i_spike\": 61.0, \"isi\": 0.0571257994753636, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 5, \"stim\": 0, \"Log power\": 1.602261117233085, \"Firing rate\": 40.01852867050867, \"Power\": 40.01852867050867, \"i_spike\": 41.0, \"isi\": 0.08396914660009884, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 5, \"stim\": 1, \"Log power\": 2.1676279280310933, \"Firing rate\": 147.105167218697, \"Power\": 147.105167218697, \"i_spike\": 60.5, \"isi\": 0.055888297846155975, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 6, \"stim\": 0, \"Log power\": 2.098654745663673, \"Firing rate\": 125.50318449428715, \"Power\": 125.50318449428715, \"i_spike\": 47.0, \"isi\": 0.07385768666688437, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 6, \"stim\": 1, \"Log power\": 2.5488082727817987, \"Firing rate\": 353.8410969931714, \"Power\": 353.8410969931714, \"i_spike\": 59.5, \"isi\": 0.05694677428313995, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 7, \"stim\": 0, \"Log power\": 1.8221041784074723, \"Firing rate\": 66.39023079542034, \"Power\": 66.39023079542034, \"i_spike\": 54.0, \"isi\": 0.06538704928530525, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 7, \"stim\": 1, \"Log power\": 1.9531847896970977, \"Firing rate\": 89.78107263189972, \"Power\": 89.78107263189972, \"i_spike\": 69.0, \"isi\": 0.05063702611448185, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 8, \"stim\": 0, \"Log power\": 1.6314292886068242, \"Firing rate\": 42.79857297044858, \"Power\": 42.79857297044858, \"i_spike\": 29.5, \"isi\": 0.11334221440940868, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 8, \"stim\": 1, \"Log power\": 1.7437102279701466, \"Firing rate\": 55.425577638088086, \"Power\": 55.425577638088086, \"i_spike\": 59.5, \"isi\": 0.058638471806429476, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 9, \"stim\": 0, \"Log power\": 1.8892446205360307, \"Firing rate\": 77.4898143721203, \"Power\": 77.4898143721203, \"i_spike\": 54.0, \"isi\": 0.06465582544822876, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 9, \"stim\": 1, \"Log power\": 2.390153806733938, \"Firing rate\": 245.55784123977463, \"Power\": 245.55784123977463, \"i_spike\": 58.5, \"isi\": 0.05763090286491456, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 10, \"stim\": 0, \"Log power\": 2.004258339640889, \"Firing rate\": 100.98534177479273, \"Power\": 100.98534177479273, \"i_spike\": 45.5, \"isi\": 0.0756493889425548, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 10, \"stim\": 1, \"Log power\": 1.7589598733803482, \"Firing rate\": 57.40634191924138, \"Power\": 57.40634191924138, \"i_spike\": 51.0, \"isi\": 0.06888395328815433, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 11, \"stim\": 0, \"Log power\": 1.7950781114705112, \"Firing rate\": 62.384702946352924, \"Power\": 62.384702946352924, \"i_spike\": 56.5, \"isi\": 0.06144963670899324, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 11, \"stim\": 1, \"Log power\": 2.1837043190277847, \"Firing rate\": 152.65263984800197, \"Power\": 152.65263984800197, \"i_spike\": 63.0, \"isi\": 0.05453352297859983, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 12, \"stim\": 0, \"Log power\": 2.3970283594074218, \"Firing rate\": 249.475762916957, \"Power\": 249.475762916957, \"i_spike\": 53.5, \"isi\": 0.06304146324290939, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 12, \"stim\": 1, \"Log power\": 2.2226213705303826, \"Firing rate\": 166.96343480061486, \"Power\": 166.96343480061486, \"i_spike\": 65.5, \"isi\": 0.05315542116866027, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 13, \"stim\": 0, \"Log power\": 1.8709612273394876, \"Firing rate\": 74.2952806077999, \"Power\": 74.2952806077999, \"i_spike\": 43.5, \"isi\": 0.07909166860639033, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 13, \"stim\": 1, \"Log power\": 1.9753321332694342, \"Firing rate\": 94.47831372554293, \"Power\": 94.47831372554293, \"i_spike\": 63.0, \"isi\": 0.055301470012196256, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 14, \"stim\": 0, \"Log power\": 1.8955470129786793, \"Firing rate\": 78.62252965180498, \"Power\": 78.62252965180498, \"i_spike\": 40.5, \"isi\": 0.08719393495628738, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 14, \"stim\": 1, \"Log power\": 2.1058290192212112, \"Firing rate\": 127.59363765798803, \"Power\": 127.59363765798803, \"i_spike\": 56.0, \"isi\": 0.06299174969701729, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 15, \"stim\": 0, \"Log power\": 1.607415105698803, \"Firing rate\": 40.496277675250546, \"Power\": 40.496277675250546, \"i_spike\": 43.0, \"isi\": 0.07929321197222094, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 15, \"stim\": 1, \"Log power\": 2.1000543443335, \"Firing rate\": 125.9082954074708, \"Power\": 125.9082954074708, \"i_spike\": 72.5, \"isi\": 0.04832104841538376, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 16, \"stim\": 0, \"Log power\": 2.435560088127117, \"Firing rate\": 272.6214906548113, \"Power\": 272.6214906548113, \"i_spike\": 53.5, \"isi\": 0.0650092804331374, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 16, \"stim\": 1, \"Log power\": 1.8683211970842133, \"Firing rate\": 73.84501738700077, \"Power\": 73.84501738700077, \"i_spike\": 59.5, \"isi\": 0.057092843596689154, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 17, \"stim\": 0, \"Log power\": 1.860862812222898, \"Firing rate\": 72.58766265666598, \"Power\": 72.58766265666598, \"i_spike\": 55.0, \"isi\": 0.06276728694895076, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 17, \"stim\": 1, \"Log power\": 2.305683378096692, \"Firing rate\": 202.15448363217362, \"Power\": 202.15448363217362, \"i_spike\": 63.0, \"isi\": 0.05465439904503797, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 18, \"stim\": 0, \"Log power\": 1.6203301754694193, \"Firing rate\": 41.718643188859495, \"Power\": 41.718643188859495, \"i_spike\": 38.0, \"isi\": 0.09167432617879921, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 18, \"stim\": 1, \"Log power\": 2.175452637332575, \"Firing rate\": 149.77958996513343, \"Power\": 149.77958996513343, \"i_spike\": 64.0, \"isi\": 0.05444090600504606, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 19, \"stim\": 0, \"Log power\": 1.7835551727170662, \"Firing rate\": 60.751243626591595, \"Power\": 60.751243626591595, \"i_spike\": 51.5, \"isi\": 0.06688282354188704, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 19, \"stim\": 1, \"Log power\": 1.8681234159204716, \"Firing rate\": 73.81139543476033, \"Power\": 73.81139543476033, \"i_spike\": 65.0, \"isi\": 0.05327101980445804, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 20, \"stim\": 0, \"Log power\": 1.710002248419502, \"Firing rate\": 51.28640391725188, \"Power\": 51.28640391725188, \"i_spike\": 42.0, \"isi\": 0.08340065116217678, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 20, \"stim\": 1, \"Log power\": 2.1572801968125295, \"Firing rate\": 143.64158769529283, \"Power\": 143.64158769529283, \"i_spike\": 48.0, \"isi\": 0.07218699351822976, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 21, \"stim\": 0, \"Log power\": 2.2585814196585257, \"Firing rate\": 181.3766681162104, \"Power\": 181.3766681162104, \"i_spike\": 50.0, \"isi\": 0.07030757299836425, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 21, \"stim\": 1, \"Log power\": 1.8992648486610908, \"Firing rate\": 79.29847741764938, \"Power\": 79.29847741764938, \"i_spike\": 60.0, \"isi\": 0.05569971857310687, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 22, \"stim\": 0, \"Log power\": 1.8165667473170657, \"Firing rate\": 65.54910214100495, \"Power\": 65.54910214100495, \"i_spike\": 43.5, \"isi\": 0.08015000650371439, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 22, \"stim\": 1, \"Log power\": 1.9593718324882727, \"Firing rate\": 91.06926520833012, \"Power\": 91.06926520833012, \"i_spike\": 63.0, \"isi\": 0.05506193456730659, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 23, \"stim\": 0, \"Log power\": 1.9536006413110272, \"Firing rate\": 89.8670822089673, \"Power\": 89.8670822089673, \"i_spike\": 45.5, \"isi\": 0.07754426414754421, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 23, \"stim\": 1, \"Log power\": 1.8409394097260192, \"Firing rate\": 69.33290699754185, \"Power\": 69.33290699754185, \"i_spike\": 55.5, \"isi\": 0.06217230960205396, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 24, \"stim\": 0, \"Log power\": 1.7280094916746713, \"Firing rate\": 53.457604263645436, \"Power\": 53.457604263645436, \"i_spike\": 53.0, \"isi\": 0.06550508122419536, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 24, \"stim\": 1, \"Log power\": 2.1270437908276056, \"Firing rate\": 133.98117766594035, \"Power\": 133.98117766594035, \"i_spike\": 65.0, \"isi\": 0.05180429801419451, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 25, \"stim\": 0, \"Log power\": 1.8289142103762999, \"Firing rate\": 67.43947960015883, \"Power\": 67.43947960015883, \"i_spike\": 46.5, \"isi\": 0.07494512699752216, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 25, \"stim\": 1, \"Log power\": 2.0662181771820283, \"Firing rate\": 116.47110001054703, \"Power\": 116.47110001054703, \"i_spike\": 49.5, \"isi\": 0.06707792843445651, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 26, \"stim\": 0, \"Log power\": 2.201481288535549, \"Firing rate\": 159.03081643340516, \"Power\": 159.03081643340516, \"i_spike\": 47.5, \"isi\": 0.07228217341540072, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 26, \"stim\": 1, \"Log power\": 1.9623142367032338, \"Firing rate\": 91.68836675350812, \"Power\": 91.68836675350812, \"i_spike\": 60.5, \"isi\": 0.05754195177143786, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 27, \"stim\": 0, \"Log power\": 2.3460231294371283, \"Firing rate\": 221.83145585355663, \"Power\": 221.83145585355663, \"i_spike\": 53.5, \"isi\": 0.06561722001036949, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 27, \"stim\": 1, \"Log power\": 2.097552000634322, \"Firing rate\": 125.1849155325413, \"Power\": 125.1849155325413, \"i_spike\": 58.0, \"isi\": 0.060542714823405085, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 28, \"stim\": 0, \"Log power\": 1.7092604578451096, \"Firing rate\": 51.19887966578024, \"Power\": 51.19887966578024, \"i_spike\": 47.5, \"isi\": 0.07187822658043035, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 28, \"stim\": 1, \"Log power\": 1.7099871781359743, \"Firing rate\": 51.28462427861813, \"Power\": 51.28462427861813, \"i_spike\": 48.0, \"isi\": 0.06948687684331202, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 29, \"stim\": 0, \"Log power\": 1.716331459857159, \"Firing rate\": 52.03930165179824, \"Power\": 52.03930165179824, \"i_spike\": 36.0, \"isi\": 0.09566167214847764, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 29, \"stim\": 1, \"Log power\": 2.2802308112925194, \"Firing rate\": 190.64736682983855, \"Power\": 190.64736682983855, \"i_spike\": 63.5, \"isi\": 0.05502595912921827, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 30, \"stim\": 0, \"Log power\": 2.166107964762489, \"Firing rate\": 146.59122185851825, \"Power\": 146.59122185851825, \"i_spike\": 41.5, \"isi\": 0.08509278304434821, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 30, \"stim\": 1, \"Log power\": 1.96843204685748, \"Firing rate\": 92.98910052841663, \"Power\": 92.98910052841663, \"i_spike\": 68.5, \"isi\": 0.050767575046353784, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 31, \"stim\": 0, \"Log power\": 1.675194170946537, \"Firing rate\": 47.336284988079996, \"Power\": 47.336284988079996, \"i_spike\": 45.5, \"isi\": 0.07593695371188272, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 31, \"stim\": 1, \"Log power\": 2.235941835122672, \"Firing rate\": 172.16379812938368, \"Power\": 172.16379812938368, \"i_spike\": 68.5, \"isi\": 0.051392551482525556, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 32, \"stim\": 0, \"Log power\": 2.112705985449168, \"Firing rate\": 129.6301386215487, \"Power\": 129.6301386215487, \"i_spike\": 55.0, \"isi\": 0.0636875752020839, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 32, \"stim\": 1, \"Log power\": 1.8667573958909214, \"Firing rate\": 73.57959548315647, \"Power\": 73.57959548315647, \"i_spike\": 54.5, \"isi\": 0.0631955586906425, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 33, \"stim\": 0, \"Log power\": 1.7081579564417666, \"Firing rate\": 51.06907085733897, \"Power\": 51.06907085733897, \"i_spike\": 57.0, \"isi\": 0.06079206029631382, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 33, \"stim\": 1, \"Log power\": 2.8665676380402996, \"Firing rate\": 735.4745310830756, \"Power\": 735.4745310830756, \"i_spike\": 60.0, \"isi\": 0.05801241029630827, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 34, \"stim\": 0, \"Log power\": 1.9186016347178718, \"Firing rate\": 82.90899193388682, \"Power\": 82.90899193388682, \"i_spike\": 59.0, \"isi\": 0.059141286752589194, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 34, \"stim\": 1, \"Log power\": 2.500187983897243, \"Firing rate\": 316.3646744918804, \"Power\": 316.3646744918804, \"i_spike\": 73.5, \"isi\": 0.046817307776523404, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 35, \"stim\": 0, \"Log power\": 1.8423892086564415, \"Firing rate\": 69.5647467874487, \"Power\": 69.5647467874487, \"i_spike\": 50.0, \"isi\": 0.0696193650284176, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 35, \"stim\": 1, \"Log power\": 2.297964596367422, \"Firing rate\": 198.59330177438818, \"Power\": 198.59330177438818, \"i_spike\": 77.5, \"isi\": 0.04533033715636319, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 36, \"stim\": 0, \"Log power\": 1.9331897837575438, \"Firing rate\": 85.74124468278278, \"Power\": 85.74124468278278, \"i_spike\": 44.0, \"isi\": 0.08022358370232796, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 36, \"stim\": 1, \"Log power\": 2.015407301423971, \"Firing rate\": 103.61134261883807, \"Power\": 103.61134261883807, \"i_spike\": 58.5, \"isi\": 0.058672660133941484, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 37, \"stim\": 0, \"Log power\": 1.7499094218568783, \"Firing rate\": 56.22240533302668, \"Power\": 56.22240533302668, \"i_spike\": 60.0, \"isi\": 0.05695915322275858, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 37, \"stim\": 1, \"Log power\": 1.7761697777193903, \"Firing rate\": 59.72687298096115, \"Power\": 59.72687298096115, \"i_spike\": 65.0, \"isi\": 0.05310541567529866, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 38, \"stim\": 0, \"Log power\": 1.7570636279235325, \"Firing rate\": 57.156236940234116, \"Power\": 57.156236940234116, \"i_spike\": 40.0, \"isi\": 0.0877566954604918, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 38, \"stim\": 1, \"Log power\": 3.7648748797590907, \"Firing rate\": 5819.355379883706, \"Power\": 5819.355379883706, \"i_spike\": 66.5, \"isi\": 0.0527493504451116, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 39, \"stim\": 0, \"Log power\": 2.056864355758071, \"Firing rate\": 113.98937062084418, \"Power\": 113.98937062084418, \"i_spike\": 49.0, \"isi\": 0.06983233686183395, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 39, \"stim\": 1, \"Log power\": 2.260943222908559, \"Firing rate\": 182.36572725707586, \"Power\": 182.36572725707586, \"i_spike\": 58.5, \"isi\": 0.06014605367962231, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 40, \"stim\": 0, \"Log power\": 1.9266917568178796, \"Firing rate\": 84.46791161521107, \"Power\": 84.46791161521107, \"i_spike\": 44.5, \"isi\": 0.07760110510077572, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 40, \"stim\": 1, \"Log power\": 2.0667919022515884, \"Firing rate\": 116.6250659255421, \"Power\": 116.6250659255421, \"i_spike\": 64.0, \"isi\": 0.05387424415734139, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 41, \"stim\": 0, \"Log power\": 2.010778792483049, \"Firing rate\": 102.51296443572734, \"Power\": 102.51296443572734, \"i_spike\": 42.0, \"isi\": 0.08173793363079603, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 41, \"stim\": 1, \"Log power\": 1.8037716137380864, \"Firing rate\": 63.64607316791711, \"Power\": 63.64607316791711, \"i_spike\": 64.0, \"isi\": 0.053895648457897204, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 42, \"stim\": 0, \"Log power\": 1.6390377968334473, \"Firing rate\": 43.55497781185341, \"Power\": 43.55497781185341, \"i_spike\": 43.0, \"isi\": 0.08222098566390974, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 42, \"stim\": 1, \"Log power\": 2.1295477196874817, \"Firing rate\": 134.7558785137993, \"Power\": 134.7558785137993, \"i_spike\": 63.0, \"isi\": 0.055721477370543955, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 43, \"stim\": 0, \"Log power\": 1.7921719719408802, \"Firing rate\": 61.968640994136265, \"Power\": 61.968640994136265, \"i_spike\": 47.5, \"isi\": 0.0741629541847166, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 43, \"stim\": 1, \"Log power\": 1.7675861143073723, \"Firing rate\": 58.557983681238504, \"Power\": 58.557983681238504, \"i_spike\": 53.0, \"isi\": 0.06655392709645236, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 44, \"stim\": 0, \"Log power\": 1.7843804009385642, \"Firing rate\": 60.866790344152825, \"Power\": 60.866790344152825, \"i_spike\": 53.5, \"isi\": 0.06497889644938687, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 44, \"stim\": 1, \"Log power\": 2.2967602499954918, \"Firing rate\": 198.04334360243965, \"Power\": 198.04334360243965, \"i_spike\": 60.0, \"isi\": 0.05831372042423525, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 45, \"stim\": 0, \"Log power\": 1.8318174405516163, \"Firing rate\": 67.89181834850056, \"Power\": 67.89181834850056, \"i_spike\": 43.0, \"isi\": 0.08089249585234823, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 45, \"stim\": 1, \"Log power\": 2.376885075262605, \"Firing rate\": 238.1689133886673, \"Power\": 238.1689133886673, \"i_spike\": 51.5, \"isi\": 0.0680359374983816, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 46, \"stim\": 0, \"Log power\": 2.249406957954258, \"Firing rate\": 177.5852773757087, \"Power\": 177.5852773757087, \"i_spike\": 47.0, \"isi\": 0.07332592828051299, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 46, \"stim\": 1, \"Log power\": 2.478647596376612, \"Firing rate\": 301.0562144260962, \"Power\": 301.0562144260962, \"i_spike\": 66.0, \"isi\": 0.052266590357286, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 47, \"stim\": 0, \"Log power\": 1.7483394293552887, \"Firing rate\": 56.019525943692976, \"Power\": 56.019525943692976, \"i_spike\": 55.0, \"isi\": 0.06293066793625537, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 47, \"stim\": 1, \"Log power\": 2.3051901104271675, \"Firing rate\": 201.9250087753657, \"Power\": 201.9250087753657, \"i_spike\": 54.5, \"isi\": 0.06251982599653465, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 48, \"stim\": 0, \"Log power\": 1.7978371487852123, \"Firing rate\": 62.782289440628126, \"Power\": 62.782289440628126, \"i_spike\": 50.0, \"isi\": 0.06917168256935709, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 48, \"stim\": 1, \"Log power\": 1.8061762555059597, \"Firing rate\": 63.99945202718756, \"Power\": 63.99945202718756, \"i_spike\": 63.5, \"isi\": 0.053023515277869866, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 49, \"stim\": 0, \"Log power\": 1.8721528224989463, \"Firing rate\": 74.49940813764353, \"Power\": 74.49940813764353, \"i_spike\": 50.0, \"isi\": 0.06911196120055126, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 49, \"stim\": 1, \"Log power\": 2.0867666071011053, \"Firing rate\": 122.11432328630274, \"Power\": 122.11432328630274, \"i_spike\": 56.0, \"isi\": 0.06111629309538056, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 50, \"stim\": 0, \"Log power\": 1.8519996035338695, \"Firing rate\": 71.12128643889423, \"Power\": 71.12128643889423, \"i_spike\": 46.5, \"isi\": 0.07314392377799805, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 50, \"stim\": 1, \"Log power\": 2.1495371267579664, \"Firing rate\": 141.10328570010492, \"Power\": 141.10328570010492, \"i_spike\": 65.5, \"isi\": 0.05280846460485796, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 51, \"stim\": 0, \"Log power\": 1.7877434741967277, \"Firing rate\": 61.33995798804333, \"Power\": 61.33995798804333, \"i_spike\": 43.5, \"isi\": 0.07990038729878156, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 51, \"stim\": 1, \"Log power\": 1.895603837361479, \"Firing rate\": 78.63281753065888, \"Power\": 78.63281753065888, \"i_spike\": 64.5, \"isi\": 0.054490396781366794, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 52, \"stim\": 0, \"Log power\": 1.7538139121158478, \"Firing rate\": 56.73014741792149, \"Power\": 56.73014741792149, \"i_spike\": 47.5, \"isi\": 0.07357993345490055, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 52, \"stim\": 1, \"Log power\": 2.268198432618725, \"Firing rate\": 185.43787103286044, \"Power\": 185.43787103286044, \"i_spike\": 52.0, \"isi\": 0.06736885220536926, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 53, \"stim\": 0, \"Log power\": 1.9589413108863118, \"Firing rate\": 90.97903182830602, \"Power\": 90.97903182830602, \"i_spike\": 48.5, \"isi\": 0.06962547087720211, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 53, \"stim\": 1, \"Log power\": 2.137013106155986, \"Firing rate\": 137.09231373130604, \"Power\": 137.09231373130604, \"i_spike\": 70.5, \"isi\": 0.04954390129623645, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 54, \"stim\": 0, \"Log power\": 1.8585185328471514, \"Firing rate\": 72.19689711920756, \"Power\": 72.19689711920756, \"i_spike\": 45.0, \"isi\": 0.07646790351630087, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 54, \"stim\": 1, \"Log power\": 1.8620451315900062, \"Firing rate\": 72.7855438853719, \"Power\": 72.7855438853719, \"i_spike\": 57.5, \"isi\": 0.059443689053625945, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 55, \"stim\": 0, \"Log power\": 1.9132387563346331, \"Firing rate\": 81.89148684047898, \"Power\": 81.89148684047898, \"i_spike\": 46.0, \"isi\": 0.07614485204133571, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 55, \"stim\": 1, \"Log power\": 1.8888918002743154, \"Firing rate\": 77.42688731398066, \"Power\": 77.42688731398066, \"i_spike\": 65.5, \"isi\": 0.05010081751369354, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 56, \"stim\": 0, \"Log power\": 1.743234980715878, \"Firing rate\": 55.364958754866095, \"Power\": 55.364958754866095, \"i_spike\": 44.5, \"isi\": 0.07680740641986206, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 56, \"stim\": 1, \"Log power\": 2.027320675449232, \"Firing rate\": 106.49290529775867, \"Power\": 106.49290529775867, \"i_spike\": 58.0, \"isi\": 0.05888108168336176, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 57, \"stim\": 0, \"Log power\": 1.751326601668993, \"Firing rate\": 56.40616866222888, \"Power\": 56.40616866222888, \"i_spike\": 37.0, \"isi\": 0.0931779251203798, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 57, \"stim\": 1, \"Log power\": 1.8494568108848146, \"Firing rate\": 70.70608823750923, \"Power\": 70.70608823750923, \"i_spike\": 53.5, \"isi\": 0.0599419762698349, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 58, \"stim\": 0, \"Log power\": 1.6448252330164623, \"Firing rate\": 44.13927881547818, \"Power\": 44.13927881547818, \"i_spike\": 49.0, \"isi\": 0.07023803265524316, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 58, \"stim\": 1, \"Log power\": 1.8884949185180364, \"Firing rate\": 77.35616276296585, \"Power\": 77.35616276296585, \"i_spike\": 62.0, \"isi\": 0.056362068578471286, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 59, \"stim\": 0, \"Log power\": 1.6406935493359673, \"Firing rate\": 43.721348588863776, \"Power\": 43.721348588863776, \"i_spike\": 44.0, \"isi\": 0.0794396115347186, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 59, \"stim\": 1, \"Log power\": 2.0746174468035523, \"Firing rate\": 118.74557827888167, \"Power\": 118.74557827888167, \"i_spike\": 73.5, \"isi\": 0.04678315504422022, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 60, \"stim\": 0, \"Log power\": 1.7674445251591069, \"Firing rate\": 58.538895656920495, \"Power\": 58.538895656920495, \"i_spike\": 56.0, \"isi\": 0.06255112236133384, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 60, \"stim\": 1, \"Log power\": 1.8755250681119262, \"Firing rate\": 75.08013902222497, \"Power\": 75.08013902222497, \"i_spike\": 57.5, \"isi\": 0.0593770388609109, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 61, \"stim\": 0, \"Log power\": 1.7131961636562605, \"Firing rate\": 51.66496787177685, \"Power\": 51.66496787177685, \"i_spike\": 34.0, \"isi\": 0.10379193041068026, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 61, \"stim\": 1, \"Log power\": 1.8685689829439356, \"Firing rate\": 73.88716153745173, \"Power\": 73.88716153745173, \"i_spike\": 67.5, \"isi\": 0.04960459166380905, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 62, \"stim\": 0, \"Log power\": 1.8480944142938047, \"Firing rate\": 70.4846283741453, \"Power\": 70.4846283741453, \"i_spike\": 51.0, \"isi\": 0.06820607253642479, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 62, \"stim\": 1, \"Log power\": 1.8761790545398978, \"Firing rate\": 75.1932843244069, \"Power\": 75.1932843244069, \"i_spike\": 65.5, \"isi\": 0.05151696276499542, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 63, \"stim\": 0, \"Log power\": 1.8012461809840061, \"Firing rate\": 63.27704373419866, \"Power\": 63.27704373419866, \"i_spike\": 45.0, \"isi\": 0.07787659669585852, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 63, \"stim\": 1, \"Log power\": 1.9703096728033718, \"Firing rate\": 93.39199931987974, \"Power\": 93.39199931987974, \"i_spike\": 48.5, \"isi\": 0.07047794037722925, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 64, \"stim\": 0, \"Log power\": 2.368232068195027, \"Firing rate\": 233.47052945895814, \"Power\": 233.47052945895814, \"i_spike\": 48.5, \"isi\": 0.07132832196829238, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 64, \"stim\": 1, \"Log power\": 2.564636679636346, \"Firing rate\": 366.975169407842, \"Power\": 366.975169407842, \"i_spike\": 59.5, \"isi\": 0.05796363426746963, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 65, \"stim\": 0, \"Log power\": 1.964729502055727, \"Firing rate\": 92.19969874958568, \"Power\": 92.19969874958568, \"i_spike\": 49.5, \"isi\": 0.06931393053522295, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 65, \"stim\": 1, \"Log power\": 1.9992228822825648, \"Firing rate\": 99.82122203136544, \"Power\": 99.82122203136544, \"i_spike\": 64.5, \"isi\": 0.05398610216395981, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 66, \"stim\": 0, \"Log power\": 1.9607257251188324, \"Firing rate\": 91.35361235046447, \"Power\": 91.35361235046447, \"i_spike\": 49.5, \"isi\": 0.07107494214712384, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 66, \"stim\": 1, \"Log power\": 2.5437068320755944, \"Firing rate\": 349.7090183250186, \"Power\": 349.7090183250186, \"i_spike\": 65.0, \"isi\": 0.0528257220821202, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 67, \"stim\": 0, \"Log power\": 1.7725244099733481, \"Firing rate\": 59.22763754507072, \"Power\": 59.22763754507072, \"i_spike\": 46.0, \"isi\": 0.07523362975717417, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 67, \"stim\": 1, \"Log power\": 1.980759681071056, \"Firing rate\": 95.66645498970142, \"Power\": 95.66645498970142, \"i_spike\": 56.5, \"isi\": 0.060859803109121494, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 68, \"stim\": 0, \"Log power\": 1.9851574152116886, \"Firing rate\": 96.64010991129788, \"Power\": 96.64010991129788, \"i_spike\": 59.0, \"isi\": 0.05848152512787494, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 68, \"stim\": 1, \"Log power\": 2.2341678477033775, \"Firing rate\": 171.46198519556606, \"Power\": 171.46198519556606, \"i_spike\": 76.5, \"isi\": 0.044652895682355434, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 69, \"stim\": 0, \"Log power\": 1.8922841068864193, \"Firing rate\": 78.03404269057248, \"Power\": 78.03404269057248, \"i_spike\": 45.0, \"isi\": 0.07710366474469474, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 69, \"stim\": 1, \"Log power\": 2.6330885771583836, \"Firing rate\": 429.6240424218396, \"Power\": 429.6240424218396, \"i_spike\": 61.5, \"isi\": 0.05541413498056847, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 0, \"stim\": 0, \"Log power\": 1.5749334932957881, \"Firing rate\": 37.577985395260065, \"Power\": 37.577985395260065, \"i_spike\": 44.5, \"isi\": 0.07943377321968279, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 0, \"stim\": 1, \"Log power\": 2.7379107333474635, \"Firing rate\": 546.9035385646763, \"Power\": 546.9035385646763, \"i_spike\": 64.5, \"isi\": 0.05296536918135109, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 1, \"stim\": 0, \"Log power\": 1.9135891974918313, \"Firing rate\": 81.95759343470856, \"Power\": 81.95759343470856, \"i_spike\": 52.5, \"isi\": 0.06492397836022258, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 1, \"stim\": 1, \"Log power\": 2.176636843485199, \"Firing rate\": 150.18855659890426, \"Power\": 150.18855659890426, \"i_spike\": 79.5, \"isi\": 0.04339997376703324, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 2, \"stim\": 0, \"Log power\": 2.365843066540015, \"Firing rate\": 232.18976208991054, \"Power\": 232.18976208991054, \"i_spike\": 50.0, \"isi\": 0.0695887963223545, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 2, \"stim\": 1, \"Log power\": 2.101771230670745, \"Firing rate\": 126.40703093179754, \"Power\": 126.40703093179754, \"i_spike\": 77.0, \"isi\": 0.04545097357364374, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 3, \"stim\": 0, \"Log power\": 1.8758446119981347, \"Firing rate\": 75.13540158881375, \"Power\": 75.13540158881375, \"i_spike\": 59.0, \"isi\": 0.05926684155623455, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 3, \"stim\": 1, \"Log power\": 1.9430147459839289, \"Firing rate\": 87.70305992322396, \"Power\": 87.70305992322396, \"i_spike\": 73.5, \"isi\": 0.04631258689336168, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 4, \"stim\": 0, \"Log power\": 2.0002063897585765, \"Firing rate\": 100.04753429211092, \"Power\": 100.04753429211092, \"i_spike\": 51.0, \"isi\": 0.06860582437524661, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 4, \"stim\": 1, \"Log power\": 1.9174826026889007, \"Firing rate\": 82.69563810330793, \"Power\": 82.69563810330793, \"i_spike\": 56.0, \"isi\": 0.06275838648586149, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 5, \"stim\": 0, \"Log power\": 1.9267683854606334, \"Firing rate\": 84.48281678384164, \"Power\": 84.48281678384164, \"i_spike\": 51.5, \"isi\": 0.06793945207092161, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 5, \"stim\": 1, \"Log power\": 1.908299581880051, \"Firing rate\": 80.96542164077601, \"Power\": 80.96542164077601, \"i_spike\": 67.0, \"isi\": 0.051368507563807606, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 6, \"stim\": 0, \"Log power\": 1.8873505997145592, \"Firing rate\": 77.15260596632854, \"Power\": 77.15260596632854, \"i_spike\": 58.5, \"isi\": 0.0579618809705398, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 6, \"stim\": 1, \"Log power\": 1.9545251652313096, \"Firing rate\": 90.05859457692718, \"Power\": 90.05859457692718, \"i_spike\": 65.5, \"isi\": 0.05361815158539187, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 7, \"stim\": 0, \"Log power\": 2.0365086921538613, \"Firing rate\": 108.76989070801689, \"Power\": 108.76989070801689, \"i_spike\": 49.5, \"isi\": 0.07095370965697212, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 7, \"stim\": 1, \"Log power\": 2.9572655364455462, \"Firing rate\": 906.2865534932351, \"Power\": 906.2865534932351, \"i_spike\": 65.5, \"isi\": 0.05102668271170815, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 8, \"stim\": 0, \"Log power\": 2.0637908529837152, \"Firing rate\": 115.82194478934085, \"Power\": 115.82194478934085, \"i_spike\": 58.0, \"isi\": 0.059443844633995366, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 8, \"stim\": 1, \"Log power\": 2.313764630792303, \"Firing rate\": 205.95134417353907, \"Power\": 205.95134417353907, \"i_spike\": 91.5, \"isi\": 0.037848569180159435, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 9, \"stim\": 0, \"Log power\": 2.676106443418234, \"Firing rate\": 474.35823385832896, \"Power\": 474.35823385832896, \"i_spike\": 70.5, \"isi\": 0.04830495068709241, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 9, \"stim\": 1, \"Log power\": 2.1110639907459863, \"Firing rate\": 129.14095412211825, \"Power\": 129.14095412211825, \"i_spike\": 75.0, \"isi\": 0.046616310271433786, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 10, \"stim\": 0, \"Log power\": 1.6232640506566587, \"Firing rate\": 42.0014274678324, \"Power\": 42.0014274678324, \"i_spike\": 40.5, \"isi\": 0.08535459247423569, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 10, \"stim\": 1, \"Log power\": 2.096919647626915, \"Firing rate\": 125.00277309697886, \"Power\": 125.00277309697886, \"i_spike\": 84.0, \"isi\": 0.04178774067595231, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 11, \"stim\": 0, \"Log power\": 1.9331854406639293, \"Firing rate\": 85.74038724524688, \"Power\": 85.74038724524688, \"i_spike\": 45.5, \"isi\": 0.07475416969775076, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 11, \"stim\": 1, \"Log power\": 2.2860338712566945, \"Firing rate\": 193.21189999046956, \"Power\": 193.21189999046956, \"i_spike\": 74.5, \"isi\": 0.04694483981113364, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 12, \"stim\": 0, \"Log power\": 2.013785634185715, \"Firing rate\": 103.2251765138098, \"Power\": 103.2251765138098, \"i_spike\": 54.5, \"isi\": 0.062377994946183596, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 12, \"stim\": 1, \"Log power\": 2.0552981499105014, \"Firing rate\": 113.57902857632192, \"Power\": 113.57902857632192, \"i_spike\": 65.0, \"isi\": 0.05367344487702657, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 13, \"stim\": 0, \"Log power\": 2.001328032832847, \"Firing rate\": 100.30625887757395, \"Power\": 100.30625887757395, \"i_spike\": 52.5, \"isi\": 0.06643355183897345, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 13, \"stim\": 1, \"Log power\": 2.029055684492109, \"Firing rate\": 106.91919603900165, \"Power\": 106.91919603900165, \"i_spike\": 58.0, \"isi\": 0.05998731336495791, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 14, \"stim\": 0, \"Log power\": 1.6091774409452742, \"Firing rate\": 40.6609424813706, \"Power\": 40.6609424813706, \"i_spike\": 52.5, \"isi\": 0.06685430488723255, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 14, \"stim\": 1, \"Log power\": 1.9512456770494337, \"Firing rate\": 89.38109627367753, \"Power\": 89.38109627367753, \"i_spike\": 68.0, \"isi\": 0.050811430830218406, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 15, \"stim\": 0, \"Log power\": 1.8708622847115643, \"Firing rate\": 74.27835630110869, \"Power\": 74.27835630110869, \"i_spike\": 45.5, \"isi\": 0.07706380011527493, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 15, \"stim\": 1, \"Log power\": 2.402509178566846, \"Firing rate\": 252.6441104463376, \"Power\": 252.6441104463376, \"i_spike\": 84.5, \"isi\": 0.0409896751820409, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 16, \"stim\": 0, \"Log power\": 1.7573271226032456, \"Firing rate\": 57.19092523263051, \"Power\": 57.19092523263051, \"i_spike\": 55.0, \"isi\": 0.06298129999971641, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 16, \"stim\": 1, \"Log power\": 2.0334988253784623, \"Firing rate\": 108.01866993336576, \"Power\": 108.01866993336576, \"i_spike\": 80.5, \"isi\": 0.04283848037014697, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 17, \"stim\": 0, \"Log power\": 1.8130314591265084, \"Firing rate\": 65.01767856984583, \"Power\": 65.01767856984583, \"i_spike\": 58.0, \"isi\": 0.05878616317174657, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 17, \"stim\": 1, \"Log power\": 1.8576971574606225, \"Firing rate\": 72.06048112794512, \"Power\": 72.06048112794512, \"i_spike\": 65.0, \"isi\": 0.05276322771816143, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 18, \"stim\": 0, \"Log power\": 1.9662726500610492, \"Firing rate\": 92.52788816856142, \"Power\": 92.52788816856142, \"i_spike\": 54.0, \"isi\": 0.06453141568118712, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 18, \"stim\": 1, \"Log power\": 2.1391130916934205, \"Firing rate\": 137.75681454102437, \"Power\": 137.75681454102437, \"i_spike\": 67.0, \"isi\": 0.05099781661502978, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 19, \"stim\": 0, \"Log power\": 1.9572099265690788, \"Firing rate\": 90.61705141263072, \"Power\": 90.61705141263072, \"i_spike\": 42.0, \"isi\": 0.08289420319793103, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 19, \"stim\": 1, \"Log power\": 1.8312652893919428, \"Firing rate\": 67.80555723268918, \"Power\": 67.80555723268918, \"i_spike\": 61.0, \"isi\": 0.056178025827661744, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 20, \"stim\": 0, \"Log power\": 2.4328155806031537, \"Firing rate\": 270.90410167632683, \"Power\": 270.90410167632683, \"i_spike\": 49.0, \"isi\": 0.07016731889146319, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 20, \"stim\": 1, \"Log power\": 3.263607949335591, \"Firing rate\": 1834.8811931531834, \"Power\": 1834.8811931531834, \"i_spike\": 63.0, \"isi\": 0.055385375919981265, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 21, \"stim\": 0, \"Log power\": 2.101449051830407, \"Firing rate\": 126.31329138406011, \"Power\": 126.31329138406011, \"i_spike\": 59.5, \"isi\": 0.05911349078894557, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 21, \"stim\": 1, \"Log power\": 2.207888777043339, \"Firing rate\": 161.39451720165172, \"Power\": 161.39451720165172, \"i_spike\": 59.0, \"isi\": 0.05926310741411494, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 22, \"stim\": 0, \"Log power\": 1.9267003699521277, \"Firing rate\": 84.46958683952812, \"Power\": 84.46958683952812, \"i_spike\": 48.0, \"isi\": 0.07261532335973822, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 22, \"stim\": 1, \"Log power\": 2.250950713277555, \"Firing rate\": 178.21765023337846, \"Power\": 178.21765023337846, \"i_spike\": 79.0, \"isi\": 0.04399623943179176, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 23, \"stim\": 0, \"Log power\": 1.7798858917359148, \"Firing rate\": 60.240128796262965, \"Power\": 60.240128796262965, \"i_spike\": 42.0, \"isi\": 0.08365202131924515, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 23, \"stim\": 1, \"Log power\": 1.8698328179868842, \"Firing rate\": 74.10249282414293, \"Power\": 74.10249282414293, \"i_spike\": 69.5, \"isi\": 0.05011512971498861, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 24, \"stim\": 0, \"Log power\": 1.7408339300589264, \"Firing rate\": 55.05971132213829, \"Power\": 55.05971132213829, \"i_spike\": 49.0, \"isi\": 0.0679345835370269, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 24, \"stim\": 1, \"Log power\": 1.7982632759418413, \"Firing rate\": 62.843921280206814, \"Power\": 62.843921280206814, \"i_spike\": 63.0, \"isi\": 0.055739153709884005, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 25, \"stim\": 0, \"Log power\": 1.9257106345353552, \"Firing rate\": 84.27730405783585, \"Power\": 84.27730405783585, \"i_spike\": 57.5, \"isi\": 0.05961181748074482, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 25, \"stim\": 1, \"Log power\": 3.4328561307238497, \"Firing rate\": 2709.293972012237, \"Power\": 2709.293972012237, \"i_spike\": 81.0, \"isi\": 0.04150756463032279, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 26, \"stim\": 0, \"Log power\": 1.7865120222870157, \"Firing rate\": 61.166273497540935, \"Power\": 61.166273497540935, \"i_spike\": 52.0, \"isi\": 0.06678049819191981, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 26, \"stim\": 1, \"Log power\": 1.992808441381079, \"Firing rate\": 98.35771738289635, \"Power\": 98.35771738289635, \"i_spike\": 63.5, \"isi\": 0.05531311910417264, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 27, \"stim\": 0, \"Log power\": 1.8157312484019956, \"Firing rate\": 65.42311951871677, \"Power\": 65.42311951871677, \"i_spike\": 55.5, \"isi\": 0.0630077631729468, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 27, \"stim\": 1, \"Log power\": 2.3333621104879745, \"Firing rate\": 215.45774515840802, \"Power\": 215.45774515840802, \"i_spike\": 69.0, \"isi\": 0.05050560630228121, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 28, \"stim\": 0, \"Log power\": 1.9940130947745829, \"Firing rate\": 98.6309224213637, \"Power\": 98.6309224213637, \"i_spike\": 36.0, \"isi\": 0.09770522784054125, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 28, \"stim\": 1, \"Log power\": 2.144296934165306, \"Firing rate\": 139.4109652498616, \"Power\": 139.4109652498616, \"i_spike\": 83.5, \"isi\": 0.041017041130571, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 29, \"stim\": 0, \"Log power\": 1.9328772321264005, \"Firing rate\": 85.67956090332135, \"Power\": 85.67956090332135, \"i_spike\": 50.5, \"isi\": 0.06853776265768526, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 29, \"stim\": 1, \"Log power\": 1.854008200560399, \"Firing rate\": 71.45098176712787, \"Power\": 71.45098176712787, \"i_spike\": 66.0, \"isi\": 0.052863568415280456, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 30, \"stim\": 0, \"Log power\": 1.9628713359768517, \"Firing rate\": 91.80605716925574, \"Power\": 91.80605716925574, \"i_spike\": 50.0, \"isi\": 0.06904275105113092, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 30, \"stim\": 1, \"Log power\": 2.32517167071787, \"Firing rate\": 211.43246385259874, \"Power\": 211.43246385259874, \"i_spike\": 65.5, \"isi\": 0.0536052118675172, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 31, \"stim\": 0, \"Log power\": 1.7467076000407382, \"Firing rate\": 55.80943168256906, \"Power\": 55.80943168256906, \"i_spike\": 56.0, \"isi\": 0.0624376332844464, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 31, \"stim\": 1, \"Log power\": 2.2299630977330533, \"Firing rate\": 169.80993577935809, \"Power\": 169.80993577935809, \"i_spike\": 78.5, \"isi\": 0.04406643580014228, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 32, \"stim\": 0, \"Log power\": 1.7164036797602218, \"Firing rate\": 52.04795611548826, \"Power\": 52.04795611548826, \"i_spike\": 51.5, \"isi\": 0.06830738696668638, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 32, \"stim\": 1, \"Log power\": 2.249629835663377, \"Firing rate\": 177.67643662192964, \"Power\": 177.67643662192964, \"i_spike\": 61.0, \"isi\": 0.056569210250451946, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 33, \"stim\": 0, \"Log power\": 1.8388352349235668, \"Firing rate\": 68.99779864600258, \"Power\": 68.99779864600258, \"i_spike\": 43.5, \"isi\": 0.07991809546173433, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 33, \"stim\": 1, \"Log power\": 2.0555628811154856, \"Firing rate\": 113.64828361041003, \"Power\": 113.64828361041003, \"i_spike\": 74.5, \"isi\": 0.04701472940190168, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 34, \"stim\": 0, \"Log power\": 2.1194341234074137, \"Firing rate\": 131.654019625294, \"Power\": 131.654019625294, \"i_spike\": 52.5, \"isi\": 0.06680919856324574, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 34, \"stim\": 1, \"Log power\": 2.884714590473734, \"Firing rate\": 766.8573606223978, \"Power\": 766.8573606223978, \"i_spike\": 71.0, \"isi\": 0.04866439823348472, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 35, \"stim\": 0, \"Log power\": 1.9778409282425284, \"Firing rate\": 95.02566734481009, \"Power\": 95.02566734481009, \"i_spike\": 50.0, \"isi\": 0.06923707956214095, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 35, \"stim\": 1, \"Log power\": 2.202953374065545, \"Firing rate\": 159.57078225585417, \"Power\": 159.57078225585417, \"i_spike\": 70.0, \"isi\": 0.04885789752684091, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 36, \"stim\": 0, \"Log power\": 1.784812013580816, \"Firing rate\": 60.92731134073771, \"Power\": 60.92731134073771, \"i_spike\": 50.0, \"isi\": 0.07058595343558123, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 36, \"stim\": 1, \"Log power\": 3.1409738312028175, \"Firing rate\": 1383.4830134705974, \"Power\": 1383.4830134705974, \"i_spike\": 85.0, \"isi\": 0.041308395897538035, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 37, \"stim\": 0, \"Log power\": 1.9184706072757933, \"Firing rate\": 82.88398191186509, \"Power\": 82.88398191186509, \"i_spike\": 55.5, \"isi\": 0.06324923640619608, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 37, \"stim\": 1, \"Log power\": 2.716295639106646, \"Firing rate\": 520.3500961023163, \"Power\": 520.3500961023163, \"i_spike\": 62.0, \"isi\": 0.056727244498762444, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 38, \"stim\": 0, \"Log power\": 3.8473651307621854, \"Firing rate\": 7036.636727288945, \"Power\": 7036.636727288945, \"i_spike\": 62.0, \"isi\": 0.05600353313547211, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 38, \"stim\": 1, \"Log power\": 2.3112382775280116, \"Firing rate\": 204.75677354098664, \"Power\": 204.75677354098664, \"i_spike\": 73.0, \"isi\": 0.0479308847316747, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 39, \"stim\": 0, \"Log power\": 1.4952981541167647, \"Firing rate\": 31.282262363194192, \"Power\": 31.282262363194192, \"i_spike\": 42.5, \"isi\": 0.08203877964939713, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 39, \"stim\": 1, \"Log power\": 2.5654954718423877, \"Firing rate\": 367.70155952961085, \"Power\": 367.70155952961085, \"i_spike\": 63.5, \"isi\": 0.05521422344425198, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 40, \"stim\": 0, \"Log power\": 2.0587434113870398, \"Firing rate\": 114.48363526837838, \"Power\": 114.48363526837838, \"i_spike\": 59.0, \"isi\": 0.05775697926389982, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 40, \"stim\": 1, \"Log power\": 2.535494934297201, \"Firing rate\": 343.15863709811487, \"Power\": 343.15863709811487, \"i_spike\": 73.0, \"isi\": 0.04544940564685203, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 41, \"stim\": 0, \"Log power\": 1.9290986505059227, \"Firing rate\": 84.93733892964764, \"Power\": 84.93733892964764, \"i_spike\": 54.5, \"isi\": 0.06426866341860926, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 41, \"stim\": 1, \"Log power\": 2.119529189060382, \"Firing rate\": 131.68284141740725, \"Power\": 131.68284141740725, \"i_spike\": 69.0, \"isi\": 0.0500901476136261, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 42, \"stim\": 0, \"Log power\": 1.7707721647357468, \"Firing rate\": 58.989153593622866, \"Power\": 58.989153593622866, \"i_spike\": 54.0, \"isi\": 0.06402896021244067, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 42, \"stim\": 1, \"Log power\": 2.272592238901273, \"Firing rate\": 187.3234893231929, \"Power\": 187.3234893231929, \"i_spike\": 72.5, \"isi\": 0.047910871843303254, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 43, \"stim\": 0, \"Log power\": 1.7923160216809917, \"Firing rate\": 61.98919858254278, \"Power\": 61.98919858254278, \"i_spike\": 48.5, \"isi\": 0.0701745235340201, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 43, \"stim\": 1, \"Log power\": 2.102684459160395, \"Firing rate\": 126.67311756914205, \"Power\": 126.67311756914205, \"i_spike\": 65.5, \"isi\": 0.05124378233589835, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 44, \"stim\": 0, \"Log power\": 1.9886048303170087, \"Firing rate\": 97.4102886614267, \"Power\": 97.4102886614267, \"i_spike\": 50.5, \"isi\": 0.06689126712943644, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 44, \"stim\": 1, \"Log power\": 3.9339798307893687, \"Firing rate\": 8589.736287066924, \"Power\": 8589.736287066924, \"i_spike\": 71.5, \"isi\": 0.04806362754846643, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 45, \"stim\": 0, \"Log power\": 2.1181574574401316, \"Firing rate\": 131.26757353592208, \"Power\": 131.26757353592208, \"i_spike\": 54.0, \"isi\": 0.06475218118244992, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 45, \"stim\": 1, \"Log power\": 3.0155915580898944, \"Firing rate\": 1036.553107827582, \"Power\": 1036.553107827582, \"i_spike\": 66.5, \"isi\": 0.052121906724335185, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 46, \"stim\": 0, \"Log power\": 2.460612200995431, \"Firing rate\": 288.80998301605393, \"Power\": 288.80998301605393, \"i_spike\": 60.0, \"isi\": 0.05816834663971174, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 46, \"stim\": 1, \"Log power\": 2.123614018958845, \"Firing rate\": 132.92724963341564, \"Power\": 132.92724963341564, \"i_spike\": 64.0, \"isi\": 0.054730564194953035, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 47, \"stim\": 0, \"Log power\": 1.8178551381587797, \"Firing rate\": 65.7438507748311, \"Power\": 65.7438507748311, \"i_spike\": 45.0, \"isi\": 0.0770782687061177, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 47, \"stim\": 1, \"Log power\": 2.0392006786431494, \"Firing rate\": 109.44619780568075, \"Power\": 109.44619780568075, \"i_spike\": 69.0, \"isi\": 0.05089717719977343, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 48, \"stim\": 0, \"Log power\": 1.9129060917684284, \"Firing rate\": 81.82878292398146, \"Power\": 81.82878292398146, \"i_spike\": 64.0, \"isi\": 0.05427807930305203, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 48, \"stim\": 1, \"Log power\": 2.44882038792332, \"Firing rate\": 281.0738147138083, \"Power\": 281.0738147138083, \"i_spike\": 63.5, \"isi\": 0.055157625575869694, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 49, \"stim\": 0, \"Log power\": 1.8920662465296576, \"Firing rate\": 77.99490735334801, \"Power\": 77.99490735334801, \"i_spike\": 62.5, \"isi\": 0.056077534750193836, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 49, \"stim\": 1, \"Log power\": 1.9118080169571057, \"Firing rate\": 81.62214749405882, \"Power\": 81.62214749405882, \"i_spike\": 75.5, \"isi\": 0.04601891455309904, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 50, \"stim\": 0, \"Log power\": 1.8896810485448365, \"Firing rate\": 77.56772400469606, \"Power\": 77.56772400469606, \"i_spike\": 60.0, \"isi\": 0.05704692797691012, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 50, \"stim\": 1, \"Log power\": 2.084255331653626, \"Firing rate\": 121.4102439254533, \"Power\": 121.4102439254533, \"i_spike\": 70.5, \"isi\": 0.04957238168445212, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 51, \"stim\": 0, \"Log power\": 2.2357643372895453, \"Firing rate\": 172.09344849681145, \"Power\": 172.09344849681145, \"i_spike\": 55.5, \"isi\": 0.06334381628913896, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 51, \"stim\": 1, \"Log power\": 2.512421061543573, \"Firing rate\": 325.4026321222985, \"Power\": 325.4026321222985, \"i_spike\": 59.5, \"isi\": 0.05782776269814487, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 52, \"stim\": 0, \"Log power\": 1.850990963535423, \"Firing rate\": 70.95630037701366, \"Power\": 70.95630037701366, \"i_spike\": 60.5, \"isi\": 0.05808960247706074, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 52, \"stim\": 1, \"Log power\": 2.3688201645347062, \"Firing rate\": 233.78689583127294, \"Power\": 233.78689583127294, \"i_spike\": 63.5, \"isi\": 0.05487145922751193, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 53, \"stim\": 0, \"Log power\": 2.032687263703032, \"Firing rate\": 107.81700502819685, \"Power\": 107.81700502819685, \"i_spike\": 68.5, \"isi\": 0.0506952002626119, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 53, \"stim\": 1, \"Log power\": 3.030683823901768, \"Firing rate\": 1073.2078085703633, \"Power\": 1073.2078085703633, \"i_spike\": 76.0, \"isi\": 0.04623168479801761, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 54, \"stim\": 0, \"Log power\": 2.0906978838113996, \"Firing rate\": 123.22473243283689, \"Power\": 123.22473243283689, \"i_spike\": 60.5, \"isi\": 0.05676048699786371, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 54, \"stim\": 1, \"Log power\": 1.9156319780205426, \"Firing rate\": 82.34400346079876, \"Power\": 82.34400346079876, \"i_spike\": 65.5, \"isi\": 0.05232473190697469, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 55, \"stim\": 0, \"Log power\": 1.7510340341312678, \"Firing rate\": 56.368182785769, \"Power\": 56.368182785769, \"i_spike\": 57.0, \"isi\": 0.061559740824834466, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 55, \"stim\": 1, \"Log power\": 1.7979907921739262, \"Firing rate\": 62.804504298485014, \"Power\": 62.804504298485014, \"i_spike\": 64.5, \"isi\": 0.05399189150381069, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 56, \"stim\": 0, \"Log power\": 1.7360671783913546, \"Firing rate\": 54.45868851848893, \"Power\": 54.45868851848893, \"i_spike\": 45.5, \"isi\": 0.07661942966192567, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 56, \"stim\": 1, \"Log power\": 2.098760747371754, \"Firing rate\": 125.53382079330537, \"Power\": 125.53382079330537, \"i_spike\": 58.5, \"isi\": 0.059506741815825555, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 57, \"stim\": 0, \"Log power\": 2.5657078174242756, \"Firing rate\": 367.8813888765108, \"Power\": 367.8813888765108, \"i_spike\": 45.5, \"isi\": 0.07315243806126524, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 57, \"stim\": 1, \"Log power\": 1.8640379658323025, \"Firing rate\": 73.12030021338683, \"Power\": 73.12030021338683, \"i_spike\": 70.5, \"isi\": 0.048833407705651144, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 58, \"stim\": 0, \"Log power\": 1.759046405272301, \"Firing rate\": 57.417781102777354, \"Power\": 57.417781102777354, \"i_spike\": 66.5, \"isi\": 0.05260699813845276, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 58, \"stim\": 1, \"Log power\": 1.886550639943834, \"Firing rate\": 77.01062356496165, \"Power\": 77.01062356496165, \"i_spike\": 58.5, \"isi\": 0.06012533608644614, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 59, \"stim\": 0, \"Log power\": 1.918524506801241, \"Firing rate\": 82.89426913565212, \"Power\": 82.89426913565212, \"i_spike\": 54.5, \"isi\": 0.06303437750717443, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 59, \"stim\": 1, \"Log power\": 1.8919699622345283, \"Firing rate\": 77.97761758202086, \"Power\": 77.97761758202086, \"i_spike\": 69.5, \"isi\": 0.04978629715324452, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 60, \"stim\": 0, \"Log power\": 1.7912057599234485, \"Firing rate\": 61.830927315630035, \"Power\": 61.830927315630035, \"i_spike\": 58.5, \"isi\": 0.059698311157695944, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 60, \"stim\": 1, \"Log power\": 2.799019387447701, \"Firing rate\": 629.5342854261299, \"Power\": 629.5342854261299, \"i_spike\": 65.5, \"isi\": 0.05303682204808934, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 61, \"stim\": 0, \"Log power\": 2.0020113649422253, \"Firing rate\": 100.46420801583665, \"Power\": 100.46420801583665, \"i_spike\": 49.5, \"isi\": 0.07090914062608861, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 61, \"stim\": 1, \"Log power\": 2.1721405640830866, \"Firing rate\": 148.64166591886863, \"Power\": 148.64166591886863, \"i_spike\": 58.5, \"isi\": 0.05956371920280016, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 62, \"stim\": 0, \"Log power\": 2.450257798525738, \"Firing rate\": 282.00564285943705, \"Power\": 282.00564285943705, \"i_spike\": 46.0, \"isi\": 0.07612686186128655, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 62, \"stim\": 1, \"Log power\": 1.904903066566133, \"Firing rate\": 80.33467971933419, \"Power\": 80.33467971933419, \"i_spike\": 67.0, \"isi\": 0.05226169166686549, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 63, \"stim\": 0, \"Log power\": 1.9515815834905088, \"Firing rate\": 89.45025510749112, \"Power\": 89.45025510749112, \"i_spike\": 66.5, \"isi\": 0.052318934660735186, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 63, \"stim\": 1, \"Log power\": 1.9259032990375113, \"Firing rate\": 84.31469999002974, \"Power\": 84.31469999002974, \"i_spike\": 70.5, \"isi\": 0.049361689940967755, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 64, \"stim\": 0, \"Log power\": 2.1252356086753323, \"Firing rate\": 133.42450758473038, \"Power\": 133.42450758473038, \"i_spike\": 47.0, \"isi\": 0.07396953612595625, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 64, \"stim\": 1, \"Log power\": 3.920078035222342, \"Firing rate\": 8319.132381237787, \"Power\": 8319.132381237787, \"i_spike\": 72.0, \"isi\": 0.04800705242748367, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 65, \"stim\": 0, \"Log power\": 2.1131749285435153, \"Firing rate\": 129.77018642822452, \"Power\": 129.77018642822452, \"i_spike\": 59.5, \"isi\": 0.0590103513672145, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 65, \"stim\": 1, \"Log power\": 2.181321182621592, \"Firing rate\": 151.81727175049062, \"Power\": 151.81727175049062, \"i_spike\": 69.5, \"isi\": 0.05019603665826838, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 66, \"stim\": 0, \"Log power\": 1.8915333023587966, \"Firing rate\": 77.89925465920646, \"Power\": 77.89925465920646, \"i_spike\": 57.5, \"isi\": 0.05958827839860185, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 66, \"stim\": 1, \"Log power\": 2.0004037782187587, \"Firing rate\": 100.09301660437578, \"Power\": 100.09301660437578, \"i_spike\": 68.5, \"isi\": 0.050901759835215436, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 67, \"stim\": 0, \"Log power\": 2.432051900275914, \"Firing rate\": 270.42815194256787, \"Power\": 270.42815194256787, \"i_spike\": 59.0, \"isi\": 0.05949685594732218, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 67, \"stim\": 1, \"Log power\": 2.0663732604586826, \"Firing rate\": 116.51269838674719, \"Power\": 116.51269838674719, \"i_spike\": 67.0, \"isi\": 0.05166934513187805, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 68, \"stim\": 0, \"Log power\": 1.6179708721178778, \"Firing rate\": 41.49262128376992, \"Power\": 41.49262128376992, \"i_spike\": 46.0, \"isi\": 0.07608370206752937, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 68, \"stim\": 1, \"Log power\": 3.8344656384323454, \"Firing rate\": 6830.706709936496, \"Power\": 6830.706709936496, \"i_spike\": 67.5, \"isi\": 0.049648481688443484, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 69, \"stim\": 0, \"Log power\": 2.0241434282381983, \"Firing rate\": 105.71665868837164, \"Power\": 105.71665868837164, \"i_spike\": 55.5, \"isi\": 0.0630208962135097, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 69, \"stim\": 1, \"Log power\": 2.3744322551616337, \"Firing rate\": 236.82756797792314, \"Power\": 236.82756797792314, \"i_spike\": 85.5, \"isi\": 0.04019396169521371, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 0, \"stim\": 0, \"Log power\": 1.8395227614847653, \"Firing rate\": 69.10711476712522, \"Power\": 69.10711476712522, \"i_spike\": 65.0, \"isi\": 0.053630916270348744, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 0, \"stim\": 1, \"Log power\": 1.979559114361202, \"Firing rate\": 95.40235917332403, \"Power\": 95.40235917332403, \"i_spike\": 71.0, \"isi\": 0.04957983023166928, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 1, \"stim\": 0, \"Log power\": 2.293578194133035, \"Firing rate\": 196.59759200169472, \"Power\": 196.59759200169472, \"i_spike\": 63.5, \"isi\": 0.053322075452964926, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 1, \"stim\": 1, \"Log power\": 2.0387605537249542, \"Firing rate\": 109.33533846768843, \"Power\": 109.33533846768843, \"i_spike\": 74.5, \"isi\": 0.04683335212008752, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 2, \"stim\": 0, \"Log power\": 1.8289112223980541, \"Firing rate\": 67.43901561313284, \"Power\": 67.43901561313284, \"i_spike\": 48.5, \"isi\": 0.069337401412852, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 2, \"stim\": 1, \"Log power\": 2.1499710092746973, \"Firing rate\": 141.24432557867806, \"Power\": 141.24432557867806, \"i_spike\": 73.5, \"isi\": 0.046739319993110824, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 3, \"stim\": 0, \"Log power\": 2.428602938706723, \"Firing rate\": 268.2890444711559, \"Power\": 268.2890444711559, \"i_spike\": 51.0, \"isi\": 0.06678710477113814, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 3, \"stim\": 1, \"Log power\": 2.5291754817531187, \"Firing rate\": 338.20146284881105, \"Power\": 338.20146284881105, \"i_spike\": 76.0, \"isi\": 0.045911592591222884, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 4, \"stim\": 0, \"Log power\": 2.1295435110498584, \"Firing rate\": 134.7545726350998, \"Power\": 134.7545726350998, \"i_spike\": 65.0, \"isi\": 0.0537364841967957, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 4, \"stim\": 1, \"Log power\": 2.425691481003578, \"Firing rate\": 266.49648242457556, \"Power\": 266.49648242457556, \"i_spike\": 80.0, \"isi\": 0.041417840771848076, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 5, \"stim\": 0, \"Log power\": 2.0928402051454493, \"Firing rate\": 123.83408660101263, \"Power\": 123.83408660101263, \"i_spike\": 59.5, \"isi\": 0.05672579442062913, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 5, \"stim\": 1, \"Log power\": 2.20598593072847, \"Firing rate\": 160.68891958775558, \"Power\": 160.68891958775558, \"i_spike\": 67.0, \"isi\": 0.05048218807963795, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 6, \"stim\": 0, \"Log power\": 2.334110408290884, \"Firing rate\": 215.82930303467967, \"Power\": 215.82930303467967, \"i_spike\": 74.5, \"isi\": 0.04675683517064576, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 6, \"stim\": 1, \"Log power\": 1.8517544491264242, \"Firing rate\": 71.08115059246538, \"Power\": 71.08115059246538, \"i_spike\": 74.0, \"isi\": 0.046828455704508894, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 7, \"stim\": 0, \"Log power\": 2.018284511572204, \"Firing rate\": 104.30004878739969, \"Power\": 104.30004878739969, \"i_spike\": 58.5, \"isi\": 0.05966489405441446, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 7, \"stim\": 1, \"Log power\": 2.1312009713091857, \"Firing rate\": 135.26983843494207, \"Power\": 135.26983843494207, \"i_spike\": 80.0, \"isi\": 0.04278028451646302, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 8, \"stim\": 0, \"Log power\": 2.3953511892459347, \"Firing rate\": 248.51418858872697, \"Power\": 248.51418858872697, \"i_spike\": 67.0, \"isi\": 0.05210801101169798, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 8, \"stim\": 1, \"Log power\": 2.1586375368539525, \"Firing rate\": 144.09122609475662, \"Power\": 144.09122609475662, \"i_spike\": 75.5, \"isi\": 0.04571636564392706, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 9, \"stim\": 0, \"Log power\": 2.0225205738655703, \"Firing rate\": 105.32235803888173, \"Power\": 105.32235803888173, \"i_spike\": 64.0, \"isi\": 0.054042474504752316, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 9, \"stim\": 1, \"Log power\": 2.053885464972099, \"Firing rate\": 113.21017584604715, \"Power\": 113.21017584604715, \"i_spike\": 79.0, \"isi\": 0.04412611854187347, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 10, \"stim\": 0, \"Log power\": 2.257812971503425, \"Firing rate\": 181.05602087091782, \"Power\": 181.05602087091782, \"i_spike\": 61.5, \"isi\": 0.05610863794720149, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 10, \"stim\": 1, \"Log power\": 2.0545631134716364, \"Firing rate\": 113.38696047568332, \"Power\": 113.38696047568332, \"i_spike\": 75.5, \"isi\": 0.04665898036022994, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 11, \"stim\": 0, \"Log power\": 2.0890447210245844, \"Firing rate\": 122.75656319501711, \"Power\": 122.75656319501711, \"i_spike\": 51.5, \"isi\": 0.06782397951607, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 11, \"stim\": 1, \"Log power\": 3.371026629766224, \"Firing rate\": 2349.7768984125396, \"Power\": 2349.7768984125396, \"i_spike\": 69.0, \"isi\": 0.049785332077325654, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 12, \"stim\": 0, \"Log power\": 1.56303824583675, \"Firing rate\": 36.56269888778751, \"Power\": 36.56269888778751, \"i_spike\": 42.5, \"isi\": 0.0825037340286652, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 12, \"stim\": 1, \"Log power\": 1.8933843551443503, \"Firing rate\": 78.23198595372384, \"Power\": 78.23198595372384, \"i_spike\": 64.5, \"isi\": 0.05209097235210884, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 13, \"stim\": 0, \"Log power\": 1.8705785933701065, \"Firing rate\": 74.22985178052824, \"Power\": 74.22985178052824, \"i_spike\": 70.5, \"isi\": 0.0489380128420369, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 13, \"stim\": 1, \"Log power\": 2.4851462691102593, \"Firing rate\": 305.595017498699, \"Power\": 305.595017498699, \"i_spike\": 74.0, \"isi\": 0.04711311131950498, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 14, \"stim\": 0, \"Log power\": 1.7994585757748236, \"Firing rate\": 63.01712356250882, \"Power\": 63.01712356250882, \"i_spike\": 41.0, \"isi\": 0.0846530791433244, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 14, \"stim\": 1, \"Log power\": 2.0675077288707153, \"Firing rate\": 116.81745189568983, \"Power\": 116.81745189568983, \"i_spike\": 75.5, \"isi\": 0.04637873254787389, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 15, \"stim\": 0, \"Log power\": 1.995079841151202, \"Firing rate\": 98.87348479968038, \"Power\": 98.87348479968038, \"i_spike\": 61.0, \"isi\": 0.0571959600126965, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 15, \"stim\": 1, \"Log power\": 2.2210379560276947, \"Firing rate\": 166.35580339711643, \"Power\": 166.35580339711643, \"i_spike\": 82.0, \"isi\": 0.041816157103671266, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 16, \"stim\": 0, \"Log power\": 2.1339499123050127, \"Firing rate\": 136.12876744985942, \"Power\": 136.12876744985942, \"i_spike\": 61.5, \"isi\": 0.05714983504152593, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 16, \"stim\": 1, \"Log power\": 2.3323286944799815, \"Firing rate\": 214.94566685148686, \"Power\": 214.94566685148686, \"i_spike\": 79.0, \"isi\": 0.04434022368413476, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 17, \"stim\": 0, \"Log power\": 1.9833345526972057, \"Firing rate\": 96.23533283832164, \"Power\": 96.23533283832164, \"i_spike\": 45.5, \"isi\": 0.07654583109411725, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 17, \"stim\": 1, \"Log power\": 2.172141104199998, \"Firing rate\": 148.64185077944452, \"Power\": 148.64185077944452, \"i_spike\": 67.0, \"isi\": 0.05010246250655258, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 18, \"stim\": 0, \"Log power\": 2.112543667841299, \"Firing rate\": 129.58169839656338, \"Power\": 129.58169839656338, \"i_spike\": 62.5, \"isi\": 0.05377112082842086, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 18, \"stim\": 1, \"Log power\": 2.210021715459556, \"Firing rate\": 162.1891192637679, \"Power\": 162.1891192637679, \"i_spike\": 77.0, \"isi\": 0.04519498045540092, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 19, \"stim\": 0, \"Log power\": 2.0026131647641905, \"Firing rate\": 100.60351729441955, \"Power\": 100.60351729441955, \"i_spike\": 50.5, \"isi\": 0.06820489580832796, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 19, \"stim\": 1, \"Log power\": 2.0370318323637453, \"Firing rate\": 108.9009911269532, \"Power\": 108.9009911269532, \"i_spike\": 81.0, \"isi\": 0.042853414388179994, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 20, \"stim\": 0, \"Log power\": 1.9207855796775546, \"Firing rate\": 83.32696802722485, \"Power\": 83.32696802722485, \"i_spike\": 70.0, \"isi\": 0.04973868124870691, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 20, \"stim\": 1, \"Log power\": 1.9051076683804824, \"Firing rate\": 80.37253535479195, \"Power\": 80.37253535479195, \"i_spike\": 70.0, \"isi\": 0.050203277291417964, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 21, \"stim\": 0, \"Log power\": 2.198728743545616, \"Firing rate\": 158.02607142376806, \"Power\": 158.02607142376806, \"i_spike\": 59.5, \"isi\": 0.05823314590575576, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 21, \"stim\": 1, \"Log power\": 2.0807437060272305, \"Firing rate\": 120.43250118450901, \"Power\": 120.43250118450901, \"i_spike\": 72.0, \"isi\": 0.04819694913579527, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 22, \"stim\": 0, \"Log power\": 1.7444740065038793, \"Firing rate\": 55.52313842848224, \"Power\": 55.52313842848224, \"i_spike\": 57.5, \"isi\": 0.059489116350756516, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 22, \"stim\": 1, \"Log power\": 2.2276621162228643, \"Firing rate\": 168.91262696788266, \"Power\": 168.91262696788266, \"i_spike\": 78.5, \"isi\": 0.044507207562924936, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 23, \"stim\": 0, \"Log power\": 2.32247577879472, \"Firing rate\": 210.1240576679081, \"Power\": 210.1240576679081, \"i_spike\": 62.0, \"isi\": 0.05639881136849346, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 23, \"stim\": 1, \"Log power\": 2.324669250510721, \"Firing rate\": 211.1880064056577, \"Power\": 211.1880064056577, \"i_spike\": 79.0, \"isi\": 0.04356023384962629, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 24, \"stim\": 0, \"Log power\": 1.876376207234443, \"Firing rate\": 75.22742688119314, \"Power\": 75.22742688119314, \"i_spike\": 78.5, \"isi\": 0.04422677905394997, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 24, \"stim\": 1, \"Log power\": 2.284454779689932, \"Firing rate\": 192.51065855906467, \"Power\": 192.51065855906467, \"i_spike\": 79.5, \"isi\": 0.04416270392967511, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 25, \"stim\": 0, \"Log power\": 1.9935599536950763, \"Firing rate\": 98.52806499166216, \"Power\": 98.52806499166216, \"i_spike\": 58.5, \"isi\": 0.05983079937723857, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 25, \"stim\": 1, \"Log power\": 1.9595423974551718, \"Firing rate\": 91.10503880784559, \"Power\": 91.10503880784559, \"i_spike\": 76.5, \"isi\": 0.04528216368486609, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 26, \"stim\": 0, \"Log power\": 1.880525000768862, \"Firing rate\": 75.9495142808881, \"Power\": 75.9495142808881, \"i_spike\": 62.0, \"isi\": 0.0560710156245103, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 26, \"stim\": 1, \"Log power\": 2.0083875550012302, \"Firing rate\": 101.95007626679772, \"Power\": 101.95007626679772, \"i_spike\": 76.0, \"isi\": 0.045828336953587664, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 27, \"stim\": 0, \"Log power\": 3.300002014564387, \"Firing rate\": 1995.2715704255168, \"Power\": 1995.2715704255168, \"i_spike\": 64.5, \"isi\": 0.052761225476386724, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 27, \"stim\": 1, \"Log power\": 2.192438683086075, \"Firing rate\": 155.7538114531551, \"Power\": 155.7538114531551, \"i_spike\": 81.0, \"isi\": 0.04331741035829043, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 28, \"stim\": 0, \"Log power\": 1.9356546504018293, \"Firing rate\": 86.2292582730473, \"Power\": 86.2292582730473, \"i_spike\": 59.0, \"isi\": 0.05941604520777876, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 28, \"stim\": 1, \"Log power\": 2.269221962253762, \"Firing rate\": 185.87541974337458, \"Power\": 185.87541974337458, \"i_spike\": 85.5, \"isi\": 0.03956519477652128, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 29, \"stim\": 0, \"Log power\": 1.960880655217778, \"Firing rate\": 91.3862076277134, \"Power\": 91.3862076277134, \"i_spike\": 66.0, \"isi\": 0.052851259401009494, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 29, \"stim\": 1, \"Log power\": 2.317904343401113, \"Firing rate\": 207.92386688394922, \"Power\": 207.92386688394922, \"i_spike\": 90.5, \"isi\": 0.03878139701103411, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 30, \"stim\": 0, \"Log power\": 2.213722233665811, \"Firing rate\": 163.57699800109793, \"Power\": 163.57699800109793, \"i_spike\": 59.0, \"isi\": 0.05920905747166483, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 30, \"stim\": 1, \"Log power\": 2.0800578436836923, \"Firing rate\": 120.24245748863318, \"Power\": 120.24245748863318, \"i_spike\": 88.0, \"isi\": 0.03910171807630423, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 31, \"stim\": 0, \"Log power\": 1.959418764889166, \"Firing rate\": 91.07910721736455, \"Power\": 91.07910721736455, \"i_spike\": 62.5, \"isi\": 0.0555235970240056, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 31, \"stim\": 1, \"Log power\": 2.197394436254224, \"Firing rate\": 157.54130413283562, \"Power\": 157.54130413283562, \"i_spike\": 76.0, \"isi\": 0.045570952048349815, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 32, \"stim\": 0, \"Log power\": 1.7831137783812137, \"Firing rate\": 60.68953058682318, \"Power\": 60.68953058682318, \"i_spike\": 56.0, \"isi\": 0.06178825380128117, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 32, \"stim\": 1, \"Log power\": 2.0298311584650195, \"Firing rate\": 107.11028094988397, \"Power\": 107.11028094988397, \"i_spike\": 81.0, \"isi\": 0.04322528281096521, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 33, \"stim\": 0, \"Log power\": 2.1342867035110866, \"Firing rate\": 136.2343749471251, \"Power\": 136.2343749471251, \"i_spike\": 54.0, \"isi\": 0.06418255607584347, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 33, \"stim\": 1, \"Log power\": 1.9285537107556434, \"Firing rate\": 84.83082892927328, \"Power\": 84.83082892927328, \"i_spike\": 56.0, \"isi\": 0.062126303086487214, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 34, \"stim\": 0, \"Log power\": 2.411721977725596, \"Firing rate\": 258.0607634286396, \"Power\": 258.0607634286396, \"i_spike\": 62.0, \"isi\": 0.05673612752079895, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 34, \"stim\": 1, \"Log power\": 2.0836455742839335, \"Firing rate\": 121.2399013397276, \"Power\": 121.2399013397276, \"i_spike\": 84.0, \"isi\": 0.04166917607367692, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 35, \"stim\": 0, \"Log power\": 1.9655454922420286, \"Firing rate\": 92.37309439451325, \"Power\": 92.37309439451325, \"i_spike\": 67.0, \"isi\": 0.05147935072043162, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 35, \"stim\": 1, \"Log power\": 2.097459264073676, \"Firing rate\": 125.15818717286099, \"Power\": 125.15818717286099, \"i_spike\": 77.0, \"isi\": 0.045003396025821846, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 36, \"stim\": 0, \"Log power\": 2.046121334396872, \"Firing rate\": 111.20423693669547, \"Power\": 111.20423693669547, \"i_spike\": 62.0, \"isi\": 0.05605824680268041, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 36, \"stim\": 1, \"Log power\": 1.86387178240841, \"Firing rate\": 73.09232597522241, \"Power\": 73.09232597522241, \"i_spike\": 69.0, \"isi\": 0.05031902720804942, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 37, \"stim\": 0, \"Log power\": 2.3424498028391265, \"Firing rate\": 220.01373959442577, \"Power\": 220.01373959442577, \"i_spike\": 52.0, \"isi\": 0.06576199942048623, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 37, \"stim\": 1, \"Log power\": 2.549693083159014, \"Firing rate\": 354.5627304320859, \"Power\": 354.5627304320859, \"i_spike\": 85.0, \"isi\": 0.0413221930981557, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 38, \"stim\": 0, \"Log power\": 2.1577205254413134, \"Firing rate\": 143.78729891423066, \"Power\": 143.78729891423066, \"i_spike\": 66.5, \"isi\": 0.05174969918429245, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 38, \"stim\": 1, \"Log power\": 2.078704072053142, \"Firing rate\": 119.86822435925174, \"Power\": 119.86822435925174, \"i_spike\": 76.5, \"isi\": 0.045005351605003574, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 39, \"stim\": 0, \"Log power\": 2.149206273527988, \"Firing rate\": 140.9958316527641, \"Power\": 140.9958316527641, \"i_spike\": 72.0, \"isi\": 0.047556963977426, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 39, \"stim\": 1, \"Log power\": 2.0104729231475376, \"Firing rate\": 102.4407909808483, \"Power\": 102.4407909808483, \"i_spike\": 74.5, \"isi\": 0.04675157654815791, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 40, \"stim\": 0, \"Log power\": 2.063744731640358, \"Firing rate\": 115.80964534675512, \"Power\": 115.80964534675512, \"i_spike\": 69.0, \"isi\": 0.05068026335149265, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 40, \"stim\": 1, \"Log power\": 3.226696129956056, \"Firing rate\": 1685.3733795197395, \"Power\": 1685.3733795197395, \"i_spike\": 83.5, \"isi\": 0.04155538295653413, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 41, \"stim\": 0, \"Log power\": 2.2891336299906766, \"Firing rate\": 194.59587501722018, \"Power\": 194.59587501722018, \"i_spike\": 67.5, \"isi\": 0.05076586195092699, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 41, \"stim\": 1, \"Log power\": 2.1620541706659013, \"Firing rate\": 145.22927544951278, \"Power\": 145.22927544951278, \"i_spike\": 79.5, \"isi\": 0.04327072519579295, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 42, \"stim\": 0, \"Log power\": 2.2438446783318393, \"Firing rate\": 175.3253353791518, \"Power\": 175.3253353791518, \"i_spike\": 59.5, \"isi\": 0.05876741761237487, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 42, \"stim\": 1, \"Log power\": 1.9093134217935919, \"Firing rate\": 81.15465237478982, \"Power\": 81.15465237478982, \"i_spike\": 70.5, \"isi\": 0.04928685424464279, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 43, \"stim\": 0, \"Log power\": 2.041486224886291, \"Firing rate\": 110.02369470180963, \"Power\": 110.02369470180963, \"i_spike\": 75.0, \"isi\": 0.04640738541500625, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 43, \"stim\": 1, \"Log power\": 1.9275313391361222, \"Firing rate\": 84.63136374656517, \"Power\": 84.63136374656517, \"i_spike\": 73.5, \"isi\": 0.04764079103977659, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 44, \"stim\": 0, \"Log power\": 1.9616890267525733, \"Firing rate\": 91.55646722611571, \"Power\": 91.55646722611571, \"i_spike\": 71.0, \"isi\": 0.04866344986542914, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 44, \"stim\": 1, \"Log power\": 2.64134610644652, \"Firing rate\": 437.8709228002045, \"Power\": 437.8709228002045, \"i_spike\": 71.0, \"isi\": 0.04907690843798719, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 45, \"stim\": 0, \"Log power\": 2.1628963706005546, \"Firing rate\": 145.51118269023607, \"Power\": 145.51118269023607, \"i_spike\": 66.0, \"isi\": 0.05222590121956029, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 45, \"stim\": 1, \"Log power\": 1.8493807156738755, \"Firing rate\": 70.69370050617624, \"Power\": 70.69370050617624, \"i_spike\": 65.5, \"isi\": 0.05341209958719847, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 46, \"stim\": 0, \"Log power\": 2.278284442298818, \"Firing rate\": 189.79485805771773, \"Power\": 189.79485805771773, \"i_spike\": 59.0, \"isi\": 0.05854495635726631, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 46, \"stim\": 1, \"Log power\": 1.9533853257729372, \"Firing rate\": 89.82253873876067, \"Power\": 89.82253873876067, \"i_spike\": 80.5, \"isi\": 0.043330345478925704, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 47, \"stim\": 0, \"Log power\": 2.000786573603222, \"Firing rate\": 100.18127937809187, \"Power\": 100.18127937809187, \"i_spike\": 55.5, \"isi\": 0.06353133496020094, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 47, \"stim\": 1, \"Log power\": 1.915459958304518, \"Firing rate\": 82.31139428019394, \"Power\": 82.31139428019394, \"i_spike\": 60.0, \"isi\": 0.05674268704317264, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 48, \"stim\": 0, \"Log power\": 1.722041976050747, \"Firing rate\": 52.728082245938886, \"Power\": 52.728082245938886, \"i_spike\": 57.5, \"isi\": 0.06089572372609493, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 48, \"stim\": 1, \"Log power\": 1.9500160967050648, \"Firing rate\": 89.12839721002277, \"Power\": 89.12839721002277, \"i_spike\": 81.0, \"isi\": 0.041996433467597946, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 49, \"stim\": 0, \"Log power\": 2.0799770859908677, \"Firing rate\": 120.22010030689178, \"Power\": 120.22010030689178, \"i_spike\": 59.0, \"isi\": 0.05718912583525473, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 49, \"stim\": 1, \"Log power\": 2.389018466686593, \"Firing rate\": 244.91673809640653, \"Power\": 244.91673809640653, \"i_spike\": 77.0, \"isi\": 0.044287128544366984, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 50, \"stim\": 0, \"Log power\": 2.3947582761463004, \"Firing rate\": 248.17514034369765, \"Power\": 248.17514034369765, \"i_spike\": 64.0, \"isi\": 0.054551854973539024, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 50, \"stim\": 1, \"Log power\": 2.074220071896661, \"Firing rate\": 118.63697700928783, \"Power\": 118.63697700928783, \"i_spike\": 71.0, \"isi\": 0.04873642884097521, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 51, \"stim\": 0, \"Log power\": 2.290428193168792, \"Firing rate\": 195.17679994286672, \"Power\": 195.17679994286672, \"i_spike\": 64.5, \"isi\": 0.0543907495448116, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 51, \"stim\": 1, \"Log power\": 2.1352746335778603, \"Firing rate\": 136.54463270800733, \"Power\": 136.54463270800733, \"i_spike\": 77.5, \"isi\": 0.04482107602743747, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 52, \"stim\": 0, \"Log power\": 1.9538187381998564, \"Firing rate\": 89.91222359123263, \"Power\": 89.91222359123263, \"i_spike\": 62.0, \"isi\": 0.05579194105793636, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 52, \"stim\": 1, \"Log power\": 2.0801641534611686, \"Firing rate\": 120.27189491901869, \"Power\": 120.27189491901869, \"i_spike\": 74.0, \"isi\": 0.04625952932986763, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 53, \"stim\": 0, \"Log power\": 1.70612338922617, \"Firing rate\": 50.830383838188354, \"Power\": 50.830383838188354, \"i_spike\": 53.0, \"isi\": 0.0655037393851745, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 53, \"stim\": 1, \"Log power\": 2.1727862370937014, \"Firing rate\": 148.86281837263735, \"Power\": 148.86281837263735, \"i_spike\": 73.0, \"isi\": 0.046751286254206756, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 54, \"stim\": 0, \"Log power\": 2.2406370503140987, \"Firing rate\": 174.03518142312774, \"Power\": 174.03518142312774, \"i_spike\": 57.0, \"isi\": 0.06130726853232248, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 54, \"stim\": 1, \"Log power\": 1.9385530697782305, \"Firing rate\": 86.80666465420352, \"Power\": 86.80666465420352, \"i_spike\": 71.0, \"isi\": 0.04906811469508298, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 55, \"stim\": 0, \"Log power\": 2.0838149412371427, \"Firing rate\": 121.28719191795192, \"Power\": 121.28719191795192, \"i_spike\": 58.0, \"isi\": 0.05960943092388339, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 55, \"stim\": 1, \"Log power\": 2.178450297516235, \"Firing rate\": 150.81699993571598, \"Power\": 150.81699993571598, \"i_spike\": 80.0, \"isi\": 0.043019613868388075, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 56, \"stim\": 0, \"Log power\": 1.947638975016476, \"Firing rate\": 88.64188339026938, \"Power\": 88.64188339026938, \"i_spike\": 65.5, \"isi\": 0.052462561015574866, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 56, \"stim\": 1, \"Log power\": 1.9920170910582269, \"Firing rate\": 98.17865791116809, \"Power\": 98.17865791116809, \"i_spike\": 79.0, \"isi\": 0.043632409857137476, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 57, \"stim\": 0, \"Log power\": 1.7306247816787002, \"Firing rate\": 53.780493327210344, \"Power\": 53.780493327210344, \"i_spike\": 45.0, \"isi\": 0.07824840991160138, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 57, \"stim\": 1, \"Log power\": 2.1359589368588563, \"Firing rate\": 136.75995110660125, \"Power\": 136.75995110660125, \"i_spike\": 86.0, \"isi\": 0.040615574703963715, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 58, \"stim\": 0, \"Log power\": 2.036849447064988, \"Firing rate\": 108.85526692223716, \"Power\": 108.85526692223716, \"i_spike\": 64.0, \"isi\": 0.05491747336030449, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 58, \"stim\": 1, \"Log power\": 1.931494963112017, \"Firing rate\": 85.40729419399811, \"Power\": 85.40729419399811, \"i_spike\": 82.5, \"isi\": 0.042321351439420195, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 59, \"stim\": 0, \"Log power\": 1.8879886175842346, \"Firing rate\": 77.26603341904224, \"Power\": 77.26603341904224, \"i_spike\": 62.0, \"isi\": 0.05575039809744501, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 59, \"stim\": 1, \"Log power\": 1.8421100332620293, \"Firing rate\": 69.52004319186932, \"Power\": 69.52004319186932, \"i_spike\": 71.5, \"isi\": 0.04794731195203566, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 60, \"stim\": 0, \"Log power\": 2.4391899653450095, \"Firing rate\": 274.909637616679, \"Power\": 274.909637616679, \"i_spike\": 59.5, \"isi\": 0.0572702645448569, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 60, \"stim\": 1, \"Log power\": 2.464328275830878, \"Firing rate\": 291.291811149653, \"Power\": 291.291811149653, \"i_spike\": 90.0, \"isi\": 0.03859238638465199, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 61, \"stim\": 0, \"Log power\": 1.643735949627737, \"Firing rate\": 44.02870882436891, \"Power\": 44.02870882436891, \"i_spike\": 58.0, \"isi\": 0.0606749308553595, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 61, \"stim\": 1, \"Log power\": 2.034685711373777, \"Firing rate\": 108.31427855583021, \"Power\": 108.31427855583021, \"i_spike\": 76.5, \"isi\": 0.04513350252425625, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 62, \"stim\": 0, \"Log power\": 1.865028683859883, \"Firing rate\": 73.2872935619889, \"Power\": 73.2872935619889, \"i_spike\": 65.5, \"isi\": 0.05314316905673091, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 62, \"stim\": 1, \"Log power\": 2.2549423384677465, \"Firing rate\": 179.8632093840352, \"Power\": 179.8632093840352, \"i_spike\": 90.0, \"isi\": 0.038709246237376094, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 63, \"stim\": 0, \"Log power\": 2.00410804969701, \"Firing rate\": 100.95040129954573, \"Power\": 100.95040129954573, \"i_spike\": 62.5, \"isi\": 0.055910373747440845, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 63, \"stim\": 1, \"Log power\": 2.5468486688444205, \"Firing rate\": 352.248107793503, \"Power\": 352.248107793503, \"i_spike\": 74.0, \"isi\": 0.0457100415574829, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 64, \"stim\": 0, \"Log power\": 2.2100406407956443, \"Firing rate\": 162.19618716493179, \"Power\": 162.19618716493179, \"i_spike\": 72.5, \"isi\": 0.047832157439283846, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 64, \"stim\": 1, \"Log power\": 2.206805334328521, \"Firing rate\": 160.9923850378919, \"Power\": 160.9923850378919, \"i_spike\": 78.5, \"isi\": 0.044735514069732626, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 65, \"stim\": 0, \"Log power\": 2.3216886947061224, \"Firing rate\": 209.74358880728713, \"Power\": 209.74358880728713, \"i_spike\": 59.0, \"isi\": 0.05821886664579464, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 65, \"stim\": 1, \"Log power\": 2.100987425882594, \"Firing rate\": 126.17910014581133, \"Power\": 126.17910014581133, \"i_spike\": 87.5, \"isi\": 0.03963874923645763, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 66, \"stim\": 0, \"Log power\": 1.8110817602834581, \"Firing rate\": 64.72644582925086, \"Power\": 64.72644582925086, \"i_spike\": 52.0, \"isi\": 0.06640358087592768, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 66, \"stim\": 1, \"Log power\": 2.1218311979207036, \"Firing rate\": 132.38268886250552, \"Power\": 132.38268886250552, \"i_spike\": 79.0, \"isi\": 0.04350156166751065, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 67, \"stim\": 0, \"Log power\": 2.2026781701888978, \"Firing rate\": 159.46969741879522, \"Power\": 159.46969741879522, \"i_spike\": 56.5, \"isi\": 0.06039985534920441, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 67, \"stim\": 1, \"Log power\": 2.34413067284426, \"Firing rate\": 220.8669189238454, \"Power\": 220.8669189238454, \"i_spike\": 74.0, \"isi\": 0.04672800497942512, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 68, \"stim\": 0, \"Log power\": 1.8164969353012714, \"Firing rate\": 65.5385660937755, \"Power\": 65.5385660937755, \"i_spike\": 56.5, \"isi\": 0.06222518933329653, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 68, \"stim\": 1, \"Log power\": 2.0275037207599116, \"Firing rate\": 106.53779911119778, \"Power\": 106.53779911119778, \"i_spike\": 66.5, \"isi\": 0.05208268039668318, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 69, \"stim\": 0, \"Log power\": 2.1450307532346056, \"Firing rate\": 139.64672441089303, \"Power\": 139.64672441089303, \"i_spike\": 55.5, \"isi\": 0.06323715264133578, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 69, \"stim\": 1, \"Log power\": 2.1361298759520073, \"Firing rate\": 136.81379066555488, \"Power\": 136.81379066555488, \"i_spike\": 79.5, \"isi\": 0.043796729119885316, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 0, \"stim\": 0, \"Log power\": 2.232038147432775, \"Firing rate\": 170.62322539551283, \"Power\": 170.62322539551283, \"i_spike\": 70.0, \"isi\": 0.0491130196515757, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 0, \"stim\": 1, \"Log power\": 2.599957413336581, \"Firing rate\": 398.0681343106645, \"Power\": 398.0681343106645, \"i_spike\": 86.5, \"isi\": 0.04000209845556195, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 1, \"stim\": 0, \"Log power\": 2.278330660292888, \"Firing rate\": 189.81505726531861, \"Power\": 189.81505726531861, \"i_spike\": 73.0, \"isi\": 0.04776099369998709, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 1, \"stim\": 1, \"Log power\": 2.3887631284314317, \"Firing rate\": 244.77278454657807, \"Power\": 244.77278454657807, \"i_spike\": 87.0, \"isi\": 0.03995345346002543, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 2, \"stim\": 0, \"Log power\": 2.569799502719949, \"Firing rate\": 371.36374496922457, \"Power\": 371.36374496922457, \"i_spike\": 77.5, \"isi\": 0.045316800774711764, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 2, \"stim\": 1, \"Log power\": 2.3344446471049305, \"Firing rate\": 215.99547207388645, \"Power\": 215.99547207388645, \"i_spike\": 80.0, \"isi\": 0.04385558032881749, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 3, \"stim\": 0, \"Log power\": 2.3294168207243575, \"Firing rate\": 213.50931181358135, \"Power\": 213.50931181358135, \"i_spike\": 80.0, \"isi\": 0.04392404358489545, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 3, \"stim\": 1, \"Log power\": 2.3918449649094096, \"Firing rate\": 246.5159163953205, \"Power\": 246.5159163953205, \"i_spike\": 80.0, \"isi\": 0.0436247428990221, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 4, \"stim\": 0, \"Log power\": 1.9115006065981393, \"Firing rate\": 81.5643926377616, \"Power\": 81.5643926377616, \"i_spike\": 65.5, \"isi\": 0.053447225091462686, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 4, \"stim\": 1, \"Log power\": 2.156842406228217, \"Firing rate\": 143.4968627395441, \"Power\": 143.4968627395441, \"i_spike\": 83.0, \"isi\": 0.04178583071021657, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 5, \"stim\": 0, \"Log power\": 2.1274437270755846, \"Firing rate\": 134.10461605091186, \"Power\": 134.10461605091186, \"i_spike\": 62.5, \"isi\": 0.05596335232460724, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 5, \"stim\": 1, \"Log power\": 2.551041432145341, \"Firing rate\": 355.66524778513855, \"Power\": 355.66524778513855, \"i_spike\": 88.0, \"isi\": 0.039725712216166754, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 6, \"stim\": 0, \"Log power\": 2.3185312179428226, \"Firing rate\": 208.22420755026928, \"Power\": 208.22420755026928, \"i_spike\": 61.5, \"isi\": 0.05611004939399525, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 6, \"stim\": 1, \"Log power\": 1.8782340435815654, \"Firing rate\": 75.54992605064632, \"Power\": 75.54992605064632, \"i_spike\": 73.0, \"isi\": 0.047713609074224415, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 7, \"stim\": 0, \"Log power\": 1.9065439461042506, \"Firing rate\": 80.63877953208015, \"Power\": 80.63877953208015, \"i_spike\": 68.0, \"isi\": 0.05105255314305981, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 7, \"stim\": 1, \"Log power\": 2.2543416656570066, \"Firing rate\": 179.61461248925124, \"Power\": 179.61461248925124, \"i_spike\": 93.0, \"isi\": 0.036988914784223705, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 8, \"stim\": 0, \"Log power\": 2.242001307384897, \"Firing rate\": 174.58274084902857, \"Power\": 174.58274084902857, \"i_spike\": 70.0, \"isi\": 0.04973202237338439, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 8, \"stim\": 1, \"Log power\": 2.3294069464255354, \"Firing rate\": 213.50445743281963, \"Power\": 213.50445743281963, \"i_spike\": 77.5, \"isi\": 0.04389890022446278, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 9, \"stim\": 0, \"Log power\": 2.493796821675739, \"Firing rate\": 311.7430798460456, \"Power\": 311.7430798460456, \"i_spike\": 73.5, \"isi\": 0.04780352772167597, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 9, \"stim\": 1, \"Log power\": 2.0100891562690846, \"Firing rate\": 102.3503085557127, \"Power\": 102.3503085557127, \"i_spike\": 84.5, \"isi\": 0.04119735626526618, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 10, \"stim\": 0, \"Log power\": 1.889819357963796, \"Firing rate\": 77.59243087017438, \"Power\": 77.59243087017438, \"i_spike\": 67.5, \"isi\": 0.05143337599283355, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 10, \"stim\": 1, \"Log power\": 2.2158402928766874, \"Firing rate\": 164.37671343771925, \"Power\": 164.37671343771925, \"i_spike\": 93.5, \"isi\": 0.0375359048585295, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 11, \"stim\": 0, \"Log power\": 2.3578016483359687, \"Firing rate\": 227.93008283528286, \"Power\": 227.93008283528286, \"i_spike\": 75.5, \"isi\": 0.046220060995291676, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 11, \"stim\": 1, \"Log power\": 2.50412573206576, \"Firing rate\": 319.2461967095441, \"Power\": 319.2461967095441, \"i_spike\": 91.0, \"isi\": 0.037483644789133456, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 12, \"stim\": 0, \"Log power\": 1.9212858295138626, \"Firing rate\": 83.42300498020799, \"Power\": 83.42300498020799, \"i_spike\": 62.0, \"isi\": 0.05519875987047357, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 12, \"stim\": 1, \"Log power\": 2.6213186217715485, \"Firing rate\": 418.1370219340618, \"Power\": 418.1370219340618, \"i_spike\": 91.0, \"isi\": 0.03732588057037207, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 13, \"stim\": 0, \"Log power\": 2.0969475751850832, \"Firing rate\": 125.01081173115705, \"Power\": 125.01081173115705, \"i_spike\": 78.5, \"isi\": 0.04424670921347804, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 13, \"stim\": 1, \"Log power\": 2.0969675268088532, \"Firing rate\": 125.01655489870704, \"Power\": 125.01655489870704, \"i_spike\": 96.5, \"isi\": 0.03638232765042332, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 14, \"stim\": 0, \"Log power\": 2.231039751335855, \"Firing rate\": 170.23143155121952, \"Power\": 170.23143155121952, \"i_spike\": 62.0, \"isi\": 0.05549114240926127, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 14, \"stim\": 1, \"Log power\": 2.112360305126023, \"Firing rate\": 129.5269994818085, \"Power\": 129.5269994818085, \"i_spike\": 88.5, \"isi\": 0.03883932239913435, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 15, \"stim\": 0, \"Log power\": 1.8763943639116516, \"Firing rate\": 75.23057200211062, \"Power\": 75.23057200211062, \"i_spike\": 62.0, \"isi\": 0.05589366131761056, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 15, \"stim\": 1, \"Log power\": 2.0940547028568357, \"Firing rate\": 124.18087134623556, \"Power\": 124.18087134623556, \"i_spike\": 84.5, \"isi\": 0.041267956622407356, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 16, \"stim\": 0, \"Log power\": 2.0836760266317165, \"Firing rate\": 121.2484028732266, \"Power\": 121.2484028732266, \"i_spike\": 69.0, \"isi\": 0.05096882642951272, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 16, \"stim\": 1, \"Log power\": 2.1692674286772835, \"Firing rate\": 147.6615519677361, \"Power\": 147.6615519677361, \"i_spike\": 94.0, \"isi\": 0.036918817343829013, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 17, \"stim\": 0, \"Log power\": 1.8546165444141078, \"Firing rate\": 71.55113782473569, \"Power\": 71.55113782473569, \"i_spike\": 64.5, \"isi\": 0.05391089243848297, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 17, \"stim\": 1, \"Log power\": 2.2311220797274656, \"Firing rate\": 170.26370506381744, \"Power\": 170.26370506381744, \"i_spike\": 72.0, \"isi\": 0.046489046451503806, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 18, \"stim\": 0, \"Log power\": 2.160610889616275, \"Firing rate\": 144.74743935721597, \"Power\": 144.74743935721597, \"i_spike\": 68.5, \"isi\": 0.05086969639486453, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 18, \"stim\": 1, \"Log power\": 2.0018789178030842, \"Firing rate\": 100.43357403659718, \"Power\": 100.43357403659718, \"i_spike\": 91.0, \"isi\": 0.03810469312612988, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 19, \"stim\": 0, \"Log power\": 2.8306025979423044, \"Firing rate\": 677.0217139722474, \"Power\": 677.0217139722474, \"i_spike\": 63.5, \"isi\": 0.05497249271354088, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 19, \"stim\": 1, \"Log power\": 2.0977683035824697, \"Firing rate\": 125.24728015306488, \"Power\": 125.24728015306488, \"i_spike\": 92.5, \"isi\": 0.03745661919011265, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 20, \"stim\": 0, \"Log power\": 1.8777543164783022, \"Firing rate\": 75.46651873457924, \"Power\": 75.46651873457924, \"i_spike\": 66.0, \"isi\": 0.05206064635436501, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 20, \"stim\": 1, \"Log power\": 2.211454274997359, \"Firing rate\": 162.72499804541417, \"Power\": 162.72499804541417, \"i_spike\": 80.5, \"isi\": 0.04301396543358983, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 21, \"stim\": 0, \"Log power\": 1.9098933967209388, \"Firing rate\": 81.26310207339468, \"Power\": 81.26310207339468, \"i_spike\": 69.5, \"isi\": 0.05034827323975612, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 21, \"stim\": 1, \"Log power\": 2.469721633650958, \"Firing rate\": 294.9318219187844, \"Power\": 294.9318219187844, \"i_spike\": 79.0, \"isi\": 0.043000843432657566, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 22, \"stim\": 0, \"Log power\": 2.039879985614243, \"Firing rate\": 109.61752335638403, \"Power\": 109.61752335638403, \"i_spike\": 75.0, \"isi\": 0.04673950155431668, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 22, \"stim\": 1, \"Log power\": 2.167107531171989, \"Firing rate\": 146.92900283412388, \"Power\": 146.92900283412388, \"i_spike\": 88.0, \"isi\": 0.03988897300081299, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 23, \"stim\": 0, \"Log power\": 2.12203420952307, \"Firing rate\": 132.44458581335738, \"Power\": 132.44458581335738, \"i_spike\": 72.5, \"isi\": 0.04765591026218666, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 23, \"stim\": 1, \"Log power\": 2.201032599733594, \"Firing rate\": 158.86659952072657, \"Power\": 158.86659952072657, \"i_spike\": 82.0, \"isi\": 0.0427264693927373, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 24, \"stim\": 0, \"Log power\": 2.1112377485313307, \"Firing rate\": 129.19263273329634, \"Power\": 129.19263273329634, \"i_spike\": 57.5, \"isi\": 0.06116911842536544, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 24, \"stim\": 1, \"Log power\": 2.092537549107306, \"Firing rate\": 123.747817769169, \"Power\": 123.747817769169, \"i_spike\": 85.5, \"isi\": 0.040531307879378455, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 25, \"stim\": 0, \"Log power\": 2.133925438227551, \"Firing rate\": 136.12109631364984, \"Power\": 136.12109631364984, \"i_spike\": 76.0, \"isi\": 0.04582546370705599, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 25, \"stim\": 1, \"Log power\": 2.221381809649203, \"Firing rate\": 166.48756812990516, \"Power\": 166.48756812990516, \"i_spike\": 88.5, \"isi\": 0.03962847795483152, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 26, \"stim\": 0, \"Log power\": 2.1469549125563647, \"Firing rate\": 140.26680752634317, \"Power\": 140.26680752634317, \"i_spike\": 65.5, \"isi\": 0.052703095911150126, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 26, \"stim\": 1, \"Log power\": 2.0790327258815346, \"Firing rate\": 119.95896937777833, \"Power\": 119.95896937777833, \"i_spike\": 81.5, \"isi\": 0.04313936191452062, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 27, \"stim\": 0, \"Log power\": 2.095262730469243, \"Firing rate\": 124.52677201893819, \"Power\": 124.52677201893819, \"i_spike\": 82.5, \"isi\": 0.04235340093771166, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 27, \"stim\": 1, \"Log power\": 2.128077775880001, \"Firing rate\": 134.30054525158872, \"Power\": 134.30054525158872, \"i_spike\": 89.5, \"isi\": 0.038255416798234056, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 28, \"stim\": 0, \"Log power\": 2.0035464763817874, \"Firing rate\": 100.81994968911617, \"Power\": 100.81994968911617, \"i_spike\": 60.5, \"isi\": 0.05628909414787073, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 28, \"stim\": 1, \"Log power\": 2.1511785476140175, \"Firing rate\": 141.63759622825782, \"Power\": 141.63759622825782, \"i_spike\": 71.0, \"isi\": 0.04905386223218206, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 29, \"stim\": 0, \"Log power\": 2.0271904745581186, \"Firing rate\": 106.46098365581244, \"Power\": 106.46098365581244, \"i_spike\": 63.0, \"isi\": 0.05587379286121105, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 29, \"stim\": 1, \"Log power\": 2.82166271152805, \"Firing rate\": 663.2277841525802, \"Power\": 663.2277841525802, \"i_spike\": 79.0, \"isi\": 0.04378802341130802, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 30, \"stim\": 0, \"Log power\": 1.9368112244218252, \"Firing rate\": 86.45920232871202, \"Power\": 86.45920232871202, \"i_spike\": 69.5, \"isi\": 0.050053824959915276, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 30, \"stim\": 1, \"Log power\": 2.142940239147891, \"Firing rate\": 138.97613807086597, \"Power\": 138.97613807086597, \"i_spike\": 80.0, \"isi\": 0.04323590081742858, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 31, \"stim\": 0, \"Log power\": 2.578661903769391, \"Firing rate\": 379.0198049383157, \"Power\": 379.0198049383157, \"i_spike\": 66.0, \"isi\": 0.052747029630007755, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 31, \"stim\": 1, \"Log power\": 1.9758127140433446, \"Firing rate\": 94.58291922729767, \"Power\": 94.58291922729767, \"i_spike\": 69.5, \"isi\": 0.04965834393131281, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 32, \"stim\": 0, \"Log power\": 2.0823911555240735, \"Firing rate\": 120.89021654784788, \"Power\": 120.89021654784788, \"i_spike\": 75.5, \"isi\": 0.04600020447219519, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 32, \"stim\": 1, \"Log power\": 2.202518278208964, \"Firing rate\": 159.41099708163156, \"Power\": 159.41099708163156, \"i_spike\": 70.0, \"isi\": 0.04783331306717344, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 33, \"stim\": 0, \"Log power\": 1.9097496627139794, \"Firing rate\": 81.23621170492812, \"Power\": 81.23621170492812, \"i_spike\": 68.5, \"isi\": 0.05114018440803222, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 33, \"stim\": 1, \"Log power\": 1.9007914064635327, \"Firing rate\": 79.57770434232367, \"Power\": 79.57770434232367, \"i_spike\": 88.5, \"isi\": 0.03929077635522098, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 34, \"stim\": 0, \"Log power\": 1.8613063646955428, \"Firing rate\": 72.66183556372675, \"Power\": 72.66183556372675, \"i_spike\": 71.5, \"isi\": 0.048652076906969294, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 34, \"stim\": 1, \"Log power\": 1.983298333805918, \"Firing rate\": 96.22730742730312, \"Power\": 96.22730742730312, \"i_spike\": 93.0, \"isi\": 0.03775425935173657, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 35, \"stim\": 0, \"Log power\": 2.303264757550591, \"Firing rate\": 201.03179828197327, \"Power\": 201.03179828197327, \"i_spike\": 73.5, \"isi\": 0.04643742276038672, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 35, \"stim\": 1, \"Log power\": 2.0625307632296823, \"Firing rate\": 115.48637865154846, \"Power\": 115.48637865154846, \"i_spike\": 75.5, \"isi\": 0.045075323441407404, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 36, \"stim\": 0, \"Log power\": 2.4779416635478615, \"Firing rate\": 300.56725396140996, \"Power\": 300.56725396140996, \"i_spike\": 59.0, \"isi\": 0.057861074937277504, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 36, \"stim\": 1, \"Log power\": 2.032555307965476, \"Firing rate\": 107.78425095956347, \"Power\": 107.78425095956347, \"i_spike\": 84.0, \"isi\": 0.04136941517833224, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 37, \"stim\": 0, \"Log power\": 1.7928724485060814, \"Firing rate\": 62.068671290687455, \"Power\": 62.068671290687455, \"i_spike\": 66.5, \"isi\": 0.051625259341073856, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 37, \"stim\": 1, \"Log power\": 2.202854024414535, \"Firing rate\": 159.53428285505737, \"Power\": 159.53428285505737, \"i_spike\": 87.5, \"isi\": 0.039990808735530535, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 38, \"stim\": 0, \"Log power\": 2.0562441439289505, \"Firing rate\": 113.82669966423785, \"Power\": 113.82669966423785, \"i_spike\": 74.0, \"isi\": 0.04747140920605517, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 38, \"stim\": 1, \"Log power\": 3.0256981333491924, \"Firing rate\": 1060.9578570000572, \"Power\": 1060.9578570000572, \"i_spike\": 79.0, \"isi\": 0.04364780345053541, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 39, \"stim\": 0, \"Log power\": 1.8179321498739058, \"Firing rate\": 65.75550990440746, \"Power\": 65.75550990440746, \"i_spike\": 70.0, \"isi\": 0.04979511086536484, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 39, \"stim\": 1, \"Log power\": 2.0444777454384666, \"Firing rate\": 110.78417947586794, \"Power\": 110.78417947586794, \"i_spike\": 93.0, \"isi\": 0.03737886976706276, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 40, \"stim\": 0, \"Log power\": 1.8791649756238011, \"Firing rate\": 75.71204480576654, \"Power\": 75.71204480576654, \"i_spike\": 75.5, \"isi\": 0.04588671514072249, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 40, \"stim\": 1, \"Log power\": 2.1788081516688185, \"Firing rate\": 150.94132279411852, \"Power\": 150.94132279411852, \"i_spike\": 102.5, \"isi\": 0.03413982107180815, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 41, \"stim\": 0, \"Log power\": 2.0681295873894516, \"Firing rate\": 116.98484053227716, \"Power\": 116.98484053227716, \"i_spike\": 58.0, \"isi\": 0.060451676756293524, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 41, \"stim\": 1, \"Log power\": 2.0113092800917785, \"Firing rate\": 102.6382597979464, \"Power\": 102.6382597979464, \"i_spike\": 84.5, \"isi\": 0.04076096428259957, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 42, \"stim\": 0, \"Log power\": 2.203409983603535, \"Firing rate\": 159.73864038045465, \"Power\": 159.73864038045465, \"i_spike\": 80.5, \"isi\": 0.04265078877116619, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 42, \"stim\": 1, \"Log power\": 1.9982770016666047, \"Firing rate\": 99.60405092591064, \"Power\": 99.60405092591064, \"i_spike\": 80.0, \"isi\": 0.04385187498495034, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 43, \"stim\": 0, \"Log power\": 2.4765270844787897, \"Firing rate\": 299.5898423761487, \"Power\": 299.5898423761487, \"i_spike\": 70.5, \"isi\": 0.04945560394498052, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 43, \"stim\": 1, \"Log power\": 2.222737695898371, \"Firing rate\": 167.00816178916187, \"Power\": 167.00816178916187, \"i_spike\": 93.5, \"isi\": 0.03748781691017344, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 44, \"stim\": 0, \"Log power\": 2.170070048233791, \"Firing rate\": 147.93469757869522, \"Power\": 147.93469757869522, \"i_spike\": 71.0, \"isi\": 0.04877167378863692, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 44, \"stim\": 1, \"Log power\": 2.3864072376652525, \"Firing rate\": 243.44857548872312, \"Power\": 243.44857548872312, \"i_spike\": 91.5, \"isi\": 0.03682931140140326, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 45, \"stim\": 0, \"Log power\": 2.641681465797716, \"Firing rate\": 438.20917443664143, \"Power\": 438.20917443664143, \"i_spike\": 77.5, \"isi\": 0.0452759724091139, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 45, \"stim\": 1, \"Log power\": 2.1534415281003594, \"Firing rate\": 142.37755415507456, \"Power\": 142.37755415507456, \"i_spike\": 78.0, \"isi\": 0.04433230736020616, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 46, \"stim\": 0, \"Log power\": 2.021450437034387, \"Firing rate\": 105.06315468564793, \"Power\": 105.06315468564793, \"i_spike\": 67.5, \"isi\": 0.05185954016231027, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 46, \"stim\": 1, \"Log power\": 2.3589690108749433, \"Firing rate\": 228.5435720068663, \"Power\": 228.5435720068663, \"i_spike\": 89.0, \"isi\": 0.03924991221174787, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 47, \"stim\": 0, \"Log power\": 2.2385221162693583, \"Firing rate\": 173.18972246642412, \"Power\": 173.18972246642412, \"i_spike\": 56.5, \"isi\": 0.062210298760414215, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 47, \"stim\": 1, \"Log power\": 2.3720203998947835, \"Firing rate\": 235.51599090316526, \"Power\": 235.51599090316526, \"i_spike\": 81.5, \"isi\": 0.04295886454546449, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 48, \"stim\": 0, \"Log power\": 2.3585378687733174, \"Firing rate\": 228.3167999283142, \"Power\": 228.3167999283142, \"i_spike\": 70.0, \"isi\": 0.05004490648204437, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 48, \"stim\": 1, \"Log power\": 2.63234144834843, \"Firing rate\": 428.88558367575286, \"Power\": 428.88558367575286, \"i_spike\": 91.5, \"isi\": 0.03806742624086263, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 49, \"stim\": 0, \"Log power\": 2.061546266851199, \"Firing rate\": 115.2248806226435, \"Power\": 115.2248806226435, \"i_spike\": 70.0, \"isi\": 0.049045682871381585, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 49, \"stim\": 1, \"Log power\": 2.300847178584243, \"Firing rate\": 199.9158273410503, \"Power\": 199.9158273410503, \"i_spike\": 79.0, \"isi\": 0.04399934402707993, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 50, \"stim\": 0, \"Log power\": 2.287512271691143, \"Firing rate\": 193.87074164836233, \"Power\": 193.87074164836233, \"i_spike\": 82.0, \"isi\": 0.04285623260336847, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 50, \"stim\": 1, \"Log power\": 2.069409366386217, \"Firing rate\": 117.33007989091897, \"Power\": 117.33007989091897, \"i_spike\": 79.0, \"isi\": 0.04350847596629497, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 51, \"stim\": 0, \"Log power\": 1.8739209578075193, \"Firing rate\": 74.80333450246087, \"Power\": 74.80333450246087, \"i_spike\": 66.0, \"isi\": 0.05232826780496725, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 51, \"stim\": 1, \"Log power\": 2.0484774100130307, \"Firing rate\": 111.80916651230424, \"Power\": 111.80916651230424, \"i_spike\": 94.0, \"isi\": 0.037137675083695025, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 52, \"stim\": 0, \"Log power\": 2.2532583135765667, \"Firing rate\": 179.16712034816658, \"Power\": 179.16712034816658, \"i_spike\": 84.0, \"isi\": 0.04101481659557463, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 52, \"stim\": 1, \"Log power\": 2.045543784057372, \"Firing rate\": 111.05644929349369, \"Power\": 111.05644929349369, \"i_spike\": 72.5, \"isi\": 0.047111487819189696, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 53, \"stim\": 0, \"Log power\": 1.7634131288762156, \"Firing rate\": 57.998014856022365, \"Power\": 57.998014856022365, \"i_spike\": 64.0, \"isi\": 0.05361432591956375, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 53, \"stim\": 1, \"Log power\": 2.0245437420278645, \"Firing rate\": 105.81414863660403, \"Power\": 105.81414863660403, \"i_spike\": 88.0, \"isi\": 0.03909789468441393, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 54, \"stim\": 0, \"Log power\": 2.1945391248662602, \"Firing rate\": 156.50893091621558, \"Power\": 156.50893091621558, \"i_spike\": 61.5, \"isi\": 0.05702201652717915, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 54, \"stim\": 1, \"Log power\": 2.2843292450877324, \"Firing rate\": 192.45502060478535, \"Power\": 192.45502060478535, \"i_spike\": 82.5, \"isi\": 0.04244989134563342, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 55, \"stim\": 0, \"Log power\": 1.9046711807268994, \"Firing rate\": 80.29179752056864, \"Power\": 80.29179752056864, \"i_spike\": 68.0, \"isi\": 0.0515410512918051, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 55, \"stim\": 1, \"Log power\": 3.0374545786681884, \"Firing rate\": 1090.0704797870224, \"Power\": 1090.0704797870224, \"i_spike\": 77.5, \"isi\": 0.04414683503429014, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 56, \"stim\": 0, \"Log power\": 2.0817884216740477, \"Firing rate\": 120.72255591749642, \"Power\": 120.72255591749642, \"i_spike\": 80.5, \"isi\": 0.04281893409295219, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 56, \"stim\": 1, \"Log power\": 1.8074663748602113, \"Firing rate\": 64.18985207543321, \"Power\": 64.18985207543321, \"i_spike\": 75.5, \"isi\": 0.04604935251046432, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 57, \"stim\": 0, \"Log power\": 2.3205078294918398, \"Firing rate\": 209.1740616811728, \"Power\": 209.1740616811728, \"i_spike\": 69.0, \"isi\": 0.05050950728034611, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 57, \"stim\": 1, \"Log power\": 2.1111916160700117, \"Firing rate\": 129.1789101145487, \"Power\": 129.1789101145487, \"i_spike\": 93.5, \"isi\": 0.036639775378327896, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 58, \"stim\": 0, \"Log power\": 2.0551473270373064, \"Firing rate\": 113.53959141570147, \"Power\": 113.53959141570147, \"i_spike\": 65.0, \"isi\": 0.051598564277225104, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 58, \"stim\": 1, \"Log power\": 2.428625275031335, \"Firing rate\": 268.30284327713224, \"Power\": 268.30284327713224, \"i_spike\": 91.5, \"isi\": 0.037486935189800424, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 59, \"stim\": 0, \"Log power\": 1.9777708217953112, \"Firing rate\": 95.01032896374592, \"Power\": 95.01032896374592, \"i_spike\": 72.0, \"isi\": 0.04836697693215443, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 59, \"stim\": 1, \"Log power\": 2.2206753088496116, \"Firing rate\": 166.21694995949937, \"Power\": 166.21694995949937, \"i_spike\": 84.0, \"isi\": 0.04159242484725453, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 60, \"stim\": 0, \"Log power\": 2.0748668133734274, \"Firing rate\": 118.81378011333257, \"Power\": 118.81378011333257, \"i_spike\": 64.5, \"isi\": 0.05360323455215154, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 60, \"stim\": 1, \"Log power\": 1.8245191993437966, \"Firing rate\": 66.76044138498695, \"Power\": 66.76044138498695, \"i_spike\": 75.5, \"isi\": 0.046406207187297016, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 61, \"stim\": 0, \"Log power\": 1.7624618536341912, \"Firing rate\": 57.871115487580916, \"Power\": 57.871115487580916, \"i_spike\": 71.0, \"isi\": 0.04848991815553226, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 61, \"stim\": 1, \"Log power\": 2.7888482581179757, \"Firing rate\": 614.9619683203597, \"Power\": 614.9619683203597, \"i_spike\": 93.5, \"isi\": 0.03747178381241545, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 62, \"stim\": 0, \"Log power\": 1.980958428493352, \"Firing rate\": 95.71024512146126, \"Power\": 95.71024512146126, \"i_spike\": 60.5, \"isi\": 0.05816532362887076, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 62, \"stim\": 1, \"Log power\": 1.8912197346369923, \"Firing rate\": 77.84303042261719, \"Power\": 77.84303042261719, \"i_spike\": 78.0, \"isi\": 0.04501908822135116, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 63, \"stim\": 0, \"Log power\": 1.9068895173624372, \"Firing rate\": 80.70296992677737, \"Power\": 80.70296992677737, \"i_spike\": 73.5, \"isi\": 0.04733946934783415, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 63, \"stim\": 1, \"Log power\": 2.234515639911591, \"Firing rate\": 171.59935057564164, \"Power\": 171.59935057564164, \"i_spike\": 85.0, \"isi\": 0.04126163702068313, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 64, \"stim\": 0, \"Log power\": 2.4227416682437934, \"Firing rate\": 264.6925197473862, \"Power\": 264.6925197473862, \"i_spike\": 68.0, \"isi\": 0.051644432696175586, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 64, \"stim\": 1, \"Log power\": 2.184095251891732, \"Firing rate\": 152.79011293023987, \"Power\": 152.79011293023987, \"i_spike\": 75.0, \"isi\": 0.045862840979918024, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 65, \"stim\": 0, \"Log power\": 1.8777324977191123, \"Firing rate\": 75.46272742590195, \"Power\": 75.46272742590195, \"i_spike\": 74.0, \"isi\": 0.046939977074058704, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 65, \"stim\": 1, \"Log power\": 2.1641919566166776, \"Firing rate\": 145.9459193509549, \"Power\": 145.9459193509549, \"i_spike\": 88.0, \"isi\": 0.039594622444447496, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 66, \"stim\": 0, \"Log power\": 1.9200786002328414, \"Firing rate\": 83.19143204309013, \"Power\": 83.19143204309013, \"i_spike\": 77.0, \"isi\": 0.04466927783319466, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 66, \"stim\": 1, \"Log power\": 2.2188946085858565, \"Firing rate\": 165.53682020535805, \"Power\": 165.53682020535805, \"i_spike\": 89.0, \"isi\": 0.03843920379212688, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 67, \"stim\": 0, \"Log power\": 1.9693104848895153, \"Firing rate\": 93.17737791393978, \"Power\": 93.17737791393978, \"i_spike\": 73.5, \"isi\": 0.046612652853912764, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 67, \"stim\": 1, \"Log power\": 2.1660592971445736, \"Firing rate\": 146.57479557139985, \"Power\": 146.57479557139985, \"i_spike\": 75.5, \"isi\": 0.04585462244265719, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 68, \"stim\": 0, \"Log power\": 2.231103875856838, \"Firing rate\": 170.25656844654443, \"Power\": 170.25656844654443, \"i_spike\": 64.5, \"isi\": 0.05432441582127602, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 68, \"stim\": 1, \"Log power\": 2.069741379943365, \"Firing rate\": 117.41981179637644, \"Power\": 117.41981179637644, \"i_spike\": 79.0, \"isi\": 0.04378843197920455, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 69, \"stim\": 0, \"Log power\": 2.134310897397825, \"Firing rate\": 136.241964568881, \"Power\": 136.241964568881, \"i_spike\": 74.5, \"isi\": 0.046998844339694056, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 69, \"stim\": 1, \"Log power\": 2.120773951213158, \"Firing rate\": 132.0608083294635, \"Power\": 132.0608083294635, \"i_spike\": 76.5, \"isi\": 0.04470880710258207, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 0, \"stim\": 0, \"Log power\": 2.3902767300347882, \"Firing rate\": 245.62735410219472, \"Power\": 245.62735410219472, \"i_spike\": 81.5, \"isi\": 0.042619869511965974, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 0, \"stim\": 1, \"Log power\": 2.2694304804073924, \"Firing rate\": 185.96468568385507, \"Power\": 185.96468568385507, \"i_spike\": 96.0, \"isi\": 0.03652254517150431, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 1, \"stim\": 0, \"Log power\": 1.958521828135469, \"Firing rate\": 90.89119808692828, \"Power\": 90.89119808692828, \"i_spike\": 72.5, \"isi\": 0.04835148192954819, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 1, \"stim\": 1, \"Log power\": 2.012420917851579, \"Firing rate\": 102.9013133657859, \"Power\": 102.9013133657859, \"i_spike\": 80.0, \"isi\": 0.042661149578471884, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 2, \"stim\": 0, \"Log power\": 1.9747539514340826, \"Firing rate\": 94.35261721931417, \"Power\": 94.35261721931417, \"i_spike\": 80.0, \"isi\": 0.04352966903790672, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 2, \"stim\": 1, \"Log power\": 2.15969611144152, \"Firing rate\": 144.442870801434, \"Power\": 144.442870801434, \"i_spike\": 103.5, \"isi\": 0.033327778965951835, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 3, \"stim\": 0, \"Log power\": 2.379101107660456, \"Firing rate\": 239.38730066974614, \"Power\": 239.38730066974614, \"i_spike\": 82.5, \"isi\": 0.0423398023038074, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 3, \"stim\": 1, \"Log power\": 2.277140927013535, \"Firing rate\": 189.29577770542915, \"Power\": 189.29577770542915, \"i_spike\": 85.0, \"isi\": 0.041298582475299835, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 4, \"stim\": 0, \"Log power\": 2.061660040023107, \"Firing rate\": 115.25507031652876, \"Power\": 115.25507031652876, \"i_spike\": 79.5, \"isi\": 0.04399573266904359, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 4, \"stim\": 1, \"Log power\": 2.489822796194061, \"Firing rate\": 308.9034766237801, \"Power\": 308.9034766237801, \"i_spike\": 100.5, \"isi\": 0.034746292496689514, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 5, \"stim\": 0, \"Log power\": 1.9184294788959952, \"Firing rate\": 82.87613303829859, \"Power\": 82.87613303829859, \"i_spike\": 70.5, \"isi\": 0.048490515329570515, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 5, \"stim\": 1, \"Log power\": 2.228859167578203, \"Firing rate\": 169.3788451973878, \"Power\": 169.3788451973878, \"i_spike\": 89.0, \"isi\": 0.03933014861247911, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 6, \"stim\": 0, \"Log power\": 1.9155387110296833, \"Firing rate\": 82.32632155798872, \"Power\": 82.32632155798872, \"i_spike\": 69.5, \"isi\": 0.049537933322936274, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 6, \"stim\": 1, \"Log power\": 2.1536463895832263, \"Firing rate\": 142.4447310558281, \"Power\": 142.4447310558281, \"i_spike\": 92.5, \"isi\": 0.03767784483674681, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 7, \"stim\": 0, \"Log power\": 2.0768017021945697, \"Firing rate\": 119.34430568394144, \"Power\": 119.34430568394144, \"i_spike\": 102.5, \"isi\": 0.03400083063420156, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 7, \"stim\": 1, \"Log power\": 2.276752620104717, \"Firing rate\": 189.12660215647745, \"Power\": 189.12660215647745, \"i_spike\": 93.5, \"isi\": 0.03741409744096958, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 8, \"stim\": 0, \"Log power\": 2.597536746632061, \"Firing rate\": 395.855557647055, \"Power\": 395.855557647055, \"i_spike\": 83.0, \"isi\": 0.042003623329564505, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 8, \"stim\": 1, \"Log power\": 2.3932027281005084, \"Firing rate\": 247.28782119766916, \"Power\": 247.28782119766916, \"i_spike\": 92.5, \"isi\": 0.03793708648814726, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 9, \"stim\": 0, \"Log power\": 1.9747332367736905, \"Firing rate\": 94.34811696454868, \"Power\": 94.34811696454868, \"i_spike\": 69.0, \"isi\": 0.050566989140269254, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 9, \"stim\": 1, \"Log power\": 2.0237030045198607, \"Firing rate\": 105.60950438360523, \"Power\": 105.60950438360523, \"i_spike\": 75.0, \"isi\": 0.04644474487428645, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 10, \"stim\": 0, \"Log power\": 2.125757880868325, \"Firing rate\": 133.5850572347659, \"Power\": 133.5850572347659, \"i_spike\": 74.0, \"isi\": 0.046432698345023615, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 10, \"stim\": 1, \"Log power\": 2.374827729377504, \"Firing rate\": 237.04332446859914, \"Power\": 237.04332446859914, \"i_spike\": 88.5, \"isi\": 0.03931981800664395, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 11, \"stim\": 0, \"Log power\": 2.3681047233513417, \"Firing rate\": 233.40208072013024, \"Power\": 233.40208072013024, \"i_spike\": 84.0, \"isi\": 0.04168243687481907, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 11, \"stim\": 1, \"Log power\": 2.8367287133564165, \"Firing rate\": 686.6393894624349, \"Power\": 686.6393894624349, \"i_spike\": 98.5, \"isi\": 0.03533258070787268, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 12, \"stim\": 0, \"Log power\": 2.017353098976058, \"Firing rate\": 104.07660067816654, \"Power\": 104.07660067816654, \"i_spike\": 88.0, \"isi\": 0.039828091088892015, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 12, \"stim\": 1, \"Log power\": 2.2747759486551486, \"Firing rate\": 188.2677570658957, \"Power\": 188.2677570658957, \"i_spike\": 100.0, \"isi\": 0.03462845859722044, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 13, \"stim\": 0, \"Log power\": 2.264587162030694, \"Firing rate\": 183.90230050542502, \"Power\": 183.90230050542502, \"i_spike\": 87.0, \"isi\": 0.040226572332675126, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 13, \"stim\": 1, \"Log power\": 2.077774030806954, \"Firing rate\": 119.61180132639494, \"Power\": 119.61180132639494, \"i_spike\": 97.0, \"isi\": 0.03593715763533768, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 14, \"stim\": 0, \"Log power\": 2.8268829403591136, \"Firing rate\": 671.2479005259485, \"Power\": 671.2479005259485, \"i_spike\": 84.0, \"isi\": 0.04168142058901511, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 14, \"stim\": 1, \"Log power\": 2.102540691069691, \"Firing rate\": 126.63119086045222, \"Power\": 126.63119086045222, \"i_spike\": 90.5, \"isi\": 0.038573118123092005, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 15, \"stim\": 0, \"Log power\": 2.477194369687193, \"Firing rate\": 300.0505102819587, \"Power\": 300.0505102819587, \"i_spike\": 82.5, \"isi\": 0.041769315610210356, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 15, \"stim\": 1, \"Log power\": 2.1638899417126423, \"Firing rate\": 145.84446164882405, \"Power\": 145.84446164882405, \"i_spike\": 95.5, \"isi\": 0.03617104505627241, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 16, \"stim\": 0, \"Log power\": 1.8870726689834516, \"Firing rate\": 77.10324724501879, \"Power\": 77.10324724501879, \"i_spike\": 63.0, \"isi\": 0.05554194230853322, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 16, \"stim\": 1, \"Log power\": 3.938981762732595, \"Firing rate\": 8689.23939918732, \"Power\": 8689.23939918732, \"i_spike\": 99.0, \"isi\": 0.03549288155637231, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 17, \"stim\": 0, \"Log power\": 2.1122896813085177, \"Firing rate\": 129.50593785701673, \"Power\": 129.50593785701673, \"i_spike\": 62.0, \"isi\": 0.05668484492334408, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 17, \"stim\": 1, \"Log power\": 2.2813299927825432, \"Firing rate\": 191.1304986176846, \"Power\": 191.1304986176846, \"i_spike\": 93.0, \"isi\": 0.037662702254703743, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 18, \"stim\": 0, \"Log power\": 2.233663936121563, \"Firing rate\": 171.26315334930743, \"Power\": 171.26315334930743, \"i_spike\": 77.0, \"isi\": 0.045263656289490986, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 18, \"stim\": 1, \"Log power\": 2.1567684957264484, \"Firing rate\": 143.47244377238135, \"Power\": 143.47244377238135, \"i_spike\": 81.0, \"isi\": 0.04184487908693864, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 19, \"stim\": 0, \"Log power\": 1.9082146423163502, \"Firing rate\": 80.94958792563553, \"Power\": 80.94958792563553, \"i_spike\": 72.0, \"isi\": 0.04773241632387789, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 19, \"stim\": 1, \"Log power\": 2.3791115910248064, \"Firing rate\": 239.39307927087594, \"Power\": 239.39307927087594, \"i_spike\": 99.0, \"isi\": 0.03498076700771902, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 20, \"stim\": 0, \"Log power\": 2.722188914724935, \"Firing rate\": 527.4592522036695, \"Power\": 527.4592522036695, \"i_spike\": 90.5, \"isi\": 0.03886800764516744, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 20, \"stim\": 1, \"Log power\": 1.959231475948763, \"Firing rate\": 91.03983793677432, \"Power\": 91.03983793677432, \"i_spike\": 78.5, \"isi\": 0.044704558164798854, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 21, \"stim\": 0, \"Log power\": 3.2185817164864834, \"Firing rate\": 1654.1760038644406, \"Power\": 1654.1760038644406, \"i_spike\": 80.0, \"isi\": 0.04370227445188171, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 21, \"stim\": 1, \"Log power\": 2.197284872051377, \"Firing rate\": 157.5015644837986, \"Power\": 157.5015644837986, \"i_spike\": 78.5, \"isi\": 0.04447004454967937, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 22, \"stim\": 0, \"Log power\": 2.1005118006246093, \"Firing rate\": 126.04098852138367, \"Power\": 126.04098852138367, \"i_spike\": 77.0, \"isi\": 0.04470656964627002, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 22, \"stim\": 1, \"Log power\": 2.391208603791071, \"Firing rate\": 246.15496714153875, \"Power\": 246.15496714153875, \"i_spike\": 86.5, \"isi\": 0.03954045664914847, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 23, \"stim\": 0, \"Log power\": 2.1054385098917696, \"Firing rate\": 127.47895945425998, \"Power\": 127.47895945425998, \"i_spike\": 80.0, \"isi\": 0.0432753395838561, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 23, \"stim\": 1, \"Log power\": 2.481772420974368, \"Firing rate\": 303.2301780793786, \"Power\": 303.2301780793786, \"i_spike\": 92.0, \"isi\": 0.03783006298127069, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 24, \"stim\": 0, \"Log power\": 2.035176308442397, \"Firing rate\": 108.4367039950008, \"Power\": 108.4367039950008, \"i_spike\": 77.0, \"isi\": 0.044684563068532565, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 24, \"stim\": 1, \"Log power\": 2.202137467844878, \"Firing rate\": 159.27127908969848, \"Power\": 159.27127908969848, \"i_spike\": 89.5, \"isi\": 0.039267627829104146, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 25, \"stim\": 0, \"Log power\": 2.408800314722153, \"Firing rate\": 256.33051774271803, \"Power\": 256.33051774271803, \"i_spike\": 82.0, \"isi\": 0.042873237473504446, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 25, \"stim\": 1, \"Log power\": 2.350376414421529, \"Firing rate\": 224.0662338036484, \"Power\": 224.0662338036484, \"i_spike\": 101.0, \"isi\": 0.034542656351622736, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 26, \"stim\": 0, \"Log power\": 1.964445577030255, \"Firing rate\": 92.13944183232938, \"Power\": 92.13944183232938, \"i_spike\": 79.5, \"isi\": 0.04413428271376092, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 26, \"stim\": 1, \"Log power\": 2.1856007112471443, \"Firing rate\": 153.3206709976319, \"Power\": 153.3206709976319, \"i_spike\": 90.5, \"isi\": 0.03813454718769625, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 27, \"stim\": 0, \"Log power\": 3.064853377658025, \"Firing rate\": 1161.0565628711975, \"Power\": 1161.0565628711975, \"i_spike\": 84.5, \"isi\": 0.04155041385228782, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 27, \"stim\": 1, \"Log power\": 2.1488757743857145, \"Firing rate\": 140.8885743034591, \"Power\": 140.8885743034591, \"i_spike\": 96.0, \"isi\": 0.03629880237469381, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 28, \"stim\": 0, \"Log power\": 2.0146860820502988, \"Firing rate\": 103.43942126805995, \"Power\": 103.43942126805995, \"i_spike\": 77.5, \"isi\": 0.04499926589592764, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 28, \"stim\": 1, \"Log power\": 2.012099228830681, \"Firing rate\": 102.82512090313094, \"Power\": 102.82512090313094, \"i_spike\": 80.5, \"isi\": 0.04333897792230511, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 29, \"stim\": 0, \"Log power\": 2.438313925221379, \"Firing rate\": 274.3556606532389, \"Power\": 274.3556606532389, \"i_spike\": 75.5, \"isi\": 0.04611688402579955, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 29, \"stim\": 1, \"Log power\": 2.203991896115611, \"Firing rate\": 159.95281813268588, \"Power\": 159.95281813268588, \"i_spike\": 92.0, \"isi\": 0.03778943593927792, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 30, \"stim\": 0, \"Log power\": 2.437468495754161, \"Firing rate\": 273.82209932041843, \"Power\": 273.82209932041843, \"i_spike\": 79.5, \"isi\": 0.04411339180947841, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 30, \"stim\": 1, \"Log power\": 2.37144540499986, \"Firing rate\": 235.20438002395287, \"Power\": 235.20438002395287, \"i_spike\": 85.5, \"isi\": 0.04016451214004707, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 31, \"stim\": 0, \"Log power\": 3.0151572267148308, \"Firing rate\": 1035.5169848567782, \"Power\": 1035.5169848567782, \"i_spike\": 68.0, \"isi\": 0.050275996658705545, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 31, \"stim\": 1, \"Log power\": 2.3357834522839918, \"Firing rate\": 216.6623514614178, \"Power\": 216.6623514614178, \"i_spike\": 104.5, \"isi\": 0.03354631897455346, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 32, \"stim\": 0, \"Log power\": 2.117220677249924, \"Firing rate\": 130.98473242230142, \"Power\": 130.98473242230142, \"i_spike\": 74.0, \"isi\": 0.046939794374730615, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 32, \"stim\": 1, \"Log power\": 2.031157568395182, \"Firing rate\": 107.43791421165186, \"Power\": 107.43791421165186, \"i_spike\": 86.5, \"isi\": 0.04044583633215689, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 33, \"stim\": 0, \"Log power\": 2.278923560850274, \"Firing rate\": 190.07437050538292, \"Power\": 190.07437050538292, \"i_spike\": 75.0, \"isi\": 0.04622083901946486, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 33, \"stim\": 1, \"Log power\": 2.1354549030091725, \"Firing rate\": 136.60132219785848, \"Power\": 136.60132219785848, \"i_spike\": 91.5, \"isi\": 0.038309406313921705, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 34, \"stim\": 0, \"Log power\": 2.035169873468667, \"Firing rate\": 108.43509729217311, \"Power\": 108.43509729217311, \"i_spike\": 83.5, \"isi\": 0.04187324019096305, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 34, \"stim\": 1, \"Log power\": 2.3502839584161985, \"Firing rate\": 224.01853790880466, \"Power\": 224.01853790880466, \"i_spike\": 90.0, \"isi\": 0.037426289075066184, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 35, \"stim\": 0, \"Log power\": 2.076575297066767, \"Firing rate\": 119.28210567428565, \"Power\": 119.28210567428565, \"i_spike\": 79.0, \"isi\": 0.04413361288128363, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 35, \"stim\": 1, \"Log power\": 2.830205838820181, \"Firing rate\": 676.4034885742151, \"Power\": 676.4034885742151, \"i_spike\": 96.0, \"isi\": 0.03640031427050218, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 36, \"stim\": 0, \"Log power\": 2.126358476769516, \"Firing rate\": 133.76992290349398, \"Power\": 133.76992290349398, \"i_spike\": 88.5, \"isi\": 0.039051472792598345, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 36, \"stim\": 1, \"Log power\": 2.573693794282305, \"Firing rate\": 374.7087151909854, \"Power\": 374.7087151909854, \"i_spike\": 89.0, \"isi\": 0.03844359052658583, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 37, \"stim\": 0, \"Log power\": 2.2199232125565938, \"Firing rate\": 165.92935024421234, \"Power\": 165.92935024421234, \"i_spike\": 96.5, \"isi\": 0.0356363129844972, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 37, \"stim\": 1, \"Log power\": 2.2000514294004896, \"Firing rate\": 158.5080887531039, \"Power\": 158.5080887531039, \"i_spike\": 96.0, \"isi\": 0.035504269599892266, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 38, \"stim\": 0, \"Log power\": 2.11800437349651, \"Firing rate\": 131.2213113395195, \"Power\": 131.2213113395195, \"i_spike\": 79.0, \"isi\": 0.04452655221254388, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 38, \"stim\": 1, \"Log power\": 2.2018982405363667, \"Firing rate\": 159.18357006081078, \"Power\": 159.18357006081078, \"i_spike\": 96.5, \"isi\": 0.03612563762560523, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 39, \"stim\": 0, \"Log power\": 2.3501231945969043, \"Firing rate\": 223.93562778131565, \"Power\": 223.93562778131565, \"i_spike\": 80.5, \"isi\": 0.04361839933697641, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 39, \"stim\": 1, \"Log power\": 2.261770647609365, \"Firing rate\": 182.71350450884103, \"Power\": 182.71350450884103, \"i_spike\": 109.0, \"isi\": 0.031680848473518375, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 40, \"stim\": 0, \"Log power\": 2.129227742768365, \"Firing rate\": 134.65663044102854, \"Power\": 134.65663044102854, \"i_spike\": 84.5, \"isi\": 0.04121733562132662, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 40, \"stim\": 1, \"Log power\": 2.036054420206707, \"Firing rate\": 108.6561769052754, \"Power\": 108.6561769052754, \"i_spike\": 98.5, \"isi\": 0.03443038358465565, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 41, \"stim\": 0, \"Log power\": 2.0214344112928866, \"Firing rate\": 105.05927786021482, \"Power\": 105.05927786021482, \"i_spike\": 80.5, \"isi\": 0.04341752386134683, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 41, \"stim\": 1, \"Log power\": 2.2801877464378846, \"Firing rate\": 190.62846308034958, \"Power\": 190.62846308034958, \"i_spike\": 87.0, \"isi\": 0.040023759558599235, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 42, \"stim\": 0, \"Log power\": 2.034147544455625, \"Firing rate\": 108.1801413232719, \"Power\": 108.1801413232719, \"i_spike\": 73.0, \"isi\": 0.0481554507770081, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 42, \"stim\": 1, \"Log power\": 2.235320218736905, \"Firing rate\": 171.9175521168936, \"Power\": 171.9175521168936, \"i_spike\": 91.5, \"isi\": 0.03781409026308163, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 43, \"stim\": 0, \"Log power\": 2.1042890077139886, \"Firing rate\": 127.14199090150949, \"Power\": 127.14199090150949, \"i_spike\": 72.5, \"isi\": 0.04796095280925005, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 43, \"stim\": 1, \"Log power\": 2.2169679941366094, \"Firing rate\": 164.80409326564038, \"Power\": 164.80409326564038, \"i_spike\": 86.5, \"isi\": 0.04026712440232783, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 44, \"stim\": 0, \"Log power\": 2.0599908015808013, \"Firing rate\": 114.812930369662, \"Power\": 114.812930369662, \"i_spike\": 72.5, \"isi\": 0.048015157928590804, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 44, \"stim\": 1, \"Log power\": 2.4958710210057116, \"Firing rate\": 313.23553232759195, \"Power\": 313.23553232759195, \"i_spike\": 96.5, \"isi\": 0.03601443926807861, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 45, \"stim\": 0, \"Log power\": 2.1248525581168387, \"Firing rate\": 133.30687818357538, \"Power\": 133.30687818357538, \"i_spike\": 74.0, \"isi\": 0.04629864948672247, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 45, \"stim\": 1, \"Log power\": 2.2399729100024106, \"Firing rate\": 173.7692433285049, \"Power\": 173.7692433285049, \"i_spike\": 89.0, \"isi\": 0.03916844862361351, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 46, \"stim\": 0, \"Log power\": 1.992376196375254, \"Firing rate\": 98.25987252437143, \"Power\": 98.25987252437143, \"i_spike\": 69.5, \"isi\": 0.04945101163970742, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 46, \"stim\": 1, \"Log power\": 1.9671785203622278, \"Firing rate\": 92.72108828074352, \"Power\": 92.72108828074352, \"i_spike\": 83.5, \"isi\": 0.04205700383631014, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 47, \"stim\": 0, \"Log power\": 2.2732301619371413, \"Firing rate\": 187.59884574742568, \"Power\": 187.59884574742568, \"i_spike\": 69.0, \"isi\": 0.05037450237591499, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 47, \"stim\": 1, \"Log power\": 2.1483047197128395, \"Firing rate\": 140.70344138106435, \"Power\": 140.70344138106435, \"i_spike\": 99.0, \"isi\": 0.035426074423501826, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 48, \"stim\": 0, \"Log power\": 1.9062193756330787, \"Firing rate\": 80.57853656332131, \"Power\": 80.57853656332131, \"i_spike\": 73.0, \"isi\": 0.0470237082466002, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 48, \"stim\": 1, \"Log power\": 2.531568228651864, \"Firing rate\": 340.0699273674691, \"Power\": 340.0699273674691, \"i_spike\": 94.5, \"isi\": 0.03627442532577132, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 49, \"stim\": 0, \"Log power\": 2.3148858301167423, \"Firing rate\": 206.4837267910725, \"Power\": 206.4837267910725, \"i_spike\": 65.0, \"isi\": 0.053994393349553374, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 49, \"stim\": 1, \"Log power\": 2.060927018840327, \"Firing rate\": 115.06070185608658, \"Power\": 115.06070185608658, \"i_spike\": 89.5, \"isi\": 0.038382936100858626, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 50, \"stim\": 0, \"Log power\": 2.7020989607527808, \"Firing rate\": 503.6153523056961, \"Power\": 503.6153523056961, \"i_spike\": 91.5, \"isi\": 0.038099384158494884, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 50, \"stim\": 1, \"Log power\": 2.423763726092603, \"Firing rate\": 265.3161741087237, \"Power\": 265.3161741087237, \"i_spike\": 104.5, \"isi\": 0.033106776587616474, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 51, \"stim\": 0, \"Log power\": 2.690885345559745, \"Firing rate\": 490.7782927912564, \"Power\": 490.7782927912564, \"i_spike\": 72.0, \"isi\": 0.04846127311236185, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 51, \"stim\": 1, \"Log power\": 3.252336045962304, \"Firing rate\": 1787.8704481921338, \"Power\": 1787.8704481921338, \"i_spike\": 89.5, \"isi\": 0.03880921123952882, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 52, \"stim\": 0, \"Log power\": 2.183013987093658, \"Firing rate\": 152.41018389521068, \"Power\": 152.41018389521068, \"i_spike\": 76.0, \"isi\": 0.04571636198149553, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 52, \"stim\": 1, \"Log power\": 2.111932764125637, \"Firing rate\": 129.39954943187234, \"Power\": 129.39954943187234, \"i_spike\": 92.0, \"isi\": 0.037884870904735996, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 53, \"stim\": 0, \"Log power\": 2.0002055329373643, \"Firing rate\": 100.04733690814997, \"Power\": 100.04733690814997, \"i_spike\": 83.0, \"isi\": 0.04158059792339157, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 53, \"stim\": 1, \"Log power\": 2.3477074879838975, \"Firing rate\": 222.69347282076808, \"Power\": 222.69347282076808, \"i_spike\": 84.0, \"isi\": 0.04162992182736283, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 54, \"stim\": 0, \"Log power\": 1.9341768326033797, \"Firing rate\": 85.93633590762555, \"Power\": 85.93633590762555, \"i_spike\": 78.0, \"isi\": 0.045012229750569926, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 54, \"stim\": 1, \"Log power\": 2.34580072109996, \"Firing rate\": 221.717881916258, \"Power\": 221.717881916258, \"i_spike\": 92.5, \"isi\": 0.03770778920077267, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 55, \"stim\": 0, \"Log power\": 1.9405042951185283, \"Firing rate\": 87.19755249741561, \"Power\": 87.19755249741561, \"i_spike\": 68.0, \"isi\": 0.05083046929234572, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 55, \"stim\": 1, \"Log power\": 2.142327165579497, \"Firing rate\": 138.78009024978994, \"Power\": 138.78009024978994, \"i_spike\": 85.5, \"isi\": 0.040633913519646986, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 56, \"stim\": 0, \"Log power\": 2.1251622337835516, \"Firing rate\": 133.4019671605714, \"Power\": 133.4019671605714, \"i_spike\": 84.5, \"isi\": 0.04101955938244394, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 56, \"stim\": 1, \"Log power\": 2.3485522102197196, \"Firing rate\": 223.12704312843545, \"Power\": 223.12704312843545, \"i_spike\": 92.5, \"isi\": 0.03761838911837241, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 57, \"stim\": 0, \"Log power\": 2.1503939073182834, \"Firing rate\": 141.38193046001842, \"Power\": 141.38193046001842, \"i_spike\": 73.0, \"isi\": 0.04802559324545982, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 57, \"stim\": 1, \"Log power\": 2.1260692132039494, \"Firing rate\": 133.68085458018663, \"Power\": 133.68085458018663, \"i_spike\": 99.5, \"isi\": 0.034995192572097385, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 58, \"stim\": 0, \"Log power\": 1.9549156859017107, \"Firing rate\": 90.13961232266641, \"Power\": 90.13961232266641, \"i_spike\": 82.5, \"isi\": 0.0417629871101117, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 58, \"stim\": 1, \"Log power\": 2.047943028867528, \"Firing rate\": 111.67167462857988, \"Power\": 111.67167462857988, \"i_spike\": 86.0, \"isi\": 0.04026444725351672, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 59, \"stim\": 0, \"Log power\": 2.3711818400166798, \"Firing rate\": 235.06168230597203, \"Power\": 235.06168230597203, \"i_spike\": 74.5, \"isi\": 0.047202619206625766, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 59, \"stim\": 1, \"Log power\": 2.3450036328974706, \"Firing rate\": 221.3113222343229, \"Power\": 221.3113222343229, \"i_spike\": 91.0, \"isi\": 0.03768689815954936, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 60, \"stim\": 0, \"Log power\": 2.028638978046254, \"Firing rate\": 106.81665605270607, \"Power\": 106.81665605270607, \"i_spike\": 85.0, \"isi\": 0.04025438607843918, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 60, \"stim\": 1, \"Log power\": 3.122981180357786, \"Firing rate\": 1327.336937893441, \"Power\": 1327.336937893441, \"i_spike\": 110.0, \"isi\": 0.031649962845656, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 61, \"stim\": 0, \"Log power\": 1.9189228869043955, \"Firing rate\": 82.97034327373213, \"Power\": 82.97034327373213, \"i_spike\": 68.5, \"isi\": 0.05107868043162692, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 61, \"stim\": 1, \"Log power\": 2.2647314138224597, \"Firing rate\": 183.9633941726351, \"Power\": 183.9633941726351, \"i_spike\": 82.0, \"isi\": 0.04260797849386971, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 62, \"stim\": 0, \"Log power\": 2.2271454036659244, \"Firing rate\": 168.7117785153499, \"Power\": 168.7117785153499, \"i_spike\": 72.5, \"isi\": 0.048504983040768945, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 62, \"stim\": 1, \"Log power\": 2.1797310080380496, \"Firing rate\": 151.26240738519203, \"Power\": 151.26240738519203, \"i_spike\": 116.0, \"isi\": 0.030217082967535017, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 63, \"stim\": 0, \"Log power\": 2.1012918434320054, \"Firing rate\": 126.26757605165413, \"Power\": 126.26757605165413, \"i_spike\": 78.5, \"isi\": 0.044229580165290855, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 63, \"stim\": 1, \"Log power\": 2.1898982119562365, \"Firing rate\": 154.84536565746825, \"Power\": 154.84536565746825, \"i_spike\": 95.0, \"isi\": 0.03688936577512914, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 64, \"stim\": 0, \"Log power\": 2.3719403235832064, \"Firing rate\": 235.47256987410964, \"Power\": 235.47256987410964, \"i_spike\": 89.0, \"isi\": 0.038942333933919694, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 64, \"stim\": 1, \"Log power\": 2.328926309805585, \"Firing rate\": 213.2683013177163, \"Power\": 213.2683013177163, \"i_spike\": 86.5, \"isi\": 0.04060560846145227, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 65, \"stim\": 0, \"Log power\": 2.371795781656299, \"Firing rate\": 235.39421291320727, \"Power\": 235.39421291320727, \"i_spike\": 80.5, \"isi\": 0.042905013846376704, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 65, \"stim\": 1, \"Log power\": 2.447751295191256, \"Firing rate\": 280.38275270692804, \"Power\": 280.38275270692804, \"i_spike\": 101.0, \"isi\": 0.0345218645275521, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 66, \"stim\": 0, \"Log power\": 2.3363267652959547, \"Firing rate\": 216.93357097453847, \"Power\": 216.93357097453847, \"i_spike\": 90.0, \"isi\": 0.039001609317802687, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 66, \"stim\": 1, \"Log power\": 2.153873642104243, \"Firing rate\": 142.51928736820147, \"Power\": 142.51928736820147, \"i_spike\": 89.5, \"isi\": 0.0386929289575087, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 67, \"stim\": 0, \"Log power\": 2.214673864187398, \"Firing rate\": 163.93582258276027, \"Power\": 163.93582258276027, \"i_spike\": 72.0, \"isi\": 0.04865938437102392, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 67, \"stim\": 1, \"Log power\": 2.217400139907223, \"Firing rate\": 164.96816359147397, \"Power\": 164.96816359147397, \"i_spike\": 101.5, \"isi\": 0.03430245475694499, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 68, \"stim\": 0, \"Log power\": 2.0518725867194165, \"Firing rate\": 112.68668075806144, \"Power\": 112.68668075806144, \"i_spike\": 79.0, \"isi\": 0.044452295368766895, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 68, \"stim\": 1, \"Log power\": 2.0441496578753386, \"Firing rate\": 110.70051922385393, \"Power\": 110.70051922385393, \"i_spike\": 93.5, \"isi\": 0.037249380170555284, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 69, \"stim\": 0, \"Log power\": 2.6884245517721284, \"Firing rate\": 488.0053146888535, \"Power\": 488.0053146888535, \"i_spike\": 76.0, \"isi\": 0.04582984669243768, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 69, \"stim\": 1, \"Log power\": 2.232802531439049, \"Firing rate\": 170.92379681035248, \"Power\": 170.92379681035248, \"i_spike\": 95.5, \"isi\": 0.03666286179296799, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 0, \"stim\": 0, \"Log power\": 2.049865870707151, \"Firing rate\": 112.16719790169377, \"Power\": 112.16719790169377, \"i_spike\": 94.5, \"isi\": 0.03701507410602717, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 0, \"stim\": 1, \"Log power\": 2.3995715699890194, \"Firing rate\": 250.94096860454673, \"Power\": 250.94096860454673, \"i_spike\": 95.0, \"isi\": 0.03691786487828881, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 1, \"stim\": 0, \"Log power\": 2.791662427924049, \"Firing rate\": 618.9597777737547, \"Power\": 618.9597777737547, \"i_spike\": 94.5, \"isi\": 0.036918096417175555, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 1, \"stim\": 1, \"Log power\": 2.449589854300197, \"Firing rate\": 281.5722519898917, \"Power\": 281.5722519898917, \"i_spike\": 109.5, \"isi\": 0.0318405679907412, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 2, \"stim\": 0, \"Log power\": 2.19085468323881, \"Firing rate\": 155.18676616249215, \"Power\": 155.18676616249215, \"i_spike\": 101.0, \"isi\": 0.034719434705591634, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 2, \"stim\": 1, \"Log power\": 2.2583378203428306, \"Firing rate\": 181.27496099114794, \"Power\": 181.27496099114794, \"i_spike\": 105.5, \"isi\": 0.0324920228248927, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 3, \"stim\": 0, \"Log power\": 2.2956845041599636, \"Firing rate\": 197.55339801540765, \"Power\": 197.55339801540765, \"i_spike\": 91.0, \"isi\": 0.038429078275265864, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 3, \"stim\": 1, \"Log power\": 2.256613588190719, \"Firing rate\": 180.556691504212, \"Power\": 180.556691504212, \"i_spike\": 100.0, \"isi\": 0.034816247833637334, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 4, \"stim\": 0, \"Log power\": 2.121652053368341, \"Firing rate\": 132.32809285012374, \"Power\": 132.32809285012374, \"i_spike\": 99.5, \"isi\": 0.03462490660318668, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 4, \"stim\": 1, \"Log power\": 2.544203256074575, \"Firing rate\": 350.1089847398484, \"Power\": 350.1089847398484, \"i_spike\": 108.0, \"isi\": 0.031837329751804706, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 5, \"stim\": 0, \"Log power\": 2.2501523275236504, \"Firing rate\": 177.8903245756527, \"Power\": 177.8903245756527, \"i_spike\": 104.0, \"isi\": 0.03346113817626028, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 5, \"stim\": 1, \"Log power\": 2.394338149157585, \"Firing rate\": 247.93517722394407, \"Power\": 247.93517722394407, \"i_spike\": 111.5, \"isi\": 0.03144047303213581, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 6, \"stim\": 0, \"Log power\": 2.269406953709791, \"Firing rate\": 185.9546118362607, \"Power\": 185.9546118362607, \"i_spike\": 98.0, \"isi\": 0.035183460450413366, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 6, \"stim\": 1, \"Log power\": 2.319049439990794, \"Firing rate\": 208.47281946003915, \"Power\": 208.47281946003915, \"i_spike\": 99.5, \"isi\": 0.03522093167013208, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 7, \"stim\": 0, \"Log power\": 2.242299390373659, \"Firing rate\": 174.7026088432321, \"Power\": 174.7026088432321, \"i_spike\": 87.5, \"isi\": 0.03938645133426472, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 7, \"stim\": 1, \"Log power\": 2.5834283036288084, \"Firing rate\": 383.2024734328876, \"Power\": 383.2024734328876, \"i_spike\": 101.0, \"isi\": 0.034651191886894174, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 8, \"stim\": 0, \"Log power\": 2.4652247762897606, \"Firing rate\": 291.8937367409695, \"Power\": 291.8937367409695, \"i_spike\": 86.5, \"isi\": 0.04006756859128422, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 8, \"stim\": 1, \"Log power\": 2.0750134242946516, \"Firing rate\": 118.85389652989004, \"Power\": 118.85389652989004, \"i_spike\": 103.5, \"isi\": 0.033628674874080104, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 9, \"stim\": 0, \"Log power\": 2.1823187858641355, \"Firing rate\": 152.16640693736196, \"Power\": 152.16640693736196, \"i_spike\": 87.5, \"isi\": 0.03973970292963168, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 9, \"stim\": 1, \"Log power\": 3.4106368463020207, \"Firing rate\": 2574.1677575643375, \"Power\": 2574.1677575643375, \"i_spike\": 97.0, \"isi\": 0.035886344440640955, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 10, \"stim\": 0, \"Log power\": 2.0327846376106526, \"Firing rate\": 107.84118157329219, \"Power\": 107.84118157329219, \"i_spike\": 86.5, \"isi\": 0.040527509405361324, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 10, \"stim\": 1, \"Log power\": 2.1864264243749445, \"Firing rate\": 153.61245300738298, \"Power\": 153.61245300738298, \"i_spike\": 106.0, \"isi\": 0.03265966817873545, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 11, \"stim\": 0, \"Log power\": 2.216228474299822, \"Firing rate\": 164.52370243749098, \"Power\": 164.52370243749098, \"i_spike\": 93.5, \"isi\": 0.037384037129707094, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 11, \"stim\": 1, \"Log power\": 2.336915071273709, \"Firing rate\": 217.22763364810388, \"Power\": 217.22763364810388, \"i_spike\": 88.5, \"isi\": 0.03863177065436268, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 12, \"stim\": 0, \"Log power\": 1.950842353314783, \"Firing rate\": 89.29812772382137, \"Power\": 89.29812772382137, \"i_spike\": 81.0, \"isi\": 0.04222406662540614, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 12, \"stim\": 1, \"Log power\": 2.854420365530545, \"Firing rate\": 715.188241457645, \"Power\": 715.188241457645, \"i_spike\": 121.0, \"isi\": 0.028903743042685497, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 13, \"stim\": 0, \"Log power\": 2.165080809954873, \"Firing rate\": 146.24492697056124, \"Power\": 146.24492697056124, \"i_spike\": 92.5, \"isi\": 0.037752834827337454, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 13, \"stim\": 1, \"Log power\": 2.382410087368043, \"Firing rate\": 241.21820832513015, \"Power\": 241.21820832513015, \"i_spike\": 110.0, \"isi\": 0.03180305116958324, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 14, \"stim\": 0, \"Log power\": 2.1941293098895485, \"Firing rate\": 156.36131344956817, \"Power\": 156.36131344956817, \"i_spike\": 100.5, \"isi\": 0.03473714823441939, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 14, \"stim\": 1, \"Log power\": 2.1080179676610524, \"Firing rate\": 128.2383636422167, \"Power\": 128.2383636422167, \"i_spike\": 103.5, \"isi\": 0.03394488322547342, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 15, \"stim\": 0, \"Log power\": 2.5010018461855483, \"Firing rate\": 316.9580936901311, \"Power\": 316.9580936901311, \"i_spike\": 95.0, \"isi\": 0.03657594576718727, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 15, \"stim\": 1, \"Log power\": 2.227716895845958, \"Firing rate\": 168.93393406251582, \"Power\": 168.93393406251582, \"i_spike\": 115.5, \"isi\": 0.03022682403024804, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 16, \"stim\": 0, \"Log power\": 2.8093322981441826, \"Firing rate\": 644.6623368603022, \"Power\": 644.6623368603022, \"i_spike\": 95.5, \"isi\": 0.03656935625535361, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 16, \"stim\": 1, \"Log power\": 2.579066887548101, \"Firing rate\": 379.3734093936126, \"Power\": 379.3734093936126, \"i_spike\": 112.0, \"isi\": 0.031238374197649663, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 17, \"stim\": 0, \"Log power\": 2.0829026125053502, \"Firing rate\": 121.03266958363359, \"Power\": 121.03266958363359, \"i_spike\": 97.0, \"isi\": 0.03603962392544161, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 17, \"stim\": 1, \"Log power\": 2.416023823568151, \"Firing rate\": 260.62965165395354, \"Power\": 260.62965165395354, \"i_spike\": 103.5, \"isi\": 0.03370619984527249, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 18, \"stim\": 0, \"Log power\": 2.389727241481994, \"Firing rate\": 245.31677205172565, \"Power\": 245.31677205172565, \"i_spike\": 94.5, \"isi\": 0.036371509993615964, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 18, \"stim\": 1, \"Log power\": 2.3788666581690574, \"Firing rate\": 239.25810472805614, \"Power\": 239.25810472805614, \"i_spike\": 123.5, \"isi\": 0.028395939939136108, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 19, \"stim\": 0, \"Log power\": 2.3292819033481598, \"Firing rate\": 213.44299358167112, \"Power\": 213.44299358167112, \"i_spike\": 95.5, \"isi\": 0.036232222224746875, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 19, \"stim\": 1, \"Log power\": 3.703215247027324, \"Firing rate\": 5049.114821091642, \"Power\": 5049.114821091642, \"i_spike\": 102.5, \"isi\": 0.03409732226882638, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 20, \"stim\": 0, \"Log power\": 2.047425806214623, \"Firing rate\": 111.53875850421532, \"Power\": 111.53875850421532, \"i_spike\": 102.5, \"isi\": 0.03420051475774344, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 20, \"stim\": 1, \"Log power\": 2.272738798302673, \"Firing rate\": 187.38671520452775, \"Power\": 187.38671520452775, \"i_spike\": 99.0, \"isi\": 0.03483112591864753, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 21, \"stim\": 0, \"Log power\": 2.4865632779669067, \"Firing rate\": 306.593736285853, \"Power\": 306.593736285853, \"i_spike\": 91.5, \"isi\": 0.03804957199751072, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 21, \"stim\": 1, \"Log power\": 2.5373618025156595, \"Firing rate\": 344.6369217020402, \"Power\": 344.6369217020402, \"i_spike\": 113.5, \"isi\": 0.030727788861441695, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 22, \"stim\": 0, \"Log power\": 2.0780936056626573, \"Firing rate\": 119.69984985812728, \"Power\": 119.69984985812728, \"i_spike\": 86.0, \"isi\": 0.04048426050724916, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 22, \"stim\": 1, \"Log power\": 2.522894575959712, \"Firing rate\": 333.34548405023975, \"Power\": 333.34548405023975, \"i_spike\": 105.5, \"isi\": 0.032647697348818595, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 23, \"stim\": 0, \"Log power\": 2.07792146569388, \"Firing rate\": 119.65241419818234, \"Power\": 119.65241419818234, \"i_spike\": 95.0, \"isi\": 0.03640332365466288, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 23, \"stim\": 1, \"Log power\": 2.1688152158089755, \"Firing rate\": 147.50787812645916, \"Power\": 147.50787812645916, \"i_spike\": 105.5, \"isi\": 0.0333143797264023, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 24, \"stim\": 0, \"Log power\": 2.444932956243232, \"Firing rate\": 278.5691097282813, \"Power\": 278.5691097282813, \"i_spike\": 100.0, \"isi\": 0.03497423549862524, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 24, \"stim\": 1, \"Log power\": 2.2747213779131967, \"Firing rate\": 188.24410199735067, \"Power\": 188.24410199735067, \"i_spike\": 117.0, \"isi\": 0.02933052653153711, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 25, \"stim\": 0, \"Log power\": 2.2678347327795763, \"Firing rate\": 185.28264112737062, \"Power\": 185.28264112737062, \"i_spike\": 90.5, \"isi\": 0.03840913448674816, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 25, \"stim\": 1, \"Log power\": 2.9770584397850928, \"Firing rate\": 948.546093521299, \"Power\": 948.546093521299, \"i_spike\": 117.0, \"isi\": 0.029882568199263458, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 26, \"stim\": 0, \"Log power\": 1.9936175215572702, \"Firing rate\": 98.54112623524102, \"Power\": 98.54112623524102, \"i_spike\": 85.0, \"isi\": 0.04068391962895357, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 26, \"stim\": 1, \"Log power\": 2.1239609781424797, \"Firing rate\": 133.03348804924457, \"Power\": 133.03348804924457, \"i_spike\": 104.5, \"isi\": 0.03332742393336239, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 27, \"stim\": 0, \"Log power\": 2.269730700970873, \"Firing rate\": 186.0932844269218, \"Power\": 186.0932844269218, \"i_spike\": 82.5, \"isi\": 0.042409855730631135, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 27, \"stim\": 1, \"Log power\": 2.2771519656875365, \"Firing rate\": 189.3005891893915, \"Power\": 189.3005891893915, \"i_spike\": 88.5, \"isi\": 0.03944712182994111, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 28, \"stim\": 0, \"Log power\": 2.2046740011381343, \"Firing rate\": 160.20423819479393, \"Power\": 160.20423819479393, \"i_spike\": 77.0, \"isi\": 0.04465177101190972, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 28, \"stim\": 1, \"Log power\": 2.0915521742748666, \"Firing rate\": 123.46736346519779, \"Power\": 123.46736346519779, \"i_spike\": 94.5, \"isi\": 0.03659650578109923, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 29, \"stim\": 0, \"Log power\": 2.1512873485809823, \"Firing rate\": 141.67308421752384, \"Power\": 141.67308421752384, \"i_spike\": 107.0, \"isi\": 0.032690901649981764, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 29, \"stim\": 1, \"Log power\": 2.5216456699266847, \"Firing rate\": 332.3882553204822, \"Power\": 332.3882553204822, \"i_spike\": 97.0, \"isi\": 0.03571555473087041, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 30, \"stim\": 0, \"Log power\": 2.403016419375036, \"Firing rate\": 252.93936234439082, \"Power\": 252.93936234439082, \"i_spike\": 101.5, \"isi\": 0.03415195531604658, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 30, \"stim\": 1, \"Log power\": 2.147563035790999, \"Firing rate\": 140.46335447017458, \"Power\": 140.46335447017458, \"i_spike\": 110.0, \"isi\": 0.03162182479040262, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 31, \"stim\": 0, \"Log power\": 2.9919019318438265, \"Firing rate\": 981.5262792754213, \"Power\": 981.5262792754213, \"i_spike\": 87.0, \"isi\": 0.040395816763747545, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 31, \"stim\": 1, \"Log power\": 2.1632512074575065, \"Firing rate\": 145.63012002808313, \"Power\": 145.63012002808313, \"i_spike\": 96.0, \"isi\": 0.03589492104063558, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 32, \"stim\": 0, \"Log power\": 2.8698620099502152, \"Firing rate\": 741.0747393729686, \"Power\": 741.0747393729686, \"i_spike\": 99.5, \"isi\": 0.034786276626342864, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 32, \"stim\": 1, \"Log power\": 2.2880586366105145, \"Firing rate\": 194.11479455149185, \"Power\": 194.11479455149185, \"i_spike\": 104.0, \"isi\": 0.033305821562326185, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 33, \"stim\": 0, \"Log power\": 2.40472969594144, \"Firing rate\": 253.9391701033941, \"Power\": 253.9391701033941, \"i_spike\": 96.5, \"isi\": 0.03583774900437598, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 33, \"stim\": 1, \"Log power\": 2.3016356086681635, \"Firing rate\": 200.27908964171385, \"Power\": 200.27908964171385, \"i_spike\": 96.5, \"isi\": 0.036133742872390955, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 34, \"stim\": 0, \"Log power\": 2.911962972942329, \"Firing rate\": 816.5127541865324, \"Power\": 816.5127541865324, \"i_spike\": 109.0, \"isi\": 0.0319560791134234, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 34, \"stim\": 1, \"Log power\": 2.206190561201838, \"Firing rate\": 160.76465068471592, \"Power\": 160.76465068471592, \"i_spike\": 103.5, \"isi\": 0.03328813077844599, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 35, \"stim\": 0, \"Log power\": 2.207030436927808, \"Firing rate\": 161.0758519004449, \"Power\": 161.0758519004449, \"i_spike\": 103.5, \"isi\": 0.033743526895481074, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 35, \"stim\": 1, \"Log power\": 2.1942178316819674, \"Firing rate\": 156.3931876617498, \"Power\": 156.3931876617498, \"i_spike\": 99.0, \"isi\": 0.035107969582574956, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 36, \"stim\": 0, \"Log power\": 2.1872280469348246, \"Firing rate\": 153.89625335099842, \"Power\": 153.89625335099842, \"i_spike\": 87.0, \"isi\": 0.04012166395844514, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 36, \"stim\": 1, \"Log power\": 2.827528032260252, \"Firing rate\": 672.2456989288453, \"Power\": 672.2456989288453, \"i_spike\": 109.5, \"isi\": 0.031545143849617055, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 37, \"stim\": 0, \"Log power\": 2.282567270672262, \"Firing rate\": 191.6757938737064, \"Power\": 191.6757938737064, \"i_spike\": 95.0, \"isi\": 0.03696371886977528, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 37, \"stim\": 1, \"Log power\": 2.7891240552886143, \"Firing rate\": 615.3526217659995, \"Power\": 615.3526217659995, \"i_spike\": 102.5, \"isi\": 0.03414172007225115, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 38, \"stim\": 0, \"Log power\": 2.172910528519711, \"Firing rate\": 148.90542775546808, \"Power\": 148.90542775546808, \"i_spike\": 100.5, \"isi\": 0.03477773570250784, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 38, \"stim\": 1, \"Log power\": 2.484988954272366, \"Firing rate\": 305.48434161715903, \"Power\": 305.48434161715903, \"i_spike\": 91.0, \"isi\": 0.038256458484013135, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 39, \"stim\": 0, \"Log power\": 2.388784585683084, \"Firing rate\": 244.7848783704825, \"Power\": 244.7848783704825, \"i_spike\": 101.5, \"isi\": 0.0344536970378176, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 39, \"stim\": 1, \"Log power\": 2.1329994994142516, \"Firing rate\": 135.83118809398724, \"Power\": 135.83118809398724, \"i_spike\": 105.0, \"isi\": 0.0333304025871286, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 40, \"stim\": 0, \"Log power\": 2.2723208250028377, \"Firing rate\": 187.20645740838236, \"Power\": 187.20645740838236, \"i_spike\": 92.5, \"isi\": 0.03732707520178261, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 40, \"stim\": 1, \"Log power\": 2.5400873994017696, \"Firing rate\": 346.80663637909447, \"Power\": 346.80663637909447, \"i_spike\": 108.5, \"isi\": 0.032130697882747666, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 41, \"stim\": 0, \"Log power\": 2.1606303461707665, \"Firing rate\": 144.75392424165685, \"Power\": 144.75392424165685, \"i_spike\": 96.0, \"isi\": 0.03647953163452035, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 41, \"stim\": 1, \"Log power\": 2.190669307420531, \"Firing rate\": 155.1205398203529, \"Power\": 155.1205398203529, \"i_spike\": 104.0, \"isi\": 0.033480124705509734, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 42, \"stim\": 0, \"Log power\": 2.070607591510561, \"Firing rate\": 117.65424235655631, \"Power\": 117.65424235655631, \"i_spike\": 86.0, \"isi\": 0.04039985472758259, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 42, \"stim\": 1, \"Log power\": 2.437928225845542, \"Firing rate\": 274.1121120099851, \"Power\": 274.1121120099851, \"i_spike\": 101.5, \"isi\": 0.03435525714292649, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 43, \"stim\": 0, \"Log power\": 2.8022321754007753, \"Firing rate\": 634.2086708935926, \"Power\": 634.2086708935926, \"i_spike\": 92.0, \"isi\": 0.03798101081557126, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 43, \"stim\": 1, \"Log power\": 3.002708595209304, \"Firing rate\": 1006.2562601032454, \"Power\": 1006.2562601032454, \"i_spike\": 93.5, \"isi\": 0.03633576921417587, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 44, \"stim\": 0, \"Log power\": 2.0406532298021993, \"Firing rate\": 109.81286688037261, \"Power\": 109.81286688037261, \"i_spike\": 94.5, \"isi\": 0.03715996073462623, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 44, \"stim\": 1, \"Log power\": 2.2105583006522203, \"Firing rate\": 162.38963312876896, \"Power\": 162.38963312876896, \"i_spike\": 106.5, \"isi\": 0.03291389269473498, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 45, \"stim\": 0, \"Log power\": 2.1189954689135844, \"Firing rate\": 131.5211110244284, \"Power\": 131.5211110244284, \"i_spike\": 97.0, \"isi\": 0.0359134040438695, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 45, \"stim\": 1, \"Log power\": 2.6046629338115284, \"Firing rate\": 402.4045973991937, \"Power\": 402.4045973991937, \"i_spike\": 114.5, \"isi\": 0.030518526236899643, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 46, \"stim\": 0, \"Log power\": 2.0576266628207756, \"Firing rate\": 114.18962923076832, \"Power\": 114.18962923076832, \"i_spike\": 86.5, \"isi\": 0.04052410258619352, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 46, \"stim\": 1, \"Log power\": 2.1316461199494374, \"Firing rate\": 135.4085601036795, \"Power\": 135.4085601036795, \"i_spike\": 102.0, \"isi\": 0.034102681022305986, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 47, \"stim\": 0, \"Log power\": 2.996948488731432, \"Firing rate\": 992.9982628263147, \"Power\": 992.9982628263147, \"i_spike\": 95.5, \"isi\": 0.03653095469210809, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 47, \"stim\": 1, \"Log power\": 2.3114166683397577, \"Firing rate\": 204.84089671420935, \"Power\": 204.84089671420935, \"i_spike\": 109.0, \"isi\": 0.032176692812204324, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 48, \"stim\": 0, \"Log power\": 2.0937664163251806, \"Firing rate\": 124.09846690678148, \"Power\": 124.09846690678148, \"i_spike\": 91.0, \"isi\": 0.03816372310698342, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 48, \"stim\": 1, \"Log power\": 2.570854068555648, \"Firing rate\": 372.2665963750322, \"Power\": 372.2665963750322, \"i_spike\": 122.5, \"isi\": 0.02863410645610159, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 49, \"stim\": 0, \"Log power\": 2.3168057162654874, \"Firing rate\": 207.3985502460628, \"Power\": 207.3985502460628, \"i_spike\": 82.0, \"isi\": 0.041918238553273264, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 49, \"stim\": 1, \"Log power\": 2.2004335273452926, \"Firing rate\": 158.64760760147766, \"Power\": 158.64760760147766, \"i_spike\": 103.5, \"isi\": 0.03364452841885504, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 50, \"stim\": 0, \"Log power\": 2.500627082974062, \"Firing rate\": 316.68470086131714, \"Power\": 316.68470086131714, \"i_spike\": 101.0, \"isi\": 0.034459536731957084, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 50, \"stim\": 1, \"Log power\": 2.370237198250822, \"Firing rate\": 234.55095105006856, \"Power\": 234.55095105006856, \"i_spike\": 103.0, \"isi\": 0.033862948171056666, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 51, \"stim\": 0, \"Log power\": 2.3083261489861124, \"Firing rate\": 203.38838554263134, \"Power\": 203.38838554263134, \"i_spike\": 100.5, \"isi\": 0.03492060374537045, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 51, \"stim\": 1, \"Log power\": 2.432051118594306, \"Firing rate\": 270.4276652025166, \"Power\": 270.4276652025166, \"i_spike\": 90.5, \"isi\": 0.03855951707210525, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 52, \"stim\": 0, \"Log power\": 2.227537544969761, \"Firing rate\": 168.86418370870595, \"Power\": 168.86418370870595, \"i_spike\": 94.0, \"isi\": 0.03700846999692974, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 52, \"stim\": 1, \"Log power\": 2.2920389943177626, \"Firing rate\": 195.90205616282455, \"Power\": 195.90205616282455, \"i_spike\": 99.5, \"isi\": 0.034929898747469254, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 53, \"stim\": 0, \"Log power\": 2.1875993123107955, \"Firing rate\": 154.02787090954817, \"Power\": 154.02787090954817, \"i_spike\": 110.0, \"isi\": 0.03194548076984301, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 53, \"stim\": 1, \"Log power\": 2.0620360299734517, \"Firing rate\": 115.354895467182, \"Power\": 115.354895467182, \"i_spike\": 93.5, \"isi\": 0.036860586758950965, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 54, \"stim\": 0, \"Log power\": 2.490104338649092, \"Firing rate\": 309.1037960912743, \"Power\": 309.1037960912743, \"i_spike\": 89.5, \"isi\": 0.03897712690206408, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 54, \"stim\": 1, \"Log power\": 2.3222529307323048, \"Firing rate\": 210.01626507703392, \"Power\": 210.01626507703392, \"i_spike\": 99.0, \"isi\": 0.035255455825196576, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 55, \"stim\": 0, \"Log power\": 2.003092437502987, \"Firing rate\": 100.71460122509565, \"Power\": 100.71460122509565, \"i_spike\": 94.5, \"isi\": 0.037125360718610195, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 55, \"stim\": 1, \"Log power\": 2.624988091494971, \"Firing rate\": 421.6849405230178, \"Power\": 421.6849405230178, \"i_spike\": 120.0, \"isi\": 0.02925514251565867, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 56, \"stim\": 0, \"Log power\": 2.272341090882363, \"Firing rate\": 187.21519339787787, \"Power\": 187.21519339787787, \"i_spike\": 99.0, \"isi\": 0.03528011539972761, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 56, \"stim\": 1, \"Log power\": 2.0473782423397275, \"Firing rate\": 111.52654346286492, \"Power\": 111.52654346286492, \"i_spike\": 97.5, \"isi\": 0.035817158366059525, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 57, \"stim\": 0, \"Log power\": 2.130956587455104, \"Firing rate\": 135.19374153172342, \"Power\": 135.19374153172342, \"i_spike\": 90.0, \"isi\": 0.03788913766143979, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 57, \"stim\": 1, \"Log power\": 2.1886971204132837, \"Firing rate\": 154.4177145487128, \"Power\": 154.4177145487128, \"i_spike\": 110.5, \"isi\": 0.03146414289122245, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 58, \"stim\": 0, \"Log power\": 2.0137173772538413, \"Firing rate\": 103.20895415668714, \"Power\": 103.20895415668714, \"i_spike\": 96.0, \"isi\": 0.03649902834421934, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 58, \"stim\": 1, \"Log power\": 3.0504050010867214, \"Firing rate\": 1123.0652800436872, \"Power\": 1123.0652800436872, \"i_spike\": 106.5, \"isi\": 0.03270856841372044, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 59, \"stim\": 0, \"Log power\": 2.132495596403032, \"Firing rate\": 135.67367733849468, \"Power\": 135.67367733849468, \"i_spike\": 89.5, \"isi\": 0.03911453564823164, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 59, \"stim\": 1, \"Log power\": 2.177901683415613, \"Firing rate\": 150.62660356146165, \"Power\": 150.62660356146165, \"i_spike\": 113.0, \"isi\": 0.029982077843513415, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 60, \"stim\": 0, \"Log power\": 2.415633412085809, \"Firing rate\": 260.39546243222634, \"Power\": 260.39546243222634, \"i_spike\": 92.5, \"isi\": 0.03750213816263816, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 60, \"stim\": 1, \"Log power\": 2.564383425839126, \"Firing rate\": 366.7612344709279, \"Power\": 366.7612344709279, \"i_spike\": 104.5, \"isi\": 0.03363193643758971, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 61, \"stim\": 0, \"Log power\": 2.10069282031721, \"Firing rate\": 126.09353502518454, \"Power\": 126.09353502518454, \"i_spike\": 97.5, \"isi\": 0.035814143057264096, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 61, \"stim\": 1, \"Log power\": 2.4653794813557823, \"Firing rate\": 291.9977341106646, \"Power\": 291.9977341106646, \"i_spike\": 106.0, \"isi\": 0.03218964341987222, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 62, \"stim\": 0, \"Log power\": 2.0767429005144487, \"Firing rate\": 119.3281480514624, \"Power\": 119.3281480514624, \"i_spike\": 102.5, \"isi\": 0.03383614250267985, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 62, \"stim\": 1, \"Log power\": 2.067148357373883, \"Firing rate\": 116.72082737051937, \"Power\": 116.72082737051937, \"i_spike\": 110.5, \"isi\": 0.03174555157719116, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 63, \"stim\": 0, \"Log power\": 2.3226037717827226, \"Firing rate\": 210.1859934524735, \"Power\": 210.1859934524735, \"i_spike\": 97.5, \"isi\": 0.03603710191672075, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 63, \"stim\": 1, \"Log power\": 2.3267482252196, \"Firing rate\": 212.20139041558224, \"Power\": 212.20139041558224, \"i_spike\": 95.0, \"isi\": 0.03666207283733454, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 64, \"stim\": 0, \"Log power\": 2.697745732615259, \"Firing rate\": 498.59248990340376, \"Power\": 498.59248990340376, \"i_spike\": 96.5, \"isi\": 0.03565795521394092, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 64, \"stim\": 1, \"Log power\": 2.2247337995757444, \"Firing rate\": 167.77753119669728, \"Power\": 167.77753119669728, \"i_spike\": 100.0, \"isi\": 0.03498757630600934, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 65, \"stim\": 0, \"Log power\": 2.189809551535702, \"Firing rate\": 154.81375748705634, \"Power\": 154.81375748705634, \"i_spike\": 95.5, \"isi\": 0.03666674506259677, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 65, \"stim\": 1, \"Log power\": 2.9248945758676084, \"Firing rate\": 841.1909194156078, \"Power\": 841.1909194156078, \"i_spike\": 86.0, \"isi\": 0.04088986994272091, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 66, \"stim\": 0, \"Log power\": 2.5529139686224758, \"Firing rate\": 357.20207135309295, \"Power\": 357.20207135309295, \"i_spike\": 93.5, \"isi\": 0.03737221426409719, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 66, \"stim\": 1, \"Log power\": 2.4254936397573346, \"Firing rate\": 266.37510858467425, \"Power\": 266.37510858467425, \"i_spike\": 105.5, \"isi\": 0.03308633612026871, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 67, \"stim\": 0, \"Log power\": 1.9783713103033747, \"Firing rate\": 95.14178831653237, \"Power\": 95.14178831653237, \"i_spike\": 84.0, \"isi\": 0.04179207230886426, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 67, \"stim\": 1, \"Log power\": 2.1544111192796542, \"Firing rate\": 142.69577656363273, \"Power\": 142.69577656363273, \"i_spike\": 123.0, \"isi\": 0.028412920348173352, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 68, \"stim\": 0, \"Log power\": 2.0467103482182747, \"Firing rate\": 111.35516049955697, \"Power\": 111.35516049955697, \"i_spike\": 87.0, \"isi\": 0.04003573761358942, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 68, \"stim\": 1, \"Log power\": 2.4981402272478173, \"Firing rate\": 314.87648394539394, \"Power\": 314.87648394539394, \"i_spike\": 113.5, \"isi\": 0.030638896852984522, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 69, \"stim\": 0, \"Log power\": 2.435026957261303, \"Firing rate\": 272.2870315172498, \"Power\": 272.2870315172498, \"i_spike\": 105.5, \"isi\": 0.03327992150262829, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 69, \"stim\": 1, \"Log power\": 2.4247242107434213, \"Firing rate\": 265.9035960640525, \"Power\": 265.9035960640525, \"i_spike\": 123.5, \"isi\": 0.02837822239107863, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 0, \"stim\": 0, \"Log power\": 2.2387808412134245, \"Firing rate\": 173.29292859221957, \"Power\": 173.29292859221957, \"i_spike\": 121.5, \"isi\": 0.02853313550231764, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 0, \"stim\": 1, \"Log power\": 2.096133152854477, \"Firing rate\": 124.77660153953627, \"Power\": 124.77660153953627, \"i_spike\": 122.0, \"isi\": 0.028637764746772102, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 1, \"stim\": 0, \"Log power\": 2.3306606671518435, \"Firing rate\": 214.12169230115245, \"Power\": 214.12169230115245, \"i_spike\": 111.5, \"isi\": 0.030795571603757246, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 1, \"stim\": 1, \"Log power\": 2.454754227716879, \"Firing rate\": 284.94052996493735, \"Power\": 284.94052996493735, \"i_spike\": 120.5, \"isi\": 0.02866635579527785, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 2, \"stim\": 0, \"Log power\": 2.4449068976145303, \"Firing rate\": 278.5523954675138, \"Power\": 278.5523954675138, \"i_spike\": 106.0, \"isi\": 0.03270825812886764, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 2, \"stim\": 1, \"Log power\": 2.5159745848493342, \"Firing rate\": 328.07609335886747, \"Power\": 328.07609335886747, \"i_spike\": 104.0, \"isi\": 0.03374536388414777, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 3, \"stim\": 0, \"Log power\": 2.1054452651983815, \"Firing rate\": 127.48094236260913, \"Power\": 127.48094236260913, \"i_spike\": 105.0, \"isi\": 0.03330027747626142, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 3, \"stim\": 1, \"Log power\": 2.4826726288282566, \"Firing rate\": 303.85936703252935, \"Power\": 303.85936703252935, \"i_spike\": 123.0, \"isi\": 0.02840222379669739, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 4, \"stim\": 0, \"Log power\": 2.35857725609834, \"Firing rate\": 228.33750752692865, \"Power\": 228.33750752692865, \"i_spike\": 107.0, \"isi\": 0.032712368159145445, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 4, \"stim\": 1, \"Log power\": 2.236661228890842, \"Firing rate\": 172.44921782702298, \"Power\": 172.44921782702298, \"i_spike\": 115.5, \"isi\": 0.030225597798228577, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 5, \"stim\": 0, \"Log power\": 2.3745855814604018, \"Firing rate\": 236.91119396585378, \"Power\": 236.91119396585378, \"i_spike\": 116.5, \"isi\": 0.02980765180185336, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 5, \"stim\": 1, \"Log power\": 2.3451067191463575, \"Firing rate\": 221.3638600003979, \"Power\": 221.3638600003979, \"i_spike\": 111.0, \"isi\": 0.03142477518766983, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 6, \"stim\": 0, \"Log power\": 2.1301642991864047, \"Firing rate\": 134.9473309138702, \"Power\": 134.9473309138702, \"i_spike\": 107.5, \"isi\": 0.03261229738311003, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 6, \"stim\": 1, \"Log power\": 2.729332964095691, \"Firing rate\": 536.2075986202508, \"Power\": 536.2075986202508, \"i_spike\": 99.0, \"isi\": 0.03486523175058692, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 7, \"stim\": 0, \"Log power\": 2.1887693802154895, \"Firing rate\": 154.44340937630207, \"Power\": 154.44340937630207, \"i_spike\": 116.5, \"isi\": 0.02976395860271862, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 7, \"stim\": 1, \"Log power\": 2.185085368633124, \"Firing rate\": 153.1388454894073, \"Power\": 153.1388454894073, \"i_spike\": 118.0, \"isi\": 0.029559906970417216, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 8, \"stim\": 0, \"Log power\": 2.046933689200291, \"Firing rate\": 111.4124409116263, \"Power\": 111.4124409116263, \"i_spike\": 99.5, \"isi\": 0.035011040872484335, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 8, \"stim\": 1, \"Log power\": 2.330466738914528, \"Firing rate\": 214.02610054387887, \"Power\": 214.02610054387887, \"i_spike\": 130.5, \"isi\": 0.02685016334501855, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 9, \"stim\": 0, \"Log power\": 2.6040783631816535, \"Firing rate\": 401.86331567775045, \"Power\": 401.86331567775045, \"i_spike\": 95.0, \"isi\": 0.036828573966649736, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 9, \"stim\": 1, \"Log power\": 2.66712880789423, \"Firing rate\": 464.653066769291, \"Power\": 464.653066769291, \"i_spike\": 101.0, \"isi\": 0.03464347342911677, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 10, \"stim\": 0, \"Log power\": 2.149863385780744, \"Firing rate\": 141.2093278407666, \"Power\": 141.2093278407666, \"i_spike\": 118.0, \"isi\": 0.02936961420932318, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 10, \"stim\": 1, \"Log power\": 2.382543649036834, \"Firing rate\": 241.2924032834708, \"Power\": 241.2924032834708, \"i_spike\": 108.5, \"isi\": 0.03199536499601757, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 11, \"stim\": 0, \"Log power\": 2.2796785548439935, \"Firing rate\": 190.40509038247552, \"Power\": 190.40509038247552, \"i_spike\": 108.0, \"isi\": 0.03240543937197036, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 11, \"stim\": 1, \"Log power\": 2.5074163728625587, \"Firing rate\": 321.67430615146355, \"Power\": 321.67430615146355, \"i_spike\": 109.0, \"isi\": 0.03220714621480586, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 12, \"stim\": 0, \"Log power\": 2.3421475145468063, \"Firing rate\": 219.86065352114574, \"Power\": 219.86065352114574, \"i_spike\": 115.0, \"isi\": 0.030419146207378286, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 12, \"stim\": 1, \"Log power\": 2.1776126404311484, \"Firing rate\": 150.5263879705745, \"Power\": 150.5263879705745, \"i_spike\": 105.5, \"isi\": 0.03305901432051696, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 13, \"stim\": 0, \"Log power\": 2.297912606143595, \"Firing rate\": 198.56952921301112, \"Power\": 198.56952921301112, \"i_spike\": 117.0, \"isi\": 0.02989840227540727, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 13, \"stim\": 1, \"Log power\": 2.30769948840374, \"Firing rate\": 203.09512007787026, \"Power\": 203.09512007787026, \"i_spike\": 120.0, \"isi\": 0.029093337874130366, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 14, \"stim\": 0, \"Log power\": 3.4278473990717298, \"Firing rate\": 2678.227093074703, \"Power\": 2678.227093074703, \"i_spike\": 111.0, \"isi\": 0.03126499157278554, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 14, \"stim\": 1, \"Log power\": 2.717699390581335, \"Firing rate\": 522.0347225636683, \"Power\": 522.0347225636683, \"i_spike\": 113.5, \"isi\": 0.0307233617907161, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 15, \"stim\": 0, \"Log power\": 2.36183243824792, \"Firing rate\": 230.05540344518576, \"Power\": 230.05540344518576, \"i_spike\": 99.0, \"isi\": 0.0343015931390401, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 15, \"stim\": 1, \"Log power\": 2.554709227912624, \"Firing rate\": 358.68170697727527, \"Power\": 358.68170697727527, \"i_spike\": 125.0, \"isi\": 0.02789607262944401, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 16, \"stim\": 0, \"Log power\": 2.329198111803566, \"Firing rate\": 213.4018164687659, \"Power\": 213.4018164687659, \"i_spike\": 112.5, \"isi\": 0.031046858517410705, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 16, \"stim\": 1, \"Log power\": 2.230685703680478, \"Firing rate\": 170.0927112091951, \"Power\": 170.0927112091951, \"i_spike\": 115.5, \"isi\": 0.030204049514166147, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 17, \"stim\": 0, \"Log power\": 2.2642261298274744, \"Firing rate\": 183.74948469504963, \"Power\": 183.74948469504963, \"i_spike\": 108.5, \"isi\": 0.03205723968047504, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 17, \"stim\": 1, \"Log power\": 2.430658278801683, \"Firing rate\": 269.5617572278199, \"Power\": 269.5617572278199, \"i_spike\": 129.0, \"isi\": 0.027180442215705067, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 18, \"stim\": 0, \"Log power\": 2.1133912561054853, \"Firing rate\": 129.83484269741788, \"Power\": 129.83484269741788, \"i_spike\": 108.5, \"isi\": 0.032171855970717415, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 18, \"stim\": 1, \"Log power\": 2.746589338733493, \"Firing rate\": 557.9423646807952, \"Power\": 557.9423646807952, \"i_spike\": 106.5, \"isi\": 0.032948995964470464, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 19, \"stim\": 0, \"Log power\": 2.2005069685287015, \"Firing rate\": 158.6744379060992, \"Power\": 158.6744379060992, \"i_spike\": 101.5, \"isi\": 0.03445190535524738, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 19, \"stim\": 1, \"Log power\": 2.1772925164901826, \"Firing rate\": 150.4154739542893, \"Power\": 150.4154739542893, \"i_spike\": 103.5, \"isi\": 0.03379602328938959, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 20, \"stim\": 0, \"Log power\": 2.494573728478383, \"Firing rate\": 312.30125428672767, \"Power\": 312.30125428672767, \"i_spike\": 106.5, \"isi\": 0.03281068889325777, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 20, \"stim\": 1, \"Log power\": 2.446100083893624, \"Firing rate\": 279.31874618201937, \"Power\": 279.31874618201937, \"i_spike\": 114.5, \"isi\": 0.030627413326107546, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 21, \"stim\": 0, \"Log power\": 2.1127456313852675, \"Firing rate\": 129.64197285613145, \"Power\": 129.64197285613145, \"i_spike\": 109.5, \"isi\": 0.0319742372826735, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 21, \"stim\": 1, \"Log power\": 2.1251717012253395, \"Firing rate\": 133.40487530050714, \"Power\": 133.40487530050714, \"i_spike\": 107.5, \"isi\": 0.032511587514608885, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 22, \"stim\": 0, \"Log power\": 2.426871647707529, \"Firing rate\": 267.2216539527633, \"Power\": 267.2216539527633, \"i_spike\": 107.0, \"isi\": 0.0327107869078027, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 22, \"stim\": 1, \"Log power\": 2.4566033945783494, \"Firing rate\": 286.1563545748738, \"Power\": 286.1563545748738, \"i_spike\": 117.0, \"isi\": 0.029710588805103032, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 23, \"stim\": 0, \"Log power\": 2.099173905708598, \"Firing rate\": 125.65330198680839, \"Power\": 125.65330198680839, \"i_spike\": 102.0, \"isi\": 0.0340190094687851, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 23, \"stim\": 1, \"Log power\": 2.26947101101024, \"Firing rate\": 185.98204167812224, \"Power\": 185.98204167812224, \"i_spike\": 111.5, \"isi\": 0.030767543761461826, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 24, \"stim\": 0, \"Log power\": 2.652122477261477, \"Firing rate\": 448.8719604040662, \"Power\": 448.8719604040662, \"i_spike\": 118.0, \"isi\": 0.029507656578313866, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 24, \"stim\": 1, \"Log power\": 2.6004872452034076, \"Firing rate\": 398.55406700533206, \"Power\": 398.55406700533206, \"i_spike\": 99.5, \"isi\": 0.03521714985778055, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 25, \"stim\": 0, \"Log power\": 2.470793305458199, \"Firing rate\": 295.6604989398605, \"Power\": 295.6604989398605, \"i_spike\": 100.5, \"isi\": 0.034873628042610016, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 25, \"stim\": 1, \"Log power\": 2.4308165301563354, \"Firing rate\": 269.6599999826232, \"Power\": 269.6599999826232, \"i_spike\": 111.0, \"isi\": 0.0314959857744625, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 26, \"stim\": 0, \"Log power\": 2.2535161115176163, \"Firing rate\": 179.2735058268592, \"Power\": 179.2735058268592, \"i_spike\": 132.5, \"isi\": 0.026313526039833154, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 26, \"stim\": 1, \"Log power\": 2.539226970390633, \"Firing rate\": 346.1202194440859, \"Power\": 346.1202194440859, \"i_spike\": 122.0, \"isi\": 0.028644120081677854, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 27, \"stim\": 0, \"Log power\": 1.9745962611978733, \"Firing rate\": 94.31836445698384, \"Power\": 94.31836445698384, \"i_spike\": 103.0, \"isi\": 0.03368347640039113, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 27, \"stim\": 1, \"Log power\": 2.2445236493562732, \"Firing rate\": 175.59965137803889, \"Power\": 175.59965137803889, \"i_spike\": 121.0, \"isi\": 0.02889642763577631, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 28, \"stim\": 0, \"Log power\": 2.408110695844926, \"Firing rate\": 255.9238119288369, \"Power\": 255.9238119288369, \"i_spike\": 108.0, \"isi\": 0.032075536933765136, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 28, \"stim\": 1, \"Log power\": 2.1461617786922598, \"Firing rate\": 140.01087788513078, \"Power\": 140.01087788513078, \"i_spike\": 101.5, \"isi\": 0.034289675717336855, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 29, \"stim\": 0, \"Log power\": 2.275883152416509, \"Firing rate\": 188.74834505130065, \"Power\": 188.74834505130065, \"i_spike\": 113.5, \"isi\": 0.030596784366782447, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 29, \"stim\": 1, \"Log power\": 2.357203307583858, \"Firing rate\": 227.61627283156676, \"Power\": 227.61627283156676, \"i_spike\": 114.0, \"isi\": 0.030445378630869175, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 30, \"stim\": 0, \"Log power\": 2.2674304748910568, \"Firing rate\": 185.11025321454034, \"Power\": 185.11025321454034, \"i_spike\": 120.0, \"isi\": 0.028739279895104598, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 30, \"stim\": 1, \"Log power\": 2.139306408160454, \"Firing rate\": 137.8181475528611, \"Power\": 137.8181475528611, \"i_spike\": 124.5, \"isi\": 0.02755647056725143, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 31, \"stim\": 0, \"Log power\": 2.6991239574182, \"Firing rate\": 500.17727645553845, \"Power\": 500.17727645553845, \"i_spike\": 116.0, \"isi\": 0.030182207181704338, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 31, \"stim\": 1, \"Log power\": 2.2645085398735425, \"Firing rate\": 183.8690109116505, \"Power\": 183.8690109116505, \"i_spike\": 116.5, \"isi\": 0.0298144087225485, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 32, \"stim\": 0, \"Log power\": 3.675167030945279, \"Firing rate\": 4733.332693370173, \"Power\": 4733.332693370173, \"i_spike\": 102.5, \"isi\": 0.0341948505174295, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 32, \"stim\": 1, \"Log power\": 2.579121770095857, \"Firing rate\": 379.4213544994617, \"Power\": 379.4213544994617, \"i_spike\": 112.5, \"isi\": 0.030548979437905074, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 33, \"stim\": 0, \"Log power\": 2.473423185018472, \"Firing rate\": 297.4563092358735, \"Power\": 297.4563092358735, \"i_spike\": 111.0, \"isi\": 0.03128525124700106, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 33, \"stim\": 1, \"Log power\": 2.3147507543345798, \"Firing rate\": 206.41951548943078, \"Power\": 206.41951548943078, \"i_spike\": 111.0, \"isi\": 0.0313602784198251, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 34, \"stim\": 0, \"Log power\": 2.5129112657095236, \"Firing rate\": 325.7701334167359, \"Power\": 325.7701334167359, \"i_spike\": 122.0, \"isi\": 0.028579181731945975, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 34, \"stim\": 1, \"Log power\": 2.486560473175817, \"Firing rate\": 306.59175622708653, \"Power\": 306.59175622708653, \"i_spike\": 126.5, \"isi\": 0.027469975937145875, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 35, \"stim\": 0, \"Log power\": 2.4054076701105522, \"Firing rate\": 254.3359024064175, \"Power\": 254.3359024064175, \"i_spike\": 102.5, \"isi\": 0.03423830234930001, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 35, \"stim\": 1, \"Log power\": 2.183329046833763, \"Firing rate\": 152.5207902616969, \"Power\": 152.5207902616969, \"i_spike\": 106.5, \"isi\": 0.03288467618567741, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 36, \"stim\": 0, \"Log power\": 2.9286769699248194, \"Firing rate\": 848.5490858461727, \"Power\": 848.5490858461727, \"i_spike\": 118.0, \"isi\": 0.029439056168683992, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 36, \"stim\": 1, \"Log power\": 2.285060714626855, \"Firing rate\": 192.77944011569602, \"Power\": 192.77944011569602, \"i_spike\": 117.0, \"isi\": 0.02986760205847878, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 37, \"stim\": 0, \"Log power\": 2.398728491472142, \"Firing rate\": 250.45429946202108, \"Power\": 250.45429946202108, \"i_spike\": 116.5, \"isi\": 0.02998685226351414, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 37, \"stim\": 1, \"Log power\": 2.20144153445091, \"Firing rate\": 159.01625986993247, \"Power\": 159.01625986993247, \"i_spike\": 121.5, \"isi\": 0.028685604773161143, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 38, \"stim\": 0, \"Log power\": 2.1501579662028116, \"Firing rate\": 141.3051421235651, \"Power\": 141.3051421235651, \"i_spike\": 99.5, \"isi\": 0.035003266775068945, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 38, \"stim\": 1, \"Log power\": 2.132477161429446, \"Firing rate\": 135.66791837152783, \"Power\": 135.66791837152783, \"i_spike\": 110.5, \"isi\": 0.03150650597686094, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 39, \"stim\": 0, \"Log power\": 2.26922398769437, \"Firing rate\": 185.87628662177042, \"Power\": 185.87628662177042, \"i_spike\": 121.5, \"isi\": 0.02842579471518814, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 39, \"stim\": 1, \"Log power\": 2.675034652549503, \"Firing rate\": 473.189013416686, \"Power\": 473.189013416686, \"i_spike\": 135.0, \"isi\": 0.025790169320093242, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 40, \"stim\": 0, \"Log power\": 2.2879406029124265, \"Firing rate\": 194.06204468996046, \"Power\": 194.06204468996046, \"i_spike\": 117.0, \"isi\": 0.029928326408534683, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 40, \"stim\": 1, \"Log power\": 2.2724987351480226, \"Firing rate\": 187.2831628519918, \"Power\": 187.2831628519918, \"i_spike\": 105.5, \"isi\": 0.03265090411657685, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 41, \"stim\": 0, \"Log power\": 2.265491941591164, \"Firing rate\": 184.28582941005587, \"Power\": 184.28582941005587, \"i_spike\": 104.0, \"isi\": 0.03353107892671971, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 41, \"stim\": 1, \"Log power\": 2.9267934171824654, \"Firing rate\": 844.8768631684944, \"Power\": 844.8768631684944, \"i_spike\": 109.5, \"isi\": 0.03176179686356341, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 42, \"stim\": 0, \"Log power\": 2.098875137531294, \"Firing rate\": 125.56688988741465, \"Power\": 125.56688988741465, \"i_spike\": 118.0, \"isi\": 0.029608479294162836, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 42, \"stim\": 1, \"Log power\": 2.204829224872131, \"Firing rate\": 160.26150796367202, \"Power\": 160.26150796367202, \"i_spike\": 127.0, \"isi\": 0.027569249250649776, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 43, \"stim\": 0, \"Log power\": 2.260386959132079, \"Firing rate\": 182.13229461299554, \"Power\": 182.13229461299554, \"i_spike\": 118.5, \"isi\": 0.029325069146959797, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 43, \"stim\": 1, \"Log power\": 2.2871682586153987, \"Firing rate\": 193.7172336830329, \"Power\": 193.7172336830329, \"i_spike\": 114.0, \"isi\": 0.03067635653844497, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 44, \"stim\": 0, \"Log power\": 2.2832346683358224, \"Firing rate\": 191.97057616000512, \"Power\": 191.97057616000512, \"i_spike\": 105.5, \"isi\": 0.033215883222790926, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 44, \"stim\": 1, \"Log power\": 2.4752003265571125, \"Firing rate\": 298.67600008537323, \"Power\": 298.67600008537323, \"i_spike\": 131.5, \"isi\": 0.026379811918953958, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 45, \"stim\": 0, \"Log power\": 2.416449540331155, \"Firing rate\": 260.88525888712104, \"Power\": 260.88525888712104, \"i_spike\": 105.5, \"isi\": 0.033071276672261514, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 45, \"stim\": 1, \"Log power\": 2.10913685885185, \"Firing rate\": 128.5691755064261, \"Power\": 128.5691755064261, \"i_spike\": 126.5, \"isi\": 0.027551029141299626, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 46, \"stim\": 0, \"Log power\": 2.2643717122662537, \"Firing rate\": 183.81109077882925, \"Power\": 183.81109077882925, \"i_spike\": 105.0, \"isi\": 0.033075202067634264, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 46, \"stim\": 1, \"Log power\": 2.2359977063506333, \"Firing rate\": 172.1859481266153, \"Power\": 172.1859481266153, \"i_spike\": 112.0, \"isi\": 0.03130093077934107, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 47, \"stim\": 0, \"Log power\": 2.2124352181332774, \"Firing rate\": 163.0929612226353, \"Power\": 163.0929612226353, \"i_spike\": 98.0, \"isi\": 0.03568639495351731, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 47, \"stim\": 1, \"Log power\": 2.1927699480724407, \"Firing rate\": 155.87266045799402, \"Power\": 155.87266045799402, \"i_spike\": 118.0, \"isi\": 0.029593876949170844, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 48, \"stim\": 0, \"Log power\": 2.507867322139585, \"Firing rate\": 322.00848984190674, \"Power\": 322.00848984190674, \"i_spike\": 104.0, \"isi\": 0.033195922048375646, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 48, \"stim\": 1, \"Log power\": 2.112923288386241, \"Firing rate\": 129.69501639344497, \"Power\": 129.69501639344497, \"i_spike\": 99.0, \"isi\": 0.03536605585301242, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 49, \"stim\": 0, \"Log power\": 2.3166390901874885, \"Firing rate\": 207.31899275719462, \"Power\": 207.31899275719462, \"i_spike\": 115.0, \"isi\": 0.030455265453359113, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 49, \"stim\": 1, \"Log power\": 2.710592898423363, \"Firing rate\": 513.5620200215044, \"Power\": 513.5620200215044, \"i_spike\": 120.5, \"isi\": 0.02904853954153947, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 50, \"stim\": 0, \"Log power\": 2.615183670349505, \"Firing rate\": 412.2718388413622, \"Power\": 412.2718388413622, \"i_spike\": 111.5, \"isi\": 0.031063691116774393, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 50, \"stim\": 1, \"Log power\": 2.399296858339606, \"Firing rate\": 250.78228685263502, \"Power\": 250.78228685263502, \"i_spike\": 128.0, \"isi\": 0.027343413569181144, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 51, \"stim\": 0, \"Log power\": 2.492740181520329, \"Firing rate\": 310.9855296611351, \"Power\": 310.9855296611351, \"i_spike\": 92.5, \"isi\": 0.03752250780384972, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 51, \"stim\": 1, \"Log power\": 2.4350873876317563, \"Firing rate\": 272.3249218237246, \"Power\": 272.3249218237246, \"i_spike\": 124.5, \"isi\": 0.028183217746151, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 52, \"stim\": 0, \"Log power\": 2.265406219480201, \"Firing rate\": 184.24945821029056, \"Power\": 184.24945821029056, \"i_spike\": 108.5, \"isi\": 0.03199014709906729, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 52, \"stim\": 1, \"Log power\": 2.1397685719778257, \"Firing rate\": 137.96488776445858, \"Power\": 137.96488776445858, \"i_spike\": 116.0, \"isi\": 0.030072371130960625, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 53, \"stim\": 0, \"Log power\": 2.773777400501974, \"Firing rate\": 593.9876296730947, \"Power\": 593.9876296730947, \"i_spike\": 109.5, \"isi\": 0.03190069082562815, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 53, \"stim\": 1, \"Log power\": 3.497852809007061, \"Firing rate\": 3146.681660680951, \"Power\": 3146.681660680951, \"i_spike\": 102.5, \"isi\": 0.03377067321923456, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 54, \"stim\": 0, \"Log power\": 2.036135583584991, \"Firing rate\": 108.67648507604592, \"Power\": 108.67648507604592, \"i_spike\": 100.0, \"isi\": 0.034673360892123015, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 54, \"stim\": 1, \"Log power\": 2.288670286865175, \"Firing rate\": 194.38837392281806, \"Power\": 194.38837392281806, \"i_spike\": 116.0, \"isi\": 0.03025330468824207, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 55, \"stim\": 0, \"Log power\": 2.304147910548738, \"Firing rate\": 201.44101940719474, \"Power\": 201.44101940719474, \"i_spike\": 104.5, \"isi\": 0.03337564378851508, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 55, \"stim\": 1, \"Log power\": 2.728174282230713, \"Firing rate\": 534.7789229453224, \"Power\": 534.7789229453224, \"i_spike\": 105.0, \"isi\": 0.03327383580693417, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 56, \"stim\": 0, \"Log power\": 2.2825010454355796, \"Firing rate\": 191.64656760544074, \"Power\": 191.64656760544074, \"i_spike\": 124.5, \"isi\": 0.028075272388274203, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 56, \"stim\": 1, \"Log power\": 3.3560467201589663, \"Firing rate\": 2270.1090505913025, \"Power\": 2270.1090505913025, \"i_spike\": 117.0, \"isi\": 0.029807087566469537, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 57, \"stim\": 0, \"Log power\": 2.195584728666235, \"Firing rate\": 156.88619448895693, \"Power\": 156.88619448895693, \"i_spike\": 120.5, \"isi\": 0.028951183908237487, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 57, \"stim\": 1, \"Log power\": 2.351384739659477, \"Firing rate\": 224.58706501372157, \"Power\": 224.58706501372157, \"i_spike\": 110.5, \"isi\": 0.03149307351834277, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 58, \"stim\": 0, \"Log power\": 2.2946449832944595, \"Firing rate\": 197.08110258125876, \"Power\": 197.08110258125876, \"i_spike\": 99.5, \"isi\": 0.03518385998989156, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 58, \"stim\": 1, \"Log power\": 2.2544251671222884, \"Firing rate\": 179.6491501725082, \"Power\": 179.6491501725082, \"i_spike\": 115.5, \"isi\": 0.030275274947618364, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 59, \"stim\": 0, \"Log power\": 2.385140382222065, \"Firing rate\": 242.73946041978857, \"Power\": 242.73946041978857, \"i_spike\": 115.5, \"isi\": 0.02995113370801157, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 59, \"stim\": 1, \"Log power\": 2.342816906049887, \"Firing rate\": 220.19979283512473, \"Power\": 220.19979283512473, \"i_spike\": 119.5, \"isi\": 0.029087809038737335, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 60, \"stim\": 0, \"Log power\": 2.6775165359642448, \"Firing rate\": 475.9009107922214, \"Power\": 475.9009107922214, \"i_spike\": 102.5, \"isi\": 0.03410830456044359, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 60, \"stim\": 1, \"Log power\": 2.2903041005548754, \"Firing rate\": 195.12103930030753, \"Power\": 195.12103930030753, \"i_spike\": 128.0, \"isi\": 0.027235099762763736, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 61, \"stim\": 0, \"Log power\": 2.627788853818587, \"Firing rate\": 424.41317171250887, \"Power\": 424.41317171250887, \"i_spike\": 108.0, \"isi\": 0.03224267023787479, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 61, \"stim\": 1, \"Log power\": 2.2598552510014973, \"Firing rate\": 181.90944590411786, \"Power\": 181.90944590411786, \"i_spike\": 122.0, \"isi\": 0.028208277821132176, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 62, \"stim\": 0, \"Log power\": 3.213618680095133, \"Firing rate\": 1635.3799920278398, \"Power\": 1635.3799920278398, \"i_spike\": 120.5, \"isi\": 0.028791547889913692, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 62, \"stim\": 1, \"Log power\": 4.131380948623693, \"Firing rate\": 13532.590764261435, \"Power\": 13532.590764261435, \"i_spike\": 122.5, \"isi\": 0.028391707813144238, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 63, \"stim\": 0, \"Log power\": 2.1902031909767206, \"Firing rate\": 154.95414247894684, \"Power\": 154.95414247894684, \"i_spike\": 97.5, \"isi\": 0.03583563434629115, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 63, \"stim\": 1, \"Log power\": 2.469658643290861, \"Firing rate\": 294.8890479135148, \"Power\": 294.8890479135148, \"i_spike\": 116.0, \"isi\": 0.030016571952686665, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 64, \"stim\": 0, \"Log power\": 2.434945801813104, \"Firing rate\": 272.2361547217169, \"Power\": 272.2361547217169, \"i_spike\": 117.5, \"isi\": 0.02968121825009195, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 64, \"stim\": 1, \"Log power\": 2.2641517706568814, \"Firing rate\": 183.71802611061156, \"Power\": 183.71802611061156, \"i_spike\": 119.0, \"isi\": 0.0293492608638867, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 65, \"stim\": 0, \"Log power\": 2.3114202559055887, \"Firing rate\": 204.84258884538642, \"Power\": 204.84258884538642, \"i_spike\": 108.5, \"isi\": 0.0320918977619244, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 65, \"stim\": 1, \"Log power\": 2.3669601924562342, \"Firing rate\": 232.7877874001859, \"Power\": 232.7877874001859, \"i_spike\": 112.5, \"isi\": 0.030675861793260633, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 66, \"stim\": 0, \"Log power\": 2.356813109757627, \"Firing rate\": 227.41185971598574, \"Power\": 227.41185971598574, \"i_spike\": 101.5, \"isi\": 0.03450849107312674, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 66, \"stim\": 1, \"Log power\": 2.5326082192706747, \"Firing rate\": 340.88525739705557, \"Power\": 340.88525739705557, \"i_spike\": 117.5, \"isi\": 0.02981588907480375, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 67, \"stim\": 0, \"Log power\": 2.097935965046632, \"Firing rate\": 125.2956417997786, \"Power\": 125.2956417997786, \"i_spike\": 104.5, \"isi\": 0.03327364561048795, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 67, \"stim\": 1, \"Log power\": 2.757390357100196, \"Firing rate\": 571.9925299831053, \"Power\": 571.9925299831053, \"i_spike\": 129.0, \"isi\": 0.02705361852230315, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 68, \"stim\": 0, \"Log power\": 3.31584008230167, \"Firing rate\": 2069.379213165911, \"Power\": 2069.379213165911, \"i_spike\": 118.5, \"isi\": 0.0295394008307952, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 68, \"stim\": 1, \"Log power\": 3.0971608396183656, \"Firing rate\": 1250.7221455346228, \"Power\": 1250.7221455346228, \"i_spike\": 115.5, \"isi\": 0.029995273909913828, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 69, \"stim\": 0, \"Log power\": 2.51574368845365, \"Firing rate\": 327.9017152417151, \"Power\": 327.9017152417151, \"i_spike\": 107.5, \"isi\": 0.032534872608338705, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 69, \"stim\": 1, \"Log power\": 2.386341620518817, \"Firing rate\": 243.4117958500848, \"Power\": 243.4117958500848, \"i_spike\": 110.0, \"isi\": 0.03187254275350649, \"combined_condition\": 1.0}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.LayerChart(...)"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "text/html": [
       "\n",
       "<div id=\"altair-viz-49a09815018649f8b2a4a321f59ff55b\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-49a09815018649f8b2a4a321f59ff55b\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-49a09815018649f8b2a4a321f59ff55b\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm//vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm//vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm//vega-lite@4.8.1?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm//vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function loadScript(lib) {\n",
       "      return new Promise(function(resolve, reject) {\n",
       "        var s = document.createElement('script');\n",
       "        s.src = paths[lib];\n",
       "        s.async = true;\n",
       "        s.onload = () => resolve(paths[lib]);\n",
       "        s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "        document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "      });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else if (typeof vegaEmbed === \"function\") {\n",
       "      displayChart(vegaEmbed);\n",
       "    } else {\n",
       "      loadScript(\"vega\")\n",
       "        .then(() => loadScript(\"vega-lite\"))\n",
       "        .then(() => loadScript(\"vega-embed\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 400, \"continuousHeight\": 300}}, \"layer\": [{\"layer\": [{\"mark\": {\"type\": \"line\", \"clip\": true, \"fill\": null, \"opacity\": 0.8}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"ordinal\", \"field\": \"\"}, \"size\": {\"value\": 1.0}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\"}, \"field\": \"Log power\", \"scale\": {\"domain\": [1.7465959203638952, 2.7991800268453546], \"zero\": false}, \"title\": \"Log power\"}}}, {\"mark\": {\"type\": \"circle\", \"clip\": true, \"filled\": true, \"opacity\": 0}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"ordinal\", \"field\": \"\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"Log power\", \"scale\": {\"domain\": [1.7465959203638952, 2.7991800268453546], \"zero\": false}}}}, {\"mark\": {\"type\": \"boxplot\", \"clip\": true, \"color\": \"black\", \"median\": {\"color\": \"red\", \"strokeWidth\": 20}, \"opacity\": 0.3, \"size\": 9}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"Log power\", \"scale\": {\"domain\": [1.7465959203638952, 2.7991800268453546], \"zero\": false}}}}], \"width\": 60}, {\"mark\": {\"type\": \"line\", \"fill\": null}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"quantitative\", \"field\": \"i_trial\"}, \"opacity\": {\"value\": 0.5}, \"size\": {\"value\": 0.9}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"Log power\", \"scale\": {\"clamp\": true, \"domain\": [1.7465959203638952, 2.7991800268453546], \"zero\": false}}}}], \"data\": {\"name\": \"data-64baf6555841c3bad0ba6097e6ff8585\"}, \"$schema\": \"https://vega.github.io/schema/vega-lite/v4.8.1.json\", \"datasets\": {\"data-64baf6555841c3bad0ba6097e6ff8585\": [{\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 0, \"stim\": 0, \"Log power\": 1.6625497755180054, \"Firing rate\": 45.977968194823, \"Power\": 45.977968194823, \"i_spike\": 47.5, \"isi\": 0.07354283633507393, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 0, \"stim\": 1, \"Log power\": 1.782475432512846, \"Firing rate\": 60.600391868556535, \"Power\": 60.600391868556535, \"i_spike\": 50.5, \"isi\": 0.06709212109537435, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 1, \"stim\": 0, \"Log power\": 1.6780165775152507, \"Firing rate\": 47.644917306616556, \"Power\": 47.644917306616556, \"i_spike\": 43.0, \"isi\": 0.07926214363259138, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 1, \"stim\": 1, \"Log power\": 1.8211077850924373, \"Firing rate\": 66.23808758688277, \"Power\": 66.23808758688277, \"i_spike\": 57.5, \"isi\": 0.058750136147541036, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 2, \"stim\": 0, \"Log power\": 2.0766150819706195, \"Firing rate\": 119.29303338504354, \"Power\": 119.29303338504354, \"i_spike\": 32.0, \"isi\": 0.10970724102139953, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 2, \"stim\": 1, \"Log power\": 1.9391979776076984, \"Firing rate\": 86.93566441404978, \"Power\": 86.93566441404978, \"i_spike\": 66.5, \"isi\": 0.04968085796225274, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 3, \"stim\": 0, \"Log power\": 1.6476537252223684, \"Firing rate\": 44.4276892187081, \"Power\": 44.4276892187081, \"i_spike\": 44.5, \"isi\": 0.07727660502735256, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 3, \"stim\": 1, \"Log power\": 2.009877408326617, \"Firing rate\": 102.3004180191958, \"Power\": 102.3004180191958, \"i_spike\": 50.0, \"isi\": 0.06874825391126772, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 4, \"stim\": 0, \"Log power\": 1.9957416381817628, \"Firing rate\": 99.02426741941034, \"Power\": 99.02426741941034, \"i_spike\": 45.5, \"isi\": 0.07620278604838457, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 4, \"stim\": 1, \"Log power\": 1.927856333796681, \"Firing rate\": 84.69471945641088, \"Power\": 84.69471945641088, \"i_spike\": 55.0, \"isi\": 0.0616251200000963, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 5, \"stim\": 0, \"Log power\": 1.9132809823976238, \"Firing rate\": 81.89944946339625, \"Power\": 81.89944946339625, \"i_spike\": 39.5, \"isi\": 0.08739212204242809, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 5, \"stim\": 1, \"Log power\": 2.3898214408114526, \"Firing rate\": 245.36998751434663, \"Power\": 245.36998751434663, \"i_spike\": 52.5, \"isi\": 0.06635568745876487, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 6, \"stim\": 0, \"Log power\": 1.9969983418381505, \"Firing rate\": 99.31122566527485, \"Power\": 99.31122566527485, \"i_spike\": 51.0, \"isi\": 0.0673386975882036, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 6, \"stim\": 1, \"Log power\": 1.7542980267354813, \"Firing rate\": 56.79342062949033, \"Power\": 56.79342062949033, \"i_spike\": 51.0, \"isi\": 0.06821465228737356, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 7, \"stim\": 0, \"Log power\": 1.8473378581898523, \"Firing rate\": 70.36194858541609, \"Power\": 70.36194858541609, \"i_spike\": 47.5, \"isi\": 0.07357355109764273, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 7, \"stim\": 1, \"Log power\": 1.8004488619718322, \"Firing rate\": 63.160980306830645, \"Power\": 63.160980306830645, \"i_spike\": 61.5, \"isi\": 0.05648394362971899, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 8, \"stim\": 0, \"Log power\": 1.7149420010583498, \"Firing rate\": 51.87307591077447, \"Power\": 51.87307591077447, \"i_spike\": 43.5, \"isi\": 0.08011524793269516, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 8, \"stim\": 1, \"Log power\": 2.641833120822674, \"Firing rate\": 438.3622231874032, \"Power\": 438.3622231874032, \"i_spike\": 62.5, \"isi\": 0.05363123023346108, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 9, \"stim\": 0, \"Log power\": 1.8379665875535347, \"Firing rate\": 68.85993169170796, \"Power\": 68.85993169170796, \"i_spike\": 45.0, \"isi\": 0.07837657942481951, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 9, \"stim\": 1, \"Log power\": 1.8859828114170158, \"Firing rate\": 76.91000001098662, \"Power\": 76.91000001098662, \"i_spike\": 57.0, \"isi\": 0.06042001776535927, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 10, \"stim\": 0, \"Log power\": 1.8077611512333742, \"Firing rate\": 64.23343557820496, \"Power\": 64.23343557820496, \"i_spike\": 42.0, \"isi\": 0.083046735898273, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 10, \"stim\": 1, \"Log power\": 2.3461271529189394, \"Firing rate\": 221.88459593516652, \"Power\": 221.88459593516652, \"i_spike\": 55.5, \"isi\": 0.06103085765500905, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 11, \"stim\": 0, \"Log power\": 1.7415319117614236, \"Firing rate\": 55.14827235932182, \"Power\": 55.14827235932182, \"i_spike\": 33.5, \"isi\": 0.10297915019077108, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 11, \"stim\": 1, \"Log power\": 2.1007648420307206, \"Firing rate\": 126.11444762226479, \"Power\": 126.11444762226479, \"i_spike\": 59.5, \"isi\": 0.0576395291856615, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 12, \"stim\": 0, \"Log power\": 2.0006701859195495, \"Firing rate\": 100.15443513921579, \"Power\": 100.15443513921579, \"i_spike\": 33.5, \"isi\": 0.10247731872421481, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 12, \"stim\": 1, \"Log power\": 2.500914066076398, \"Firing rate\": 316.8940362230377, \"Power\": 316.8940362230377, \"i_spike\": 54.5, \"isi\": 0.061916597674327487, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 13, \"stim\": 0, \"Log power\": 1.8816301513737979, \"Firing rate\": 76.14302937597942, \"Power\": 76.14302937597942, \"i_spike\": 37.0, \"isi\": 0.09351272470863202, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 13, \"stim\": 1, \"Log power\": 2.10938763550984, \"Firing rate\": 128.6434372347139, \"Power\": 128.6434372347139, \"i_spike\": 58.0, \"isi\": 0.06005302527969796, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 14, \"stim\": 0, \"Log power\": 2.2716052348133373, \"Firing rate\": 186.89824994890884, \"Power\": 186.89824994890884, \"i_spike\": 55.5, \"isi\": 0.06297327071513874, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 14, \"stim\": 1, \"Log power\": 1.9845826624506278, \"Firing rate\": 96.51229932546447, \"Power\": 96.51229932546447, \"i_spike\": 64.0, \"isi\": 0.05383194516091484, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 15, \"stim\": 0, \"Log power\": 2.250477990975017, \"Firing rate\": 178.02376883001423, \"Power\": 178.02376883001423, \"i_spike\": 31.5, \"isi\": 0.10816378961221756, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 15, \"stim\": 1, \"Log power\": 1.9057488929454696, \"Firing rate\": 80.49129097179582, \"Power\": 80.49129097179582, \"i_spike\": 55.5, \"isi\": 0.06271382662498402, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 16, \"stim\": 0, \"Log power\": 1.85309886906835, \"Firing rate\": 71.30153327597479, \"Power\": 71.30153327597479, \"i_spike\": 43.0, \"isi\": 0.08193823451241652, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 16, \"stim\": 1, \"Log power\": 2.2312550060163914, \"Firing rate\": 170.3158263487131, \"Power\": 170.3158263487131, \"i_spike\": 68.5, \"isi\": 0.05136776537701065, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 17, \"stim\": 0, \"Log power\": 2.3671270453085143, \"Firing rate\": 232.8772399955018, \"Power\": 232.8772399955018, \"i_spike\": 45.0, \"isi\": 0.07420621878282166, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 17, \"stim\": 1, \"Log power\": 2.312739155336508, \"Firing rate\": 205.46561638202544, \"Power\": 205.46561638202544, \"i_spike\": 50.5, \"isi\": 0.0687503819850757, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 18, \"stim\": 0, \"Log power\": 1.9427273969748382, \"Firing rate\": 87.64505077722241, \"Power\": 87.64505077722241, \"i_spike\": 49.5, \"isi\": 0.07008707305661183, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 18, \"stim\": 1, \"Log power\": 2.7684057930927617, \"Firing rate\": 586.6860922077974, \"Power\": 586.6860922077974, \"i_spike\": 42.5, \"isi\": 0.0780428505654008, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 19, \"stim\": 0, \"Log power\": 1.742783557903538, \"Firing rate\": 55.30744013197595, \"Power\": 55.30744013197595, \"i_spike\": 41.0, \"isi\": 0.08430000837937159, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 19, \"stim\": 1, \"Log power\": 1.5724192175144618, \"Firing rate\": 37.36106241490691, \"Power\": 37.36106241490691, \"i_spike\": 44.0, \"isi\": 0.07924970852204646, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 20, \"stim\": 0, \"Log power\": 1.6757122987665798, \"Firing rate\": 47.392792457798336, \"Power\": 47.392792457798336, \"i_spike\": 40.5, \"isi\": 0.08438587583548386, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 20, \"stim\": 1, \"Log power\": 1.8910718120342573, \"Firing rate\": 77.81652126032918, \"Power\": 77.81652126032918, \"i_spike\": 53.5, \"isi\": 0.06367926738304572, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 21, \"stim\": 0, \"Log power\": 1.571384669791069, \"Firing rate\": 37.27216927138806, \"Power\": 37.27216927138806, \"i_spike\": 39.5, \"isi\": 0.08672838699138857, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 21, \"stim\": 1, \"Log power\": 2.1544848415763638, \"Firing rate\": 142.72000149337688, \"Power\": 142.72000149337688, \"i_spike\": 57.5, \"isi\": 0.058690930111028224, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 22, \"stim\": 0, \"Log power\": 2.0990155569441233, \"Firing rate\": 125.60749569857214, \"Power\": 125.60749569857214, \"i_spike\": 42.5, \"isi\": 0.08142636059032474, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 22, \"stim\": 1, \"Log power\": 1.9671675230283032, \"Firing rate\": 92.71874039952, \"Power\": 92.71874039952, \"i_spike\": 68.5, \"isi\": 0.05080615403599393, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 23, \"stim\": 0, \"Log power\": 1.8915945580103632, \"Firing rate\": 77.91024283965878, \"Power\": 77.91024283965878, \"i_spike\": 40.5, \"isi\": 0.08723072421561726, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 23, \"stim\": 1, \"Log power\": 2.0138506338400366, \"Firing rate\": 103.2406270967658, \"Power\": 103.2406270967658, \"i_spike\": 61.0, \"isi\": 0.05603803867480305, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 24, \"stim\": 0, \"Log power\": 1.838615657540525, \"Firing rate\": 68.96292247934187, \"Power\": 68.96292247934187, \"i_spike\": 49.5, \"isi\": 0.07011998827474242, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 24, \"stim\": 1, \"Log power\": 2.0378266686393847, \"Firing rate\": 109.10048183856799, \"Power\": 109.10048183856799, \"i_spike\": 49.5, \"isi\": 0.07007645686923011, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 25, \"stim\": 0, \"Log power\": 2.160395765698059, \"Firing rate\": 144.6757577523293, \"Power\": 144.6757577523293, \"i_spike\": 37.5, \"isi\": 0.0911316621841269, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 25, \"stim\": 1, \"Log power\": 1.8370901904033095, \"Firing rate\": 68.72111390746909, \"Power\": 68.72111390746909, \"i_spike\": 65.0, \"isi\": 0.053356165398502436, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 26, \"stim\": 0, \"Log power\": 1.5792670047135864, \"Firing rate\": 37.954825993505, \"Power\": 37.954825993505, \"i_spike\": 38.5, \"isi\": 0.09106403685321714, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 26, \"stim\": 1, \"Log power\": 1.7660847171662621, \"Firing rate\": 58.355892712709014, \"Power\": 58.355892712709014, \"i_spike\": 47.0, \"isi\": 0.07402118305549837, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 27, \"stim\": 0, \"Log power\": 2.9950507930809986, \"Firing rate\": 988.6687180320453, \"Power\": 988.6687180320453, \"i_spike\": 44.5, \"isi\": 0.07735688495976953, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 27, \"stim\": 1, \"Log power\": 2.2143078512574506, \"Firing rate\": 163.79771962276013, \"Power\": 163.79771962276013, \"i_spike\": 53.5, \"isi\": 0.06225282994792721, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 28, \"stim\": 0, \"Log power\": 1.7959439115726101, \"Firing rate\": 62.509195795069836, \"Power\": 62.509195795069836, \"i_spike\": 42.5, \"isi\": 0.08128744285068623, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 28, \"stim\": 1, \"Log power\": 2.3013973109202865, \"Firing rate\": 200.16922648036277, \"Power\": 200.16922648036277, \"i_spike\": 52.5, \"isi\": 0.06516971434220052, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 29, \"stim\": 0, \"Log power\": 2.1946297973583544, \"Firing rate\": 156.54161043876903, \"Power\": 156.54161043876903, \"i_spike\": 44.5, \"isi\": 0.07727557206965738, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 29, \"stim\": 1, \"Log power\": 1.9558089784240185, \"Firing rate\": 90.32520968335054, \"Power\": 90.32520968335054, \"i_spike\": 59.0, \"isi\": 0.058649479068032195, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 30, \"stim\": 0, \"Log power\": 2.034248188304255, \"Firing rate\": 108.20521400524017, \"Power\": 108.20521400524017, \"i_spike\": 41.0, \"isi\": 0.08579087565424744, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 30, \"stim\": 1, \"Log power\": 2.5721986608468432, \"Firing rate\": 373.4209339798544, \"Power\": 373.4209339798544, \"i_spike\": 66.0, \"isi\": 0.05330483207625823, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 31, \"stim\": 0, \"Log power\": 2.0273796056901263, \"Firing rate\": 106.50735650223092, \"Power\": 106.50735650223092, \"i_spike\": 45.0, \"isi\": 0.07676633890225787, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 31, \"stim\": 1, \"Log power\": 2.286022654934577, \"Firing rate\": 193.2069100607903, \"Power\": 193.2069100607903, \"i_spike\": 56.0, \"isi\": 0.0613939932540251, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 32, \"stim\": 0, \"Log power\": 3.3280364641909714, \"Firing rate\": 2128.317736087387, \"Power\": 2128.317736087387, \"i_spike\": 47.5, \"isi\": 0.07322765281217154, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 32, \"stim\": 1, \"Log power\": 1.9083047527132848, \"Firing rate\": 80.96638564377915, \"Power\": 80.96638564377915, \"i_spike\": 52.5, \"isi\": 0.0632778022576872, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 33, \"stim\": 0, \"Log power\": 1.9016810185687205, \"Firing rate\": 79.7408789814844, \"Power\": 79.7408789814844, \"i_spike\": 40.0, \"isi\": 0.08782328408815572, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 33, \"stim\": 1, \"Log power\": 2.0296871276111905, \"Firing rate\": 107.07476443290204, \"Power\": 107.07476443290204, \"i_spike\": 63.5, \"isi\": 0.05487293151804296, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 34, \"stim\": 0, \"Log power\": 1.650726640690192, \"Firing rate\": 44.743158728629496, \"Power\": 44.743158728629496, \"i_spike\": 37.0, \"isi\": 0.09257067023090851, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 34, \"stim\": 1, \"Log power\": 2.031334590839408, \"Firing rate\": 107.48171582470553, \"Power\": 107.48171582470553, \"i_spike\": 64.0, \"isi\": 0.05462807637479468, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 35, \"stim\": 0, \"Log power\": 1.9781418238636843, \"Firing rate\": 95.09152752901628, \"Power\": 95.09152752901628, \"i_spike\": 42.0, \"isi\": 0.08276101154579588, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 35, \"stim\": 1, \"Log power\": 2.0520094239126423, \"Firing rate\": 112.72219159051606, \"Power\": 112.72219159051606, \"i_spike\": 75.5, \"isi\": 0.04415771856047787, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 36, \"stim\": 0, \"Log power\": 1.8060331458619012, \"Firing rate\": 63.97836626554339, \"Power\": 63.97836626554339, \"i_spike\": 51.0, \"isi\": 0.06650204153706461, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 36, \"stim\": 1, \"Log power\": 1.8623423129251562, \"Firing rate\": 72.8353670086671, \"Power\": 72.8353670086671, \"i_spike\": 53.0, \"isi\": 0.06572110225049307, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 37, \"stim\": 0, \"Log power\": 1.9532183819686684, \"Firing rate\": 89.78801738239333, \"Power\": 89.78801738239333, \"i_spike\": 33.5, \"isi\": 0.09955159917609266, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 37, \"stim\": 1, \"Log power\": 1.7973003649356576, \"Firing rate\": 62.70473906356686, \"Power\": 62.70473906356686, \"i_spike\": 59.5, \"isi\": 0.057688428183748225, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 38, \"stim\": 0, \"Log power\": 1.9476318198751157, \"Firing rate\": 88.64042299874271, \"Power\": 88.64042299874271, \"i_spike\": 43.5, \"isi\": 0.07973225992194521, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 38, \"stim\": 1, \"Log power\": 2.0979555122430877, \"Firing rate\": 125.30128136865821, \"Power\": 125.30128136865821, \"i_spike\": 66.0, \"isi\": 0.05281247759359185, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 39, \"stim\": 0, \"Log power\": 2.679786300644913, \"Firing rate\": 478.3946350794061, \"Power\": 478.3946350794061, \"i_spike\": 40.0, \"isi\": 0.0873890906244907, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 39, \"stim\": 1, \"Log power\": 1.8833105457337704, \"Firing rate\": 76.43821657722582, \"Power\": 76.43821657722582, \"i_spike\": 55.5, \"isi\": 0.0609562796143166, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 40, \"stim\": 0, \"Log power\": 1.673695178196339, \"Firing rate\": 47.1731826783389, \"Power\": 47.1731826783389, \"i_spike\": 46.5, \"isi\": 0.07329633431697158, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 40, \"stim\": 1, \"Log power\": 2.079308312644918, \"Firing rate\": 120.03511493507222, \"Power\": 120.03511493507222, \"i_spike\": 57.0, \"isi\": 0.05839535654311927, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 41, \"stim\": 0, \"Log power\": 1.9556957540470727, \"Firing rate\": 90.30166417910256, \"Power\": 90.30166417910256, \"i_spike\": 39.0, \"isi\": 0.08852862505917714, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 41, \"stim\": 1, \"Log power\": 2.059912145837366, \"Firing rate\": 114.7921383056625, \"Power\": 114.7921383056625, \"i_spike\": 49.0, \"isi\": 0.06835247186146068, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 42, \"stim\": 0, \"Log power\": 2.0507511848871642, \"Firing rate\": 112.3960852100619, \"Power\": 112.3960852100619, \"i_spike\": 41.0, \"isi\": 0.08601568296080994, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 42, \"stim\": 1, \"Log power\": 2.0748263042980017, \"Firing rate\": 118.8026982043569, \"Power\": 118.8026982043569, \"i_spike\": 48.0, \"isi\": 0.07172681228584546, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 43, \"stim\": 0, \"Log power\": 1.8359221100954841, \"Firing rate\": 68.53652964429995, \"Power\": 68.53652964429995, \"i_spike\": 46.0, \"isi\": 0.07597072035963864, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 43, \"stim\": 1, \"Log power\": 1.9937090050607151, \"Firing rate\": 98.56188596715207, \"Power\": 98.56188596715207, \"i_spike\": 68.0, \"isi\": 0.0513725347971293, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 44, \"stim\": 0, \"Log power\": 2.0293463061900066, \"Firing rate\": 106.99076829849588, \"Power\": 106.99076829849588, \"i_spike\": 44.0, \"isi\": 0.07882303495908782, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 44, \"stim\": 1, \"Log power\": 2.0196048170210186, \"Firing rate\": 104.61761547259218, \"Power\": 104.61761547259218, \"i_spike\": 58.5, \"isi\": 0.05958144841822776, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 45, \"stim\": 0, \"Log power\": 1.8377265654586405, \"Firing rate\": 68.82188529844396, \"Power\": 68.82188529844396, \"i_spike\": 41.0, \"isi\": 0.0807325683170197, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 45, \"stim\": 1, \"Log power\": 2.1682453616157247, \"Firing rate\": 147.31445439515846, \"Power\": 147.31445439515846, \"i_spike\": 56.0, \"isi\": 0.06217689188937558, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 46, \"stim\": 0, \"Log power\": 1.7205940818714955, \"Firing rate\": 52.552584824029516, \"Power\": 52.552584824029516, \"i_spike\": 51.0, \"isi\": 0.06645190302631439, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 46, \"stim\": 1, \"Log power\": 1.8710696912300562, \"Firing rate\": 74.31383797355485, \"Power\": 74.31383797355485, \"i_spike\": 58.5, \"isi\": 0.05891229914424447, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 47, \"stim\": 0, \"Log power\": 1.7039842864544466, \"Firing rate\": 50.5806360699715, \"Power\": 50.5806360699715, \"i_spike\": 27.5, \"isi\": 0.12400270581990115, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 47, \"stim\": 1, \"Log power\": 3.312638298459702, \"Firing rate\": 2054.1790632540356, \"Power\": 2054.1790632540356, \"i_spike\": 58.5, \"isi\": 0.059458853061755274, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 48, \"stim\": 0, \"Log power\": 1.6772508055992832, \"Firing rate\": 47.56098119016587, \"Power\": 47.56098119016587, \"i_spike\": 47.0, \"isi\": 0.0705228308378095, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 48, \"stim\": 1, \"Log power\": 2.232253611662001, \"Firing rate\": 170.70789679787646, \"Power\": 170.70789679787646, \"i_spike\": 53.5, \"isi\": 0.06344505318954197, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 49, \"stim\": 0, \"Log power\": 1.655062404256302, \"Firing rate\": 45.192087672225654, \"Power\": 45.192087672225654, \"i_spike\": 40.0, \"isi\": 0.08775481269360264, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 49, \"stim\": 1, \"Log power\": 2.085772014037125, \"Firing rate\": 121.83498496401806, \"Power\": 121.83498496401806, \"i_spike\": 64.5, \"isi\": 0.05425207715902479, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 50, \"stim\": 0, \"Log power\": 1.6266525026336474, \"Firing rate\": 42.330412698891415, \"Power\": 42.330412698891415, \"i_spike\": 41.5, \"isi\": 0.08370436160465566, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 50, \"stim\": 1, \"Log power\": 1.918969810182661, \"Firing rate\": 82.97930827558643, \"Power\": 82.97930827558643, \"i_spike\": 68.5, \"isi\": 0.05137691086662653, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 51, \"stim\": 0, \"Log power\": 1.8125656859069499, \"Firing rate\": 64.94798562811408, \"Power\": 64.94798562811408, \"i_spike\": 38.0, \"isi\": 0.09086928979593929, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 51, \"stim\": 1, \"Log power\": 1.8439844567083397, \"Firing rate\": 69.8207414959996, \"Power\": 69.8207414959996, \"i_spike\": 64.5, \"isi\": 0.05180500982536453, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 52, \"stim\": 0, \"Log power\": 1.6776999534416146, \"Firing rate\": 47.610194254196784, \"Power\": 47.610194254196784, \"i_spike\": 46.0, \"isi\": 0.0762207315983537, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 52, \"stim\": 1, \"Log power\": 2.1999947056869247, \"Firing rate\": 158.4873871769851, \"Power\": 158.4873871769851, \"i_spike\": 60.0, \"isi\": 0.05797460508991254, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 53, \"stim\": 0, \"Log power\": 1.6565284821536752, \"Firing rate\": 45.344903516262065, \"Power\": 45.344903516262065, \"i_spike\": 46.0, \"isi\": 0.07515393887896518, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 53, \"stim\": 1, \"Log power\": 2.1065073265681913, \"Firing rate\": 127.79307681361739, \"Power\": 127.79307681361739, \"i_spike\": 45.5, \"isi\": 0.07531185034790498, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 54, \"stim\": 0, \"Log power\": 1.932341365963057, \"Firing rate\": 85.57390802085132, \"Power\": 85.57390802085132, \"i_spike\": 46.5, \"isi\": 0.07504054660234809, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 54, \"stim\": 1, \"Log power\": 1.9947039553731538, \"Firing rate\": 98.7879459324626, \"Power\": 98.7879459324626, \"i_spike\": 59.0, \"isi\": 0.05931616360677708, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 55, \"stim\": 0, \"Log power\": 1.7616316370565803, \"Firing rate\": 57.76059217291501, \"Power\": 57.76059217291501, \"i_spike\": 35.0, \"isi\": 0.09882212944229501, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 55, \"stim\": 1, \"Log power\": 1.8491341909710781, \"Firing rate\": 70.65358303107308, \"Power\": 70.65358303107308, \"i_spike\": 54.0, \"isi\": 0.06396292039828358, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 56, \"stim\": 0, \"Log power\": 2.0847769811202665, \"Firing rate\": 121.55616252029836, \"Power\": 121.55616252029836, \"i_spike\": 36.5, \"isi\": 0.09620098339847712, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 56, \"stim\": 1, \"Log power\": 2.337404701680528, \"Firing rate\": 217.47267759474167, \"Power\": 217.47267759474167, \"i_spike\": 51.0, \"isi\": 0.06589074308543828, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 57, \"stim\": 0, \"Log power\": 1.6836821030312688, \"Firing rate\": 48.270533970919125, \"Power\": 48.270533970919125, \"i_spike\": 43.5, \"isi\": 0.08008582237911993, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 57, \"stim\": 1, \"Log power\": 2.3710565727711237, \"Firing rate\": 234.99389124598048, \"Power\": 234.99389124598048, \"i_spike\": 61.0, \"isi\": 0.056089999180668156, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 58, \"stim\": 0, \"Log power\": 1.8798793374432592, \"Firing rate\": 75.83668442940264, \"Power\": 75.83668442940264, \"i_spike\": 40.5, \"isi\": 0.08562695135109932, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 58, \"stim\": 1, \"Log power\": 2.008600214584485, \"Firing rate\": 102.00001005746722, \"Power\": 102.00001005746722, \"i_spike\": 50.0, \"isi\": 0.06849064602311145, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 59, \"stim\": 0, \"Log power\": 1.8378644867771181, \"Firing rate\": 68.843744918886, \"Power\": 68.843744918886, \"i_spike\": 44.5, \"isi\": 0.07615217690726388, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 59, \"stim\": 1, \"Log power\": 2.3442124438177028, \"Firing rate\": 220.90850868397348, \"Power\": 220.90850868397348, \"i_spike\": 58.5, \"isi\": 0.058405571923777766, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 60, \"stim\": 0, \"Log power\": 1.9434719738476816, \"Firing rate\": 87.79544285859512, \"Power\": 87.79544285859512, \"i_spike\": 40.5, \"isi\": 0.08584070225119106, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 60, \"stim\": 1, \"Log power\": 2.316164503886908, \"Firing rate\": 207.09256341490877, \"Power\": 207.09256341490877, \"i_spike\": 55.5, \"isi\": 0.06323412106138424, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 61, \"stim\": 0, \"Log power\": 1.7530151270124552, \"Firing rate\": 56.62590121945686, \"Power\": 56.62590121945686, \"i_spike\": 45.0, \"isi\": 0.07812840761067365, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 61, \"stim\": 1, \"Log power\": 1.9686998222743461, \"Firing rate\": 93.04645302586161, \"Power\": 93.04645302586161, \"i_spike\": 50.5, \"isi\": 0.06774657488528416, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 62, \"stim\": 0, \"Log power\": 1.7637851710770174, \"Firing rate\": 58.04772065472716, \"Power\": 58.04772065472716, \"i_spike\": 41.5, \"isi\": 0.0833785270374119, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 62, \"stim\": 1, \"Log power\": 2.0159295170988667, \"Firing rate\": 103.73600460089305, \"Power\": 103.73600460089305, \"i_spike\": 59.5, \"isi\": 0.05866318726774495, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 63, \"stim\": 0, \"Log power\": 1.4582398560956404, \"Firing rate\": 28.723665206713104, \"Power\": 28.723665206713104, \"i_spike\": 28.0, \"isi\": 0.11678930604740018, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 63, \"stim\": 1, \"Log power\": 1.8378189324404344, \"Firing rate\": 68.83652408879881, \"Power\": 68.83652408879881, \"i_spike\": 57.0, \"isi\": 0.0613482699561352, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 64, \"stim\": 0, \"Log power\": 1.7259416502256677, \"Firing rate\": 53.203677249347386, \"Power\": 53.203677249347386, \"i_spike\": 39.5, \"isi\": 0.08957622999624087, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 64, \"stim\": 1, \"Log power\": 2.1782772307373075, \"Firing rate\": 150.75691118615725, \"Power\": 150.75691118615725, \"i_spike\": 66.5, \"isi\": 0.05166655104038336, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 65, \"stim\": 0, \"Log power\": 1.588376096085825, \"Firing rate\": 38.75931526773088, \"Power\": 38.75931526773088, \"i_spike\": 33.5, \"isi\": 0.09652616577103539, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 65, \"stim\": 1, \"Log power\": 2.026607254930215, \"Firing rate\": 106.31811178961277, \"Power\": 106.31811178961277, \"i_spike\": 66.0, \"isi\": 0.052910628121811076, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 66, \"stim\": 0, \"Log power\": 1.9720315758493399, \"Firing rate\": 93.76301758622593, \"Power\": 93.76301758622593, \"i_spike\": 39.0, \"isi\": 0.08724811354150354, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 66, \"stim\": 1, \"Log power\": 2.038134329011705, \"Firing rate\": 109.1777975502512, \"Power\": 109.1777975502512, \"i_spike\": 52.0, \"isi\": 0.06683320213445922, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 67, \"stim\": 0, \"Log power\": 1.836084974166112, \"Firing rate\": 68.56223623712768, \"Power\": 68.56223623712768, \"i_spike\": 38.5, \"isi\": 0.0902314893192157, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 67, \"stim\": 1, \"Log power\": 1.8227859692521355, \"Firing rate\": 66.49453743935133, \"Power\": 66.49453743935133, \"i_spike\": 42.0, \"isi\": 0.08234930398597237, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 68, \"stim\": 0, \"Log power\": 1.632339131898025, \"Firing rate\": 42.888329608155786, \"Power\": 42.888329608155786, \"i_spike\": 40.5, \"isi\": 0.08650216056129542, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 68, \"stim\": 1, \"Log power\": 2.3205536004723557, \"Firing rate\": 209.19610802721925, \"Power\": 209.19610802721925, \"i_spike\": 71.5, \"isi\": 0.04782229208407432, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 69, \"stim\": 0, \"Log power\": 1.8767864116081252, \"Firing rate\": 75.29851504569253, \"Power\": 75.29851504569253, \"i_spike\": 51.5, \"isi\": 0.06771616734836566, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 69, \"stim\": 1, \"Log power\": 1.7421760508548234, \"Firing rate\": 55.23012814238975, \"Power\": 55.23012814238975, \"i_spike\": 59.5, \"isi\": 0.05879567455052462, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 0, \"stim\": 0, \"Log power\": 2.00520516503773, \"Firing rate\": 101.20574473623418, \"Power\": 101.20574473623418, \"i_spike\": 49.5, \"isi\": 0.06904948547500527, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 0, \"stim\": 1, \"Log power\": 2.626101753125223, \"Firing rate\": 422.76765510744195, \"Power\": 422.76765510744195, \"i_spike\": 72.0, \"isi\": 0.04790010526381386, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 1, \"stim\": 0, \"Log power\": 1.8756880718175075, \"Firing rate\": 75.10832413251623, \"Power\": 75.10832413251623, \"i_spike\": 40.5, \"isi\": 0.084983571214487, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 1, \"stim\": 1, \"Log power\": 2.2806503708815176, \"Firing rate\": 190.83163484080103, \"Power\": 190.83163484080103, \"i_spike\": 49.0, \"isi\": 0.0665926715195611, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 2, \"stim\": 0, \"Log power\": 1.8611592156038326, \"Firing rate\": 72.63722021081432, \"Power\": 72.63722021081432, \"i_spike\": 60.5, \"isi\": 0.05765868054822749, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 2, \"stim\": 1, \"Log power\": 1.9544841070398389, \"Firing rate\": 90.0500808416818, \"Power\": 90.0500808416818, \"i_spike\": 65.5, \"isi\": 0.05360725803483716, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 3, \"stim\": 0, \"Log power\": 1.7955485102399653, \"Firing rate\": 62.45231049631098, \"Power\": 62.45231049631098, \"i_spike\": 52.0, \"isi\": 0.06771236917900902, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 3, \"stim\": 1, \"Log power\": 2.0234617050041317, \"Firing rate\": 105.55084270321642, \"Power\": 105.55084270321642, \"i_spike\": 62.0, \"isi\": 0.05666229965325677, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 4, \"stim\": 0, \"Log power\": 1.860354134538902, \"Firing rate\": 72.50269241133196, \"Power\": 72.50269241133196, \"i_spike\": 57.5, \"isi\": 0.061064656757891606, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 4, \"stim\": 1, \"Log power\": 2.037876665515965, \"Firing rate\": 109.11304243406458, \"Power\": 109.11304243406458, \"i_spike\": 61.0, \"isi\": 0.0571257994753636, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 5, \"stim\": 0, \"Log power\": 1.602261117233085, \"Firing rate\": 40.01852867050867, \"Power\": 40.01852867050867, \"i_spike\": 41.0, \"isi\": 0.08396914660009884, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 5, \"stim\": 1, \"Log power\": 2.1676279280310933, \"Firing rate\": 147.105167218697, \"Power\": 147.105167218697, \"i_spike\": 60.5, \"isi\": 0.055888297846155975, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 6, \"stim\": 0, \"Log power\": 2.098654745663673, \"Firing rate\": 125.50318449428715, \"Power\": 125.50318449428715, \"i_spike\": 47.0, \"isi\": 0.07385768666688437, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 6, \"stim\": 1, \"Log power\": 2.5488082727817987, \"Firing rate\": 353.8410969931714, \"Power\": 353.8410969931714, \"i_spike\": 59.5, \"isi\": 0.05694677428313995, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 7, \"stim\": 0, \"Log power\": 1.8221041784074723, \"Firing rate\": 66.39023079542034, \"Power\": 66.39023079542034, \"i_spike\": 54.0, \"isi\": 0.06538704928530525, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 7, \"stim\": 1, \"Log power\": 1.9531847896970977, \"Firing rate\": 89.78107263189972, \"Power\": 89.78107263189972, \"i_spike\": 69.0, \"isi\": 0.05063702611448185, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 8, \"stim\": 0, \"Log power\": 1.6314292886068242, \"Firing rate\": 42.79857297044858, \"Power\": 42.79857297044858, \"i_spike\": 29.5, \"isi\": 0.11334221440940868, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 8, \"stim\": 1, \"Log power\": 1.7437102279701466, \"Firing rate\": 55.425577638088086, \"Power\": 55.425577638088086, \"i_spike\": 59.5, \"isi\": 0.058638471806429476, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 9, \"stim\": 0, \"Log power\": 1.8892446205360307, \"Firing rate\": 77.4898143721203, \"Power\": 77.4898143721203, \"i_spike\": 54.0, \"isi\": 0.06465582544822876, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 9, \"stim\": 1, \"Log power\": 2.390153806733938, \"Firing rate\": 245.55784123977463, \"Power\": 245.55784123977463, \"i_spike\": 58.5, \"isi\": 0.05763090286491456, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 10, \"stim\": 0, \"Log power\": 2.004258339640889, \"Firing rate\": 100.98534177479273, \"Power\": 100.98534177479273, \"i_spike\": 45.5, \"isi\": 0.0756493889425548, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 10, \"stim\": 1, \"Log power\": 1.7589598733803482, \"Firing rate\": 57.40634191924138, \"Power\": 57.40634191924138, \"i_spike\": 51.0, \"isi\": 0.06888395328815433, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 11, \"stim\": 0, \"Log power\": 1.7950781114705112, \"Firing rate\": 62.384702946352924, \"Power\": 62.384702946352924, \"i_spike\": 56.5, \"isi\": 0.06144963670899324, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 11, \"stim\": 1, \"Log power\": 2.1837043190277847, \"Firing rate\": 152.65263984800197, \"Power\": 152.65263984800197, \"i_spike\": 63.0, \"isi\": 0.05453352297859983, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 12, \"stim\": 0, \"Log power\": 2.3970283594074218, \"Firing rate\": 249.475762916957, \"Power\": 249.475762916957, \"i_spike\": 53.5, \"isi\": 0.06304146324290939, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 12, \"stim\": 1, \"Log power\": 2.2226213705303826, \"Firing rate\": 166.96343480061486, \"Power\": 166.96343480061486, \"i_spike\": 65.5, \"isi\": 0.05315542116866027, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 13, \"stim\": 0, \"Log power\": 1.8709612273394876, \"Firing rate\": 74.2952806077999, \"Power\": 74.2952806077999, \"i_spike\": 43.5, \"isi\": 0.07909166860639033, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 13, \"stim\": 1, \"Log power\": 1.9753321332694342, \"Firing rate\": 94.47831372554293, \"Power\": 94.47831372554293, \"i_spike\": 63.0, \"isi\": 0.055301470012196256, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 14, \"stim\": 0, \"Log power\": 1.8955470129786793, \"Firing rate\": 78.62252965180498, \"Power\": 78.62252965180498, \"i_spike\": 40.5, \"isi\": 0.08719393495628738, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 14, \"stim\": 1, \"Log power\": 2.1058290192212112, \"Firing rate\": 127.59363765798803, \"Power\": 127.59363765798803, \"i_spike\": 56.0, \"isi\": 0.06299174969701729, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 15, \"stim\": 0, \"Log power\": 1.607415105698803, \"Firing rate\": 40.496277675250546, \"Power\": 40.496277675250546, \"i_spike\": 43.0, \"isi\": 0.07929321197222094, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 15, \"stim\": 1, \"Log power\": 2.1000543443335, \"Firing rate\": 125.9082954074708, \"Power\": 125.9082954074708, \"i_spike\": 72.5, \"isi\": 0.04832104841538376, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 16, \"stim\": 0, \"Log power\": 2.435560088127117, \"Firing rate\": 272.6214906548113, \"Power\": 272.6214906548113, \"i_spike\": 53.5, \"isi\": 0.0650092804331374, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 16, \"stim\": 1, \"Log power\": 1.8683211970842133, \"Firing rate\": 73.84501738700077, \"Power\": 73.84501738700077, \"i_spike\": 59.5, \"isi\": 0.057092843596689154, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 17, \"stim\": 0, \"Log power\": 1.860862812222898, \"Firing rate\": 72.58766265666598, \"Power\": 72.58766265666598, \"i_spike\": 55.0, \"isi\": 0.06276728694895076, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 17, \"stim\": 1, \"Log power\": 2.305683378096692, \"Firing rate\": 202.15448363217362, \"Power\": 202.15448363217362, \"i_spike\": 63.0, \"isi\": 0.05465439904503797, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 18, \"stim\": 0, \"Log power\": 1.6203301754694193, \"Firing rate\": 41.718643188859495, \"Power\": 41.718643188859495, \"i_spike\": 38.0, \"isi\": 0.09167432617879921, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 18, \"stim\": 1, \"Log power\": 2.175452637332575, \"Firing rate\": 149.77958996513343, \"Power\": 149.77958996513343, \"i_spike\": 64.0, \"isi\": 0.05444090600504606, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 19, \"stim\": 0, \"Log power\": 1.7835551727170662, \"Firing rate\": 60.751243626591595, \"Power\": 60.751243626591595, \"i_spike\": 51.5, \"isi\": 0.06688282354188704, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 19, \"stim\": 1, \"Log power\": 1.8681234159204716, \"Firing rate\": 73.81139543476033, \"Power\": 73.81139543476033, \"i_spike\": 65.0, \"isi\": 0.05327101980445804, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 20, \"stim\": 0, \"Log power\": 1.710002248419502, \"Firing rate\": 51.28640391725188, \"Power\": 51.28640391725188, \"i_spike\": 42.0, \"isi\": 0.08340065116217678, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 20, \"stim\": 1, \"Log power\": 2.1572801968125295, \"Firing rate\": 143.64158769529283, \"Power\": 143.64158769529283, \"i_spike\": 48.0, \"isi\": 0.07218699351822976, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 21, \"stim\": 0, \"Log power\": 2.2585814196585257, \"Firing rate\": 181.3766681162104, \"Power\": 181.3766681162104, \"i_spike\": 50.0, \"isi\": 0.07030757299836425, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 21, \"stim\": 1, \"Log power\": 1.8992648486610908, \"Firing rate\": 79.29847741764938, \"Power\": 79.29847741764938, \"i_spike\": 60.0, \"isi\": 0.05569971857310687, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 22, \"stim\": 0, \"Log power\": 1.8165667473170657, \"Firing rate\": 65.54910214100495, \"Power\": 65.54910214100495, \"i_spike\": 43.5, \"isi\": 0.08015000650371439, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 22, \"stim\": 1, \"Log power\": 1.9593718324882727, \"Firing rate\": 91.06926520833012, \"Power\": 91.06926520833012, \"i_spike\": 63.0, \"isi\": 0.05506193456730659, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 23, \"stim\": 0, \"Log power\": 1.9536006413110272, \"Firing rate\": 89.8670822089673, \"Power\": 89.8670822089673, \"i_spike\": 45.5, \"isi\": 0.07754426414754421, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 23, \"stim\": 1, \"Log power\": 1.8409394097260192, \"Firing rate\": 69.33290699754185, \"Power\": 69.33290699754185, \"i_spike\": 55.5, \"isi\": 0.06217230960205396, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 24, \"stim\": 0, \"Log power\": 1.7280094916746713, \"Firing rate\": 53.457604263645436, \"Power\": 53.457604263645436, \"i_spike\": 53.0, \"isi\": 0.06550508122419536, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 24, \"stim\": 1, \"Log power\": 2.1270437908276056, \"Firing rate\": 133.98117766594035, \"Power\": 133.98117766594035, \"i_spike\": 65.0, \"isi\": 0.05180429801419451, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 25, \"stim\": 0, \"Log power\": 1.8289142103762999, \"Firing rate\": 67.43947960015883, \"Power\": 67.43947960015883, \"i_spike\": 46.5, \"isi\": 0.07494512699752216, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 25, \"stim\": 1, \"Log power\": 2.0662181771820283, \"Firing rate\": 116.47110001054703, \"Power\": 116.47110001054703, \"i_spike\": 49.5, \"isi\": 0.06707792843445651, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 26, \"stim\": 0, \"Log power\": 2.201481288535549, \"Firing rate\": 159.03081643340516, \"Power\": 159.03081643340516, \"i_spike\": 47.5, \"isi\": 0.07228217341540072, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 26, \"stim\": 1, \"Log power\": 1.9623142367032338, \"Firing rate\": 91.68836675350812, \"Power\": 91.68836675350812, \"i_spike\": 60.5, \"isi\": 0.05754195177143786, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 27, \"stim\": 0, \"Log power\": 2.3460231294371283, \"Firing rate\": 221.83145585355663, \"Power\": 221.83145585355663, \"i_spike\": 53.5, \"isi\": 0.06561722001036949, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 27, \"stim\": 1, \"Log power\": 2.097552000634322, \"Firing rate\": 125.1849155325413, \"Power\": 125.1849155325413, \"i_spike\": 58.0, \"isi\": 0.060542714823405085, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 28, \"stim\": 0, \"Log power\": 1.7092604578451096, \"Firing rate\": 51.19887966578024, \"Power\": 51.19887966578024, \"i_spike\": 47.5, \"isi\": 0.07187822658043035, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 28, \"stim\": 1, \"Log power\": 1.7099871781359743, \"Firing rate\": 51.28462427861813, \"Power\": 51.28462427861813, \"i_spike\": 48.0, \"isi\": 0.06948687684331202, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 29, \"stim\": 0, \"Log power\": 1.716331459857159, \"Firing rate\": 52.03930165179824, \"Power\": 52.03930165179824, \"i_spike\": 36.0, \"isi\": 0.09566167214847764, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 29, \"stim\": 1, \"Log power\": 2.2802308112925194, \"Firing rate\": 190.64736682983855, \"Power\": 190.64736682983855, \"i_spike\": 63.5, \"isi\": 0.05502595912921827, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 30, \"stim\": 0, \"Log power\": 2.166107964762489, \"Firing rate\": 146.59122185851825, \"Power\": 146.59122185851825, \"i_spike\": 41.5, \"isi\": 0.08509278304434821, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 30, \"stim\": 1, \"Log power\": 1.96843204685748, \"Firing rate\": 92.98910052841663, \"Power\": 92.98910052841663, \"i_spike\": 68.5, \"isi\": 0.050767575046353784, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 31, \"stim\": 0, \"Log power\": 1.675194170946537, \"Firing rate\": 47.336284988079996, \"Power\": 47.336284988079996, \"i_spike\": 45.5, \"isi\": 0.07593695371188272, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 31, \"stim\": 1, \"Log power\": 2.235941835122672, \"Firing rate\": 172.16379812938368, \"Power\": 172.16379812938368, \"i_spike\": 68.5, \"isi\": 0.051392551482525556, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 32, \"stim\": 0, \"Log power\": 2.112705985449168, \"Firing rate\": 129.6301386215487, \"Power\": 129.6301386215487, \"i_spike\": 55.0, \"isi\": 0.0636875752020839, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 32, \"stim\": 1, \"Log power\": 1.8667573958909214, \"Firing rate\": 73.57959548315647, \"Power\": 73.57959548315647, \"i_spike\": 54.5, \"isi\": 0.0631955586906425, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 33, \"stim\": 0, \"Log power\": 1.7081579564417666, \"Firing rate\": 51.06907085733897, \"Power\": 51.06907085733897, \"i_spike\": 57.0, \"isi\": 0.06079206029631382, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 33, \"stim\": 1, \"Log power\": 2.8665676380402996, \"Firing rate\": 735.4745310830756, \"Power\": 735.4745310830756, \"i_spike\": 60.0, \"isi\": 0.05801241029630827, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 34, \"stim\": 0, \"Log power\": 1.9186016347178718, \"Firing rate\": 82.90899193388682, \"Power\": 82.90899193388682, \"i_spike\": 59.0, \"isi\": 0.059141286752589194, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 34, \"stim\": 1, \"Log power\": 2.500187983897243, \"Firing rate\": 316.3646744918804, \"Power\": 316.3646744918804, \"i_spike\": 73.5, \"isi\": 0.046817307776523404, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 35, \"stim\": 0, \"Log power\": 1.8423892086564415, \"Firing rate\": 69.5647467874487, \"Power\": 69.5647467874487, \"i_spike\": 50.0, \"isi\": 0.0696193650284176, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 35, \"stim\": 1, \"Log power\": 2.297964596367422, \"Firing rate\": 198.59330177438818, \"Power\": 198.59330177438818, \"i_spike\": 77.5, \"isi\": 0.04533033715636319, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 36, \"stim\": 0, \"Log power\": 1.9331897837575438, \"Firing rate\": 85.74124468278278, \"Power\": 85.74124468278278, \"i_spike\": 44.0, \"isi\": 0.08022358370232796, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 36, \"stim\": 1, \"Log power\": 2.015407301423971, \"Firing rate\": 103.61134261883807, \"Power\": 103.61134261883807, \"i_spike\": 58.5, \"isi\": 0.058672660133941484, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 37, \"stim\": 0, \"Log power\": 1.7499094218568783, \"Firing rate\": 56.22240533302668, \"Power\": 56.22240533302668, \"i_spike\": 60.0, \"isi\": 0.05695915322275858, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 37, \"stim\": 1, \"Log power\": 1.7761697777193903, \"Firing rate\": 59.72687298096115, \"Power\": 59.72687298096115, \"i_spike\": 65.0, \"isi\": 0.05310541567529866, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 38, \"stim\": 0, \"Log power\": 1.7570636279235325, \"Firing rate\": 57.156236940234116, \"Power\": 57.156236940234116, \"i_spike\": 40.0, \"isi\": 0.0877566954604918, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 38, \"stim\": 1, \"Log power\": 3.7648748797590907, \"Firing rate\": 5819.355379883706, \"Power\": 5819.355379883706, \"i_spike\": 66.5, \"isi\": 0.0527493504451116, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 39, \"stim\": 0, \"Log power\": 2.056864355758071, \"Firing rate\": 113.98937062084418, \"Power\": 113.98937062084418, \"i_spike\": 49.0, \"isi\": 0.06983233686183395, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 39, \"stim\": 1, \"Log power\": 2.260943222908559, \"Firing rate\": 182.36572725707586, \"Power\": 182.36572725707586, \"i_spike\": 58.5, \"isi\": 0.06014605367962231, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 40, \"stim\": 0, \"Log power\": 1.9266917568178796, \"Firing rate\": 84.46791161521107, \"Power\": 84.46791161521107, \"i_spike\": 44.5, \"isi\": 0.07760110510077572, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 40, \"stim\": 1, \"Log power\": 2.0667919022515884, \"Firing rate\": 116.6250659255421, \"Power\": 116.6250659255421, \"i_spike\": 64.0, \"isi\": 0.05387424415734139, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 41, \"stim\": 0, \"Log power\": 2.010778792483049, \"Firing rate\": 102.51296443572734, \"Power\": 102.51296443572734, \"i_spike\": 42.0, \"isi\": 0.08173793363079603, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 41, \"stim\": 1, \"Log power\": 1.8037716137380864, \"Firing rate\": 63.64607316791711, \"Power\": 63.64607316791711, \"i_spike\": 64.0, \"isi\": 0.053895648457897204, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 42, \"stim\": 0, \"Log power\": 1.6390377968334473, \"Firing rate\": 43.55497781185341, \"Power\": 43.55497781185341, \"i_spike\": 43.0, \"isi\": 0.08222098566390974, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 42, \"stim\": 1, \"Log power\": 2.1295477196874817, \"Firing rate\": 134.7558785137993, \"Power\": 134.7558785137993, \"i_spike\": 63.0, \"isi\": 0.055721477370543955, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 43, \"stim\": 0, \"Log power\": 1.7921719719408802, \"Firing rate\": 61.968640994136265, \"Power\": 61.968640994136265, \"i_spike\": 47.5, \"isi\": 0.0741629541847166, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 43, \"stim\": 1, \"Log power\": 1.7675861143073723, \"Firing rate\": 58.557983681238504, \"Power\": 58.557983681238504, \"i_spike\": 53.0, \"isi\": 0.06655392709645236, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 44, \"stim\": 0, \"Log power\": 1.7843804009385642, \"Firing rate\": 60.866790344152825, \"Power\": 60.866790344152825, \"i_spike\": 53.5, \"isi\": 0.06497889644938687, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 44, \"stim\": 1, \"Log power\": 2.2967602499954918, \"Firing rate\": 198.04334360243965, \"Power\": 198.04334360243965, \"i_spike\": 60.0, \"isi\": 0.05831372042423525, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 45, \"stim\": 0, \"Log power\": 1.8318174405516163, \"Firing rate\": 67.89181834850056, \"Power\": 67.89181834850056, \"i_spike\": 43.0, \"isi\": 0.08089249585234823, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 45, \"stim\": 1, \"Log power\": 2.376885075262605, \"Firing rate\": 238.1689133886673, \"Power\": 238.1689133886673, \"i_spike\": 51.5, \"isi\": 0.0680359374983816, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 46, \"stim\": 0, \"Log power\": 2.249406957954258, \"Firing rate\": 177.5852773757087, \"Power\": 177.5852773757087, \"i_spike\": 47.0, \"isi\": 0.07332592828051299, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 46, \"stim\": 1, \"Log power\": 2.478647596376612, \"Firing rate\": 301.0562144260962, \"Power\": 301.0562144260962, \"i_spike\": 66.0, \"isi\": 0.052266590357286, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 47, \"stim\": 0, \"Log power\": 1.7483394293552887, \"Firing rate\": 56.019525943692976, \"Power\": 56.019525943692976, \"i_spike\": 55.0, \"isi\": 0.06293066793625537, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 47, \"stim\": 1, \"Log power\": 2.3051901104271675, \"Firing rate\": 201.9250087753657, \"Power\": 201.9250087753657, \"i_spike\": 54.5, \"isi\": 0.06251982599653465, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 48, \"stim\": 0, \"Log power\": 1.7978371487852123, \"Firing rate\": 62.782289440628126, \"Power\": 62.782289440628126, \"i_spike\": 50.0, \"isi\": 0.06917168256935709, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 48, \"stim\": 1, \"Log power\": 1.8061762555059597, \"Firing rate\": 63.99945202718756, \"Power\": 63.99945202718756, \"i_spike\": 63.5, \"isi\": 0.053023515277869866, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 49, \"stim\": 0, \"Log power\": 1.8721528224989463, \"Firing rate\": 74.49940813764353, \"Power\": 74.49940813764353, \"i_spike\": 50.0, \"isi\": 0.06911196120055126, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 49, \"stim\": 1, \"Log power\": 2.0867666071011053, \"Firing rate\": 122.11432328630274, \"Power\": 122.11432328630274, \"i_spike\": 56.0, \"isi\": 0.06111629309538056, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 50, \"stim\": 0, \"Log power\": 1.8519996035338695, \"Firing rate\": 71.12128643889423, \"Power\": 71.12128643889423, \"i_spike\": 46.5, \"isi\": 0.07314392377799805, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 50, \"stim\": 1, \"Log power\": 2.1495371267579664, \"Firing rate\": 141.10328570010492, \"Power\": 141.10328570010492, \"i_spike\": 65.5, \"isi\": 0.05280846460485796, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 51, \"stim\": 0, \"Log power\": 1.7877434741967277, \"Firing rate\": 61.33995798804333, \"Power\": 61.33995798804333, \"i_spike\": 43.5, \"isi\": 0.07990038729878156, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 51, \"stim\": 1, \"Log power\": 1.895603837361479, \"Firing rate\": 78.63281753065888, \"Power\": 78.63281753065888, \"i_spike\": 64.5, \"isi\": 0.054490396781366794, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 52, \"stim\": 0, \"Log power\": 1.7538139121158478, \"Firing rate\": 56.73014741792149, \"Power\": 56.73014741792149, \"i_spike\": 47.5, \"isi\": 0.07357993345490055, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 52, \"stim\": 1, \"Log power\": 2.268198432618725, \"Firing rate\": 185.43787103286044, \"Power\": 185.43787103286044, \"i_spike\": 52.0, \"isi\": 0.06736885220536926, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 53, \"stim\": 0, \"Log power\": 1.9589413108863118, \"Firing rate\": 90.97903182830602, \"Power\": 90.97903182830602, \"i_spike\": 48.5, \"isi\": 0.06962547087720211, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 53, \"stim\": 1, \"Log power\": 2.137013106155986, \"Firing rate\": 137.09231373130604, \"Power\": 137.09231373130604, \"i_spike\": 70.5, \"isi\": 0.04954390129623645, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 54, \"stim\": 0, \"Log power\": 1.8585185328471514, \"Firing rate\": 72.19689711920756, \"Power\": 72.19689711920756, \"i_spike\": 45.0, \"isi\": 0.07646790351630087, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 54, \"stim\": 1, \"Log power\": 1.8620451315900062, \"Firing rate\": 72.7855438853719, \"Power\": 72.7855438853719, \"i_spike\": 57.5, \"isi\": 0.059443689053625945, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 55, \"stim\": 0, \"Log power\": 1.9132387563346331, \"Firing rate\": 81.89148684047898, \"Power\": 81.89148684047898, \"i_spike\": 46.0, \"isi\": 0.07614485204133571, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 55, \"stim\": 1, \"Log power\": 1.8888918002743154, \"Firing rate\": 77.42688731398066, \"Power\": 77.42688731398066, \"i_spike\": 65.5, \"isi\": 0.05010081751369354, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 56, \"stim\": 0, \"Log power\": 1.743234980715878, \"Firing rate\": 55.364958754866095, \"Power\": 55.364958754866095, \"i_spike\": 44.5, \"isi\": 0.07680740641986206, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 56, \"stim\": 1, \"Log power\": 2.027320675449232, \"Firing rate\": 106.49290529775867, \"Power\": 106.49290529775867, \"i_spike\": 58.0, \"isi\": 0.05888108168336176, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 57, \"stim\": 0, \"Log power\": 1.751326601668993, \"Firing rate\": 56.40616866222888, \"Power\": 56.40616866222888, \"i_spike\": 37.0, \"isi\": 0.0931779251203798, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 57, \"stim\": 1, \"Log power\": 1.8494568108848146, \"Firing rate\": 70.70608823750923, \"Power\": 70.70608823750923, \"i_spike\": 53.5, \"isi\": 0.0599419762698349, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 58, \"stim\": 0, \"Log power\": 1.6448252330164623, \"Firing rate\": 44.13927881547818, \"Power\": 44.13927881547818, \"i_spike\": 49.0, \"isi\": 0.07023803265524316, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 58, \"stim\": 1, \"Log power\": 1.8884949185180364, \"Firing rate\": 77.35616276296585, \"Power\": 77.35616276296585, \"i_spike\": 62.0, \"isi\": 0.056362068578471286, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 59, \"stim\": 0, \"Log power\": 1.6406935493359673, \"Firing rate\": 43.721348588863776, \"Power\": 43.721348588863776, \"i_spike\": 44.0, \"isi\": 0.0794396115347186, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 59, \"stim\": 1, \"Log power\": 2.0746174468035523, \"Firing rate\": 118.74557827888167, \"Power\": 118.74557827888167, \"i_spike\": 73.5, \"isi\": 0.04678315504422022, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 60, \"stim\": 0, \"Log power\": 1.7674445251591069, \"Firing rate\": 58.538895656920495, \"Power\": 58.538895656920495, \"i_spike\": 56.0, \"isi\": 0.06255112236133384, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 60, \"stim\": 1, \"Log power\": 1.8755250681119262, \"Firing rate\": 75.08013902222497, \"Power\": 75.08013902222497, \"i_spike\": 57.5, \"isi\": 0.0593770388609109, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 61, \"stim\": 0, \"Log power\": 1.7131961636562605, \"Firing rate\": 51.66496787177685, \"Power\": 51.66496787177685, \"i_spike\": 34.0, \"isi\": 0.10379193041068026, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 61, \"stim\": 1, \"Log power\": 1.8685689829439356, \"Firing rate\": 73.88716153745173, \"Power\": 73.88716153745173, \"i_spike\": 67.5, \"isi\": 0.04960459166380905, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 62, \"stim\": 0, \"Log power\": 1.8480944142938047, \"Firing rate\": 70.4846283741453, \"Power\": 70.4846283741453, \"i_spike\": 51.0, \"isi\": 0.06820607253642479, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 62, \"stim\": 1, \"Log power\": 1.8761790545398978, \"Firing rate\": 75.1932843244069, \"Power\": 75.1932843244069, \"i_spike\": 65.5, \"isi\": 0.05151696276499542, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 63, \"stim\": 0, \"Log power\": 1.8012461809840061, \"Firing rate\": 63.27704373419866, \"Power\": 63.27704373419866, \"i_spike\": 45.0, \"isi\": 0.07787659669585852, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 63, \"stim\": 1, \"Log power\": 1.9703096728033718, \"Firing rate\": 93.39199931987974, \"Power\": 93.39199931987974, \"i_spike\": 48.5, \"isi\": 0.07047794037722925, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 64, \"stim\": 0, \"Log power\": 2.368232068195027, \"Firing rate\": 233.47052945895814, \"Power\": 233.47052945895814, \"i_spike\": 48.5, \"isi\": 0.07132832196829238, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 64, \"stim\": 1, \"Log power\": 2.564636679636346, \"Firing rate\": 366.975169407842, \"Power\": 366.975169407842, \"i_spike\": 59.5, \"isi\": 0.05796363426746963, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 65, \"stim\": 0, \"Log power\": 1.964729502055727, \"Firing rate\": 92.19969874958568, \"Power\": 92.19969874958568, \"i_spike\": 49.5, \"isi\": 0.06931393053522295, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 65, \"stim\": 1, \"Log power\": 1.9992228822825648, \"Firing rate\": 99.82122203136544, \"Power\": 99.82122203136544, \"i_spike\": 64.5, \"isi\": 0.05398610216395981, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 66, \"stim\": 0, \"Log power\": 1.9607257251188324, \"Firing rate\": 91.35361235046447, \"Power\": 91.35361235046447, \"i_spike\": 49.5, \"isi\": 0.07107494214712384, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 66, \"stim\": 1, \"Log power\": 2.5437068320755944, \"Firing rate\": 349.7090183250186, \"Power\": 349.7090183250186, \"i_spike\": 65.0, \"isi\": 0.0528257220821202, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 67, \"stim\": 0, \"Log power\": 1.7725244099733481, \"Firing rate\": 59.22763754507072, \"Power\": 59.22763754507072, \"i_spike\": 46.0, \"isi\": 0.07523362975717417, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 67, \"stim\": 1, \"Log power\": 1.980759681071056, \"Firing rate\": 95.66645498970142, \"Power\": 95.66645498970142, \"i_spike\": 56.5, \"isi\": 0.060859803109121494, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 68, \"stim\": 0, \"Log power\": 1.9851574152116886, \"Firing rate\": 96.64010991129788, \"Power\": 96.64010991129788, \"i_spike\": 59.0, \"isi\": 0.05848152512787494, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 68, \"stim\": 1, \"Log power\": 2.2341678477033775, \"Firing rate\": 171.46198519556606, \"Power\": 171.46198519556606, \"i_spike\": 76.5, \"isi\": 0.044652895682355434, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 69, \"stim\": 0, \"Log power\": 1.8922841068864193, \"Firing rate\": 78.03404269057248, \"Power\": 78.03404269057248, \"i_spike\": 45.0, \"isi\": 0.07710366474469474, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 69, \"stim\": 1, \"Log power\": 2.6330885771583836, \"Firing rate\": 429.6240424218396, \"Power\": 429.6240424218396, \"i_spike\": 61.5, \"isi\": 0.05541413498056847, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 0, \"stim\": 0, \"Log power\": 1.5749334932957881, \"Firing rate\": 37.577985395260065, \"Power\": 37.577985395260065, \"i_spike\": 44.5, \"isi\": 0.07943377321968279, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 0, \"stim\": 1, \"Log power\": 2.7379107333474635, \"Firing rate\": 546.9035385646763, \"Power\": 546.9035385646763, \"i_spike\": 64.5, \"isi\": 0.05296536918135109, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 1, \"stim\": 0, \"Log power\": 1.9135891974918313, \"Firing rate\": 81.95759343470856, \"Power\": 81.95759343470856, \"i_spike\": 52.5, \"isi\": 0.06492397836022258, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 1, \"stim\": 1, \"Log power\": 2.176636843485199, \"Firing rate\": 150.18855659890426, \"Power\": 150.18855659890426, \"i_spike\": 79.5, \"isi\": 0.04339997376703324, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 2, \"stim\": 0, \"Log power\": 2.365843066540015, \"Firing rate\": 232.18976208991054, \"Power\": 232.18976208991054, \"i_spike\": 50.0, \"isi\": 0.0695887963223545, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 2, \"stim\": 1, \"Log power\": 2.101771230670745, \"Firing rate\": 126.40703093179754, \"Power\": 126.40703093179754, \"i_spike\": 77.0, \"isi\": 0.04545097357364374, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 3, \"stim\": 0, \"Log power\": 1.8758446119981347, \"Firing rate\": 75.13540158881375, \"Power\": 75.13540158881375, \"i_spike\": 59.0, \"isi\": 0.05926684155623455, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 3, \"stim\": 1, \"Log power\": 1.9430147459839289, \"Firing rate\": 87.70305992322396, \"Power\": 87.70305992322396, \"i_spike\": 73.5, \"isi\": 0.04631258689336168, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 4, \"stim\": 0, \"Log power\": 2.0002063897585765, \"Firing rate\": 100.04753429211092, \"Power\": 100.04753429211092, \"i_spike\": 51.0, \"isi\": 0.06860582437524661, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 4, \"stim\": 1, \"Log power\": 1.9174826026889007, \"Firing rate\": 82.69563810330793, \"Power\": 82.69563810330793, \"i_spike\": 56.0, \"isi\": 0.06275838648586149, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 5, \"stim\": 0, \"Log power\": 1.9267683854606334, \"Firing rate\": 84.48281678384164, \"Power\": 84.48281678384164, \"i_spike\": 51.5, \"isi\": 0.06793945207092161, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 5, \"stim\": 1, \"Log power\": 1.908299581880051, \"Firing rate\": 80.96542164077601, \"Power\": 80.96542164077601, \"i_spike\": 67.0, \"isi\": 0.051368507563807606, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 6, \"stim\": 0, \"Log power\": 1.8873505997145592, \"Firing rate\": 77.15260596632854, \"Power\": 77.15260596632854, \"i_spike\": 58.5, \"isi\": 0.0579618809705398, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 6, \"stim\": 1, \"Log power\": 1.9545251652313096, \"Firing rate\": 90.05859457692718, \"Power\": 90.05859457692718, \"i_spike\": 65.5, \"isi\": 0.05361815158539187, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 7, \"stim\": 0, \"Log power\": 2.0365086921538613, \"Firing rate\": 108.76989070801689, \"Power\": 108.76989070801689, \"i_spike\": 49.5, \"isi\": 0.07095370965697212, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 7, \"stim\": 1, \"Log power\": 2.9572655364455462, \"Firing rate\": 906.2865534932351, \"Power\": 906.2865534932351, \"i_spike\": 65.5, \"isi\": 0.05102668271170815, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 8, \"stim\": 0, \"Log power\": 2.0637908529837152, \"Firing rate\": 115.82194478934085, \"Power\": 115.82194478934085, \"i_spike\": 58.0, \"isi\": 0.059443844633995366, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 8, \"stim\": 1, \"Log power\": 2.313764630792303, \"Firing rate\": 205.95134417353907, \"Power\": 205.95134417353907, \"i_spike\": 91.5, \"isi\": 0.037848569180159435, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 9, \"stim\": 0, \"Log power\": 2.676106443418234, \"Firing rate\": 474.35823385832896, \"Power\": 474.35823385832896, \"i_spike\": 70.5, \"isi\": 0.04830495068709241, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 9, \"stim\": 1, \"Log power\": 2.1110639907459863, \"Firing rate\": 129.14095412211825, \"Power\": 129.14095412211825, \"i_spike\": 75.0, \"isi\": 0.046616310271433786, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 10, \"stim\": 0, \"Log power\": 1.6232640506566587, \"Firing rate\": 42.0014274678324, \"Power\": 42.0014274678324, \"i_spike\": 40.5, \"isi\": 0.08535459247423569, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 10, \"stim\": 1, \"Log power\": 2.096919647626915, \"Firing rate\": 125.00277309697886, \"Power\": 125.00277309697886, \"i_spike\": 84.0, \"isi\": 0.04178774067595231, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 11, \"stim\": 0, \"Log power\": 1.9331854406639293, \"Firing rate\": 85.74038724524688, \"Power\": 85.74038724524688, \"i_spike\": 45.5, \"isi\": 0.07475416969775076, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 11, \"stim\": 1, \"Log power\": 2.2860338712566945, \"Firing rate\": 193.21189999046956, \"Power\": 193.21189999046956, \"i_spike\": 74.5, \"isi\": 0.04694483981113364, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 12, \"stim\": 0, \"Log power\": 2.013785634185715, \"Firing rate\": 103.2251765138098, \"Power\": 103.2251765138098, \"i_spike\": 54.5, \"isi\": 0.062377994946183596, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 12, \"stim\": 1, \"Log power\": 2.0552981499105014, \"Firing rate\": 113.57902857632192, \"Power\": 113.57902857632192, \"i_spike\": 65.0, \"isi\": 0.05367344487702657, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 13, \"stim\": 0, \"Log power\": 2.001328032832847, \"Firing rate\": 100.30625887757395, \"Power\": 100.30625887757395, \"i_spike\": 52.5, \"isi\": 0.06643355183897345, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 13, \"stim\": 1, \"Log power\": 2.029055684492109, \"Firing rate\": 106.91919603900165, \"Power\": 106.91919603900165, \"i_spike\": 58.0, \"isi\": 0.05998731336495791, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 14, \"stim\": 0, \"Log power\": 1.6091774409452742, \"Firing rate\": 40.6609424813706, \"Power\": 40.6609424813706, \"i_spike\": 52.5, \"isi\": 0.06685430488723255, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 14, \"stim\": 1, \"Log power\": 1.9512456770494337, \"Firing rate\": 89.38109627367753, \"Power\": 89.38109627367753, \"i_spike\": 68.0, \"isi\": 0.050811430830218406, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 15, \"stim\": 0, \"Log power\": 1.8708622847115643, \"Firing rate\": 74.27835630110869, \"Power\": 74.27835630110869, \"i_spike\": 45.5, \"isi\": 0.07706380011527493, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 15, \"stim\": 1, \"Log power\": 2.402509178566846, \"Firing rate\": 252.6441104463376, \"Power\": 252.6441104463376, \"i_spike\": 84.5, \"isi\": 0.0409896751820409, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 16, \"stim\": 0, \"Log power\": 1.7573271226032456, \"Firing rate\": 57.19092523263051, \"Power\": 57.19092523263051, \"i_spike\": 55.0, \"isi\": 0.06298129999971641, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 16, \"stim\": 1, \"Log power\": 2.0334988253784623, \"Firing rate\": 108.01866993336576, \"Power\": 108.01866993336576, \"i_spike\": 80.5, \"isi\": 0.04283848037014697, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 17, \"stim\": 0, \"Log power\": 1.8130314591265084, \"Firing rate\": 65.01767856984583, \"Power\": 65.01767856984583, \"i_spike\": 58.0, \"isi\": 0.05878616317174657, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 17, \"stim\": 1, \"Log power\": 1.8576971574606225, \"Firing rate\": 72.06048112794512, \"Power\": 72.06048112794512, \"i_spike\": 65.0, \"isi\": 0.05276322771816143, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 18, \"stim\": 0, \"Log power\": 1.9662726500610492, \"Firing rate\": 92.52788816856142, \"Power\": 92.52788816856142, \"i_spike\": 54.0, \"isi\": 0.06453141568118712, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 18, \"stim\": 1, \"Log power\": 2.1391130916934205, \"Firing rate\": 137.75681454102437, \"Power\": 137.75681454102437, \"i_spike\": 67.0, \"isi\": 0.05099781661502978, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 19, \"stim\": 0, \"Log power\": 1.9572099265690788, \"Firing rate\": 90.61705141263072, \"Power\": 90.61705141263072, \"i_spike\": 42.0, \"isi\": 0.08289420319793103, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 19, \"stim\": 1, \"Log power\": 1.8312652893919428, \"Firing rate\": 67.80555723268918, \"Power\": 67.80555723268918, \"i_spike\": 61.0, \"isi\": 0.056178025827661744, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 20, \"stim\": 0, \"Log power\": 2.4328155806031537, \"Firing rate\": 270.90410167632683, \"Power\": 270.90410167632683, \"i_spike\": 49.0, \"isi\": 0.07016731889146319, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 20, \"stim\": 1, \"Log power\": 3.263607949335591, \"Firing rate\": 1834.8811931531834, \"Power\": 1834.8811931531834, \"i_spike\": 63.0, \"isi\": 0.055385375919981265, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 21, \"stim\": 0, \"Log power\": 2.101449051830407, \"Firing rate\": 126.31329138406011, \"Power\": 126.31329138406011, \"i_spike\": 59.5, \"isi\": 0.05911349078894557, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 21, \"stim\": 1, \"Log power\": 2.207888777043339, \"Firing rate\": 161.39451720165172, \"Power\": 161.39451720165172, \"i_spike\": 59.0, \"isi\": 0.05926310741411494, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 22, \"stim\": 0, \"Log power\": 1.9267003699521277, \"Firing rate\": 84.46958683952812, \"Power\": 84.46958683952812, \"i_spike\": 48.0, \"isi\": 0.07261532335973822, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 22, \"stim\": 1, \"Log power\": 2.250950713277555, \"Firing rate\": 178.21765023337846, \"Power\": 178.21765023337846, \"i_spike\": 79.0, \"isi\": 0.04399623943179176, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 23, \"stim\": 0, \"Log power\": 1.7798858917359148, \"Firing rate\": 60.240128796262965, \"Power\": 60.240128796262965, \"i_spike\": 42.0, \"isi\": 0.08365202131924515, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 23, \"stim\": 1, \"Log power\": 1.8698328179868842, \"Firing rate\": 74.10249282414293, \"Power\": 74.10249282414293, \"i_spike\": 69.5, \"isi\": 0.05011512971498861, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 24, \"stim\": 0, \"Log power\": 1.7408339300589264, \"Firing rate\": 55.05971132213829, \"Power\": 55.05971132213829, \"i_spike\": 49.0, \"isi\": 0.0679345835370269, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 24, \"stim\": 1, \"Log power\": 1.7982632759418413, \"Firing rate\": 62.843921280206814, \"Power\": 62.843921280206814, \"i_spike\": 63.0, \"isi\": 0.055739153709884005, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 25, \"stim\": 0, \"Log power\": 1.9257106345353552, \"Firing rate\": 84.27730405783585, \"Power\": 84.27730405783585, \"i_spike\": 57.5, \"isi\": 0.05961181748074482, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 25, \"stim\": 1, \"Log power\": 3.4328561307238497, \"Firing rate\": 2709.293972012237, \"Power\": 2709.293972012237, \"i_spike\": 81.0, \"isi\": 0.04150756463032279, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 26, \"stim\": 0, \"Log power\": 1.7865120222870157, \"Firing rate\": 61.166273497540935, \"Power\": 61.166273497540935, \"i_spike\": 52.0, \"isi\": 0.06678049819191981, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 26, \"stim\": 1, \"Log power\": 1.992808441381079, \"Firing rate\": 98.35771738289635, \"Power\": 98.35771738289635, \"i_spike\": 63.5, \"isi\": 0.05531311910417264, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 27, \"stim\": 0, \"Log power\": 1.8157312484019956, \"Firing rate\": 65.42311951871677, \"Power\": 65.42311951871677, \"i_spike\": 55.5, \"isi\": 0.0630077631729468, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 27, \"stim\": 1, \"Log power\": 2.3333621104879745, \"Firing rate\": 215.45774515840802, \"Power\": 215.45774515840802, \"i_spike\": 69.0, \"isi\": 0.05050560630228121, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 28, \"stim\": 0, \"Log power\": 1.9940130947745829, \"Firing rate\": 98.6309224213637, \"Power\": 98.6309224213637, \"i_spike\": 36.0, \"isi\": 0.09770522784054125, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 28, \"stim\": 1, \"Log power\": 2.144296934165306, \"Firing rate\": 139.4109652498616, \"Power\": 139.4109652498616, \"i_spike\": 83.5, \"isi\": 0.041017041130571, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 29, \"stim\": 0, \"Log power\": 1.9328772321264005, \"Firing rate\": 85.67956090332135, \"Power\": 85.67956090332135, \"i_spike\": 50.5, \"isi\": 0.06853776265768526, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 29, \"stim\": 1, \"Log power\": 1.854008200560399, \"Firing rate\": 71.45098176712787, \"Power\": 71.45098176712787, \"i_spike\": 66.0, \"isi\": 0.052863568415280456, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 30, \"stim\": 0, \"Log power\": 1.9628713359768517, \"Firing rate\": 91.80605716925574, \"Power\": 91.80605716925574, \"i_spike\": 50.0, \"isi\": 0.06904275105113092, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 30, \"stim\": 1, \"Log power\": 2.32517167071787, \"Firing rate\": 211.43246385259874, \"Power\": 211.43246385259874, \"i_spike\": 65.5, \"isi\": 0.0536052118675172, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 31, \"stim\": 0, \"Log power\": 1.7467076000407382, \"Firing rate\": 55.80943168256906, \"Power\": 55.80943168256906, \"i_spike\": 56.0, \"isi\": 0.0624376332844464, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 31, \"stim\": 1, \"Log power\": 2.2299630977330533, \"Firing rate\": 169.80993577935809, \"Power\": 169.80993577935809, \"i_spike\": 78.5, \"isi\": 0.04406643580014228, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 32, \"stim\": 0, \"Log power\": 1.7164036797602218, \"Firing rate\": 52.04795611548826, \"Power\": 52.04795611548826, \"i_spike\": 51.5, \"isi\": 0.06830738696668638, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 32, \"stim\": 1, \"Log power\": 2.249629835663377, \"Firing rate\": 177.67643662192964, \"Power\": 177.67643662192964, \"i_spike\": 61.0, \"isi\": 0.056569210250451946, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 33, \"stim\": 0, \"Log power\": 1.8388352349235668, \"Firing rate\": 68.99779864600258, \"Power\": 68.99779864600258, \"i_spike\": 43.5, \"isi\": 0.07991809546173433, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 33, \"stim\": 1, \"Log power\": 2.0555628811154856, \"Firing rate\": 113.64828361041003, \"Power\": 113.64828361041003, \"i_spike\": 74.5, \"isi\": 0.04701472940190168, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 34, \"stim\": 0, \"Log power\": 2.1194341234074137, \"Firing rate\": 131.654019625294, \"Power\": 131.654019625294, \"i_spike\": 52.5, \"isi\": 0.06680919856324574, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 34, \"stim\": 1, \"Log power\": 2.884714590473734, \"Firing rate\": 766.8573606223978, \"Power\": 766.8573606223978, \"i_spike\": 71.0, \"isi\": 0.04866439823348472, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 35, \"stim\": 0, \"Log power\": 1.9778409282425284, \"Firing rate\": 95.02566734481009, \"Power\": 95.02566734481009, \"i_spike\": 50.0, \"isi\": 0.06923707956214095, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 35, \"stim\": 1, \"Log power\": 2.202953374065545, \"Firing rate\": 159.57078225585417, \"Power\": 159.57078225585417, \"i_spike\": 70.0, \"isi\": 0.04885789752684091, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 36, \"stim\": 0, \"Log power\": 1.784812013580816, \"Firing rate\": 60.92731134073771, \"Power\": 60.92731134073771, \"i_spike\": 50.0, \"isi\": 0.07058595343558123, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 36, \"stim\": 1, \"Log power\": 3.1409738312028175, \"Firing rate\": 1383.4830134705974, \"Power\": 1383.4830134705974, \"i_spike\": 85.0, \"isi\": 0.041308395897538035, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 37, \"stim\": 0, \"Log power\": 1.9184706072757933, \"Firing rate\": 82.88398191186509, \"Power\": 82.88398191186509, \"i_spike\": 55.5, \"isi\": 0.06324923640619608, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 37, \"stim\": 1, \"Log power\": 2.716295639106646, \"Firing rate\": 520.3500961023163, \"Power\": 520.3500961023163, \"i_spike\": 62.0, \"isi\": 0.056727244498762444, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 38, \"stim\": 0, \"Log power\": 3.8473651307621854, \"Firing rate\": 7036.636727288945, \"Power\": 7036.636727288945, \"i_spike\": 62.0, \"isi\": 0.05600353313547211, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 38, \"stim\": 1, \"Log power\": 2.3112382775280116, \"Firing rate\": 204.75677354098664, \"Power\": 204.75677354098664, \"i_spike\": 73.0, \"isi\": 0.0479308847316747, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 39, \"stim\": 0, \"Log power\": 1.4952981541167647, \"Firing rate\": 31.282262363194192, \"Power\": 31.282262363194192, \"i_spike\": 42.5, \"isi\": 0.08203877964939713, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 39, \"stim\": 1, \"Log power\": 2.5654954718423877, \"Firing rate\": 367.70155952961085, \"Power\": 367.70155952961085, \"i_spike\": 63.5, \"isi\": 0.05521422344425198, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 40, \"stim\": 0, \"Log power\": 2.0587434113870398, \"Firing rate\": 114.48363526837838, \"Power\": 114.48363526837838, \"i_spike\": 59.0, \"isi\": 0.05775697926389982, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 40, \"stim\": 1, \"Log power\": 2.535494934297201, \"Firing rate\": 343.15863709811487, \"Power\": 343.15863709811487, \"i_spike\": 73.0, \"isi\": 0.04544940564685203, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 41, \"stim\": 0, \"Log power\": 1.9290986505059227, \"Firing rate\": 84.93733892964764, \"Power\": 84.93733892964764, \"i_spike\": 54.5, \"isi\": 0.06426866341860926, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 41, \"stim\": 1, \"Log power\": 2.119529189060382, \"Firing rate\": 131.68284141740725, \"Power\": 131.68284141740725, \"i_spike\": 69.0, \"isi\": 0.0500901476136261, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 42, \"stim\": 0, \"Log power\": 1.7707721647357468, \"Firing rate\": 58.989153593622866, \"Power\": 58.989153593622866, \"i_spike\": 54.0, \"isi\": 0.06402896021244067, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 42, \"stim\": 1, \"Log power\": 2.272592238901273, \"Firing rate\": 187.3234893231929, \"Power\": 187.3234893231929, \"i_spike\": 72.5, \"isi\": 0.047910871843303254, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 43, \"stim\": 0, \"Log power\": 1.7923160216809917, \"Firing rate\": 61.98919858254278, \"Power\": 61.98919858254278, \"i_spike\": 48.5, \"isi\": 0.0701745235340201, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 43, \"stim\": 1, \"Log power\": 2.102684459160395, \"Firing rate\": 126.67311756914205, \"Power\": 126.67311756914205, \"i_spike\": 65.5, \"isi\": 0.05124378233589835, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 44, \"stim\": 0, \"Log power\": 1.9886048303170087, \"Firing rate\": 97.4102886614267, \"Power\": 97.4102886614267, \"i_spike\": 50.5, \"isi\": 0.06689126712943644, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 44, \"stim\": 1, \"Log power\": 3.9339798307893687, \"Firing rate\": 8589.736287066924, \"Power\": 8589.736287066924, \"i_spike\": 71.5, \"isi\": 0.04806362754846643, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 45, \"stim\": 0, \"Log power\": 2.1181574574401316, \"Firing rate\": 131.26757353592208, \"Power\": 131.26757353592208, \"i_spike\": 54.0, \"isi\": 0.06475218118244992, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 45, \"stim\": 1, \"Log power\": 3.0155915580898944, \"Firing rate\": 1036.553107827582, \"Power\": 1036.553107827582, \"i_spike\": 66.5, \"isi\": 0.052121906724335185, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 46, \"stim\": 0, \"Log power\": 2.460612200995431, \"Firing rate\": 288.80998301605393, \"Power\": 288.80998301605393, \"i_spike\": 60.0, \"isi\": 0.05816834663971174, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 46, \"stim\": 1, \"Log power\": 2.123614018958845, \"Firing rate\": 132.92724963341564, \"Power\": 132.92724963341564, \"i_spike\": 64.0, \"isi\": 0.054730564194953035, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 47, \"stim\": 0, \"Log power\": 1.8178551381587797, \"Firing rate\": 65.7438507748311, \"Power\": 65.7438507748311, \"i_spike\": 45.0, \"isi\": 0.0770782687061177, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 47, \"stim\": 1, \"Log power\": 2.0392006786431494, \"Firing rate\": 109.44619780568075, \"Power\": 109.44619780568075, \"i_spike\": 69.0, \"isi\": 0.05089717719977343, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 48, \"stim\": 0, \"Log power\": 1.9129060917684284, \"Firing rate\": 81.82878292398146, \"Power\": 81.82878292398146, \"i_spike\": 64.0, \"isi\": 0.05427807930305203, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 48, \"stim\": 1, \"Log power\": 2.44882038792332, \"Firing rate\": 281.0738147138083, \"Power\": 281.0738147138083, \"i_spike\": 63.5, \"isi\": 0.055157625575869694, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 49, \"stim\": 0, \"Log power\": 1.8920662465296576, \"Firing rate\": 77.99490735334801, \"Power\": 77.99490735334801, \"i_spike\": 62.5, \"isi\": 0.056077534750193836, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 49, \"stim\": 1, \"Log power\": 1.9118080169571057, \"Firing rate\": 81.62214749405882, \"Power\": 81.62214749405882, \"i_spike\": 75.5, \"isi\": 0.04601891455309904, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 50, \"stim\": 0, \"Log power\": 1.8896810485448365, \"Firing rate\": 77.56772400469606, \"Power\": 77.56772400469606, \"i_spike\": 60.0, \"isi\": 0.05704692797691012, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 50, \"stim\": 1, \"Log power\": 2.084255331653626, \"Firing rate\": 121.4102439254533, \"Power\": 121.4102439254533, \"i_spike\": 70.5, \"isi\": 0.04957238168445212, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 51, \"stim\": 0, \"Log power\": 2.2357643372895453, \"Firing rate\": 172.09344849681145, \"Power\": 172.09344849681145, \"i_spike\": 55.5, \"isi\": 0.06334381628913896, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 51, \"stim\": 1, \"Log power\": 2.512421061543573, \"Firing rate\": 325.4026321222985, \"Power\": 325.4026321222985, \"i_spike\": 59.5, \"isi\": 0.05782776269814487, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 52, \"stim\": 0, \"Log power\": 1.850990963535423, \"Firing rate\": 70.95630037701366, \"Power\": 70.95630037701366, \"i_spike\": 60.5, \"isi\": 0.05808960247706074, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 52, \"stim\": 1, \"Log power\": 2.3688201645347062, \"Firing rate\": 233.78689583127294, \"Power\": 233.78689583127294, \"i_spike\": 63.5, \"isi\": 0.05487145922751193, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 53, \"stim\": 0, \"Log power\": 2.032687263703032, \"Firing rate\": 107.81700502819685, \"Power\": 107.81700502819685, \"i_spike\": 68.5, \"isi\": 0.0506952002626119, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 53, \"stim\": 1, \"Log power\": 3.030683823901768, \"Firing rate\": 1073.2078085703633, \"Power\": 1073.2078085703633, \"i_spike\": 76.0, \"isi\": 0.04623168479801761, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 54, \"stim\": 0, \"Log power\": 2.0906978838113996, \"Firing rate\": 123.22473243283689, \"Power\": 123.22473243283689, \"i_spike\": 60.5, \"isi\": 0.05676048699786371, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 54, \"stim\": 1, \"Log power\": 1.9156319780205426, \"Firing rate\": 82.34400346079876, \"Power\": 82.34400346079876, \"i_spike\": 65.5, \"isi\": 0.05232473190697469, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 55, \"stim\": 0, \"Log power\": 1.7510340341312678, \"Firing rate\": 56.368182785769, \"Power\": 56.368182785769, \"i_spike\": 57.0, \"isi\": 0.061559740824834466, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 55, \"stim\": 1, \"Log power\": 1.7979907921739262, \"Firing rate\": 62.804504298485014, \"Power\": 62.804504298485014, \"i_spike\": 64.5, \"isi\": 0.05399189150381069, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 56, \"stim\": 0, \"Log power\": 1.7360671783913546, \"Firing rate\": 54.45868851848893, \"Power\": 54.45868851848893, \"i_spike\": 45.5, \"isi\": 0.07661942966192567, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 56, \"stim\": 1, \"Log power\": 2.098760747371754, \"Firing rate\": 125.53382079330537, \"Power\": 125.53382079330537, \"i_spike\": 58.5, \"isi\": 0.059506741815825555, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 57, \"stim\": 0, \"Log power\": 2.5657078174242756, \"Firing rate\": 367.8813888765108, \"Power\": 367.8813888765108, \"i_spike\": 45.5, \"isi\": 0.07315243806126524, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 57, \"stim\": 1, \"Log power\": 1.8640379658323025, \"Firing rate\": 73.12030021338683, \"Power\": 73.12030021338683, \"i_spike\": 70.5, \"isi\": 0.048833407705651144, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 58, \"stim\": 0, \"Log power\": 1.759046405272301, \"Firing rate\": 57.417781102777354, \"Power\": 57.417781102777354, \"i_spike\": 66.5, \"isi\": 0.05260699813845276, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 58, \"stim\": 1, \"Log power\": 1.886550639943834, \"Firing rate\": 77.01062356496165, \"Power\": 77.01062356496165, \"i_spike\": 58.5, \"isi\": 0.06012533608644614, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 59, \"stim\": 0, \"Log power\": 1.918524506801241, \"Firing rate\": 82.89426913565212, \"Power\": 82.89426913565212, \"i_spike\": 54.5, \"isi\": 0.06303437750717443, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 59, \"stim\": 1, \"Log power\": 1.8919699622345283, \"Firing rate\": 77.97761758202086, \"Power\": 77.97761758202086, \"i_spike\": 69.5, \"isi\": 0.04978629715324452, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 60, \"stim\": 0, \"Log power\": 1.7912057599234485, \"Firing rate\": 61.830927315630035, \"Power\": 61.830927315630035, \"i_spike\": 58.5, \"isi\": 0.059698311157695944, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 60, \"stim\": 1, \"Log power\": 2.799019387447701, \"Firing rate\": 629.5342854261299, \"Power\": 629.5342854261299, \"i_spike\": 65.5, \"isi\": 0.05303682204808934, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 61, \"stim\": 0, \"Log power\": 2.0020113649422253, \"Firing rate\": 100.46420801583665, \"Power\": 100.46420801583665, \"i_spike\": 49.5, \"isi\": 0.07090914062608861, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 61, \"stim\": 1, \"Log power\": 2.1721405640830866, \"Firing rate\": 148.64166591886863, \"Power\": 148.64166591886863, \"i_spike\": 58.5, \"isi\": 0.05956371920280016, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 62, \"stim\": 0, \"Log power\": 2.450257798525738, \"Firing rate\": 282.00564285943705, \"Power\": 282.00564285943705, \"i_spike\": 46.0, \"isi\": 0.07612686186128655, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 62, \"stim\": 1, \"Log power\": 1.904903066566133, \"Firing rate\": 80.33467971933419, \"Power\": 80.33467971933419, \"i_spike\": 67.0, \"isi\": 0.05226169166686549, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 63, \"stim\": 0, \"Log power\": 1.9515815834905088, \"Firing rate\": 89.45025510749112, \"Power\": 89.45025510749112, \"i_spike\": 66.5, \"isi\": 0.052318934660735186, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 63, \"stim\": 1, \"Log power\": 1.9259032990375113, \"Firing rate\": 84.31469999002974, \"Power\": 84.31469999002974, \"i_spike\": 70.5, \"isi\": 0.049361689940967755, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 64, \"stim\": 0, \"Log power\": 2.1252356086753323, \"Firing rate\": 133.42450758473038, \"Power\": 133.42450758473038, \"i_spike\": 47.0, \"isi\": 0.07396953612595625, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 64, \"stim\": 1, \"Log power\": 3.920078035222342, \"Firing rate\": 8319.132381237787, \"Power\": 8319.132381237787, \"i_spike\": 72.0, \"isi\": 0.04800705242748367, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 65, \"stim\": 0, \"Log power\": 2.1131749285435153, \"Firing rate\": 129.77018642822452, \"Power\": 129.77018642822452, \"i_spike\": 59.5, \"isi\": 0.0590103513672145, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 65, \"stim\": 1, \"Log power\": 2.181321182621592, \"Firing rate\": 151.81727175049062, \"Power\": 151.81727175049062, \"i_spike\": 69.5, \"isi\": 0.05019603665826838, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 66, \"stim\": 0, \"Log power\": 1.8915333023587966, \"Firing rate\": 77.89925465920646, \"Power\": 77.89925465920646, \"i_spike\": 57.5, \"isi\": 0.05958827839860185, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 66, \"stim\": 1, \"Log power\": 2.0004037782187587, \"Firing rate\": 100.09301660437578, \"Power\": 100.09301660437578, \"i_spike\": 68.5, \"isi\": 0.050901759835215436, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 67, \"stim\": 0, \"Log power\": 2.432051900275914, \"Firing rate\": 270.42815194256787, \"Power\": 270.42815194256787, \"i_spike\": 59.0, \"isi\": 0.05949685594732218, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 67, \"stim\": 1, \"Log power\": 2.0663732604586826, \"Firing rate\": 116.51269838674719, \"Power\": 116.51269838674719, \"i_spike\": 67.0, \"isi\": 0.05166934513187805, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 68, \"stim\": 0, \"Log power\": 1.6179708721178778, \"Firing rate\": 41.49262128376992, \"Power\": 41.49262128376992, \"i_spike\": 46.0, \"isi\": 0.07608370206752937, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 68, \"stim\": 1, \"Log power\": 3.8344656384323454, \"Firing rate\": 6830.706709936496, \"Power\": 6830.706709936496, \"i_spike\": 67.5, \"isi\": 0.049648481688443484, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 69, \"stim\": 0, \"Log power\": 2.0241434282381983, \"Firing rate\": 105.71665868837164, \"Power\": 105.71665868837164, \"i_spike\": 55.5, \"isi\": 0.0630208962135097, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 69, \"stim\": 1, \"Log power\": 2.3744322551616337, \"Firing rate\": 236.82756797792314, \"Power\": 236.82756797792314, \"i_spike\": 85.5, \"isi\": 0.04019396169521371, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 0, \"stim\": 0, \"Log power\": 1.8395227614847653, \"Firing rate\": 69.10711476712522, \"Power\": 69.10711476712522, \"i_spike\": 65.0, \"isi\": 0.053630916270348744, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 0, \"stim\": 1, \"Log power\": 1.979559114361202, \"Firing rate\": 95.40235917332403, \"Power\": 95.40235917332403, \"i_spike\": 71.0, \"isi\": 0.04957983023166928, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 1, \"stim\": 0, \"Log power\": 2.293578194133035, \"Firing rate\": 196.59759200169472, \"Power\": 196.59759200169472, \"i_spike\": 63.5, \"isi\": 0.053322075452964926, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 1, \"stim\": 1, \"Log power\": 2.0387605537249542, \"Firing rate\": 109.33533846768843, \"Power\": 109.33533846768843, \"i_spike\": 74.5, \"isi\": 0.04683335212008752, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 2, \"stim\": 0, \"Log power\": 1.8289112223980541, \"Firing rate\": 67.43901561313284, \"Power\": 67.43901561313284, \"i_spike\": 48.5, \"isi\": 0.069337401412852, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 2, \"stim\": 1, \"Log power\": 2.1499710092746973, \"Firing rate\": 141.24432557867806, \"Power\": 141.24432557867806, \"i_spike\": 73.5, \"isi\": 0.046739319993110824, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 3, \"stim\": 0, \"Log power\": 2.428602938706723, \"Firing rate\": 268.2890444711559, \"Power\": 268.2890444711559, \"i_spike\": 51.0, \"isi\": 0.06678710477113814, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 3, \"stim\": 1, \"Log power\": 2.5291754817531187, \"Firing rate\": 338.20146284881105, \"Power\": 338.20146284881105, \"i_spike\": 76.0, \"isi\": 0.045911592591222884, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 4, \"stim\": 0, \"Log power\": 2.1295435110498584, \"Firing rate\": 134.7545726350998, \"Power\": 134.7545726350998, \"i_spike\": 65.0, \"isi\": 0.0537364841967957, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 4, \"stim\": 1, \"Log power\": 2.425691481003578, \"Firing rate\": 266.49648242457556, \"Power\": 266.49648242457556, \"i_spike\": 80.0, \"isi\": 0.041417840771848076, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 5, \"stim\": 0, \"Log power\": 2.0928402051454493, \"Firing rate\": 123.83408660101263, \"Power\": 123.83408660101263, \"i_spike\": 59.5, \"isi\": 0.05672579442062913, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 5, \"stim\": 1, \"Log power\": 2.20598593072847, \"Firing rate\": 160.68891958775558, \"Power\": 160.68891958775558, \"i_spike\": 67.0, \"isi\": 0.05048218807963795, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 6, \"stim\": 0, \"Log power\": 2.334110408290884, \"Firing rate\": 215.82930303467967, \"Power\": 215.82930303467967, \"i_spike\": 74.5, \"isi\": 0.04675683517064576, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 6, \"stim\": 1, \"Log power\": 1.8517544491264242, \"Firing rate\": 71.08115059246538, \"Power\": 71.08115059246538, \"i_spike\": 74.0, \"isi\": 0.046828455704508894, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 7, \"stim\": 0, \"Log power\": 2.018284511572204, \"Firing rate\": 104.30004878739969, \"Power\": 104.30004878739969, \"i_spike\": 58.5, \"isi\": 0.05966489405441446, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 7, \"stim\": 1, \"Log power\": 2.1312009713091857, \"Firing rate\": 135.26983843494207, \"Power\": 135.26983843494207, \"i_spike\": 80.0, \"isi\": 0.04278028451646302, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 8, \"stim\": 0, \"Log power\": 2.3953511892459347, \"Firing rate\": 248.51418858872697, \"Power\": 248.51418858872697, \"i_spike\": 67.0, \"isi\": 0.05210801101169798, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 8, \"stim\": 1, \"Log power\": 2.1586375368539525, \"Firing rate\": 144.09122609475662, \"Power\": 144.09122609475662, \"i_spike\": 75.5, \"isi\": 0.04571636564392706, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 9, \"stim\": 0, \"Log power\": 2.0225205738655703, \"Firing rate\": 105.32235803888173, \"Power\": 105.32235803888173, \"i_spike\": 64.0, \"isi\": 0.054042474504752316, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 9, \"stim\": 1, \"Log power\": 2.053885464972099, \"Firing rate\": 113.21017584604715, \"Power\": 113.21017584604715, \"i_spike\": 79.0, \"isi\": 0.04412611854187347, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 10, \"stim\": 0, \"Log power\": 2.257812971503425, \"Firing rate\": 181.05602087091782, \"Power\": 181.05602087091782, \"i_spike\": 61.5, \"isi\": 0.05610863794720149, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 10, \"stim\": 1, \"Log power\": 2.0545631134716364, \"Firing rate\": 113.38696047568332, \"Power\": 113.38696047568332, \"i_spike\": 75.5, \"isi\": 0.04665898036022994, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 11, \"stim\": 0, \"Log power\": 2.0890447210245844, \"Firing rate\": 122.75656319501711, \"Power\": 122.75656319501711, \"i_spike\": 51.5, \"isi\": 0.06782397951607, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 11, \"stim\": 1, \"Log power\": 3.371026629766224, \"Firing rate\": 2349.7768984125396, \"Power\": 2349.7768984125396, \"i_spike\": 69.0, \"isi\": 0.049785332077325654, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 12, \"stim\": 0, \"Log power\": 1.56303824583675, \"Firing rate\": 36.56269888778751, \"Power\": 36.56269888778751, \"i_spike\": 42.5, \"isi\": 0.0825037340286652, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 12, \"stim\": 1, \"Log power\": 1.8933843551443503, \"Firing rate\": 78.23198595372384, \"Power\": 78.23198595372384, \"i_spike\": 64.5, \"isi\": 0.05209097235210884, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 13, \"stim\": 0, \"Log power\": 1.8705785933701065, \"Firing rate\": 74.22985178052824, \"Power\": 74.22985178052824, \"i_spike\": 70.5, \"isi\": 0.0489380128420369, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 13, \"stim\": 1, \"Log power\": 2.4851462691102593, \"Firing rate\": 305.595017498699, \"Power\": 305.595017498699, \"i_spike\": 74.0, \"isi\": 0.04711311131950498, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 14, \"stim\": 0, \"Log power\": 1.7994585757748236, \"Firing rate\": 63.01712356250882, \"Power\": 63.01712356250882, \"i_spike\": 41.0, \"isi\": 0.0846530791433244, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 14, \"stim\": 1, \"Log power\": 2.0675077288707153, \"Firing rate\": 116.81745189568983, \"Power\": 116.81745189568983, \"i_spike\": 75.5, \"isi\": 0.04637873254787389, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 15, \"stim\": 0, \"Log power\": 1.995079841151202, \"Firing rate\": 98.87348479968038, \"Power\": 98.87348479968038, \"i_spike\": 61.0, \"isi\": 0.0571959600126965, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 15, \"stim\": 1, \"Log power\": 2.2210379560276947, \"Firing rate\": 166.35580339711643, \"Power\": 166.35580339711643, \"i_spike\": 82.0, \"isi\": 0.041816157103671266, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 16, \"stim\": 0, \"Log power\": 2.1339499123050127, \"Firing rate\": 136.12876744985942, \"Power\": 136.12876744985942, \"i_spike\": 61.5, \"isi\": 0.05714983504152593, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 16, \"stim\": 1, \"Log power\": 2.3323286944799815, \"Firing rate\": 214.94566685148686, \"Power\": 214.94566685148686, \"i_spike\": 79.0, \"isi\": 0.04434022368413476, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 17, \"stim\": 0, \"Log power\": 1.9833345526972057, \"Firing rate\": 96.23533283832164, \"Power\": 96.23533283832164, \"i_spike\": 45.5, \"isi\": 0.07654583109411725, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 17, \"stim\": 1, \"Log power\": 2.172141104199998, \"Firing rate\": 148.64185077944452, \"Power\": 148.64185077944452, \"i_spike\": 67.0, \"isi\": 0.05010246250655258, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 18, \"stim\": 0, \"Log power\": 2.112543667841299, \"Firing rate\": 129.58169839656338, \"Power\": 129.58169839656338, \"i_spike\": 62.5, \"isi\": 0.05377112082842086, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 18, \"stim\": 1, \"Log power\": 2.210021715459556, \"Firing rate\": 162.1891192637679, \"Power\": 162.1891192637679, \"i_spike\": 77.0, \"isi\": 0.04519498045540092, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 19, \"stim\": 0, \"Log power\": 2.0026131647641905, \"Firing rate\": 100.60351729441955, \"Power\": 100.60351729441955, \"i_spike\": 50.5, \"isi\": 0.06820489580832796, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 19, \"stim\": 1, \"Log power\": 2.0370318323637453, \"Firing rate\": 108.9009911269532, \"Power\": 108.9009911269532, \"i_spike\": 81.0, \"isi\": 0.042853414388179994, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 20, \"stim\": 0, \"Log power\": 1.9207855796775546, \"Firing rate\": 83.32696802722485, \"Power\": 83.32696802722485, \"i_spike\": 70.0, \"isi\": 0.04973868124870691, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 20, \"stim\": 1, \"Log power\": 1.9051076683804824, \"Firing rate\": 80.37253535479195, \"Power\": 80.37253535479195, \"i_spike\": 70.0, \"isi\": 0.050203277291417964, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 21, \"stim\": 0, \"Log power\": 2.198728743545616, \"Firing rate\": 158.02607142376806, \"Power\": 158.02607142376806, \"i_spike\": 59.5, \"isi\": 0.05823314590575576, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 21, \"stim\": 1, \"Log power\": 2.0807437060272305, \"Firing rate\": 120.43250118450901, \"Power\": 120.43250118450901, \"i_spike\": 72.0, \"isi\": 0.04819694913579527, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 22, \"stim\": 0, \"Log power\": 1.7444740065038793, \"Firing rate\": 55.52313842848224, \"Power\": 55.52313842848224, \"i_spike\": 57.5, \"isi\": 0.059489116350756516, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 22, \"stim\": 1, \"Log power\": 2.2276621162228643, \"Firing rate\": 168.91262696788266, \"Power\": 168.91262696788266, \"i_spike\": 78.5, \"isi\": 0.044507207562924936, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 23, \"stim\": 0, \"Log power\": 2.32247577879472, \"Firing rate\": 210.1240576679081, \"Power\": 210.1240576679081, \"i_spike\": 62.0, \"isi\": 0.05639881136849346, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 23, \"stim\": 1, \"Log power\": 2.324669250510721, \"Firing rate\": 211.1880064056577, \"Power\": 211.1880064056577, \"i_spike\": 79.0, \"isi\": 0.04356023384962629, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 24, \"stim\": 0, \"Log power\": 1.876376207234443, \"Firing rate\": 75.22742688119314, \"Power\": 75.22742688119314, \"i_spike\": 78.5, \"isi\": 0.04422677905394997, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 24, \"stim\": 1, \"Log power\": 2.284454779689932, \"Firing rate\": 192.51065855906467, \"Power\": 192.51065855906467, \"i_spike\": 79.5, \"isi\": 0.04416270392967511, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 25, \"stim\": 0, \"Log power\": 1.9935599536950763, \"Firing rate\": 98.52806499166216, \"Power\": 98.52806499166216, \"i_spike\": 58.5, \"isi\": 0.05983079937723857, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 25, \"stim\": 1, \"Log power\": 1.9595423974551718, \"Firing rate\": 91.10503880784559, \"Power\": 91.10503880784559, \"i_spike\": 76.5, \"isi\": 0.04528216368486609, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 26, \"stim\": 0, \"Log power\": 1.880525000768862, \"Firing rate\": 75.9495142808881, \"Power\": 75.9495142808881, \"i_spike\": 62.0, \"isi\": 0.0560710156245103, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 26, \"stim\": 1, \"Log power\": 2.0083875550012302, \"Firing rate\": 101.95007626679772, \"Power\": 101.95007626679772, \"i_spike\": 76.0, \"isi\": 0.045828336953587664, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 27, \"stim\": 0, \"Log power\": 3.300002014564387, \"Firing rate\": 1995.2715704255168, \"Power\": 1995.2715704255168, \"i_spike\": 64.5, \"isi\": 0.052761225476386724, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 27, \"stim\": 1, \"Log power\": 2.192438683086075, \"Firing rate\": 155.7538114531551, \"Power\": 155.7538114531551, \"i_spike\": 81.0, \"isi\": 0.04331741035829043, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 28, \"stim\": 0, \"Log power\": 1.9356546504018293, \"Firing rate\": 86.2292582730473, \"Power\": 86.2292582730473, \"i_spike\": 59.0, \"isi\": 0.05941604520777876, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 28, \"stim\": 1, \"Log power\": 2.269221962253762, \"Firing rate\": 185.87541974337458, \"Power\": 185.87541974337458, \"i_spike\": 85.5, \"isi\": 0.03956519477652128, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 29, \"stim\": 0, \"Log power\": 1.960880655217778, \"Firing rate\": 91.3862076277134, \"Power\": 91.3862076277134, \"i_spike\": 66.0, \"isi\": 0.052851259401009494, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 29, \"stim\": 1, \"Log power\": 2.317904343401113, \"Firing rate\": 207.92386688394922, \"Power\": 207.92386688394922, \"i_spike\": 90.5, \"isi\": 0.03878139701103411, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 30, \"stim\": 0, \"Log power\": 2.213722233665811, \"Firing rate\": 163.57699800109793, \"Power\": 163.57699800109793, \"i_spike\": 59.0, \"isi\": 0.05920905747166483, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 30, \"stim\": 1, \"Log power\": 2.0800578436836923, \"Firing rate\": 120.24245748863318, \"Power\": 120.24245748863318, \"i_spike\": 88.0, \"isi\": 0.03910171807630423, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 31, \"stim\": 0, \"Log power\": 1.959418764889166, \"Firing rate\": 91.07910721736455, \"Power\": 91.07910721736455, \"i_spike\": 62.5, \"isi\": 0.0555235970240056, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 31, \"stim\": 1, \"Log power\": 2.197394436254224, \"Firing rate\": 157.54130413283562, \"Power\": 157.54130413283562, \"i_spike\": 76.0, \"isi\": 0.045570952048349815, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 32, \"stim\": 0, \"Log power\": 1.7831137783812137, \"Firing rate\": 60.68953058682318, \"Power\": 60.68953058682318, \"i_spike\": 56.0, \"isi\": 0.06178825380128117, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 32, \"stim\": 1, \"Log power\": 2.0298311584650195, \"Firing rate\": 107.11028094988397, \"Power\": 107.11028094988397, \"i_spike\": 81.0, \"isi\": 0.04322528281096521, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 33, \"stim\": 0, \"Log power\": 2.1342867035110866, \"Firing rate\": 136.2343749471251, \"Power\": 136.2343749471251, \"i_spike\": 54.0, \"isi\": 0.06418255607584347, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 33, \"stim\": 1, \"Log power\": 1.9285537107556434, \"Firing rate\": 84.83082892927328, \"Power\": 84.83082892927328, \"i_spike\": 56.0, \"isi\": 0.062126303086487214, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 34, \"stim\": 0, \"Log power\": 2.411721977725596, \"Firing rate\": 258.0607634286396, \"Power\": 258.0607634286396, \"i_spike\": 62.0, \"isi\": 0.05673612752079895, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 34, \"stim\": 1, \"Log power\": 2.0836455742839335, \"Firing rate\": 121.2399013397276, \"Power\": 121.2399013397276, \"i_spike\": 84.0, \"isi\": 0.04166917607367692, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 35, \"stim\": 0, \"Log power\": 1.9655454922420286, \"Firing rate\": 92.37309439451325, \"Power\": 92.37309439451325, \"i_spike\": 67.0, \"isi\": 0.05147935072043162, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 35, \"stim\": 1, \"Log power\": 2.097459264073676, \"Firing rate\": 125.15818717286099, \"Power\": 125.15818717286099, \"i_spike\": 77.0, \"isi\": 0.045003396025821846, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 36, \"stim\": 0, \"Log power\": 2.046121334396872, \"Firing rate\": 111.20423693669547, \"Power\": 111.20423693669547, \"i_spike\": 62.0, \"isi\": 0.05605824680268041, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 36, \"stim\": 1, \"Log power\": 1.86387178240841, \"Firing rate\": 73.09232597522241, \"Power\": 73.09232597522241, \"i_spike\": 69.0, \"isi\": 0.05031902720804942, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 37, \"stim\": 0, \"Log power\": 2.3424498028391265, \"Firing rate\": 220.01373959442577, \"Power\": 220.01373959442577, \"i_spike\": 52.0, \"isi\": 0.06576199942048623, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 37, \"stim\": 1, \"Log power\": 2.549693083159014, \"Firing rate\": 354.5627304320859, \"Power\": 354.5627304320859, \"i_spike\": 85.0, \"isi\": 0.0413221930981557, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 38, \"stim\": 0, \"Log power\": 2.1577205254413134, \"Firing rate\": 143.78729891423066, \"Power\": 143.78729891423066, \"i_spike\": 66.5, \"isi\": 0.05174969918429245, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 38, \"stim\": 1, \"Log power\": 2.078704072053142, \"Firing rate\": 119.86822435925174, \"Power\": 119.86822435925174, \"i_spike\": 76.5, \"isi\": 0.045005351605003574, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 39, \"stim\": 0, \"Log power\": 2.149206273527988, \"Firing rate\": 140.9958316527641, \"Power\": 140.9958316527641, \"i_spike\": 72.0, \"isi\": 0.047556963977426, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 39, \"stim\": 1, \"Log power\": 2.0104729231475376, \"Firing rate\": 102.4407909808483, \"Power\": 102.4407909808483, \"i_spike\": 74.5, \"isi\": 0.04675157654815791, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 40, \"stim\": 0, \"Log power\": 2.063744731640358, \"Firing rate\": 115.80964534675512, \"Power\": 115.80964534675512, \"i_spike\": 69.0, \"isi\": 0.05068026335149265, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 40, \"stim\": 1, \"Log power\": 3.226696129956056, \"Firing rate\": 1685.3733795197395, \"Power\": 1685.3733795197395, \"i_spike\": 83.5, \"isi\": 0.04155538295653413, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 41, \"stim\": 0, \"Log power\": 2.2891336299906766, \"Firing rate\": 194.59587501722018, \"Power\": 194.59587501722018, \"i_spike\": 67.5, \"isi\": 0.05076586195092699, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 41, \"stim\": 1, \"Log power\": 2.1620541706659013, \"Firing rate\": 145.22927544951278, \"Power\": 145.22927544951278, \"i_spike\": 79.5, \"isi\": 0.04327072519579295, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 42, \"stim\": 0, \"Log power\": 2.2438446783318393, \"Firing rate\": 175.3253353791518, \"Power\": 175.3253353791518, \"i_spike\": 59.5, \"isi\": 0.05876741761237487, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 42, \"stim\": 1, \"Log power\": 1.9093134217935919, \"Firing rate\": 81.15465237478982, \"Power\": 81.15465237478982, \"i_spike\": 70.5, \"isi\": 0.04928685424464279, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 43, \"stim\": 0, \"Log power\": 2.041486224886291, \"Firing rate\": 110.02369470180963, \"Power\": 110.02369470180963, \"i_spike\": 75.0, \"isi\": 0.04640738541500625, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 43, \"stim\": 1, \"Log power\": 1.9275313391361222, \"Firing rate\": 84.63136374656517, \"Power\": 84.63136374656517, \"i_spike\": 73.5, \"isi\": 0.04764079103977659, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 44, \"stim\": 0, \"Log power\": 1.9616890267525733, \"Firing rate\": 91.55646722611571, \"Power\": 91.55646722611571, \"i_spike\": 71.0, \"isi\": 0.04866344986542914, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 44, \"stim\": 1, \"Log power\": 2.64134610644652, \"Firing rate\": 437.8709228002045, \"Power\": 437.8709228002045, \"i_spike\": 71.0, \"isi\": 0.04907690843798719, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 45, \"stim\": 0, \"Log power\": 2.1628963706005546, \"Firing rate\": 145.51118269023607, \"Power\": 145.51118269023607, \"i_spike\": 66.0, \"isi\": 0.05222590121956029, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 45, \"stim\": 1, \"Log power\": 1.8493807156738755, \"Firing rate\": 70.69370050617624, \"Power\": 70.69370050617624, \"i_spike\": 65.5, \"isi\": 0.05341209958719847, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 46, \"stim\": 0, \"Log power\": 2.278284442298818, \"Firing rate\": 189.79485805771773, \"Power\": 189.79485805771773, \"i_spike\": 59.0, \"isi\": 0.05854495635726631, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 46, \"stim\": 1, \"Log power\": 1.9533853257729372, \"Firing rate\": 89.82253873876067, \"Power\": 89.82253873876067, \"i_spike\": 80.5, \"isi\": 0.043330345478925704, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 47, \"stim\": 0, \"Log power\": 2.000786573603222, \"Firing rate\": 100.18127937809187, \"Power\": 100.18127937809187, \"i_spike\": 55.5, \"isi\": 0.06353133496020094, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 47, \"stim\": 1, \"Log power\": 1.915459958304518, \"Firing rate\": 82.31139428019394, \"Power\": 82.31139428019394, \"i_spike\": 60.0, \"isi\": 0.05674268704317264, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 48, \"stim\": 0, \"Log power\": 1.722041976050747, \"Firing rate\": 52.728082245938886, \"Power\": 52.728082245938886, \"i_spike\": 57.5, \"isi\": 0.06089572372609493, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 48, \"stim\": 1, \"Log power\": 1.9500160967050648, \"Firing rate\": 89.12839721002277, \"Power\": 89.12839721002277, \"i_spike\": 81.0, \"isi\": 0.041996433467597946, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 49, \"stim\": 0, \"Log power\": 2.0799770859908677, \"Firing rate\": 120.22010030689178, \"Power\": 120.22010030689178, \"i_spike\": 59.0, \"isi\": 0.05718912583525473, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 49, \"stim\": 1, \"Log power\": 2.389018466686593, \"Firing rate\": 244.91673809640653, \"Power\": 244.91673809640653, \"i_spike\": 77.0, \"isi\": 0.044287128544366984, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 50, \"stim\": 0, \"Log power\": 2.3947582761463004, \"Firing rate\": 248.17514034369765, \"Power\": 248.17514034369765, \"i_spike\": 64.0, \"isi\": 0.054551854973539024, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 50, \"stim\": 1, \"Log power\": 2.074220071896661, \"Firing rate\": 118.63697700928783, \"Power\": 118.63697700928783, \"i_spike\": 71.0, \"isi\": 0.04873642884097521, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 51, \"stim\": 0, \"Log power\": 2.290428193168792, \"Firing rate\": 195.17679994286672, \"Power\": 195.17679994286672, \"i_spike\": 64.5, \"isi\": 0.0543907495448116, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 51, \"stim\": 1, \"Log power\": 2.1352746335778603, \"Firing rate\": 136.54463270800733, \"Power\": 136.54463270800733, \"i_spike\": 77.5, \"isi\": 0.04482107602743747, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 52, \"stim\": 0, \"Log power\": 1.9538187381998564, \"Firing rate\": 89.91222359123263, \"Power\": 89.91222359123263, \"i_spike\": 62.0, \"isi\": 0.05579194105793636, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 52, \"stim\": 1, \"Log power\": 2.0801641534611686, \"Firing rate\": 120.27189491901869, \"Power\": 120.27189491901869, \"i_spike\": 74.0, \"isi\": 0.04625952932986763, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 53, \"stim\": 0, \"Log power\": 1.70612338922617, \"Firing rate\": 50.830383838188354, \"Power\": 50.830383838188354, \"i_spike\": 53.0, \"isi\": 0.0655037393851745, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 53, \"stim\": 1, \"Log power\": 2.1727862370937014, \"Firing rate\": 148.86281837263735, \"Power\": 148.86281837263735, \"i_spike\": 73.0, \"isi\": 0.046751286254206756, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 54, \"stim\": 0, \"Log power\": 2.2406370503140987, \"Firing rate\": 174.03518142312774, \"Power\": 174.03518142312774, \"i_spike\": 57.0, \"isi\": 0.06130726853232248, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 54, \"stim\": 1, \"Log power\": 1.9385530697782305, \"Firing rate\": 86.80666465420352, \"Power\": 86.80666465420352, \"i_spike\": 71.0, \"isi\": 0.04906811469508298, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 55, \"stim\": 0, \"Log power\": 2.0838149412371427, \"Firing rate\": 121.28719191795192, \"Power\": 121.28719191795192, \"i_spike\": 58.0, \"isi\": 0.05960943092388339, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 55, \"stim\": 1, \"Log power\": 2.178450297516235, \"Firing rate\": 150.81699993571598, \"Power\": 150.81699993571598, \"i_spike\": 80.0, \"isi\": 0.043019613868388075, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 56, \"stim\": 0, \"Log power\": 1.947638975016476, \"Firing rate\": 88.64188339026938, \"Power\": 88.64188339026938, \"i_spike\": 65.5, \"isi\": 0.052462561015574866, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 56, \"stim\": 1, \"Log power\": 1.9920170910582269, \"Firing rate\": 98.17865791116809, \"Power\": 98.17865791116809, \"i_spike\": 79.0, \"isi\": 0.043632409857137476, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 57, \"stim\": 0, \"Log power\": 1.7306247816787002, \"Firing rate\": 53.780493327210344, \"Power\": 53.780493327210344, \"i_spike\": 45.0, \"isi\": 0.07824840991160138, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 57, \"stim\": 1, \"Log power\": 2.1359589368588563, \"Firing rate\": 136.75995110660125, \"Power\": 136.75995110660125, \"i_spike\": 86.0, \"isi\": 0.040615574703963715, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 58, \"stim\": 0, \"Log power\": 2.036849447064988, \"Firing rate\": 108.85526692223716, \"Power\": 108.85526692223716, \"i_spike\": 64.0, \"isi\": 0.05491747336030449, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 58, \"stim\": 1, \"Log power\": 1.931494963112017, \"Firing rate\": 85.40729419399811, \"Power\": 85.40729419399811, \"i_spike\": 82.5, \"isi\": 0.042321351439420195, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 59, \"stim\": 0, \"Log power\": 1.8879886175842346, \"Firing rate\": 77.26603341904224, \"Power\": 77.26603341904224, \"i_spike\": 62.0, \"isi\": 0.05575039809744501, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 59, \"stim\": 1, \"Log power\": 1.8421100332620293, \"Firing rate\": 69.52004319186932, \"Power\": 69.52004319186932, \"i_spike\": 71.5, \"isi\": 0.04794731195203566, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 60, \"stim\": 0, \"Log power\": 2.4391899653450095, \"Firing rate\": 274.909637616679, \"Power\": 274.909637616679, \"i_spike\": 59.5, \"isi\": 0.0572702645448569, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 60, \"stim\": 1, \"Log power\": 2.464328275830878, \"Firing rate\": 291.291811149653, \"Power\": 291.291811149653, \"i_spike\": 90.0, \"isi\": 0.03859238638465199, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 61, \"stim\": 0, \"Log power\": 1.643735949627737, \"Firing rate\": 44.02870882436891, \"Power\": 44.02870882436891, \"i_spike\": 58.0, \"isi\": 0.0606749308553595, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 61, \"stim\": 1, \"Log power\": 2.034685711373777, \"Firing rate\": 108.31427855583021, \"Power\": 108.31427855583021, \"i_spike\": 76.5, \"isi\": 0.04513350252425625, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 62, \"stim\": 0, \"Log power\": 1.865028683859883, \"Firing rate\": 73.2872935619889, \"Power\": 73.2872935619889, \"i_spike\": 65.5, \"isi\": 0.05314316905673091, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 62, \"stim\": 1, \"Log power\": 2.2549423384677465, \"Firing rate\": 179.8632093840352, \"Power\": 179.8632093840352, \"i_spike\": 90.0, \"isi\": 0.038709246237376094, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 63, \"stim\": 0, \"Log power\": 2.00410804969701, \"Firing rate\": 100.95040129954573, \"Power\": 100.95040129954573, \"i_spike\": 62.5, \"isi\": 0.055910373747440845, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 63, \"stim\": 1, \"Log power\": 2.5468486688444205, \"Firing rate\": 352.248107793503, \"Power\": 352.248107793503, \"i_spike\": 74.0, \"isi\": 0.0457100415574829, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 64, \"stim\": 0, \"Log power\": 2.2100406407956443, \"Firing rate\": 162.19618716493179, \"Power\": 162.19618716493179, \"i_spike\": 72.5, \"isi\": 0.047832157439283846, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 64, \"stim\": 1, \"Log power\": 2.206805334328521, \"Firing rate\": 160.9923850378919, \"Power\": 160.9923850378919, \"i_spike\": 78.5, \"isi\": 0.044735514069732626, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 65, \"stim\": 0, \"Log power\": 2.3216886947061224, \"Firing rate\": 209.74358880728713, \"Power\": 209.74358880728713, \"i_spike\": 59.0, \"isi\": 0.05821886664579464, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 65, \"stim\": 1, \"Log power\": 2.100987425882594, \"Firing rate\": 126.17910014581133, \"Power\": 126.17910014581133, \"i_spike\": 87.5, \"isi\": 0.03963874923645763, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 66, \"stim\": 0, \"Log power\": 1.8110817602834581, \"Firing rate\": 64.72644582925086, \"Power\": 64.72644582925086, \"i_spike\": 52.0, \"isi\": 0.06640358087592768, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 66, \"stim\": 1, \"Log power\": 2.1218311979207036, \"Firing rate\": 132.38268886250552, \"Power\": 132.38268886250552, \"i_spike\": 79.0, \"isi\": 0.04350156166751065, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 67, \"stim\": 0, \"Log power\": 2.2026781701888978, \"Firing rate\": 159.46969741879522, \"Power\": 159.46969741879522, \"i_spike\": 56.5, \"isi\": 0.06039985534920441, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 67, \"stim\": 1, \"Log power\": 2.34413067284426, \"Firing rate\": 220.8669189238454, \"Power\": 220.8669189238454, \"i_spike\": 74.0, \"isi\": 0.04672800497942512, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 68, \"stim\": 0, \"Log power\": 1.8164969353012714, \"Firing rate\": 65.5385660937755, \"Power\": 65.5385660937755, \"i_spike\": 56.5, \"isi\": 0.06222518933329653, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 68, \"stim\": 1, \"Log power\": 2.0275037207599116, \"Firing rate\": 106.53779911119778, \"Power\": 106.53779911119778, \"i_spike\": 66.5, \"isi\": 0.05208268039668318, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 69, \"stim\": 0, \"Log power\": 2.1450307532346056, \"Firing rate\": 139.64672441089303, \"Power\": 139.64672441089303, \"i_spike\": 55.5, \"isi\": 0.06323715264133578, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 69, \"stim\": 1, \"Log power\": 2.1361298759520073, \"Firing rate\": 136.81379066555488, \"Power\": 136.81379066555488, \"i_spike\": 79.5, \"isi\": 0.043796729119885316, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 0, \"stim\": 0, \"Log power\": 2.232038147432775, \"Firing rate\": 170.62322539551283, \"Power\": 170.62322539551283, \"i_spike\": 70.0, \"isi\": 0.0491130196515757, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 0, \"stim\": 1, \"Log power\": 2.599957413336581, \"Firing rate\": 398.0681343106645, \"Power\": 398.0681343106645, \"i_spike\": 86.5, \"isi\": 0.04000209845556195, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 1, \"stim\": 0, \"Log power\": 2.278330660292888, \"Firing rate\": 189.81505726531861, \"Power\": 189.81505726531861, \"i_spike\": 73.0, \"isi\": 0.04776099369998709, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 1, \"stim\": 1, \"Log power\": 2.3887631284314317, \"Firing rate\": 244.77278454657807, \"Power\": 244.77278454657807, \"i_spike\": 87.0, \"isi\": 0.03995345346002543, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 2, \"stim\": 0, \"Log power\": 2.569799502719949, \"Firing rate\": 371.36374496922457, \"Power\": 371.36374496922457, \"i_spike\": 77.5, \"isi\": 0.045316800774711764, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 2, \"stim\": 1, \"Log power\": 2.3344446471049305, \"Firing rate\": 215.99547207388645, \"Power\": 215.99547207388645, \"i_spike\": 80.0, \"isi\": 0.04385558032881749, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 3, \"stim\": 0, \"Log power\": 2.3294168207243575, \"Firing rate\": 213.50931181358135, \"Power\": 213.50931181358135, \"i_spike\": 80.0, \"isi\": 0.04392404358489545, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 3, \"stim\": 1, \"Log power\": 2.3918449649094096, \"Firing rate\": 246.5159163953205, \"Power\": 246.5159163953205, \"i_spike\": 80.0, \"isi\": 0.0436247428990221, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 4, \"stim\": 0, \"Log power\": 1.9115006065981393, \"Firing rate\": 81.5643926377616, \"Power\": 81.5643926377616, \"i_spike\": 65.5, \"isi\": 0.053447225091462686, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 4, \"stim\": 1, \"Log power\": 2.156842406228217, \"Firing rate\": 143.4968627395441, \"Power\": 143.4968627395441, \"i_spike\": 83.0, \"isi\": 0.04178583071021657, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 5, \"stim\": 0, \"Log power\": 2.1274437270755846, \"Firing rate\": 134.10461605091186, \"Power\": 134.10461605091186, \"i_spike\": 62.5, \"isi\": 0.05596335232460724, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 5, \"stim\": 1, \"Log power\": 2.551041432145341, \"Firing rate\": 355.66524778513855, \"Power\": 355.66524778513855, \"i_spike\": 88.0, \"isi\": 0.039725712216166754, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 6, \"stim\": 0, \"Log power\": 2.3185312179428226, \"Firing rate\": 208.22420755026928, \"Power\": 208.22420755026928, \"i_spike\": 61.5, \"isi\": 0.05611004939399525, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 6, \"stim\": 1, \"Log power\": 1.8782340435815654, \"Firing rate\": 75.54992605064632, \"Power\": 75.54992605064632, \"i_spike\": 73.0, \"isi\": 0.047713609074224415, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 7, \"stim\": 0, \"Log power\": 1.9065439461042506, \"Firing rate\": 80.63877953208015, \"Power\": 80.63877953208015, \"i_spike\": 68.0, \"isi\": 0.05105255314305981, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 7, \"stim\": 1, \"Log power\": 2.2543416656570066, \"Firing rate\": 179.61461248925124, \"Power\": 179.61461248925124, \"i_spike\": 93.0, \"isi\": 0.036988914784223705, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 8, \"stim\": 0, \"Log power\": 2.242001307384897, \"Firing rate\": 174.58274084902857, \"Power\": 174.58274084902857, \"i_spike\": 70.0, \"isi\": 0.04973202237338439, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 8, \"stim\": 1, \"Log power\": 2.3294069464255354, \"Firing rate\": 213.50445743281963, \"Power\": 213.50445743281963, \"i_spike\": 77.5, \"isi\": 0.04389890022446278, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 9, \"stim\": 0, \"Log power\": 2.493796821675739, \"Firing rate\": 311.7430798460456, \"Power\": 311.7430798460456, \"i_spike\": 73.5, \"isi\": 0.04780352772167597, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 9, \"stim\": 1, \"Log power\": 2.0100891562690846, \"Firing rate\": 102.3503085557127, \"Power\": 102.3503085557127, \"i_spike\": 84.5, \"isi\": 0.04119735626526618, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 10, \"stim\": 0, \"Log power\": 1.889819357963796, \"Firing rate\": 77.59243087017438, \"Power\": 77.59243087017438, \"i_spike\": 67.5, \"isi\": 0.05143337599283355, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 10, \"stim\": 1, \"Log power\": 2.2158402928766874, \"Firing rate\": 164.37671343771925, \"Power\": 164.37671343771925, \"i_spike\": 93.5, \"isi\": 0.0375359048585295, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 11, \"stim\": 0, \"Log power\": 2.3578016483359687, \"Firing rate\": 227.93008283528286, \"Power\": 227.93008283528286, \"i_spike\": 75.5, \"isi\": 0.046220060995291676, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 11, \"stim\": 1, \"Log power\": 2.50412573206576, \"Firing rate\": 319.2461967095441, \"Power\": 319.2461967095441, \"i_spike\": 91.0, \"isi\": 0.037483644789133456, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 12, \"stim\": 0, \"Log power\": 1.9212858295138626, \"Firing rate\": 83.42300498020799, \"Power\": 83.42300498020799, \"i_spike\": 62.0, \"isi\": 0.05519875987047357, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 12, \"stim\": 1, \"Log power\": 2.6213186217715485, \"Firing rate\": 418.1370219340618, \"Power\": 418.1370219340618, \"i_spike\": 91.0, \"isi\": 0.03732588057037207, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 13, \"stim\": 0, \"Log power\": 2.0969475751850832, \"Firing rate\": 125.01081173115705, \"Power\": 125.01081173115705, \"i_spike\": 78.5, \"isi\": 0.04424670921347804, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 13, \"stim\": 1, \"Log power\": 2.0969675268088532, \"Firing rate\": 125.01655489870704, \"Power\": 125.01655489870704, \"i_spike\": 96.5, \"isi\": 0.03638232765042332, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 14, \"stim\": 0, \"Log power\": 2.231039751335855, \"Firing rate\": 170.23143155121952, \"Power\": 170.23143155121952, \"i_spike\": 62.0, \"isi\": 0.05549114240926127, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 14, \"stim\": 1, \"Log power\": 2.112360305126023, \"Firing rate\": 129.5269994818085, \"Power\": 129.5269994818085, \"i_spike\": 88.5, \"isi\": 0.03883932239913435, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 15, \"stim\": 0, \"Log power\": 1.8763943639116516, \"Firing rate\": 75.23057200211062, \"Power\": 75.23057200211062, \"i_spike\": 62.0, \"isi\": 0.05589366131761056, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 15, \"stim\": 1, \"Log power\": 2.0940547028568357, \"Firing rate\": 124.18087134623556, \"Power\": 124.18087134623556, \"i_spike\": 84.5, \"isi\": 0.041267956622407356, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 16, \"stim\": 0, \"Log power\": 2.0836760266317165, \"Firing rate\": 121.2484028732266, \"Power\": 121.2484028732266, \"i_spike\": 69.0, \"isi\": 0.05096882642951272, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 16, \"stim\": 1, \"Log power\": 2.1692674286772835, \"Firing rate\": 147.6615519677361, \"Power\": 147.6615519677361, \"i_spike\": 94.0, \"isi\": 0.036918817343829013, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 17, \"stim\": 0, \"Log power\": 1.8546165444141078, \"Firing rate\": 71.55113782473569, \"Power\": 71.55113782473569, \"i_spike\": 64.5, \"isi\": 0.05391089243848297, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 17, \"stim\": 1, \"Log power\": 2.2311220797274656, \"Firing rate\": 170.26370506381744, \"Power\": 170.26370506381744, \"i_spike\": 72.0, \"isi\": 0.046489046451503806, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 18, \"stim\": 0, \"Log power\": 2.160610889616275, \"Firing rate\": 144.74743935721597, \"Power\": 144.74743935721597, \"i_spike\": 68.5, \"isi\": 0.05086969639486453, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 18, \"stim\": 1, \"Log power\": 2.0018789178030842, \"Firing rate\": 100.43357403659718, \"Power\": 100.43357403659718, \"i_spike\": 91.0, \"isi\": 0.03810469312612988, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 19, \"stim\": 0, \"Log power\": 2.8306025979423044, \"Firing rate\": 677.0217139722474, \"Power\": 677.0217139722474, \"i_spike\": 63.5, \"isi\": 0.05497249271354088, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 19, \"stim\": 1, \"Log power\": 2.0977683035824697, \"Firing rate\": 125.24728015306488, \"Power\": 125.24728015306488, \"i_spike\": 92.5, \"isi\": 0.03745661919011265, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 20, \"stim\": 0, \"Log power\": 1.8777543164783022, \"Firing rate\": 75.46651873457924, \"Power\": 75.46651873457924, \"i_spike\": 66.0, \"isi\": 0.05206064635436501, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 20, \"stim\": 1, \"Log power\": 2.211454274997359, \"Firing rate\": 162.72499804541417, \"Power\": 162.72499804541417, \"i_spike\": 80.5, \"isi\": 0.04301396543358983, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 21, \"stim\": 0, \"Log power\": 1.9098933967209388, \"Firing rate\": 81.26310207339468, \"Power\": 81.26310207339468, \"i_spike\": 69.5, \"isi\": 0.05034827323975612, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 21, \"stim\": 1, \"Log power\": 2.469721633650958, \"Firing rate\": 294.9318219187844, \"Power\": 294.9318219187844, \"i_spike\": 79.0, \"isi\": 0.043000843432657566, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 22, \"stim\": 0, \"Log power\": 2.039879985614243, \"Firing rate\": 109.61752335638403, \"Power\": 109.61752335638403, \"i_spike\": 75.0, \"isi\": 0.04673950155431668, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 22, \"stim\": 1, \"Log power\": 2.167107531171989, \"Firing rate\": 146.92900283412388, \"Power\": 146.92900283412388, \"i_spike\": 88.0, \"isi\": 0.03988897300081299, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 23, \"stim\": 0, \"Log power\": 2.12203420952307, \"Firing rate\": 132.44458581335738, \"Power\": 132.44458581335738, \"i_spike\": 72.5, \"isi\": 0.04765591026218666, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 23, \"stim\": 1, \"Log power\": 2.201032599733594, \"Firing rate\": 158.86659952072657, \"Power\": 158.86659952072657, \"i_spike\": 82.0, \"isi\": 0.0427264693927373, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 24, \"stim\": 0, \"Log power\": 2.1112377485313307, \"Firing rate\": 129.19263273329634, \"Power\": 129.19263273329634, \"i_spike\": 57.5, \"isi\": 0.06116911842536544, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 24, \"stim\": 1, \"Log power\": 2.092537549107306, \"Firing rate\": 123.747817769169, \"Power\": 123.747817769169, \"i_spike\": 85.5, \"isi\": 0.040531307879378455, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 25, \"stim\": 0, \"Log power\": 2.133925438227551, \"Firing rate\": 136.12109631364984, \"Power\": 136.12109631364984, \"i_spike\": 76.0, \"isi\": 0.04582546370705599, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 25, \"stim\": 1, \"Log power\": 2.221381809649203, \"Firing rate\": 166.48756812990516, \"Power\": 166.48756812990516, \"i_spike\": 88.5, \"isi\": 0.03962847795483152, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 26, \"stim\": 0, \"Log power\": 2.1469549125563647, \"Firing rate\": 140.26680752634317, \"Power\": 140.26680752634317, \"i_spike\": 65.5, \"isi\": 0.052703095911150126, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 26, \"stim\": 1, \"Log power\": 2.0790327258815346, \"Firing rate\": 119.95896937777833, \"Power\": 119.95896937777833, \"i_spike\": 81.5, \"isi\": 0.04313936191452062, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 27, \"stim\": 0, \"Log power\": 2.095262730469243, \"Firing rate\": 124.52677201893819, \"Power\": 124.52677201893819, \"i_spike\": 82.5, \"isi\": 0.04235340093771166, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 27, \"stim\": 1, \"Log power\": 2.128077775880001, \"Firing rate\": 134.30054525158872, \"Power\": 134.30054525158872, \"i_spike\": 89.5, \"isi\": 0.038255416798234056, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 28, \"stim\": 0, \"Log power\": 2.0035464763817874, \"Firing rate\": 100.81994968911617, \"Power\": 100.81994968911617, \"i_spike\": 60.5, \"isi\": 0.05628909414787073, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 28, \"stim\": 1, \"Log power\": 2.1511785476140175, \"Firing rate\": 141.63759622825782, \"Power\": 141.63759622825782, \"i_spike\": 71.0, \"isi\": 0.04905386223218206, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 29, \"stim\": 0, \"Log power\": 2.0271904745581186, \"Firing rate\": 106.46098365581244, \"Power\": 106.46098365581244, \"i_spike\": 63.0, \"isi\": 0.05587379286121105, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 29, \"stim\": 1, \"Log power\": 2.82166271152805, \"Firing rate\": 663.2277841525802, \"Power\": 663.2277841525802, \"i_spike\": 79.0, \"isi\": 0.04378802341130802, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 30, \"stim\": 0, \"Log power\": 1.9368112244218252, \"Firing rate\": 86.45920232871202, \"Power\": 86.45920232871202, \"i_spike\": 69.5, \"isi\": 0.050053824959915276, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 30, \"stim\": 1, \"Log power\": 2.142940239147891, \"Firing rate\": 138.97613807086597, \"Power\": 138.97613807086597, \"i_spike\": 80.0, \"isi\": 0.04323590081742858, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 31, \"stim\": 0, \"Log power\": 2.578661903769391, \"Firing rate\": 379.0198049383157, \"Power\": 379.0198049383157, \"i_spike\": 66.0, \"isi\": 0.052747029630007755, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 31, \"stim\": 1, \"Log power\": 1.9758127140433446, \"Firing rate\": 94.58291922729767, \"Power\": 94.58291922729767, \"i_spike\": 69.5, \"isi\": 0.04965834393131281, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 32, \"stim\": 0, \"Log power\": 2.0823911555240735, \"Firing rate\": 120.89021654784788, \"Power\": 120.89021654784788, \"i_spike\": 75.5, \"isi\": 0.04600020447219519, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 32, \"stim\": 1, \"Log power\": 2.202518278208964, \"Firing rate\": 159.41099708163156, \"Power\": 159.41099708163156, \"i_spike\": 70.0, \"isi\": 0.04783331306717344, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 33, \"stim\": 0, \"Log power\": 1.9097496627139794, \"Firing rate\": 81.23621170492812, \"Power\": 81.23621170492812, \"i_spike\": 68.5, \"isi\": 0.05114018440803222, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 33, \"stim\": 1, \"Log power\": 1.9007914064635327, \"Firing rate\": 79.57770434232367, \"Power\": 79.57770434232367, \"i_spike\": 88.5, \"isi\": 0.03929077635522098, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 34, \"stim\": 0, \"Log power\": 1.8613063646955428, \"Firing rate\": 72.66183556372675, \"Power\": 72.66183556372675, \"i_spike\": 71.5, \"isi\": 0.048652076906969294, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 34, \"stim\": 1, \"Log power\": 1.983298333805918, \"Firing rate\": 96.22730742730312, \"Power\": 96.22730742730312, \"i_spike\": 93.0, \"isi\": 0.03775425935173657, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 35, \"stim\": 0, \"Log power\": 2.303264757550591, \"Firing rate\": 201.03179828197327, \"Power\": 201.03179828197327, \"i_spike\": 73.5, \"isi\": 0.04643742276038672, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 35, \"stim\": 1, \"Log power\": 2.0625307632296823, \"Firing rate\": 115.48637865154846, \"Power\": 115.48637865154846, \"i_spike\": 75.5, \"isi\": 0.045075323441407404, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 36, \"stim\": 0, \"Log power\": 2.4779416635478615, \"Firing rate\": 300.56725396140996, \"Power\": 300.56725396140996, \"i_spike\": 59.0, \"isi\": 0.057861074937277504, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 36, \"stim\": 1, \"Log power\": 2.032555307965476, \"Firing rate\": 107.78425095956347, \"Power\": 107.78425095956347, \"i_spike\": 84.0, \"isi\": 0.04136941517833224, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 37, \"stim\": 0, \"Log power\": 1.7928724485060814, \"Firing rate\": 62.068671290687455, \"Power\": 62.068671290687455, \"i_spike\": 66.5, \"isi\": 0.051625259341073856, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 37, \"stim\": 1, \"Log power\": 2.202854024414535, \"Firing rate\": 159.53428285505737, \"Power\": 159.53428285505737, \"i_spike\": 87.5, \"isi\": 0.039990808735530535, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 38, \"stim\": 0, \"Log power\": 2.0562441439289505, \"Firing rate\": 113.82669966423785, \"Power\": 113.82669966423785, \"i_spike\": 74.0, \"isi\": 0.04747140920605517, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 38, \"stim\": 1, \"Log power\": 3.0256981333491924, \"Firing rate\": 1060.9578570000572, \"Power\": 1060.9578570000572, \"i_spike\": 79.0, \"isi\": 0.04364780345053541, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 39, \"stim\": 0, \"Log power\": 1.8179321498739058, \"Firing rate\": 65.75550990440746, \"Power\": 65.75550990440746, \"i_spike\": 70.0, \"isi\": 0.04979511086536484, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 39, \"stim\": 1, \"Log power\": 2.0444777454384666, \"Firing rate\": 110.78417947586794, \"Power\": 110.78417947586794, \"i_spike\": 93.0, \"isi\": 0.03737886976706276, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 40, \"stim\": 0, \"Log power\": 1.8791649756238011, \"Firing rate\": 75.71204480576654, \"Power\": 75.71204480576654, \"i_spike\": 75.5, \"isi\": 0.04588671514072249, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 40, \"stim\": 1, \"Log power\": 2.1788081516688185, \"Firing rate\": 150.94132279411852, \"Power\": 150.94132279411852, \"i_spike\": 102.5, \"isi\": 0.03413982107180815, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 41, \"stim\": 0, \"Log power\": 2.0681295873894516, \"Firing rate\": 116.98484053227716, \"Power\": 116.98484053227716, \"i_spike\": 58.0, \"isi\": 0.060451676756293524, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 41, \"stim\": 1, \"Log power\": 2.0113092800917785, \"Firing rate\": 102.6382597979464, \"Power\": 102.6382597979464, \"i_spike\": 84.5, \"isi\": 0.04076096428259957, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 42, \"stim\": 0, \"Log power\": 2.203409983603535, \"Firing rate\": 159.73864038045465, \"Power\": 159.73864038045465, \"i_spike\": 80.5, \"isi\": 0.04265078877116619, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 42, \"stim\": 1, \"Log power\": 1.9982770016666047, \"Firing rate\": 99.60405092591064, \"Power\": 99.60405092591064, \"i_spike\": 80.0, \"isi\": 0.04385187498495034, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 43, \"stim\": 0, \"Log power\": 2.4765270844787897, \"Firing rate\": 299.5898423761487, \"Power\": 299.5898423761487, \"i_spike\": 70.5, \"isi\": 0.04945560394498052, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 43, \"stim\": 1, \"Log power\": 2.222737695898371, \"Firing rate\": 167.00816178916187, \"Power\": 167.00816178916187, \"i_spike\": 93.5, \"isi\": 0.03748781691017344, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 44, \"stim\": 0, \"Log power\": 2.170070048233791, \"Firing rate\": 147.93469757869522, \"Power\": 147.93469757869522, \"i_spike\": 71.0, \"isi\": 0.04877167378863692, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 44, \"stim\": 1, \"Log power\": 2.3864072376652525, \"Firing rate\": 243.44857548872312, \"Power\": 243.44857548872312, \"i_spike\": 91.5, \"isi\": 0.03682931140140326, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 45, \"stim\": 0, \"Log power\": 2.641681465797716, \"Firing rate\": 438.20917443664143, \"Power\": 438.20917443664143, \"i_spike\": 77.5, \"isi\": 0.0452759724091139, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 45, \"stim\": 1, \"Log power\": 2.1534415281003594, \"Firing rate\": 142.37755415507456, \"Power\": 142.37755415507456, \"i_spike\": 78.0, \"isi\": 0.04433230736020616, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 46, \"stim\": 0, \"Log power\": 2.021450437034387, \"Firing rate\": 105.06315468564793, \"Power\": 105.06315468564793, \"i_spike\": 67.5, \"isi\": 0.05185954016231027, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 46, \"stim\": 1, \"Log power\": 2.3589690108749433, \"Firing rate\": 228.5435720068663, \"Power\": 228.5435720068663, \"i_spike\": 89.0, \"isi\": 0.03924991221174787, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 47, \"stim\": 0, \"Log power\": 2.2385221162693583, \"Firing rate\": 173.18972246642412, \"Power\": 173.18972246642412, \"i_spike\": 56.5, \"isi\": 0.062210298760414215, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 47, \"stim\": 1, \"Log power\": 2.3720203998947835, \"Firing rate\": 235.51599090316526, \"Power\": 235.51599090316526, \"i_spike\": 81.5, \"isi\": 0.04295886454546449, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 48, \"stim\": 0, \"Log power\": 2.3585378687733174, \"Firing rate\": 228.3167999283142, \"Power\": 228.3167999283142, \"i_spike\": 70.0, \"isi\": 0.05004490648204437, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 48, \"stim\": 1, \"Log power\": 2.63234144834843, \"Firing rate\": 428.88558367575286, \"Power\": 428.88558367575286, \"i_spike\": 91.5, \"isi\": 0.03806742624086263, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 49, \"stim\": 0, \"Log power\": 2.061546266851199, \"Firing rate\": 115.2248806226435, \"Power\": 115.2248806226435, \"i_spike\": 70.0, \"isi\": 0.049045682871381585, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 49, \"stim\": 1, \"Log power\": 2.300847178584243, \"Firing rate\": 199.9158273410503, \"Power\": 199.9158273410503, \"i_spike\": 79.0, \"isi\": 0.04399934402707993, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 50, \"stim\": 0, \"Log power\": 2.287512271691143, \"Firing rate\": 193.87074164836233, \"Power\": 193.87074164836233, \"i_spike\": 82.0, \"isi\": 0.04285623260336847, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 50, \"stim\": 1, \"Log power\": 2.069409366386217, \"Firing rate\": 117.33007989091897, \"Power\": 117.33007989091897, \"i_spike\": 79.0, \"isi\": 0.04350847596629497, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 51, \"stim\": 0, \"Log power\": 1.8739209578075193, \"Firing rate\": 74.80333450246087, \"Power\": 74.80333450246087, \"i_spike\": 66.0, \"isi\": 0.05232826780496725, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 51, \"stim\": 1, \"Log power\": 2.0484774100130307, \"Firing rate\": 111.80916651230424, \"Power\": 111.80916651230424, \"i_spike\": 94.0, \"isi\": 0.037137675083695025, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 52, \"stim\": 0, \"Log power\": 2.2532583135765667, \"Firing rate\": 179.16712034816658, \"Power\": 179.16712034816658, \"i_spike\": 84.0, \"isi\": 0.04101481659557463, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 52, \"stim\": 1, \"Log power\": 2.045543784057372, \"Firing rate\": 111.05644929349369, \"Power\": 111.05644929349369, \"i_spike\": 72.5, \"isi\": 0.047111487819189696, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 53, \"stim\": 0, \"Log power\": 1.7634131288762156, \"Firing rate\": 57.998014856022365, \"Power\": 57.998014856022365, \"i_spike\": 64.0, \"isi\": 0.05361432591956375, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 53, \"stim\": 1, \"Log power\": 2.0245437420278645, \"Firing rate\": 105.81414863660403, \"Power\": 105.81414863660403, \"i_spike\": 88.0, \"isi\": 0.03909789468441393, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 54, \"stim\": 0, \"Log power\": 2.1945391248662602, \"Firing rate\": 156.50893091621558, \"Power\": 156.50893091621558, \"i_spike\": 61.5, \"isi\": 0.05702201652717915, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 54, \"stim\": 1, \"Log power\": 2.2843292450877324, \"Firing rate\": 192.45502060478535, \"Power\": 192.45502060478535, \"i_spike\": 82.5, \"isi\": 0.04244989134563342, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 55, \"stim\": 0, \"Log power\": 1.9046711807268994, \"Firing rate\": 80.29179752056864, \"Power\": 80.29179752056864, \"i_spike\": 68.0, \"isi\": 0.0515410512918051, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 55, \"stim\": 1, \"Log power\": 3.0374545786681884, \"Firing rate\": 1090.0704797870224, \"Power\": 1090.0704797870224, \"i_spike\": 77.5, \"isi\": 0.04414683503429014, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 56, \"stim\": 0, \"Log power\": 2.0817884216740477, \"Firing rate\": 120.72255591749642, \"Power\": 120.72255591749642, \"i_spike\": 80.5, \"isi\": 0.04281893409295219, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 56, \"stim\": 1, \"Log power\": 1.8074663748602113, \"Firing rate\": 64.18985207543321, \"Power\": 64.18985207543321, \"i_spike\": 75.5, \"isi\": 0.04604935251046432, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 57, \"stim\": 0, \"Log power\": 2.3205078294918398, \"Firing rate\": 209.1740616811728, \"Power\": 209.1740616811728, \"i_spike\": 69.0, \"isi\": 0.05050950728034611, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 57, \"stim\": 1, \"Log power\": 2.1111916160700117, \"Firing rate\": 129.1789101145487, \"Power\": 129.1789101145487, \"i_spike\": 93.5, \"isi\": 0.036639775378327896, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 58, \"stim\": 0, \"Log power\": 2.0551473270373064, \"Firing rate\": 113.53959141570147, \"Power\": 113.53959141570147, \"i_spike\": 65.0, \"isi\": 0.051598564277225104, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 58, \"stim\": 1, \"Log power\": 2.428625275031335, \"Firing rate\": 268.30284327713224, \"Power\": 268.30284327713224, \"i_spike\": 91.5, \"isi\": 0.037486935189800424, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 59, \"stim\": 0, \"Log power\": 1.9777708217953112, \"Firing rate\": 95.01032896374592, \"Power\": 95.01032896374592, \"i_spike\": 72.0, \"isi\": 0.04836697693215443, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 59, \"stim\": 1, \"Log power\": 2.2206753088496116, \"Firing rate\": 166.21694995949937, \"Power\": 166.21694995949937, \"i_spike\": 84.0, \"isi\": 0.04159242484725453, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 60, \"stim\": 0, \"Log power\": 2.0748668133734274, \"Firing rate\": 118.81378011333257, \"Power\": 118.81378011333257, \"i_spike\": 64.5, \"isi\": 0.05360323455215154, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 60, \"stim\": 1, \"Log power\": 1.8245191993437966, \"Firing rate\": 66.76044138498695, \"Power\": 66.76044138498695, \"i_spike\": 75.5, \"isi\": 0.046406207187297016, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 61, \"stim\": 0, \"Log power\": 1.7624618536341912, \"Firing rate\": 57.871115487580916, \"Power\": 57.871115487580916, \"i_spike\": 71.0, \"isi\": 0.04848991815553226, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 61, \"stim\": 1, \"Log power\": 2.7888482581179757, \"Firing rate\": 614.9619683203597, \"Power\": 614.9619683203597, \"i_spike\": 93.5, \"isi\": 0.03747178381241545, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 62, \"stim\": 0, \"Log power\": 1.980958428493352, \"Firing rate\": 95.71024512146126, \"Power\": 95.71024512146126, \"i_spike\": 60.5, \"isi\": 0.05816532362887076, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 62, \"stim\": 1, \"Log power\": 1.8912197346369923, \"Firing rate\": 77.84303042261719, \"Power\": 77.84303042261719, \"i_spike\": 78.0, \"isi\": 0.04501908822135116, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 63, \"stim\": 0, \"Log power\": 1.9068895173624372, \"Firing rate\": 80.70296992677737, \"Power\": 80.70296992677737, \"i_spike\": 73.5, \"isi\": 0.04733946934783415, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 63, \"stim\": 1, \"Log power\": 2.234515639911591, \"Firing rate\": 171.59935057564164, \"Power\": 171.59935057564164, \"i_spike\": 85.0, \"isi\": 0.04126163702068313, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 64, \"stim\": 0, \"Log power\": 2.4227416682437934, \"Firing rate\": 264.6925197473862, \"Power\": 264.6925197473862, \"i_spike\": 68.0, \"isi\": 0.051644432696175586, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 64, \"stim\": 1, \"Log power\": 2.184095251891732, \"Firing rate\": 152.79011293023987, \"Power\": 152.79011293023987, \"i_spike\": 75.0, \"isi\": 0.045862840979918024, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 65, \"stim\": 0, \"Log power\": 1.8777324977191123, \"Firing rate\": 75.46272742590195, \"Power\": 75.46272742590195, \"i_spike\": 74.0, \"isi\": 0.046939977074058704, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 65, \"stim\": 1, \"Log power\": 2.1641919566166776, \"Firing rate\": 145.9459193509549, \"Power\": 145.9459193509549, \"i_spike\": 88.0, \"isi\": 0.039594622444447496, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 66, \"stim\": 0, \"Log power\": 1.9200786002328414, \"Firing rate\": 83.19143204309013, \"Power\": 83.19143204309013, \"i_spike\": 77.0, \"isi\": 0.04466927783319466, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 66, \"stim\": 1, \"Log power\": 2.2188946085858565, \"Firing rate\": 165.53682020535805, \"Power\": 165.53682020535805, \"i_spike\": 89.0, \"isi\": 0.03843920379212688, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 67, \"stim\": 0, \"Log power\": 1.9693104848895153, \"Firing rate\": 93.17737791393978, \"Power\": 93.17737791393978, \"i_spike\": 73.5, \"isi\": 0.046612652853912764, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 67, \"stim\": 1, \"Log power\": 2.1660592971445736, \"Firing rate\": 146.57479557139985, \"Power\": 146.57479557139985, \"i_spike\": 75.5, \"isi\": 0.04585462244265719, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 68, \"stim\": 0, \"Log power\": 2.231103875856838, \"Firing rate\": 170.25656844654443, \"Power\": 170.25656844654443, \"i_spike\": 64.5, \"isi\": 0.05432441582127602, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 68, \"stim\": 1, \"Log power\": 2.069741379943365, \"Firing rate\": 117.41981179637644, \"Power\": 117.41981179637644, \"i_spike\": 79.0, \"isi\": 0.04378843197920455, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 69, \"stim\": 0, \"Log power\": 2.134310897397825, \"Firing rate\": 136.241964568881, \"Power\": 136.241964568881, \"i_spike\": 74.5, \"isi\": 0.046998844339694056, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 69, \"stim\": 1, \"Log power\": 2.120773951213158, \"Firing rate\": 132.0608083294635, \"Power\": 132.0608083294635, \"i_spike\": 76.5, \"isi\": 0.04470880710258207, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 0, \"stim\": 0, \"Log power\": 2.3902767300347882, \"Firing rate\": 245.62735410219472, \"Power\": 245.62735410219472, \"i_spike\": 81.5, \"isi\": 0.042619869511965974, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 0, \"stim\": 1, \"Log power\": 2.2694304804073924, \"Firing rate\": 185.96468568385507, \"Power\": 185.96468568385507, \"i_spike\": 96.0, \"isi\": 0.03652254517150431, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 1, \"stim\": 0, \"Log power\": 1.958521828135469, \"Firing rate\": 90.89119808692828, \"Power\": 90.89119808692828, \"i_spike\": 72.5, \"isi\": 0.04835148192954819, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 1, \"stim\": 1, \"Log power\": 2.012420917851579, \"Firing rate\": 102.9013133657859, \"Power\": 102.9013133657859, \"i_spike\": 80.0, \"isi\": 0.042661149578471884, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 2, \"stim\": 0, \"Log power\": 1.9747539514340826, \"Firing rate\": 94.35261721931417, \"Power\": 94.35261721931417, \"i_spike\": 80.0, \"isi\": 0.04352966903790672, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 2, \"stim\": 1, \"Log power\": 2.15969611144152, \"Firing rate\": 144.442870801434, \"Power\": 144.442870801434, \"i_spike\": 103.5, \"isi\": 0.033327778965951835, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 3, \"stim\": 0, \"Log power\": 2.379101107660456, \"Firing rate\": 239.38730066974614, \"Power\": 239.38730066974614, \"i_spike\": 82.5, \"isi\": 0.0423398023038074, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 3, \"stim\": 1, \"Log power\": 2.277140927013535, \"Firing rate\": 189.29577770542915, \"Power\": 189.29577770542915, \"i_spike\": 85.0, \"isi\": 0.041298582475299835, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 4, \"stim\": 0, \"Log power\": 2.061660040023107, \"Firing rate\": 115.25507031652876, \"Power\": 115.25507031652876, \"i_spike\": 79.5, \"isi\": 0.04399573266904359, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 4, \"stim\": 1, \"Log power\": 2.489822796194061, \"Firing rate\": 308.9034766237801, \"Power\": 308.9034766237801, \"i_spike\": 100.5, \"isi\": 0.034746292496689514, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 5, \"stim\": 0, \"Log power\": 1.9184294788959952, \"Firing rate\": 82.87613303829859, \"Power\": 82.87613303829859, \"i_spike\": 70.5, \"isi\": 0.048490515329570515, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 5, \"stim\": 1, \"Log power\": 2.228859167578203, \"Firing rate\": 169.3788451973878, \"Power\": 169.3788451973878, \"i_spike\": 89.0, \"isi\": 0.03933014861247911, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 6, \"stim\": 0, \"Log power\": 1.9155387110296833, \"Firing rate\": 82.32632155798872, \"Power\": 82.32632155798872, \"i_spike\": 69.5, \"isi\": 0.049537933322936274, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 6, \"stim\": 1, \"Log power\": 2.1536463895832263, \"Firing rate\": 142.4447310558281, \"Power\": 142.4447310558281, \"i_spike\": 92.5, \"isi\": 0.03767784483674681, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 7, \"stim\": 0, \"Log power\": 2.0768017021945697, \"Firing rate\": 119.34430568394144, \"Power\": 119.34430568394144, \"i_spike\": 102.5, \"isi\": 0.03400083063420156, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 7, \"stim\": 1, \"Log power\": 2.276752620104717, \"Firing rate\": 189.12660215647745, \"Power\": 189.12660215647745, \"i_spike\": 93.5, \"isi\": 0.03741409744096958, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 8, \"stim\": 0, \"Log power\": 2.597536746632061, \"Firing rate\": 395.855557647055, \"Power\": 395.855557647055, \"i_spike\": 83.0, \"isi\": 0.042003623329564505, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 8, \"stim\": 1, \"Log power\": 2.3932027281005084, \"Firing rate\": 247.28782119766916, \"Power\": 247.28782119766916, \"i_spike\": 92.5, \"isi\": 0.03793708648814726, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 9, \"stim\": 0, \"Log power\": 1.9747332367736905, \"Firing rate\": 94.34811696454868, \"Power\": 94.34811696454868, \"i_spike\": 69.0, \"isi\": 0.050566989140269254, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 9, \"stim\": 1, \"Log power\": 2.0237030045198607, \"Firing rate\": 105.60950438360523, \"Power\": 105.60950438360523, \"i_spike\": 75.0, \"isi\": 0.04644474487428645, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 10, \"stim\": 0, \"Log power\": 2.125757880868325, \"Firing rate\": 133.5850572347659, \"Power\": 133.5850572347659, \"i_spike\": 74.0, \"isi\": 0.046432698345023615, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 10, \"stim\": 1, \"Log power\": 2.374827729377504, \"Firing rate\": 237.04332446859914, \"Power\": 237.04332446859914, \"i_spike\": 88.5, \"isi\": 0.03931981800664395, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 11, \"stim\": 0, \"Log power\": 2.3681047233513417, \"Firing rate\": 233.40208072013024, \"Power\": 233.40208072013024, \"i_spike\": 84.0, \"isi\": 0.04168243687481907, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 11, \"stim\": 1, \"Log power\": 2.8367287133564165, \"Firing rate\": 686.6393894624349, \"Power\": 686.6393894624349, \"i_spike\": 98.5, \"isi\": 0.03533258070787268, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 12, \"stim\": 0, \"Log power\": 2.017353098976058, \"Firing rate\": 104.07660067816654, \"Power\": 104.07660067816654, \"i_spike\": 88.0, \"isi\": 0.039828091088892015, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 12, \"stim\": 1, \"Log power\": 2.2747759486551486, \"Firing rate\": 188.2677570658957, \"Power\": 188.2677570658957, \"i_spike\": 100.0, \"isi\": 0.03462845859722044, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 13, \"stim\": 0, \"Log power\": 2.264587162030694, \"Firing rate\": 183.90230050542502, \"Power\": 183.90230050542502, \"i_spike\": 87.0, \"isi\": 0.040226572332675126, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 13, \"stim\": 1, \"Log power\": 2.077774030806954, \"Firing rate\": 119.61180132639494, \"Power\": 119.61180132639494, \"i_spike\": 97.0, \"isi\": 0.03593715763533768, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 14, \"stim\": 0, \"Log power\": 2.8268829403591136, \"Firing rate\": 671.2479005259485, \"Power\": 671.2479005259485, \"i_spike\": 84.0, \"isi\": 0.04168142058901511, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 14, \"stim\": 1, \"Log power\": 2.102540691069691, \"Firing rate\": 126.63119086045222, \"Power\": 126.63119086045222, \"i_spike\": 90.5, \"isi\": 0.038573118123092005, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 15, \"stim\": 0, \"Log power\": 2.477194369687193, \"Firing rate\": 300.0505102819587, \"Power\": 300.0505102819587, \"i_spike\": 82.5, \"isi\": 0.041769315610210356, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 15, \"stim\": 1, \"Log power\": 2.1638899417126423, \"Firing rate\": 145.84446164882405, \"Power\": 145.84446164882405, \"i_spike\": 95.5, \"isi\": 0.03617104505627241, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 16, \"stim\": 0, \"Log power\": 1.8870726689834516, \"Firing rate\": 77.10324724501879, \"Power\": 77.10324724501879, \"i_spike\": 63.0, \"isi\": 0.05554194230853322, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 16, \"stim\": 1, \"Log power\": 3.938981762732595, \"Firing rate\": 8689.23939918732, \"Power\": 8689.23939918732, \"i_spike\": 99.0, \"isi\": 0.03549288155637231, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 17, \"stim\": 0, \"Log power\": 2.1122896813085177, \"Firing rate\": 129.50593785701673, \"Power\": 129.50593785701673, \"i_spike\": 62.0, \"isi\": 0.05668484492334408, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 17, \"stim\": 1, \"Log power\": 2.2813299927825432, \"Firing rate\": 191.1304986176846, \"Power\": 191.1304986176846, \"i_spike\": 93.0, \"isi\": 0.037662702254703743, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 18, \"stim\": 0, \"Log power\": 2.233663936121563, \"Firing rate\": 171.26315334930743, \"Power\": 171.26315334930743, \"i_spike\": 77.0, \"isi\": 0.045263656289490986, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 18, \"stim\": 1, \"Log power\": 2.1567684957264484, \"Firing rate\": 143.47244377238135, \"Power\": 143.47244377238135, \"i_spike\": 81.0, \"isi\": 0.04184487908693864, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 19, \"stim\": 0, \"Log power\": 1.9082146423163502, \"Firing rate\": 80.94958792563553, \"Power\": 80.94958792563553, \"i_spike\": 72.0, \"isi\": 0.04773241632387789, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 19, \"stim\": 1, \"Log power\": 2.3791115910248064, \"Firing rate\": 239.39307927087594, \"Power\": 239.39307927087594, \"i_spike\": 99.0, \"isi\": 0.03498076700771902, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 20, \"stim\": 0, \"Log power\": 2.722188914724935, \"Firing rate\": 527.4592522036695, \"Power\": 527.4592522036695, \"i_spike\": 90.5, \"isi\": 0.03886800764516744, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 20, \"stim\": 1, \"Log power\": 1.959231475948763, \"Firing rate\": 91.03983793677432, \"Power\": 91.03983793677432, \"i_spike\": 78.5, \"isi\": 0.044704558164798854, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 21, \"stim\": 0, \"Log power\": 3.2185817164864834, \"Firing rate\": 1654.1760038644406, \"Power\": 1654.1760038644406, \"i_spike\": 80.0, \"isi\": 0.04370227445188171, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 21, \"stim\": 1, \"Log power\": 2.197284872051377, \"Firing rate\": 157.5015644837986, \"Power\": 157.5015644837986, \"i_spike\": 78.5, \"isi\": 0.04447004454967937, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 22, \"stim\": 0, \"Log power\": 2.1005118006246093, \"Firing rate\": 126.04098852138367, \"Power\": 126.04098852138367, \"i_spike\": 77.0, \"isi\": 0.04470656964627002, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 22, \"stim\": 1, \"Log power\": 2.391208603791071, \"Firing rate\": 246.15496714153875, \"Power\": 246.15496714153875, \"i_spike\": 86.5, \"isi\": 0.03954045664914847, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 23, \"stim\": 0, \"Log power\": 2.1054385098917696, \"Firing rate\": 127.47895945425998, \"Power\": 127.47895945425998, \"i_spike\": 80.0, \"isi\": 0.0432753395838561, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 23, \"stim\": 1, \"Log power\": 2.481772420974368, \"Firing rate\": 303.2301780793786, \"Power\": 303.2301780793786, \"i_spike\": 92.0, \"isi\": 0.03783006298127069, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 24, \"stim\": 0, \"Log power\": 2.035176308442397, \"Firing rate\": 108.4367039950008, \"Power\": 108.4367039950008, \"i_spike\": 77.0, \"isi\": 0.044684563068532565, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 24, \"stim\": 1, \"Log power\": 2.202137467844878, \"Firing rate\": 159.27127908969848, \"Power\": 159.27127908969848, \"i_spike\": 89.5, \"isi\": 0.039267627829104146, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 25, \"stim\": 0, \"Log power\": 2.408800314722153, \"Firing rate\": 256.33051774271803, \"Power\": 256.33051774271803, \"i_spike\": 82.0, \"isi\": 0.042873237473504446, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 25, \"stim\": 1, \"Log power\": 2.350376414421529, \"Firing rate\": 224.0662338036484, \"Power\": 224.0662338036484, \"i_spike\": 101.0, \"isi\": 0.034542656351622736, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 26, \"stim\": 0, \"Log power\": 1.964445577030255, \"Firing rate\": 92.13944183232938, \"Power\": 92.13944183232938, \"i_spike\": 79.5, \"isi\": 0.04413428271376092, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 26, \"stim\": 1, \"Log power\": 2.1856007112471443, \"Firing rate\": 153.3206709976319, \"Power\": 153.3206709976319, \"i_spike\": 90.5, \"isi\": 0.03813454718769625, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 27, \"stim\": 0, \"Log power\": 3.064853377658025, \"Firing rate\": 1161.0565628711975, \"Power\": 1161.0565628711975, \"i_spike\": 84.5, \"isi\": 0.04155041385228782, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 27, \"stim\": 1, \"Log power\": 2.1488757743857145, \"Firing rate\": 140.8885743034591, \"Power\": 140.8885743034591, \"i_spike\": 96.0, \"isi\": 0.03629880237469381, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 28, \"stim\": 0, \"Log power\": 2.0146860820502988, \"Firing rate\": 103.43942126805995, \"Power\": 103.43942126805995, \"i_spike\": 77.5, \"isi\": 0.04499926589592764, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 28, \"stim\": 1, \"Log power\": 2.012099228830681, \"Firing rate\": 102.82512090313094, \"Power\": 102.82512090313094, \"i_spike\": 80.5, \"isi\": 0.04333897792230511, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 29, \"stim\": 0, \"Log power\": 2.438313925221379, \"Firing rate\": 274.3556606532389, \"Power\": 274.3556606532389, \"i_spike\": 75.5, \"isi\": 0.04611688402579955, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 29, \"stim\": 1, \"Log power\": 2.203991896115611, \"Firing rate\": 159.95281813268588, \"Power\": 159.95281813268588, \"i_spike\": 92.0, \"isi\": 0.03778943593927792, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 30, \"stim\": 0, \"Log power\": 2.437468495754161, \"Firing rate\": 273.82209932041843, \"Power\": 273.82209932041843, \"i_spike\": 79.5, \"isi\": 0.04411339180947841, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 30, \"stim\": 1, \"Log power\": 2.37144540499986, \"Firing rate\": 235.20438002395287, \"Power\": 235.20438002395287, \"i_spike\": 85.5, \"isi\": 0.04016451214004707, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 31, \"stim\": 0, \"Log power\": 3.0151572267148308, \"Firing rate\": 1035.5169848567782, \"Power\": 1035.5169848567782, \"i_spike\": 68.0, \"isi\": 0.050275996658705545, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 31, \"stim\": 1, \"Log power\": 2.3357834522839918, \"Firing rate\": 216.6623514614178, \"Power\": 216.6623514614178, \"i_spike\": 104.5, \"isi\": 0.03354631897455346, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 32, \"stim\": 0, \"Log power\": 2.117220677249924, \"Firing rate\": 130.98473242230142, \"Power\": 130.98473242230142, \"i_spike\": 74.0, \"isi\": 0.046939794374730615, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 32, \"stim\": 1, \"Log power\": 2.031157568395182, \"Firing rate\": 107.43791421165186, \"Power\": 107.43791421165186, \"i_spike\": 86.5, \"isi\": 0.04044583633215689, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 33, \"stim\": 0, \"Log power\": 2.278923560850274, \"Firing rate\": 190.07437050538292, \"Power\": 190.07437050538292, \"i_spike\": 75.0, \"isi\": 0.04622083901946486, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 33, \"stim\": 1, \"Log power\": 2.1354549030091725, \"Firing rate\": 136.60132219785848, \"Power\": 136.60132219785848, \"i_spike\": 91.5, \"isi\": 0.038309406313921705, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 34, \"stim\": 0, \"Log power\": 2.035169873468667, \"Firing rate\": 108.43509729217311, \"Power\": 108.43509729217311, \"i_spike\": 83.5, \"isi\": 0.04187324019096305, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 34, \"stim\": 1, \"Log power\": 2.3502839584161985, \"Firing rate\": 224.01853790880466, \"Power\": 224.01853790880466, \"i_spike\": 90.0, \"isi\": 0.037426289075066184, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 35, \"stim\": 0, \"Log power\": 2.076575297066767, \"Firing rate\": 119.28210567428565, \"Power\": 119.28210567428565, \"i_spike\": 79.0, \"isi\": 0.04413361288128363, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 35, \"stim\": 1, \"Log power\": 2.830205838820181, \"Firing rate\": 676.4034885742151, \"Power\": 676.4034885742151, \"i_spike\": 96.0, \"isi\": 0.03640031427050218, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 36, \"stim\": 0, \"Log power\": 2.126358476769516, \"Firing rate\": 133.76992290349398, \"Power\": 133.76992290349398, \"i_spike\": 88.5, \"isi\": 0.039051472792598345, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 36, \"stim\": 1, \"Log power\": 2.573693794282305, \"Firing rate\": 374.7087151909854, \"Power\": 374.7087151909854, \"i_spike\": 89.0, \"isi\": 0.03844359052658583, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 37, \"stim\": 0, \"Log power\": 2.2199232125565938, \"Firing rate\": 165.92935024421234, \"Power\": 165.92935024421234, \"i_spike\": 96.5, \"isi\": 0.0356363129844972, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 37, \"stim\": 1, \"Log power\": 2.2000514294004896, \"Firing rate\": 158.5080887531039, \"Power\": 158.5080887531039, \"i_spike\": 96.0, \"isi\": 0.035504269599892266, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 38, \"stim\": 0, \"Log power\": 2.11800437349651, \"Firing rate\": 131.2213113395195, \"Power\": 131.2213113395195, \"i_spike\": 79.0, \"isi\": 0.04452655221254388, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 38, \"stim\": 1, \"Log power\": 2.2018982405363667, \"Firing rate\": 159.18357006081078, \"Power\": 159.18357006081078, \"i_spike\": 96.5, \"isi\": 0.03612563762560523, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 39, \"stim\": 0, \"Log power\": 2.3501231945969043, \"Firing rate\": 223.93562778131565, \"Power\": 223.93562778131565, \"i_spike\": 80.5, \"isi\": 0.04361839933697641, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 39, \"stim\": 1, \"Log power\": 2.261770647609365, \"Firing rate\": 182.71350450884103, \"Power\": 182.71350450884103, \"i_spike\": 109.0, \"isi\": 0.031680848473518375, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 40, \"stim\": 0, \"Log power\": 2.129227742768365, \"Firing rate\": 134.65663044102854, \"Power\": 134.65663044102854, \"i_spike\": 84.5, \"isi\": 0.04121733562132662, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 40, \"stim\": 1, \"Log power\": 2.036054420206707, \"Firing rate\": 108.6561769052754, \"Power\": 108.6561769052754, \"i_spike\": 98.5, \"isi\": 0.03443038358465565, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 41, \"stim\": 0, \"Log power\": 2.0214344112928866, \"Firing rate\": 105.05927786021482, \"Power\": 105.05927786021482, \"i_spike\": 80.5, \"isi\": 0.04341752386134683, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 41, \"stim\": 1, \"Log power\": 2.2801877464378846, \"Firing rate\": 190.62846308034958, \"Power\": 190.62846308034958, \"i_spike\": 87.0, \"isi\": 0.040023759558599235, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 42, \"stim\": 0, \"Log power\": 2.034147544455625, \"Firing rate\": 108.1801413232719, \"Power\": 108.1801413232719, \"i_spike\": 73.0, \"isi\": 0.0481554507770081, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 42, \"stim\": 1, \"Log power\": 2.235320218736905, \"Firing rate\": 171.9175521168936, \"Power\": 171.9175521168936, \"i_spike\": 91.5, \"isi\": 0.03781409026308163, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 43, \"stim\": 0, \"Log power\": 2.1042890077139886, \"Firing rate\": 127.14199090150949, \"Power\": 127.14199090150949, \"i_spike\": 72.5, \"isi\": 0.04796095280925005, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 43, \"stim\": 1, \"Log power\": 2.2169679941366094, \"Firing rate\": 164.80409326564038, \"Power\": 164.80409326564038, \"i_spike\": 86.5, \"isi\": 0.04026712440232783, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 44, \"stim\": 0, \"Log power\": 2.0599908015808013, \"Firing rate\": 114.812930369662, \"Power\": 114.812930369662, \"i_spike\": 72.5, \"isi\": 0.048015157928590804, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 44, \"stim\": 1, \"Log power\": 2.4958710210057116, \"Firing rate\": 313.23553232759195, \"Power\": 313.23553232759195, \"i_spike\": 96.5, \"isi\": 0.03601443926807861, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 45, \"stim\": 0, \"Log power\": 2.1248525581168387, \"Firing rate\": 133.30687818357538, \"Power\": 133.30687818357538, \"i_spike\": 74.0, \"isi\": 0.04629864948672247, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 45, \"stim\": 1, \"Log power\": 2.2399729100024106, \"Firing rate\": 173.7692433285049, \"Power\": 173.7692433285049, \"i_spike\": 89.0, \"isi\": 0.03916844862361351, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 46, \"stim\": 0, \"Log power\": 1.992376196375254, \"Firing rate\": 98.25987252437143, \"Power\": 98.25987252437143, \"i_spike\": 69.5, \"isi\": 0.04945101163970742, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 46, \"stim\": 1, \"Log power\": 1.9671785203622278, \"Firing rate\": 92.72108828074352, \"Power\": 92.72108828074352, \"i_spike\": 83.5, \"isi\": 0.04205700383631014, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 47, \"stim\": 0, \"Log power\": 2.2732301619371413, \"Firing rate\": 187.59884574742568, \"Power\": 187.59884574742568, \"i_spike\": 69.0, \"isi\": 0.05037450237591499, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 47, \"stim\": 1, \"Log power\": 2.1483047197128395, \"Firing rate\": 140.70344138106435, \"Power\": 140.70344138106435, \"i_spike\": 99.0, \"isi\": 0.035426074423501826, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 48, \"stim\": 0, \"Log power\": 1.9062193756330787, \"Firing rate\": 80.57853656332131, \"Power\": 80.57853656332131, \"i_spike\": 73.0, \"isi\": 0.0470237082466002, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 48, \"stim\": 1, \"Log power\": 2.531568228651864, \"Firing rate\": 340.0699273674691, \"Power\": 340.0699273674691, \"i_spike\": 94.5, \"isi\": 0.03627442532577132, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 49, \"stim\": 0, \"Log power\": 2.3148858301167423, \"Firing rate\": 206.4837267910725, \"Power\": 206.4837267910725, \"i_spike\": 65.0, \"isi\": 0.053994393349553374, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 49, \"stim\": 1, \"Log power\": 2.060927018840327, \"Firing rate\": 115.06070185608658, \"Power\": 115.06070185608658, \"i_spike\": 89.5, \"isi\": 0.038382936100858626, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 50, \"stim\": 0, \"Log power\": 2.7020989607527808, \"Firing rate\": 503.6153523056961, \"Power\": 503.6153523056961, \"i_spike\": 91.5, \"isi\": 0.038099384158494884, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 50, \"stim\": 1, \"Log power\": 2.423763726092603, \"Firing rate\": 265.3161741087237, \"Power\": 265.3161741087237, \"i_spike\": 104.5, \"isi\": 0.033106776587616474, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 51, \"stim\": 0, \"Log power\": 2.690885345559745, \"Firing rate\": 490.7782927912564, \"Power\": 490.7782927912564, \"i_spike\": 72.0, \"isi\": 0.04846127311236185, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 51, \"stim\": 1, \"Log power\": 3.252336045962304, \"Firing rate\": 1787.8704481921338, \"Power\": 1787.8704481921338, \"i_spike\": 89.5, \"isi\": 0.03880921123952882, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 52, \"stim\": 0, \"Log power\": 2.183013987093658, \"Firing rate\": 152.41018389521068, \"Power\": 152.41018389521068, \"i_spike\": 76.0, \"isi\": 0.04571636198149553, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 52, \"stim\": 1, \"Log power\": 2.111932764125637, \"Firing rate\": 129.39954943187234, \"Power\": 129.39954943187234, \"i_spike\": 92.0, \"isi\": 0.037884870904735996, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 53, \"stim\": 0, \"Log power\": 2.0002055329373643, \"Firing rate\": 100.04733690814997, \"Power\": 100.04733690814997, \"i_spike\": 83.0, \"isi\": 0.04158059792339157, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 53, \"stim\": 1, \"Log power\": 2.3477074879838975, \"Firing rate\": 222.69347282076808, \"Power\": 222.69347282076808, \"i_spike\": 84.0, \"isi\": 0.04162992182736283, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 54, \"stim\": 0, \"Log power\": 1.9341768326033797, \"Firing rate\": 85.93633590762555, \"Power\": 85.93633590762555, \"i_spike\": 78.0, \"isi\": 0.045012229750569926, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 54, \"stim\": 1, \"Log power\": 2.34580072109996, \"Firing rate\": 221.717881916258, \"Power\": 221.717881916258, \"i_spike\": 92.5, \"isi\": 0.03770778920077267, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 55, \"stim\": 0, \"Log power\": 1.9405042951185283, \"Firing rate\": 87.19755249741561, \"Power\": 87.19755249741561, \"i_spike\": 68.0, \"isi\": 0.05083046929234572, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 55, \"stim\": 1, \"Log power\": 2.142327165579497, \"Firing rate\": 138.78009024978994, \"Power\": 138.78009024978994, \"i_spike\": 85.5, \"isi\": 0.040633913519646986, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 56, \"stim\": 0, \"Log power\": 2.1251622337835516, \"Firing rate\": 133.4019671605714, \"Power\": 133.4019671605714, \"i_spike\": 84.5, \"isi\": 0.04101955938244394, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 56, \"stim\": 1, \"Log power\": 2.3485522102197196, \"Firing rate\": 223.12704312843545, \"Power\": 223.12704312843545, \"i_spike\": 92.5, \"isi\": 0.03761838911837241, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 57, \"stim\": 0, \"Log power\": 2.1503939073182834, \"Firing rate\": 141.38193046001842, \"Power\": 141.38193046001842, \"i_spike\": 73.0, \"isi\": 0.04802559324545982, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 57, \"stim\": 1, \"Log power\": 2.1260692132039494, \"Firing rate\": 133.68085458018663, \"Power\": 133.68085458018663, \"i_spike\": 99.5, \"isi\": 0.034995192572097385, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 58, \"stim\": 0, \"Log power\": 1.9549156859017107, \"Firing rate\": 90.13961232266641, \"Power\": 90.13961232266641, \"i_spike\": 82.5, \"isi\": 0.0417629871101117, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 58, \"stim\": 1, \"Log power\": 2.047943028867528, \"Firing rate\": 111.67167462857988, \"Power\": 111.67167462857988, \"i_spike\": 86.0, \"isi\": 0.04026444725351672, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 59, \"stim\": 0, \"Log power\": 2.3711818400166798, \"Firing rate\": 235.06168230597203, \"Power\": 235.06168230597203, \"i_spike\": 74.5, \"isi\": 0.047202619206625766, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 59, \"stim\": 1, \"Log power\": 2.3450036328974706, \"Firing rate\": 221.3113222343229, \"Power\": 221.3113222343229, \"i_spike\": 91.0, \"isi\": 0.03768689815954936, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 60, \"stim\": 0, \"Log power\": 2.028638978046254, \"Firing rate\": 106.81665605270607, \"Power\": 106.81665605270607, \"i_spike\": 85.0, \"isi\": 0.04025438607843918, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 60, \"stim\": 1, \"Log power\": 3.122981180357786, \"Firing rate\": 1327.336937893441, \"Power\": 1327.336937893441, \"i_spike\": 110.0, \"isi\": 0.031649962845656, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 61, \"stim\": 0, \"Log power\": 1.9189228869043955, \"Firing rate\": 82.97034327373213, \"Power\": 82.97034327373213, \"i_spike\": 68.5, \"isi\": 0.05107868043162692, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 61, \"stim\": 1, \"Log power\": 2.2647314138224597, \"Firing rate\": 183.9633941726351, \"Power\": 183.9633941726351, \"i_spike\": 82.0, \"isi\": 0.04260797849386971, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 62, \"stim\": 0, \"Log power\": 2.2271454036659244, \"Firing rate\": 168.7117785153499, \"Power\": 168.7117785153499, \"i_spike\": 72.5, \"isi\": 0.048504983040768945, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 62, \"stim\": 1, \"Log power\": 2.1797310080380496, \"Firing rate\": 151.26240738519203, \"Power\": 151.26240738519203, \"i_spike\": 116.0, \"isi\": 0.030217082967535017, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 63, \"stim\": 0, \"Log power\": 2.1012918434320054, \"Firing rate\": 126.26757605165413, \"Power\": 126.26757605165413, \"i_spike\": 78.5, \"isi\": 0.044229580165290855, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 63, \"stim\": 1, \"Log power\": 2.1898982119562365, \"Firing rate\": 154.84536565746825, \"Power\": 154.84536565746825, \"i_spike\": 95.0, \"isi\": 0.03688936577512914, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 64, \"stim\": 0, \"Log power\": 2.3719403235832064, \"Firing rate\": 235.47256987410964, \"Power\": 235.47256987410964, \"i_spike\": 89.0, \"isi\": 0.038942333933919694, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 64, \"stim\": 1, \"Log power\": 2.328926309805585, \"Firing rate\": 213.2683013177163, \"Power\": 213.2683013177163, \"i_spike\": 86.5, \"isi\": 0.04060560846145227, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 65, \"stim\": 0, \"Log power\": 2.371795781656299, \"Firing rate\": 235.39421291320727, \"Power\": 235.39421291320727, \"i_spike\": 80.5, \"isi\": 0.042905013846376704, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 65, \"stim\": 1, \"Log power\": 2.447751295191256, \"Firing rate\": 280.38275270692804, \"Power\": 280.38275270692804, \"i_spike\": 101.0, \"isi\": 0.0345218645275521, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 66, \"stim\": 0, \"Log power\": 2.3363267652959547, \"Firing rate\": 216.93357097453847, \"Power\": 216.93357097453847, \"i_spike\": 90.0, \"isi\": 0.039001609317802687, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 66, \"stim\": 1, \"Log power\": 2.153873642104243, \"Firing rate\": 142.51928736820147, \"Power\": 142.51928736820147, \"i_spike\": 89.5, \"isi\": 0.0386929289575087, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 67, \"stim\": 0, \"Log power\": 2.214673864187398, \"Firing rate\": 163.93582258276027, \"Power\": 163.93582258276027, \"i_spike\": 72.0, \"isi\": 0.04865938437102392, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 67, \"stim\": 1, \"Log power\": 2.217400139907223, \"Firing rate\": 164.96816359147397, \"Power\": 164.96816359147397, \"i_spike\": 101.5, \"isi\": 0.03430245475694499, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 68, \"stim\": 0, \"Log power\": 2.0518725867194165, \"Firing rate\": 112.68668075806144, \"Power\": 112.68668075806144, \"i_spike\": 79.0, \"isi\": 0.044452295368766895, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 68, \"stim\": 1, \"Log power\": 2.0441496578753386, \"Firing rate\": 110.70051922385393, \"Power\": 110.70051922385393, \"i_spike\": 93.5, \"isi\": 0.037249380170555284, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 69, \"stim\": 0, \"Log power\": 2.6884245517721284, \"Firing rate\": 488.0053146888535, \"Power\": 488.0053146888535, \"i_spike\": 76.0, \"isi\": 0.04582984669243768, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 69, \"stim\": 1, \"Log power\": 2.232802531439049, \"Firing rate\": 170.92379681035248, \"Power\": 170.92379681035248, \"i_spike\": 95.5, \"isi\": 0.03666286179296799, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 0, \"stim\": 0, \"Log power\": 2.049865870707151, \"Firing rate\": 112.16719790169377, \"Power\": 112.16719790169377, \"i_spike\": 94.5, \"isi\": 0.03701507410602717, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 0, \"stim\": 1, \"Log power\": 2.3995715699890194, \"Firing rate\": 250.94096860454673, \"Power\": 250.94096860454673, \"i_spike\": 95.0, \"isi\": 0.03691786487828881, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 1, \"stim\": 0, \"Log power\": 2.791662427924049, \"Firing rate\": 618.9597777737547, \"Power\": 618.9597777737547, \"i_spike\": 94.5, \"isi\": 0.036918096417175555, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 1, \"stim\": 1, \"Log power\": 2.449589854300197, \"Firing rate\": 281.5722519898917, \"Power\": 281.5722519898917, \"i_spike\": 109.5, \"isi\": 0.0318405679907412, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 2, \"stim\": 0, \"Log power\": 2.19085468323881, \"Firing rate\": 155.18676616249215, \"Power\": 155.18676616249215, \"i_spike\": 101.0, \"isi\": 0.034719434705591634, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 2, \"stim\": 1, \"Log power\": 2.2583378203428306, \"Firing rate\": 181.27496099114794, \"Power\": 181.27496099114794, \"i_spike\": 105.5, \"isi\": 0.0324920228248927, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 3, \"stim\": 0, \"Log power\": 2.2956845041599636, \"Firing rate\": 197.55339801540765, \"Power\": 197.55339801540765, \"i_spike\": 91.0, \"isi\": 0.038429078275265864, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 3, \"stim\": 1, \"Log power\": 2.256613588190719, \"Firing rate\": 180.556691504212, \"Power\": 180.556691504212, \"i_spike\": 100.0, \"isi\": 0.034816247833637334, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 4, \"stim\": 0, \"Log power\": 2.121652053368341, \"Firing rate\": 132.32809285012374, \"Power\": 132.32809285012374, \"i_spike\": 99.5, \"isi\": 0.03462490660318668, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 4, \"stim\": 1, \"Log power\": 2.544203256074575, \"Firing rate\": 350.1089847398484, \"Power\": 350.1089847398484, \"i_spike\": 108.0, \"isi\": 0.031837329751804706, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 5, \"stim\": 0, \"Log power\": 2.2501523275236504, \"Firing rate\": 177.8903245756527, \"Power\": 177.8903245756527, \"i_spike\": 104.0, \"isi\": 0.03346113817626028, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 5, \"stim\": 1, \"Log power\": 2.394338149157585, \"Firing rate\": 247.93517722394407, \"Power\": 247.93517722394407, \"i_spike\": 111.5, \"isi\": 0.03144047303213581, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 6, \"stim\": 0, \"Log power\": 2.269406953709791, \"Firing rate\": 185.9546118362607, \"Power\": 185.9546118362607, \"i_spike\": 98.0, \"isi\": 0.035183460450413366, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 6, \"stim\": 1, \"Log power\": 2.319049439990794, \"Firing rate\": 208.47281946003915, \"Power\": 208.47281946003915, \"i_spike\": 99.5, \"isi\": 0.03522093167013208, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 7, \"stim\": 0, \"Log power\": 2.242299390373659, \"Firing rate\": 174.7026088432321, \"Power\": 174.7026088432321, \"i_spike\": 87.5, \"isi\": 0.03938645133426472, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 7, \"stim\": 1, \"Log power\": 2.5834283036288084, \"Firing rate\": 383.2024734328876, \"Power\": 383.2024734328876, \"i_spike\": 101.0, \"isi\": 0.034651191886894174, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 8, \"stim\": 0, \"Log power\": 2.4652247762897606, \"Firing rate\": 291.8937367409695, \"Power\": 291.8937367409695, \"i_spike\": 86.5, \"isi\": 0.04006756859128422, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 8, \"stim\": 1, \"Log power\": 2.0750134242946516, \"Firing rate\": 118.85389652989004, \"Power\": 118.85389652989004, \"i_spike\": 103.5, \"isi\": 0.033628674874080104, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 9, \"stim\": 0, \"Log power\": 2.1823187858641355, \"Firing rate\": 152.16640693736196, \"Power\": 152.16640693736196, \"i_spike\": 87.5, \"isi\": 0.03973970292963168, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 9, \"stim\": 1, \"Log power\": 3.4106368463020207, \"Firing rate\": 2574.1677575643375, \"Power\": 2574.1677575643375, \"i_spike\": 97.0, \"isi\": 0.035886344440640955, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 10, \"stim\": 0, \"Log power\": 2.0327846376106526, \"Firing rate\": 107.84118157329219, \"Power\": 107.84118157329219, \"i_spike\": 86.5, \"isi\": 0.040527509405361324, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 10, \"stim\": 1, \"Log power\": 2.1864264243749445, \"Firing rate\": 153.61245300738298, \"Power\": 153.61245300738298, \"i_spike\": 106.0, \"isi\": 0.03265966817873545, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 11, \"stim\": 0, \"Log power\": 2.216228474299822, \"Firing rate\": 164.52370243749098, \"Power\": 164.52370243749098, \"i_spike\": 93.5, \"isi\": 0.037384037129707094, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 11, \"stim\": 1, \"Log power\": 2.336915071273709, \"Firing rate\": 217.22763364810388, \"Power\": 217.22763364810388, \"i_spike\": 88.5, \"isi\": 0.03863177065436268, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 12, \"stim\": 0, \"Log power\": 1.950842353314783, \"Firing rate\": 89.29812772382137, \"Power\": 89.29812772382137, \"i_spike\": 81.0, \"isi\": 0.04222406662540614, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 12, \"stim\": 1, \"Log power\": 2.854420365530545, \"Firing rate\": 715.188241457645, \"Power\": 715.188241457645, \"i_spike\": 121.0, \"isi\": 0.028903743042685497, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 13, \"stim\": 0, \"Log power\": 2.165080809954873, \"Firing rate\": 146.24492697056124, \"Power\": 146.24492697056124, \"i_spike\": 92.5, \"isi\": 0.037752834827337454, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 13, \"stim\": 1, \"Log power\": 2.382410087368043, \"Firing rate\": 241.21820832513015, \"Power\": 241.21820832513015, \"i_spike\": 110.0, \"isi\": 0.03180305116958324, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 14, \"stim\": 0, \"Log power\": 2.1941293098895485, \"Firing rate\": 156.36131344956817, \"Power\": 156.36131344956817, \"i_spike\": 100.5, \"isi\": 0.03473714823441939, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 14, \"stim\": 1, \"Log power\": 2.1080179676610524, \"Firing rate\": 128.2383636422167, \"Power\": 128.2383636422167, \"i_spike\": 103.5, \"isi\": 0.03394488322547342, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 15, \"stim\": 0, \"Log power\": 2.5010018461855483, \"Firing rate\": 316.9580936901311, \"Power\": 316.9580936901311, \"i_spike\": 95.0, \"isi\": 0.03657594576718727, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 15, \"stim\": 1, \"Log power\": 2.227716895845958, \"Firing rate\": 168.93393406251582, \"Power\": 168.93393406251582, \"i_spike\": 115.5, \"isi\": 0.03022682403024804, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 16, \"stim\": 0, \"Log power\": 2.8093322981441826, \"Firing rate\": 644.6623368603022, \"Power\": 644.6623368603022, \"i_spike\": 95.5, \"isi\": 0.03656935625535361, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 16, \"stim\": 1, \"Log power\": 2.579066887548101, \"Firing rate\": 379.3734093936126, \"Power\": 379.3734093936126, \"i_spike\": 112.0, \"isi\": 0.031238374197649663, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 17, \"stim\": 0, \"Log power\": 2.0829026125053502, \"Firing rate\": 121.03266958363359, \"Power\": 121.03266958363359, \"i_spike\": 97.0, \"isi\": 0.03603962392544161, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 17, \"stim\": 1, \"Log power\": 2.416023823568151, \"Firing rate\": 260.62965165395354, \"Power\": 260.62965165395354, \"i_spike\": 103.5, \"isi\": 0.03370619984527249, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 18, \"stim\": 0, \"Log power\": 2.389727241481994, \"Firing rate\": 245.31677205172565, \"Power\": 245.31677205172565, \"i_spike\": 94.5, \"isi\": 0.036371509993615964, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 18, \"stim\": 1, \"Log power\": 2.3788666581690574, \"Firing rate\": 239.25810472805614, \"Power\": 239.25810472805614, \"i_spike\": 123.5, \"isi\": 0.028395939939136108, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 19, \"stim\": 0, \"Log power\": 2.3292819033481598, \"Firing rate\": 213.44299358167112, \"Power\": 213.44299358167112, \"i_spike\": 95.5, \"isi\": 0.036232222224746875, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 19, \"stim\": 1, \"Log power\": 3.703215247027324, \"Firing rate\": 5049.114821091642, \"Power\": 5049.114821091642, \"i_spike\": 102.5, \"isi\": 0.03409732226882638, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 20, \"stim\": 0, \"Log power\": 2.047425806214623, \"Firing rate\": 111.53875850421532, \"Power\": 111.53875850421532, \"i_spike\": 102.5, \"isi\": 0.03420051475774344, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 20, \"stim\": 1, \"Log power\": 2.272738798302673, \"Firing rate\": 187.38671520452775, \"Power\": 187.38671520452775, \"i_spike\": 99.0, \"isi\": 0.03483112591864753, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 21, \"stim\": 0, \"Log power\": 2.4865632779669067, \"Firing rate\": 306.593736285853, \"Power\": 306.593736285853, \"i_spike\": 91.5, \"isi\": 0.03804957199751072, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 21, \"stim\": 1, \"Log power\": 2.5373618025156595, \"Firing rate\": 344.6369217020402, \"Power\": 344.6369217020402, \"i_spike\": 113.5, \"isi\": 0.030727788861441695, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 22, \"stim\": 0, \"Log power\": 2.0780936056626573, \"Firing rate\": 119.69984985812728, \"Power\": 119.69984985812728, \"i_spike\": 86.0, \"isi\": 0.04048426050724916, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 22, \"stim\": 1, \"Log power\": 2.522894575959712, \"Firing rate\": 333.34548405023975, \"Power\": 333.34548405023975, \"i_spike\": 105.5, \"isi\": 0.032647697348818595, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 23, \"stim\": 0, \"Log power\": 2.07792146569388, \"Firing rate\": 119.65241419818234, \"Power\": 119.65241419818234, \"i_spike\": 95.0, \"isi\": 0.03640332365466288, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 23, \"stim\": 1, \"Log power\": 2.1688152158089755, \"Firing rate\": 147.50787812645916, \"Power\": 147.50787812645916, \"i_spike\": 105.5, \"isi\": 0.0333143797264023, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 24, \"stim\": 0, \"Log power\": 2.444932956243232, \"Firing rate\": 278.5691097282813, \"Power\": 278.5691097282813, \"i_spike\": 100.0, \"isi\": 0.03497423549862524, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 24, \"stim\": 1, \"Log power\": 2.2747213779131967, \"Firing rate\": 188.24410199735067, \"Power\": 188.24410199735067, \"i_spike\": 117.0, \"isi\": 0.02933052653153711, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 25, \"stim\": 0, \"Log power\": 2.2678347327795763, \"Firing rate\": 185.28264112737062, \"Power\": 185.28264112737062, \"i_spike\": 90.5, \"isi\": 0.03840913448674816, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 25, \"stim\": 1, \"Log power\": 2.9770584397850928, \"Firing rate\": 948.546093521299, \"Power\": 948.546093521299, \"i_spike\": 117.0, \"isi\": 0.029882568199263458, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 26, \"stim\": 0, \"Log power\": 1.9936175215572702, \"Firing rate\": 98.54112623524102, \"Power\": 98.54112623524102, \"i_spike\": 85.0, \"isi\": 0.04068391962895357, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 26, \"stim\": 1, \"Log power\": 2.1239609781424797, \"Firing rate\": 133.03348804924457, \"Power\": 133.03348804924457, \"i_spike\": 104.5, \"isi\": 0.03332742393336239, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 27, \"stim\": 0, \"Log power\": 2.269730700970873, \"Firing rate\": 186.0932844269218, \"Power\": 186.0932844269218, \"i_spike\": 82.5, \"isi\": 0.042409855730631135, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 27, \"stim\": 1, \"Log power\": 2.2771519656875365, \"Firing rate\": 189.3005891893915, \"Power\": 189.3005891893915, \"i_spike\": 88.5, \"isi\": 0.03944712182994111, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 28, \"stim\": 0, \"Log power\": 2.2046740011381343, \"Firing rate\": 160.20423819479393, \"Power\": 160.20423819479393, \"i_spike\": 77.0, \"isi\": 0.04465177101190972, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 28, \"stim\": 1, \"Log power\": 2.0915521742748666, \"Firing rate\": 123.46736346519779, \"Power\": 123.46736346519779, \"i_spike\": 94.5, \"isi\": 0.03659650578109923, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 29, \"stim\": 0, \"Log power\": 2.1512873485809823, \"Firing rate\": 141.67308421752384, \"Power\": 141.67308421752384, \"i_spike\": 107.0, \"isi\": 0.032690901649981764, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 29, \"stim\": 1, \"Log power\": 2.5216456699266847, \"Firing rate\": 332.3882553204822, \"Power\": 332.3882553204822, \"i_spike\": 97.0, \"isi\": 0.03571555473087041, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 30, \"stim\": 0, \"Log power\": 2.403016419375036, \"Firing rate\": 252.93936234439082, \"Power\": 252.93936234439082, \"i_spike\": 101.5, \"isi\": 0.03415195531604658, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 30, \"stim\": 1, \"Log power\": 2.147563035790999, \"Firing rate\": 140.46335447017458, \"Power\": 140.46335447017458, \"i_spike\": 110.0, \"isi\": 0.03162182479040262, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 31, \"stim\": 0, \"Log power\": 2.9919019318438265, \"Firing rate\": 981.5262792754213, \"Power\": 981.5262792754213, \"i_spike\": 87.0, \"isi\": 0.040395816763747545, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 31, \"stim\": 1, \"Log power\": 2.1632512074575065, \"Firing rate\": 145.63012002808313, \"Power\": 145.63012002808313, \"i_spike\": 96.0, \"isi\": 0.03589492104063558, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 32, \"stim\": 0, \"Log power\": 2.8698620099502152, \"Firing rate\": 741.0747393729686, \"Power\": 741.0747393729686, \"i_spike\": 99.5, \"isi\": 0.034786276626342864, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 32, \"stim\": 1, \"Log power\": 2.2880586366105145, \"Firing rate\": 194.11479455149185, \"Power\": 194.11479455149185, \"i_spike\": 104.0, \"isi\": 0.033305821562326185, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 33, \"stim\": 0, \"Log power\": 2.40472969594144, \"Firing rate\": 253.9391701033941, \"Power\": 253.9391701033941, \"i_spike\": 96.5, \"isi\": 0.03583774900437598, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 33, \"stim\": 1, \"Log power\": 2.3016356086681635, \"Firing rate\": 200.27908964171385, \"Power\": 200.27908964171385, \"i_spike\": 96.5, \"isi\": 0.036133742872390955, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 34, \"stim\": 0, \"Log power\": 2.911962972942329, \"Firing rate\": 816.5127541865324, \"Power\": 816.5127541865324, \"i_spike\": 109.0, \"isi\": 0.0319560791134234, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 34, \"stim\": 1, \"Log power\": 2.206190561201838, \"Firing rate\": 160.76465068471592, \"Power\": 160.76465068471592, \"i_spike\": 103.5, \"isi\": 0.03328813077844599, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 35, \"stim\": 0, \"Log power\": 2.207030436927808, \"Firing rate\": 161.0758519004449, \"Power\": 161.0758519004449, \"i_spike\": 103.5, \"isi\": 0.033743526895481074, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 35, \"stim\": 1, \"Log power\": 2.1942178316819674, \"Firing rate\": 156.3931876617498, \"Power\": 156.3931876617498, \"i_spike\": 99.0, \"isi\": 0.035107969582574956, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 36, \"stim\": 0, \"Log power\": 2.1872280469348246, \"Firing rate\": 153.89625335099842, \"Power\": 153.89625335099842, \"i_spike\": 87.0, \"isi\": 0.04012166395844514, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 36, \"stim\": 1, \"Log power\": 2.827528032260252, \"Firing rate\": 672.2456989288453, \"Power\": 672.2456989288453, \"i_spike\": 109.5, \"isi\": 0.031545143849617055, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 37, \"stim\": 0, \"Log power\": 2.282567270672262, \"Firing rate\": 191.6757938737064, \"Power\": 191.6757938737064, \"i_spike\": 95.0, \"isi\": 0.03696371886977528, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 37, \"stim\": 1, \"Log power\": 2.7891240552886143, \"Firing rate\": 615.3526217659995, \"Power\": 615.3526217659995, \"i_spike\": 102.5, \"isi\": 0.03414172007225115, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 38, \"stim\": 0, \"Log power\": 2.172910528519711, \"Firing rate\": 148.90542775546808, \"Power\": 148.90542775546808, \"i_spike\": 100.5, \"isi\": 0.03477773570250784, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 38, \"stim\": 1, \"Log power\": 2.484988954272366, \"Firing rate\": 305.48434161715903, \"Power\": 305.48434161715903, \"i_spike\": 91.0, \"isi\": 0.038256458484013135, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 39, \"stim\": 0, \"Log power\": 2.388784585683084, \"Firing rate\": 244.7848783704825, \"Power\": 244.7848783704825, \"i_spike\": 101.5, \"isi\": 0.0344536970378176, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 39, \"stim\": 1, \"Log power\": 2.1329994994142516, \"Firing rate\": 135.83118809398724, \"Power\": 135.83118809398724, \"i_spike\": 105.0, \"isi\": 0.0333304025871286, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 40, \"stim\": 0, \"Log power\": 2.2723208250028377, \"Firing rate\": 187.20645740838236, \"Power\": 187.20645740838236, \"i_spike\": 92.5, \"isi\": 0.03732707520178261, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 40, \"stim\": 1, \"Log power\": 2.5400873994017696, \"Firing rate\": 346.80663637909447, \"Power\": 346.80663637909447, \"i_spike\": 108.5, \"isi\": 0.032130697882747666, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 41, \"stim\": 0, \"Log power\": 2.1606303461707665, \"Firing rate\": 144.75392424165685, \"Power\": 144.75392424165685, \"i_spike\": 96.0, \"isi\": 0.03647953163452035, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 41, \"stim\": 1, \"Log power\": 2.190669307420531, \"Firing rate\": 155.1205398203529, \"Power\": 155.1205398203529, \"i_spike\": 104.0, \"isi\": 0.033480124705509734, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 42, \"stim\": 0, \"Log power\": 2.070607591510561, \"Firing rate\": 117.65424235655631, \"Power\": 117.65424235655631, \"i_spike\": 86.0, \"isi\": 0.04039985472758259, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 42, \"stim\": 1, \"Log power\": 2.437928225845542, \"Firing rate\": 274.1121120099851, \"Power\": 274.1121120099851, \"i_spike\": 101.5, \"isi\": 0.03435525714292649, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 43, \"stim\": 0, \"Log power\": 2.8022321754007753, \"Firing rate\": 634.2086708935926, \"Power\": 634.2086708935926, \"i_spike\": 92.0, \"isi\": 0.03798101081557126, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 43, \"stim\": 1, \"Log power\": 3.002708595209304, \"Firing rate\": 1006.2562601032454, \"Power\": 1006.2562601032454, \"i_spike\": 93.5, \"isi\": 0.03633576921417587, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 44, \"stim\": 0, \"Log power\": 2.0406532298021993, \"Firing rate\": 109.81286688037261, \"Power\": 109.81286688037261, \"i_spike\": 94.5, \"isi\": 0.03715996073462623, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 44, \"stim\": 1, \"Log power\": 2.2105583006522203, \"Firing rate\": 162.38963312876896, \"Power\": 162.38963312876896, \"i_spike\": 106.5, \"isi\": 0.03291389269473498, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 45, \"stim\": 0, \"Log power\": 2.1189954689135844, \"Firing rate\": 131.5211110244284, \"Power\": 131.5211110244284, \"i_spike\": 97.0, \"isi\": 0.0359134040438695, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 45, \"stim\": 1, \"Log power\": 2.6046629338115284, \"Firing rate\": 402.4045973991937, \"Power\": 402.4045973991937, \"i_spike\": 114.5, \"isi\": 0.030518526236899643, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 46, \"stim\": 0, \"Log power\": 2.0576266628207756, \"Firing rate\": 114.18962923076832, \"Power\": 114.18962923076832, \"i_spike\": 86.5, \"isi\": 0.04052410258619352, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 46, \"stim\": 1, \"Log power\": 2.1316461199494374, \"Firing rate\": 135.4085601036795, \"Power\": 135.4085601036795, \"i_spike\": 102.0, \"isi\": 0.034102681022305986, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 47, \"stim\": 0, \"Log power\": 2.996948488731432, \"Firing rate\": 992.9982628263147, \"Power\": 992.9982628263147, \"i_spike\": 95.5, \"isi\": 0.03653095469210809, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 47, \"stim\": 1, \"Log power\": 2.3114166683397577, \"Firing rate\": 204.84089671420935, \"Power\": 204.84089671420935, \"i_spike\": 109.0, \"isi\": 0.032176692812204324, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 48, \"stim\": 0, \"Log power\": 2.0937664163251806, \"Firing rate\": 124.09846690678148, \"Power\": 124.09846690678148, \"i_spike\": 91.0, \"isi\": 0.03816372310698342, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 48, \"stim\": 1, \"Log power\": 2.570854068555648, \"Firing rate\": 372.2665963750322, \"Power\": 372.2665963750322, \"i_spike\": 122.5, \"isi\": 0.02863410645610159, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 49, \"stim\": 0, \"Log power\": 2.3168057162654874, \"Firing rate\": 207.3985502460628, \"Power\": 207.3985502460628, \"i_spike\": 82.0, \"isi\": 0.041918238553273264, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 49, \"stim\": 1, \"Log power\": 2.2004335273452926, \"Firing rate\": 158.64760760147766, \"Power\": 158.64760760147766, \"i_spike\": 103.5, \"isi\": 0.03364452841885504, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 50, \"stim\": 0, \"Log power\": 2.500627082974062, \"Firing rate\": 316.68470086131714, \"Power\": 316.68470086131714, \"i_spike\": 101.0, \"isi\": 0.034459536731957084, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 50, \"stim\": 1, \"Log power\": 2.370237198250822, \"Firing rate\": 234.55095105006856, \"Power\": 234.55095105006856, \"i_spike\": 103.0, \"isi\": 0.033862948171056666, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 51, \"stim\": 0, \"Log power\": 2.3083261489861124, \"Firing rate\": 203.38838554263134, \"Power\": 203.38838554263134, \"i_spike\": 100.5, \"isi\": 0.03492060374537045, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 51, \"stim\": 1, \"Log power\": 2.432051118594306, \"Firing rate\": 270.4276652025166, \"Power\": 270.4276652025166, \"i_spike\": 90.5, \"isi\": 0.03855951707210525, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 52, \"stim\": 0, \"Log power\": 2.227537544969761, \"Firing rate\": 168.86418370870595, \"Power\": 168.86418370870595, \"i_spike\": 94.0, \"isi\": 0.03700846999692974, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 52, \"stim\": 1, \"Log power\": 2.2920389943177626, \"Firing rate\": 195.90205616282455, \"Power\": 195.90205616282455, \"i_spike\": 99.5, \"isi\": 0.034929898747469254, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 53, \"stim\": 0, \"Log power\": 2.1875993123107955, \"Firing rate\": 154.02787090954817, \"Power\": 154.02787090954817, \"i_spike\": 110.0, \"isi\": 0.03194548076984301, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 53, \"stim\": 1, \"Log power\": 2.0620360299734517, \"Firing rate\": 115.354895467182, \"Power\": 115.354895467182, \"i_spike\": 93.5, \"isi\": 0.036860586758950965, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 54, \"stim\": 0, \"Log power\": 2.490104338649092, \"Firing rate\": 309.1037960912743, \"Power\": 309.1037960912743, \"i_spike\": 89.5, \"isi\": 0.03897712690206408, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 54, \"stim\": 1, \"Log power\": 2.3222529307323048, \"Firing rate\": 210.01626507703392, \"Power\": 210.01626507703392, \"i_spike\": 99.0, \"isi\": 0.035255455825196576, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 55, \"stim\": 0, \"Log power\": 2.003092437502987, \"Firing rate\": 100.71460122509565, \"Power\": 100.71460122509565, \"i_spike\": 94.5, \"isi\": 0.037125360718610195, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 55, \"stim\": 1, \"Log power\": 2.624988091494971, \"Firing rate\": 421.6849405230178, \"Power\": 421.6849405230178, \"i_spike\": 120.0, \"isi\": 0.02925514251565867, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 56, \"stim\": 0, \"Log power\": 2.272341090882363, \"Firing rate\": 187.21519339787787, \"Power\": 187.21519339787787, \"i_spike\": 99.0, \"isi\": 0.03528011539972761, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 56, \"stim\": 1, \"Log power\": 2.0473782423397275, \"Firing rate\": 111.52654346286492, \"Power\": 111.52654346286492, \"i_spike\": 97.5, \"isi\": 0.035817158366059525, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 57, \"stim\": 0, \"Log power\": 2.130956587455104, \"Firing rate\": 135.19374153172342, \"Power\": 135.19374153172342, \"i_spike\": 90.0, \"isi\": 0.03788913766143979, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 57, \"stim\": 1, \"Log power\": 2.1886971204132837, \"Firing rate\": 154.4177145487128, \"Power\": 154.4177145487128, \"i_spike\": 110.5, \"isi\": 0.03146414289122245, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 58, \"stim\": 0, \"Log power\": 2.0137173772538413, \"Firing rate\": 103.20895415668714, \"Power\": 103.20895415668714, \"i_spike\": 96.0, \"isi\": 0.03649902834421934, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 58, \"stim\": 1, \"Log power\": 3.0504050010867214, \"Firing rate\": 1123.0652800436872, \"Power\": 1123.0652800436872, \"i_spike\": 106.5, \"isi\": 0.03270856841372044, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 59, \"stim\": 0, \"Log power\": 2.132495596403032, \"Firing rate\": 135.67367733849468, \"Power\": 135.67367733849468, \"i_spike\": 89.5, \"isi\": 0.03911453564823164, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 59, \"stim\": 1, \"Log power\": 2.177901683415613, \"Firing rate\": 150.62660356146165, \"Power\": 150.62660356146165, \"i_spike\": 113.0, \"isi\": 0.029982077843513415, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 60, \"stim\": 0, \"Log power\": 2.415633412085809, \"Firing rate\": 260.39546243222634, \"Power\": 260.39546243222634, \"i_spike\": 92.5, \"isi\": 0.03750213816263816, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 60, \"stim\": 1, \"Log power\": 2.564383425839126, \"Firing rate\": 366.7612344709279, \"Power\": 366.7612344709279, \"i_spike\": 104.5, \"isi\": 0.03363193643758971, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 61, \"stim\": 0, \"Log power\": 2.10069282031721, \"Firing rate\": 126.09353502518454, \"Power\": 126.09353502518454, \"i_spike\": 97.5, \"isi\": 0.035814143057264096, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 61, \"stim\": 1, \"Log power\": 2.4653794813557823, \"Firing rate\": 291.9977341106646, \"Power\": 291.9977341106646, \"i_spike\": 106.0, \"isi\": 0.03218964341987222, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 62, \"stim\": 0, \"Log power\": 2.0767429005144487, \"Firing rate\": 119.3281480514624, \"Power\": 119.3281480514624, \"i_spike\": 102.5, \"isi\": 0.03383614250267985, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 62, \"stim\": 1, \"Log power\": 2.067148357373883, \"Firing rate\": 116.72082737051937, \"Power\": 116.72082737051937, \"i_spike\": 110.5, \"isi\": 0.03174555157719116, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 63, \"stim\": 0, \"Log power\": 2.3226037717827226, \"Firing rate\": 210.1859934524735, \"Power\": 210.1859934524735, \"i_spike\": 97.5, \"isi\": 0.03603710191672075, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 63, \"stim\": 1, \"Log power\": 2.3267482252196, \"Firing rate\": 212.20139041558224, \"Power\": 212.20139041558224, \"i_spike\": 95.0, \"isi\": 0.03666207283733454, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 64, \"stim\": 0, \"Log power\": 2.697745732615259, \"Firing rate\": 498.59248990340376, \"Power\": 498.59248990340376, \"i_spike\": 96.5, \"isi\": 0.03565795521394092, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 64, \"stim\": 1, \"Log power\": 2.2247337995757444, \"Firing rate\": 167.77753119669728, \"Power\": 167.77753119669728, \"i_spike\": 100.0, \"isi\": 0.03498757630600934, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 65, \"stim\": 0, \"Log power\": 2.189809551535702, \"Firing rate\": 154.81375748705634, \"Power\": 154.81375748705634, \"i_spike\": 95.5, \"isi\": 0.03666674506259677, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 65, \"stim\": 1, \"Log power\": 2.9248945758676084, \"Firing rate\": 841.1909194156078, \"Power\": 841.1909194156078, \"i_spike\": 86.0, \"isi\": 0.04088986994272091, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 66, \"stim\": 0, \"Log power\": 2.5529139686224758, \"Firing rate\": 357.20207135309295, \"Power\": 357.20207135309295, \"i_spike\": 93.5, \"isi\": 0.03737221426409719, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 66, \"stim\": 1, \"Log power\": 2.4254936397573346, \"Firing rate\": 266.37510858467425, \"Power\": 266.37510858467425, \"i_spike\": 105.5, \"isi\": 0.03308633612026871, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 67, \"stim\": 0, \"Log power\": 1.9783713103033747, \"Firing rate\": 95.14178831653237, \"Power\": 95.14178831653237, \"i_spike\": 84.0, \"isi\": 0.04179207230886426, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 67, \"stim\": 1, \"Log power\": 2.1544111192796542, \"Firing rate\": 142.69577656363273, \"Power\": 142.69577656363273, \"i_spike\": 123.0, \"isi\": 0.028412920348173352, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 68, \"stim\": 0, \"Log power\": 2.0467103482182747, \"Firing rate\": 111.35516049955697, \"Power\": 111.35516049955697, \"i_spike\": 87.0, \"isi\": 0.04003573761358942, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 68, \"stim\": 1, \"Log power\": 2.4981402272478173, \"Firing rate\": 314.87648394539394, \"Power\": 314.87648394539394, \"i_spike\": 113.5, \"isi\": 0.030638896852984522, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 69, \"stim\": 0, \"Log power\": 2.435026957261303, \"Firing rate\": 272.2870315172498, \"Power\": 272.2870315172498, \"i_spike\": 105.5, \"isi\": 0.03327992150262829, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 69, \"stim\": 1, \"Log power\": 2.4247242107434213, \"Firing rate\": 265.9035960640525, \"Power\": 265.9035960640525, \"i_spike\": 123.5, \"isi\": 0.02837822239107863, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 0, \"stim\": 0, \"Log power\": 2.2387808412134245, \"Firing rate\": 173.29292859221957, \"Power\": 173.29292859221957, \"i_spike\": 121.5, \"isi\": 0.02853313550231764, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 0, \"stim\": 1, \"Log power\": 2.096133152854477, \"Firing rate\": 124.77660153953627, \"Power\": 124.77660153953627, \"i_spike\": 122.0, \"isi\": 0.028637764746772102, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 1, \"stim\": 0, \"Log power\": 2.3306606671518435, \"Firing rate\": 214.12169230115245, \"Power\": 214.12169230115245, \"i_spike\": 111.5, \"isi\": 0.030795571603757246, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 1, \"stim\": 1, \"Log power\": 2.454754227716879, \"Firing rate\": 284.94052996493735, \"Power\": 284.94052996493735, \"i_spike\": 120.5, \"isi\": 0.02866635579527785, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 2, \"stim\": 0, \"Log power\": 2.4449068976145303, \"Firing rate\": 278.5523954675138, \"Power\": 278.5523954675138, \"i_spike\": 106.0, \"isi\": 0.03270825812886764, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 2, \"stim\": 1, \"Log power\": 2.5159745848493342, \"Firing rate\": 328.07609335886747, \"Power\": 328.07609335886747, \"i_spike\": 104.0, \"isi\": 0.03374536388414777, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 3, \"stim\": 0, \"Log power\": 2.1054452651983815, \"Firing rate\": 127.48094236260913, \"Power\": 127.48094236260913, \"i_spike\": 105.0, \"isi\": 0.03330027747626142, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 3, \"stim\": 1, \"Log power\": 2.4826726288282566, \"Firing rate\": 303.85936703252935, \"Power\": 303.85936703252935, \"i_spike\": 123.0, \"isi\": 0.02840222379669739, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 4, \"stim\": 0, \"Log power\": 2.35857725609834, \"Firing rate\": 228.33750752692865, \"Power\": 228.33750752692865, \"i_spike\": 107.0, \"isi\": 0.032712368159145445, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 4, \"stim\": 1, \"Log power\": 2.236661228890842, \"Firing rate\": 172.44921782702298, \"Power\": 172.44921782702298, \"i_spike\": 115.5, \"isi\": 0.030225597798228577, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 5, \"stim\": 0, \"Log power\": 2.3745855814604018, \"Firing rate\": 236.91119396585378, \"Power\": 236.91119396585378, \"i_spike\": 116.5, \"isi\": 0.02980765180185336, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 5, \"stim\": 1, \"Log power\": 2.3451067191463575, \"Firing rate\": 221.3638600003979, \"Power\": 221.3638600003979, \"i_spike\": 111.0, \"isi\": 0.03142477518766983, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 6, \"stim\": 0, \"Log power\": 2.1301642991864047, \"Firing rate\": 134.9473309138702, \"Power\": 134.9473309138702, \"i_spike\": 107.5, \"isi\": 0.03261229738311003, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 6, \"stim\": 1, \"Log power\": 2.729332964095691, \"Firing rate\": 536.2075986202508, \"Power\": 536.2075986202508, \"i_spike\": 99.0, \"isi\": 0.03486523175058692, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 7, \"stim\": 0, \"Log power\": 2.1887693802154895, \"Firing rate\": 154.44340937630207, \"Power\": 154.44340937630207, \"i_spike\": 116.5, \"isi\": 0.02976395860271862, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 7, \"stim\": 1, \"Log power\": 2.185085368633124, \"Firing rate\": 153.1388454894073, \"Power\": 153.1388454894073, \"i_spike\": 118.0, \"isi\": 0.029559906970417216, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 8, \"stim\": 0, \"Log power\": 2.046933689200291, \"Firing rate\": 111.4124409116263, \"Power\": 111.4124409116263, \"i_spike\": 99.5, \"isi\": 0.035011040872484335, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 8, \"stim\": 1, \"Log power\": 2.330466738914528, \"Firing rate\": 214.02610054387887, \"Power\": 214.02610054387887, \"i_spike\": 130.5, \"isi\": 0.02685016334501855, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 9, \"stim\": 0, \"Log power\": 2.6040783631816535, \"Firing rate\": 401.86331567775045, \"Power\": 401.86331567775045, \"i_spike\": 95.0, \"isi\": 0.036828573966649736, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 9, \"stim\": 1, \"Log power\": 2.66712880789423, \"Firing rate\": 464.653066769291, \"Power\": 464.653066769291, \"i_spike\": 101.0, \"isi\": 0.03464347342911677, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 10, \"stim\": 0, \"Log power\": 2.149863385780744, \"Firing rate\": 141.2093278407666, \"Power\": 141.2093278407666, \"i_spike\": 118.0, \"isi\": 0.02936961420932318, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 10, \"stim\": 1, \"Log power\": 2.382543649036834, \"Firing rate\": 241.2924032834708, \"Power\": 241.2924032834708, \"i_spike\": 108.5, \"isi\": 0.03199536499601757, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 11, \"stim\": 0, \"Log power\": 2.2796785548439935, \"Firing rate\": 190.40509038247552, \"Power\": 190.40509038247552, \"i_spike\": 108.0, \"isi\": 0.03240543937197036, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 11, \"stim\": 1, \"Log power\": 2.5074163728625587, \"Firing rate\": 321.67430615146355, \"Power\": 321.67430615146355, \"i_spike\": 109.0, \"isi\": 0.03220714621480586, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 12, \"stim\": 0, \"Log power\": 2.3421475145468063, \"Firing rate\": 219.86065352114574, \"Power\": 219.86065352114574, \"i_spike\": 115.0, \"isi\": 0.030419146207378286, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 12, \"stim\": 1, \"Log power\": 2.1776126404311484, \"Firing rate\": 150.5263879705745, \"Power\": 150.5263879705745, \"i_spike\": 105.5, \"isi\": 0.03305901432051696, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 13, \"stim\": 0, \"Log power\": 2.297912606143595, \"Firing rate\": 198.56952921301112, \"Power\": 198.56952921301112, \"i_spike\": 117.0, \"isi\": 0.02989840227540727, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 13, \"stim\": 1, \"Log power\": 2.30769948840374, \"Firing rate\": 203.09512007787026, \"Power\": 203.09512007787026, \"i_spike\": 120.0, \"isi\": 0.029093337874130366, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 14, \"stim\": 0, \"Log power\": 3.4278473990717298, \"Firing rate\": 2678.227093074703, \"Power\": 2678.227093074703, \"i_spike\": 111.0, \"isi\": 0.03126499157278554, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 14, \"stim\": 1, \"Log power\": 2.717699390581335, \"Firing rate\": 522.0347225636683, \"Power\": 522.0347225636683, \"i_spike\": 113.5, \"isi\": 0.0307233617907161, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 15, \"stim\": 0, \"Log power\": 2.36183243824792, \"Firing rate\": 230.05540344518576, \"Power\": 230.05540344518576, \"i_spike\": 99.0, \"isi\": 0.0343015931390401, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 15, \"stim\": 1, \"Log power\": 2.554709227912624, \"Firing rate\": 358.68170697727527, \"Power\": 358.68170697727527, \"i_spike\": 125.0, \"isi\": 0.02789607262944401, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 16, \"stim\": 0, \"Log power\": 2.329198111803566, \"Firing rate\": 213.4018164687659, \"Power\": 213.4018164687659, \"i_spike\": 112.5, \"isi\": 0.031046858517410705, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 16, \"stim\": 1, \"Log power\": 2.230685703680478, \"Firing rate\": 170.0927112091951, \"Power\": 170.0927112091951, \"i_spike\": 115.5, \"isi\": 0.030204049514166147, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 17, \"stim\": 0, \"Log power\": 2.2642261298274744, \"Firing rate\": 183.74948469504963, \"Power\": 183.74948469504963, \"i_spike\": 108.5, \"isi\": 0.03205723968047504, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 17, \"stim\": 1, \"Log power\": 2.430658278801683, \"Firing rate\": 269.5617572278199, \"Power\": 269.5617572278199, \"i_spike\": 129.0, \"isi\": 0.027180442215705067, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 18, \"stim\": 0, \"Log power\": 2.1133912561054853, \"Firing rate\": 129.83484269741788, \"Power\": 129.83484269741788, \"i_spike\": 108.5, \"isi\": 0.032171855970717415, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 18, \"stim\": 1, \"Log power\": 2.746589338733493, \"Firing rate\": 557.9423646807952, \"Power\": 557.9423646807952, \"i_spike\": 106.5, \"isi\": 0.032948995964470464, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 19, \"stim\": 0, \"Log power\": 2.2005069685287015, \"Firing rate\": 158.6744379060992, \"Power\": 158.6744379060992, \"i_spike\": 101.5, \"isi\": 0.03445190535524738, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 19, \"stim\": 1, \"Log power\": 2.1772925164901826, \"Firing rate\": 150.4154739542893, \"Power\": 150.4154739542893, \"i_spike\": 103.5, \"isi\": 0.03379602328938959, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 20, \"stim\": 0, \"Log power\": 2.494573728478383, \"Firing rate\": 312.30125428672767, \"Power\": 312.30125428672767, \"i_spike\": 106.5, \"isi\": 0.03281068889325777, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 20, \"stim\": 1, \"Log power\": 2.446100083893624, \"Firing rate\": 279.31874618201937, \"Power\": 279.31874618201937, \"i_spike\": 114.5, \"isi\": 0.030627413326107546, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 21, \"stim\": 0, \"Log power\": 2.1127456313852675, \"Firing rate\": 129.64197285613145, \"Power\": 129.64197285613145, \"i_spike\": 109.5, \"isi\": 0.0319742372826735, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 21, \"stim\": 1, \"Log power\": 2.1251717012253395, \"Firing rate\": 133.40487530050714, \"Power\": 133.40487530050714, \"i_spike\": 107.5, \"isi\": 0.032511587514608885, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 22, \"stim\": 0, \"Log power\": 2.426871647707529, \"Firing rate\": 267.2216539527633, \"Power\": 267.2216539527633, \"i_spike\": 107.0, \"isi\": 0.0327107869078027, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 22, \"stim\": 1, \"Log power\": 2.4566033945783494, \"Firing rate\": 286.1563545748738, \"Power\": 286.1563545748738, \"i_spike\": 117.0, \"isi\": 0.029710588805103032, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 23, \"stim\": 0, \"Log power\": 2.099173905708598, \"Firing rate\": 125.65330198680839, \"Power\": 125.65330198680839, \"i_spike\": 102.0, \"isi\": 0.0340190094687851, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 23, \"stim\": 1, \"Log power\": 2.26947101101024, \"Firing rate\": 185.98204167812224, \"Power\": 185.98204167812224, \"i_spike\": 111.5, \"isi\": 0.030767543761461826, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 24, \"stim\": 0, \"Log power\": 2.652122477261477, \"Firing rate\": 448.8719604040662, \"Power\": 448.8719604040662, \"i_spike\": 118.0, \"isi\": 0.029507656578313866, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 24, \"stim\": 1, \"Log power\": 2.6004872452034076, \"Firing rate\": 398.55406700533206, \"Power\": 398.55406700533206, \"i_spike\": 99.5, \"isi\": 0.03521714985778055, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 25, \"stim\": 0, \"Log power\": 2.470793305458199, \"Firing rate\": 295.6604989398605, \"Power\": 295.6604989398605, \"i_spike\": 100.5, \"isi\": 0.034873628042610016, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 25, \"stim\": 1, \"Log power\": 2.4308165301563354, \"Firing rate\": 269.6599999826232, \"Power\": 269.6599999826232, \"i_spike\": 111.0, \"isi\": 0.0314959857744625, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 26, \"stim\": 0, \"Log power\": 2.2535161115176163, \"Firing rate\": 179.2735058268592, \"Power\": 179.2735058268592, \"i_spike\": 132.5, \"isi\": 0.026313526039833154, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 26, \"stim\": 1, \"Log power\": 2.539226970390633, \"Firing rate\": 346.1202194440859, \"Power\": 346.1202194440859, \"i_spike\": 122.0, \"isi\": 0.028644120081677854, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 27, \"stim\": 0, \"Log power\": 1.9745962611978733, \"Firing rate\": 94.31836445698384, \"Power\": 94.31836445698384, \"i_spike\": 103.0, \"isi\": 0.03368347640039113, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 27, \"stim\": 1, \"Log power\": 2.2445236493562732, \"Firing rate\": 175.59965137803889, \"Power\": 175.59965137803889, \"i_spike\": 121.0, \"isi\": 0.02889642763577631, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 28, \"stim\": 0, \"Log power\": 2.408110695844926, \"Firing rate\": 255.9238119288369, \"Power\": 255.9238119288369, \"i_spike\": 108.0, \"isi\": 0.032075536933765136, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 28, \"stim\": 1, \"Log power\": 2.1461617786922598, \"Firing rate\": 140.01087788513078, \"Power\": 140.01087788513078, \"i_spike\": 101.5, \"isi\": 0.034289675717336855, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 29, \"stim\": 0, \"Log power\": 2.275883152416509, \"Firing rate\": 188.74834505130065, \"Power\": 188.74834505130065, \"i_spike\": 113.5, \"isi\": 0.030596784366782447, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 29, \"stim\": 1, \"Log power\": 2.357203307583858, \"Firing rate\": 227.61627283156676, \"Power\": 227.61627283156676, \"i_spike\": 114.0, \"isi\": 0.030445378630869175, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 30, \"stim\": 0, \"Log power\": 2.2674304748910568, \"Firing rate\": 185.11025321454034, \"Power\": 185.11025321454034, \"i_spike\": 120.0, \"isi\": 0.028739279895104598, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 30, \"stim\": 1, \"Log power\": 2.139306408160454, \"Firing rate\": 137.8181475528611, \"Power\": 137.8181475528611, \"i_spike\": 124.5, \"isi\": 0.02755647056725143, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 31, \"stim\": 0, \"Log power\": 2.6991239574182, \"Firing rate\": 500.17727645553845, \"Power\": 500.17727645553845, \"i_spike\": 116.0, \"isi\": 0.030182207181704338, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 31, \"stim\": 1, \"Log power\": 2.2645085398735425, \"Firing rate\": 183.8690109116505, \"Power\": 183.8690109116505, \"i_spike\": 116.5, \"isi\": 0.0298144087225485, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 32, \"stim\": 0, \"Log power\": 3.675167030945279, \"Firing rate\": 4733.332693370173, \"Power\": 4733.332693370173, \"i_spike\": 102.5, \"isi\": 0.0341948505174295, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 32, \"stim\": 1, \"Log power\": 2.579121770095857, \"Firing rate\": 379.4213544994617, \"Power\": 379.4213544994617, \"i_spike\": 112.5, \"isi\": 0.030548979437905074, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 33, \"stim\": 0, \"Log power\": 2.473423185018472, \"Firing rate\": 297.4563092358735, \"Power\": 297.4563092358735, \"i_spike\": 111.0, \"isi\": 0.03128525124700106, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 33, \"stim\": 1, \"Log power\": 2.3147507543345798, \"Firing rate\": 206.41951548943078, \"Power\": 206.41951548943078, \"i_spike\": 111.0, \"isi\": 0.0313602784198251, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 34, \"stim\": 0, \"Log power\": 2.5129112657095236, \"Firing rate\": 325.7701334167359, \"Power\": 325.7701334167359, \"i_spike\": 122.0, \"isi\": 0.028579181731945975, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 34, \"stim\": 1, \"Log power\": 2.486560473175817, \"Firing rate\": 306.59175622708653, \"Power\": 306.59175622708653, \"i_spike\": 126.5, \"isi\": 0.027469975937145875, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 35, \"stim\": 0, \"Log power\": 2.4054076701105522, \"Firing rate\": 254.3359024064175, \"Power\": 254.3359024064175, \"i_spike\": 102.5, \"isi\": 0.03423830234930001, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 35, \"stim\": 1, \"Log power\": 2.183329046833763, \"Firing rate\": 152.5207902616969, \"Power\": 152.5207902616969, \"i_spike\": 106.5, \"isi\": 0.03288467618567741, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 36, \"stim\": 0, \"Log power\": 2.9286769699248194, \"Firing rate\": 848.5490858461727, \"Power\": 848.5490858461727, \"i_spike\": 118.0, \"isi\": 0.029439056168683992, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 36, \"stim\": 1, \"Log power\": 2.285060714626855, \"Firing rate\": 192.77944011569602, \"Power\": 192.77944011569602, \"i_spike\": 117.0, \"isi\": 0.02986760205847878, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 37, \"stim\": 0, \"Log power\": 2.398728491472142, \"Firing rate\": 250.45429946202108, \"Power\": 250.45429946202108, \"i_spike\": 116.5, \"isi\": 0.02998685226351414, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 37, \"stim\": 1, \"Log power\": 2.20144153445091, \"Firing rate\": 159.01625986993247, \"Power\": 159.01625986993247, \"i_spike\": 121.5, \"isi\": 0.028685604773161143, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 38, \"stim\": 0, \"Log power\": 2.1501579662028116, \"Firing rate\": 141.3051421235651, \"Power\": 141.3051421235651, \"i_spike\": 99.5, \"isi\": 0.035003266775068945, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 38, \"stim\": 1, \"Log power\": 2.132477161429446, \"Firing rate\": 135.66791837152783, \"Power\": 135.66791837152783, \"i_spike\": 110.5, \"isi\": 0.03150650597686094, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 39, \"stim\": 0, \"Log power\": 2.26922398769437, \"Firing rate\": 185.87628662177042, \"Power\": 185.87628662177042, \"i_spike\": 121.5, \"isi\": 0.02842579471518814, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 39, \"stim\": 1, \"Log power\": 2.675034652549503, \"Firing rate\": 473.189013416686, \"Power\": 473.189013416686, \"i_spike\": 135.0, \"isi\": 0.025790169320093242, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 40, \"stim\": 0, \"Log power\": 2.2879406029124265, \"Firing rate\": 194.06204468996046, \"Power\": 194.06204468996046, \"i_spike\": 117.0, \"isi\": 0.029928326408534683, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 40, \"stim\": 1, \"Log power\": 2.2724987351480226, \"Firing rate\": 187.2831628519918, \"Power\": 187.2831628519918, \"i_spike\": 105.5, \"isi\": 0.03265090411657685, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 41, \"stim\": 0, \"Log power\": 2.265491941591164, \"Firing rate\": 184.28582941005587, \"Power\": 184.28582941005587, \"i_spike\": 104.0, \"isi\": 0.03353107892671971, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 41, \"stim\": 1, \"Log power\": 2.9267934171824654, \"Firing rate\": 844.8768631684944, \"Power\": 844.8768631684944, \"i_spike\": 109.5, \"isi\": 0.03176179686356341, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 42, \"stim\": 0, \"Log power\": 2.098875137531294, \"Firing rate\": 125.56688988741465, \"Power\": 125.56688988741465, \"i_spike\": 118.0, \"isi\": 0.029608479294162836, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 42, \"stim\": 1, \"Log power\": 2.204829224872131, \"Firing rate\": 160.26150796367202, \"Power\": 160.26150796367202, \"i_spike\": 127.0, \"isi\": 0.027569249250649776, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 43, \"stim\": 0, \"Log power\": 2.260386959132079, \"Firing rate\": 182.13229461299554, \"Power\": 182.13229461299554, \"i_spike\": 118.5, \"isi\": 0.029325069146959797, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 43, \"stim\": 1, \"Log power\": 2.2871682586153987, \"Firing rate\": 193.7172336830329, \"Power\": 193.7172336830329, \"i_spike\": 114.0, \"isi\": 0.03067635653844497, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 44, \"stim\": 0, \"Log power\": 2.2832346683358224, \"Firing rate\": 191.97057616000512, \"Power\": 191.97057616000512, \"i_spike\": 105.5, \"isi\": 0.033215883222790926, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 44, \"stim\": 1, \"Log power\": 2.4752003265571125, \"Firing rate\": 298.67600008537323, \"Power\": 298.67600008537323, \"i_spike\": 131.5, \"isi\": 0.026379811918953958, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 45, \"stim\": 0, \"Log power\": 2.416449540331155, \"Firing rate\": 260.88525888712104, \"Power\": 260.88525888712104, \"i_spike\": 105.5, \"isi\": 0.033071276672261514, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 45, \"stim\": 1, \"Log power\": 2.10913685885185, \"Firing rate\": 128.5691755064261, \"Power\": 128.5691755064261, \"i_spike\": 126.5, \"isi\": 0.027551029141299626, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 46, \"stim\": 0, \"Log power\": 2.2643717122662537, \"Firing rate\": 183.81109077882925, \"Power\": 183.81109077882925, \"i_spike\": 105.0, \"isi\": 0.033075202067634264, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 46, \"stim\": 1, \"Log power\": 2.2359977063506333, \"Firing rate\": 172.1859481266153, \"Power\": 172.1859481266153, \"i_spike\": 112.0, \"isi\": 0.03130093077934107, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 47, \"stim\": 0, \"Log power\": 2.2124352181332774, \"Firing rate\": 163.0929612226353, \"Power\": 163.0929612226353, \"i_spike\": 98.0, \"isi\": 0.03568639495351731, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 47, \"stim\": 1, \"Log power\": 2.1927699480724407, \"Firing rate\": 155.87266045799402, \"Power\": 155.87266045799402, \"i_spike\": 118.0, \"isi\": 0.029593876949170844, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 48, \"stim\": 0, \"Log power\": 2.507867322139585, \"Firing rate\": 322.00848984190674, \"Power\": 322.00848984190674, \"i_spike\": 104.0, \"isi\": 0.033195922048375646, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 48, \"stim\": 1, \"Log power\": 2.112923288386241, \"Firing rate\": 129.69501639344497, \"Power\": 129.69501639344497, \"i_spike\": 99.0, \"isi\": 0.03536605585301242, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 49, \"stim\": 0, \"Log power\": 2.3166390901874885, \"Firing rate\": 207.31899275719462, \"Power\": 207.31899275719462, \"i_spike\": 115.0, \"isi\": 0.030455265453359113, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 49, \"stim\": 1, \"Log power\": 2.710592898423363, \"Firing rate\": 513.5620200215044, \"Power\": 513.5620200215044, \"i_spike\": 120.5, \"isi\": 0.02904853954153947, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 50, \"stim\": 0, \"Log power\": 2.615183670349505, \"Firing rate\": 412.2718388413622, \"Power\": 412.2718388413622, \"i_spike\": 111.5, \"isi\": 0.031063691116774393, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 50, \"stim\": 1, \"Log power\": 2.399296858339606, \"Firing rate\": 250.78228685263502, \"Power\": 250.78228685263502, \"i_spike\": 128.0, \"isi\": 0.027343413569181144, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 51, \"stim\": 0, \"Log power\": 2.492740181520329, \"Firing rate\": 310.9855296611351, \"Power\": 310.9855296611351, \"i_spike\": 92.5, \"isi\": 0.03752250780384972, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 51, \"stim\": 1, \"Log power\": 2.4350873876317563, \"Firing rate\": 272.3249218237246, \"Power\": 272.3249218237246, \"i_spike\": 124.5, \"isi\": 0.028183217746151, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 52, \"stim\": 0, \"Log power\": 2.265406219480201, \"Firing rate\": 184.24945821029056, \"Power\": 184.24945821029056, \"i_spike\": 108.5, \"isi\": 0.03199014709906729, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 52, \"stim\": 1, \"Log power\": 2.1397685719778257, \"Firing rate\": 137.96488776445858, \"Power\": 137.96488776445858, \"i_spike\": 116.0, \"isi\": 0.030072371130960625, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 53, \"stim\": 0, \"Log power\": 2.773777400501974, \"Firing rate\": 593.9876296730947, \"Power\": 593.9876296730947, \"i_spike\": 109.5, \"isi\": 0.03190069082562815, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 53, \"stim\": 1, \"Log power\": 3.497852809007061, \"Firing rate\": 3146.681660680951, \"Power\": 3146.681660680951, \"i_spike\": 102.5, \"isi\": 0.03377067321923456, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 54, \"stim\": 0, \"Log power\": 2.036135583584991, \"Firing rate\": 108.67648507604592, \"Power\": 108.67648507604592, \"i_spike\": 100.0, \"isi\": 0.034673360892123015, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 54, \"stim\": 1, \"Log power\": 2.288670286865175, \"Firing rate\": 194.38837392281806, \"Power\": 194.38837392281806, \"i_spike\": 116.0, \"isi\": 0.03025330468824207, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 55, \"stim\": 0, \"Log power\": 2.304147910548738, \"Firing rate\": 201.44101940719474, \"Power\": 201.44101940719474, \"i_spike\": 104.5, \"isi\": 0.03337564378851508, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 55, \"stim\": 1, \"Log power\": 2.728174282230713, \"Firing rate\": 534.7789229453224, \"Power\": 534.7789229453224, \"i_spike\": 105.0, \"isi\": 0.03327383580693417, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 56, \"stim\": 0, \"Log power\": 2.2825010454355796, \"Firing rate\": 191.64656760544074, \"Power\": 191.64656760544074, \"i_spike\": 124.5, \"isi\": 0.028075272388274203, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 56, \"stim\": 1, \"Log power\": 3.3560467201589663, \"Firing rate\": 2270.1090505913025, \"Power\": 2270.1090505913025, \"i_spike\": 117.0, \"isi\": 0.029807087566469537, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 57, \"stim\": 0, \"Log power\": 2.195584728666235, \"Firing rate\": 156.88619448895693, \"Power\": 156.88619448895693, \"i_spike\": 120.5, \"isi\": 0.028951183908237487, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 57, \"stim\": 1, \"Log power\": 2.351384739659477, \"Firing rate\": 224.58706501372157, \"Power\": 224.58706501372157, \"i_spike\": 110.5, \"isi\": 0.03149307351834277, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 58, \"stim\": 0, \"Log power\": 2.2946449832944595, \"Firing rate\": 197.08110258125876, \"Power\": 197.08110258125876, \"i_spike\": 99.5, \"isi\": 0.03518385998989156, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 58, \"stim\": 1, \"Log power\": 2.2544251671222884, \"Firing rate\": 179.6491501725082, \"Power\": 179.6491501725082, \"i_spike\": 115.5, \"isi\": 0.030275274947618364, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 59, \"stim\": 0, \"Log power\": 2.385140382222065, \"Firing rate\": 242.73946041978857, \"Power\": 242.73946041978857, \"i_spike\": 115.5, \"isi\": 0.02995113370801157, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 59, \"stim\": 1, \"Log power\": 2.342816906049887, \"Firing rate\": 220.19979283512473, \"Power\": 220.19979283512473, \"i_spike\": 119.5, \"isi\": 0.029087809038737335, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 60, \"stim\": 0, \"Log power\": 2.6775165359642448, \"Firing rate\": 475.9009107922214, \"Power\": 475.9009107922214, \"i_spike\": 102.5, \"isi\": 0.03410830456044359, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 60, \"stim\": 1, \"Log power\": 2.2903041005548754, \"Firing rate\": 195.12103930030753, \"Power\": 195.12103930030753, \"i_spike\": 128.0, \"isi\": 0.027235099762763736, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 61, \"stim\": 0, \"Log power\": 2.627788853818587, \"Firing rate\": 424.41317171250887, \"Power\": 424.41317171250887, \"i_spike\": 108.0, \"isi\": 0.03224267023787479, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 61, \"stim\": 1, \"Log power\": 2.2598552510014973, \"Firing rate\": 181.90944590411786, \"Power\": 181.90944590411786, \"i_spike\": 122.0, \"isi\": 0.028208277821132176, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 62, \"stim\": 0, \"Log power\": 3.213618680095133, \"Firing rate\": 1635.3799920278398, \"Power\": 1635.3799920278398, \"i_spike\": 120.5, \"isi\": 0.028791547889913692, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 62, \"stim\": 1, \"Log power\": 4.131380948623693, \"Firing rate\": 13532.590764261435, \"Power\": 13532.590764261435, \"i_spike\": 122.5, \"isi\": 0.028391707813144238, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 63, \"stim\": 0, \"Log power\": 2.1902031909767206, \"Firing rate\": 154.95414247894684, \"Power\": 154.95414247894684, \"i_spike\": 97.5, \"isi\": 0.03583563434629115, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 63, \"stim\": 1, \"Log power\": 2.469658643290861, \"Firing rate\": 294.8890479135148, \"Power\": 294.8890479135148, \"i_spike\": 116.0, \"isi\": 0.030016571952686665, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 64, \"stim\": 0, \"Log power\": 2.434945801813104, \"Firing rate\": 272.2361547217169, \"Power\": 272.2361547217169, \"i_spike\": 117.5, \"isi\": 0.02968121825009195, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 64, \"stim\": 1, \"Log power\": 2.2641517706568814, \"Firing rate\": 183.71802611061156, \"Power\": 183.71802611061156, \"i_spike\": 119.0, \"isi\": 0.0293492608638867, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 65, \"stim\": 0, \"Log power\": 2.3114202559055887, \"Firing rate\": 204.84258884538642, \"Power\": 204.84258884538642, \"i_spike\": 108.5, \"isi\": 0.0320918977619244, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 65, \"stim\": 1, \"Log power\": 2.3669601924562342, \"Firing rate\": 232.7877874001859, \"Power\": 232.7877874001859, \"i_spike\": 112.5, \"isi\": 0.030675861793260633, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 66, \"stim\": 0, \"Log power\": 2.356813109757627, \"Firing rate\": 227.41185971598574, \"Power\": 227.41185971598574, \"i_spike\": 101.5, \"isi\": 0.03450849107312674, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 66, \"stim\": 1, \"Log power\": 2.5326082192706747, \"Firing rate\": 340.88525739705557, \"Power\": 340.88525739705557, \"i_spike\": 117.5, \"isi\": 0.02981588907480375, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 67, \"stim\": 0, \"Log power\": 2.097935965046632, \"Firing rate\": 125.2956417997786, \"Power\": 125.2956417997786, \"i_spike\": 104.5, \"isi\": 0.03327364561048795, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 67, \"stim\": 1, \"Log power\": 2.757390357100196, \"Firing rate\": 571.9925299831053, \"Power\": 571.9925299831053, \"i_spike\": 129.0, \"isi\": 0.02705361852230315, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 68, \"stim\": 0, \"Log power\": 3.31584008230167, \"Firing rate\": 2069.379213165911, \"Power\": 2069.379213165911, \"i_spike\": 118.5, \"isi\": 0.0295394008307952, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 68, \"stim\": 1, \"Log power\": 3.0971608396183656, \"Firing rate\": 1250.7221455346228, \"Power\": 1250.7221455346228, \"i_spike\": 115.5, \"isi\": 0.029995273909913828, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 69, \"stim\": 0, \"Log power\": 2.51574368845365, \"Firing rate\": 327.9017152417151, \"Power\": 327.9017152417151, \"i_spike\": 107.5, \"isi\": 0.032534872608338705, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 69, \"stim\": 1, \"Log power\": 2.386341620518817, \"Firing rate\": 243.4117958500848, \"Power\": 243.4117958500848, \"i_spike\": 110.0, \"isi\": 0.03187254275350649, \"combined_condition\": 1.0}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.LayerChart(...)"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "df, df_monster, index_cols, firing_rates = generate_fake_lfp(n_trials=70, mouse_response_slope=10)\n",
    "\n",
    "BayesWindow(df, y='Power', treatment='stim', group='mouse', detail='i_trial').chart_data_box_detail.display()\n",
    "BayesWindow(df, y='Log power', treatment='stim', group='mouse', detail='i_trial').chart_data_box_detail.display()"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "slideshow": {
     "slide_type": "slide"
    }
   },
   "source": [
    "## ROC and CM, original scale"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "metadata": {
    "scrolled": true,
    "slideshow": {
     "slide_type": "slide"
    }
   },
   "outputs": [
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "100%|██████████| 450/450 [18:50<00:00,  2.51s/it]\n"
     ]
    }
   ],
   "source": [
    "# NBVAL_SKIP\n",
    "# Note: Only works with single ys and single true_slopes\n",
    "res = model_comparison.run_conditions(true_slopes=np.hstack([np.zeros(15),\n",
    "                                                             np.tile(10, 15)]),\n",
    "                                      #                                                              np.tile(np.linspace(20, 40, 3), 15)]),\n",
    "                                      n_trials=np.linspace(10, 70, 5).astype(int),\n",
    "                                      #                                       trial_baseline_randomness=np.linspace(.2, 11, 3),\n",
    "                                      ys=('Power',),\n",
    "                                      parallel=True)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### Confusion matrix"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 4,
   "metadata": {
    "scrolled": false
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<div id=\"altair-viz-58cf50806ef54c078261187603c392f7\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-58cf50806ef54c078261187603c392f7\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-58cf50806ef54c078261187603c392f7\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm//vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm//vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm//vega-lite@4.8.1?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm//vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function loadScript(lib) {\n",
       "      return new Promise(function(resolve, reject) {\n",
       "        var s = document.createElement('script');\n",
       "        s.src = paths[lib];\n",
       "        s.async = true;\n",
       "        s.onload = () => resolve(paths[lib]);\n",
       "        s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "        document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "      });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else if (typeof vegaEmbed === \"function\") {\n",
       "      displayChart(vegaEmbed);\n",
       "    } else {\n",
       "      loadScript(\"vega\")\n",
       "        .then(() => loadScript(\"vega-lite\"))\n",
       "        .then(() => loadScript(\"vega-embed\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 400, \"continuousHeight\": 300}}, \"data\": {\"name\": \"data-643c6153be275c889f276b231bac1436\"}, \"facet\": {\"column\": {\"type\": \"quantitative\", \"field\": \"n_trials\"}, \"row\": {\"type\": \"nominal\", \"field\": \"method\"}}, \"spec\": {\"mark\": \"rect\", \"encoding\": {\"color\": {\"type\": \"ordinal\", \"field\": \"Occurences\"}, \"x\": {\"type\": \"nominal\", \"field\": \"predicted\"}, \"y\": {\"type\": \"nominal\", \"field\": \"actual\"}}, \"height\": 180, \"width\": 140}, \"$schema\": \"https://vega.github.io/schema/vega-lite/v4.8.1.json\", \"datasets\": {\"data-643c6153be275c889f276b231bac1436\": [{\"actual\": false, \"predicted\": false, \"Occurences\": 15, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": true, \"Occurences\": 0, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": false, \"Occurences\": 12, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": true, \"Occurences\": 3, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": false, \"Occurences\": 15, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": true, \"Occurences\": 0, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": false, \"Occurences\": 15, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": true, \"Occurences\": 0, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": false, \"Occurences\": 15, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": true, \"Occurences\": 0, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": false, \"Occurences\": 14, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": true, \"Occurences\": 1, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": false, \"Occurences\": 15, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": true, \"Occurences\": 0, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": false, \"Occurences\": 14, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": true, \"Occurences\": 1, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": false, \"Occurences\": 15, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": true, \"Occurences\": 0, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": false, \"Occurences\": 15, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": true, \"Occurences\": 0, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": false, \"Occurences\": 14, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": true, \"Occurences\": 1, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": false, \"Occurences\": 14, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": true, \"Occurences\": 1, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": false, \"Occurences\": 15, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": true, \"Occurences\": 0, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": false, \"Occurences\": 15, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": true, \"Occurences\": 0, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": false, \"Occurences\": 15, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": true, \"Occurences\": 0, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": false, \"Occurences\": 15, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": true, \"Occurences\": 0, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": false, \"Occurences\": 14, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": true, \"Occurences\": 1, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": false, \"Occurences\": 15, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": true, \"Occurences\": 0, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": false, \"Occurences\": 15, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": true, \"Occurences\": 0, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": false, \"Occurences\": 15, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": true, \"Occurences\": 0, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": false, \"Occurences\": 15, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": true, \"Occurences\": 0, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": false, \"Occurences\": 12, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": true, \"Occurences\": 3, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": false, \"Occurences\": 14, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": true, \"Occurences\": 1, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": false, \"Occurences\": 14, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": true, \"Occurences\": 1, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": false, \"Occurences\": 15, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": true, \"Occurences\": 0, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": false, \"Occurences\": 15, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": true, \"Occurences\": 0, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": false, \"Occurences\": 15, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": true, \"Occurences\": 0, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": false, \"Occurences\": 15, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": true, \"Occurences\": 0, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": false, \"Occurences\": 15, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": true, \"Occurences\": 0, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": false, \"Occurences\": 15, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": true, \"Occurences\": 0, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": false, \"Occurences\": 14, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": true, \"Occurences\": 1, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": false, \"Occurences\": 9, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": true, \"Occurences\": 6, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": false, \"Occurences\": 15, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": true, \"Occurences\": 0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": false, \"Occurences\": 8, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": true, \"Occurences\": 7, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": false, \"Occurences\": 13, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": true, \"Occurences\": 2, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": false, \"Occurences\": 7, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": true, \"Occurences\": 8, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": false, \"Occurences\": 15, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": true, \"Occurences\": 0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": false, \"Occurences\": 3, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": true, \"Occurences\": 12, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": false, \"Occurences\": 15, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": true, \"Occurences\": 0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": false, \"Occurences\": 2, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": true, \"Occurences\": 13, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": false, \"Occurences\": 15, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": true, \"Occurences\": 0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": false, \"Occurences\": 5, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": true, \"Occurences\": 10, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": false, \"Occurences\": 15, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": true, \"Occurences\": 0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": false, \"Occurences\": 7, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": true, \"Occurences\": 8, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": false, \"Occurences\": 15, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": true, \"Occurences\": 0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": false, \"Occurences\": 9, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": true, \"Occurences\": 6, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": false, \"Occurences\": 15, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": true, \"Occurences\": 0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": false, \"Occurences\": 1, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": true, \"Occurences\": 14, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": false, \"Occurences\": 15, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": true, \"Occurences\": 0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": false, \"Occurences\": 3, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": true, \"Occurences\": 12, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": false, \"Occurences\": 14, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": true, \"Occurences\": 1, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": false, \"Occurences\": 8, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": true, \"Occurences\": 7, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": false, \"Occurences\": 13, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": true, \"Occurences\": 2, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": false, \"Occurences\": 5, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": true, \"Occurences\": 10, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": false, \"Occurences\": 15, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": true, \"Occurences\": 0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": false, \"Occurences\": 8, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": true, \"Occurences\": 7, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": false, \"Occurences\": 15, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": true, \"Occurences\": 0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": false, \"Occurences\": 2, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": true, \"Occurences\": 13, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": false, \"Occurences\": 14, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": true, \"Occurences\": 1, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": false, \"Occurences\": 4, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": true, \"Occurences\": 11, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": false, \"Occurences\": 11, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": true, \"Occurences\": 4, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": false, \"Occurences\": 7, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": true, \"Occurences\": 8, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": false, \"Occurences\": 12, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": true, \"Occurences\": 3, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": false, \"Occurences\": 6, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": true, \"Occurences\": 9, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": false, \"Occurences\": 5, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": true, \"Occurences\": 10, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": false, \"Occurences\": 5, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": true, \"Occurences\": 10, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": false, \"Occurences\": 9, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": true, \"Occurences\": 6, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": false, \"Occurences\": 6, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": true, \"Occurences\": 9, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": false, \"Occurences\": 8, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": true, \"Occurences\": 7, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": false, \"Occurences\": 5, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": true, \"Occurences\": 10, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": false, \"Occurences\": 10, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": true, \"Occurences\": 5, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": false, \"Occurences\": 3, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": true, \"Occurences\": 12, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": false, \"Occurences\": 8, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": true, \"Occurences\": 7, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": false, \"Occurences\": 6, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": true, \"Occurences\": 9, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": false, \"Occurences\": 10, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": true, \"Occurences\": 5, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": false, \"Occurences\": 7, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": true, \"Occurences\": 8, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": false, \"Occurences\": 10, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": true, \"Occurences\": 5, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": false, \"Occurences\": 6, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": true, \"Occurences\": 9, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": false, \"Occurences\": 8, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": true, \"Occurences\": 7, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": false, \"Occurences\": 4, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": true, \"Occurences\": 11, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": false, \"Occurences\": 7, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": true, \"Occurences\": 8, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": false, \"Occurences\": 2, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": true, \"Occurences\": 13, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": false, \"Occurences\": 8, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": true, \"Occurences\": 7, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": false, \"Occurences\": 8, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": true, \"Occurences\": 7, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": false, \"Occurences\": 11, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": true, \"Occurences\": 4, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": false, \"Occurences\": 4, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": true, \"Occurences\": 11, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": false, \"Occurences\": 5, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": true, \"Occurences\": 10, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": false, \"Occurences\": 8, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": true, \"Occurences\": 7, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": false, \"Occurences\": 9, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": true, \"Occurences\": 6, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": false, \"Occurences\": 3, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": true, \"Occurences\": 12, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": false, \"Occurences\": 0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": true, \"Occurences\": 15, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": false, \"Occurences\": 0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": true, \"Occurences\": 15, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": false, \"Occurences\": 0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": true, \"Occurences\": 15, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": false, \"Occurences\": 0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": true, \"Occurences\": 15, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": false, \"Occurences\": 0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": true, \"Occurences\": 15, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": false, \"Occurences\": 0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": true, \"Occurences\": 15, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": false, \"Occurences\": 1, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": true, \"Occurences\": 14, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": false, \"Occurences\": 0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": true, \"Occurences\": 15, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": false, \"Occurences\": 0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": true, \"Occurences\": 15, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": false, \"Occurences\": 0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": true, \"Occurences\": 15, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": false, \"Occurences\": 0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": true, \"Occurences\": 15, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": false, \"Occurences\": 0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": true, \"Occurences\": 15, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": false, \"Occurences\": 0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": true, \"Occurences\": 15, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": false, \"Occurences\": 0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": true, \"Occurences\": 15, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": false, \"Occurences\": 0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": true, \"Occurences\": 15, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": false, \"Occurences\": 0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": true, \"Occurences\": 15, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": false, \"Occurences\": 0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": true, \"Occurences\": 15, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": false, \"Occurences\": 0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": true, \"Occurences\": 15, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": false, \"Occurences\": 0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": true, \"Occurences\": 15, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": false, \"Occurences\": 0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": true, \"Occurences\": 15, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": false, \"Occurences\": 0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": true, \"Occurences\": 15, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": false, \"Occurences\": 0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": true, \"Occurences\": 15, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": false, \"Occurences\": 0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": true, \"Occurences\": 15, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": false, \"Occurences\": 0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": true, \"Occurences\": 15, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": false, \"Occurences\": 0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": true, \"Occurences\": 15, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": false, \"Occurences\": 0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": true, \"Occurences\": 15, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": false, \"Occurences\": 0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": true, \"Occurences\": 15, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": false, \"Occurences\": 0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": true, \"Occurences\": 15, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": false, \"Occurences\": 0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": true, \"Occurences\": 15, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": false, \"Occurences\": 0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": true, \"Occurences\": 15, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 1.8}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.FacetChart(...)"
      ]
     },
     "execution_count": 4,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "# NBVAL_SKIP\n",
    "model_comparison.plot_confusion(\n",
    "    model_comparison.make_confusion_matrix(res[res['y'] == 'Power'], ('method', 'y', 'randomness', 'n_trials')\n",
    "                                           )).properties(width=140).facet(row='method', column='n_trials')"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "slideshow": {
     "slide_type": "slide"
    }
   },
   "source": [
    "### ROC curve"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 5,
   "metadata": {
    "scrolled": false
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<div id=\"altair-viz-61b72fc933cf4b048e549c03bec642b3\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-61b72fc933cf4b048e549c03bec642b3\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-61b72fc933cf4b048e549c03bec642b3\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm//vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm//vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm//vega-lite@4.8.1?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm//vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function loadScript(lib) {\n",
       "      return new Promise(function(resolve, reject) {\n",
       "        var s = document.createElement('script');\n",
       "        s.src = paths[lib];\n",
       "        s.async = true;\n",
       "        s.onload = () => resolve(paths[lib]);\n",
       "        s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "        document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "      });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else if (typeof vegaEmbed === \"function\") {\n",
       "      displayChart(vegaEmbed);\n",
       "    } else {\n",
       "      loadScript(\"vega\")\n",
       "        .then(() => loadScript(\"vega-lite\"))\n",
       "        .then(() => loadScript(\"vega-embed\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 400, \"continuousHeight\": 300}}, \"data\": {\"name\": \"data-f3f786e8ade191214ad5c94419d47a5b\"}, \"facet\": {\"column\": {\"type\": \"quantitative\", \"field\": \"n_trials\"}, \"row\": {\"type\": \"nominal\", \"field\": \"y\"}}, \"spec\": {\"mark\": \"bar\", \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"method\"}, \"x\": {\"type\": \"nominal\", \"field\": \"method\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"AUC\"}}, \"selection\": {\"selector002\": {\"type\": \"interval\", \"bind\": \"scales\", \"encodings\": [\"x\", \"y\"]}}}, \"$schema\": \"https://vega.github.io/schema/vega-lite/v4.8.1.json\", \"datasets\": {\"data-f3f786e8ade191214ad5c94419d47a5b\": [{\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.56667, \"true_slope\": 10.0, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.15555555555555556, \"AUC\": 0.56667, \"true_slope\": 10.0, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.56667, \"true_slope\": 10.0, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.5, \"true_slope\": 10.0, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.5, \"true_slope\": 10.0, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.5, \"true_slope\": 10.0, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.51111, \"true_slope\": 10.0, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.51111, \"true_slope\": 10.0, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.51111, \"true_slope\": 10.0, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.5, \"true_slope\": 10.0, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.5, \"true_slope\": 10.0, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.5, \"true_slope\": 10.0, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.5, \"true_slope\": 10.0, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.5, \"true_slope\": 10.0, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.4, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.4, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.4222222222222222, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.4222222222222222, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.5555555555555556, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.5555555555555556, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.5777777777777777, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.1111111111111111, \"True positive rate\": 0.5777777777777777, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.1111111111111111, \"True positive rate\": 0.6, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.15555555555555556, \"True positive rate\": 0.6, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.15555555555555556, \"True positive rate\": 0.6222222222222222, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.17777777777777778, \"True positive rate\": 0.6222222222222222, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.17777777777777778, \"True positive rate\": 0.6666666666666666, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.2, \"True positive rate\": 0.6666666666666666, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.2, \"True positive rate\": 0.7333333333333333, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.24444444444444444, \"True positive rate\": 0.7333333333333333, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.24444444444444444, \"True positive rate\": 0.7555555555555555, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.28888888888888886, \"True positive rate\": 0.7555555555555555, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.28888888888888886, \"True positive rate\": 0.7777777777777778, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.37777777777777777, \"True positive rate\": 0.7777777777777778, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.37777777777777777, \"True positive rate\": 0.8222222222222222, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.5333333333333333, \"True positive rate\": 0.8222222222222222, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.5333333333333333, \"True positive rate\": 0.8444444444444444, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.5777777777777777, \"True positive rate\": 0.8444444444444444, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.5777777777777777, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.6444444444444445, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.6444444444444445, \"True positive rate\": 0.8888888888888888, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.7111111111111111, \"True positive rate\": 0.8888888888888888, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.7111111111111111, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.7777777777777778, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.7777777777777778, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.8, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.8, \"True positive rate\": 1.0, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.89778, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.89778, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.3333333333333333, \"AUC\": 0.89778, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.3333333333333333, \"AUC\": 0.89778, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.5555555555555556, \"AUC\": 0.89778, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.5555555555555556, \"AUC\": 0.89778, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.6888888888888889, \"AUC\": 0.89778, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.6888888888888889, \"AUC\": 0.89778, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.7111111111111111, \"AUC\": 0.89778, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.1111111111111111, \"True positive rate\": 0.7111111111111111, \"AUC\": 0.89778, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.1111111111111111, \"True positive rate\": 0.7777777777777778, \"AUC\": 0.89778, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.17777777777777778, \"True positive rate\": 0.7777777777777778, \"AUC\": 0.89778, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.17777777777777778, \"True positive rate\": 0.8222222222222222, \"AUC\": 0.89778, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.26666666666666666, \"True positive rate\": 0.8222222222222222, \"AUC\": 0.89778, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.26666666666666666, \"True positive rate\": 0.8444444444444444, \"AUC\": 0.89778, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.28888888888888886, \"True positive rate\": 0.8444444444444444, \"AUC\": 0.89778, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.28888888888888886, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.89778, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.37777777777777777, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.89778, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.37777777777777777, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.89778, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.4666666666666667, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.89778, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.4666666666666667, \"True positive rate\": 0.9333333333333333, \"AUC\": 0.89778, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.5111111111111111, \"True positive rate\": 0.9333333333333333, \"AUC\": 0.89778, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.5111111111111111, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.89778, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.5333333333333333, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.89778, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.5333333333333333, \"True positive rate\": 1.0, \"AUC\": 0.89778, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.89778, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.37777777777777777, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.37777777777777777, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.4222222222222222, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.4222222222222222, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.5333333333333333, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.5333333333333333, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.5555555555555556, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.08888888888888889, \"True positive rate\": 0.5555555555555556, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.08888888888888889, \"True positive rate\": 0.6444444444444445, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.1111111111111111, \"True positive rate\": 0.6444444444444445, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.1111111111111111, \"True positive rate\": 0.6888888888888889, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.13333333333333333, \"True positive rate\": 0.6888888888888889, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.13333333333333333, \"True positive rate\": 0.7555555555555555, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.15555555555555556, \"True positive rate\": 0.7555555555555555, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.15555555555555556, \"True positive rate\": 0.8444444444444444, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.26666666666666666, \"True positive rate\": 0.8444444444444444, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.26666666666666666, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.35555555555555557, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.35555555555555557, \"True positive rate\": 0.8888888888888888, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.4, \"True positive rate\": 0.8888888888888888, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.4, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.4444444444444444, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.4444444444444444, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.5111111111111111, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.5111111111111111, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.8, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.8, \"True positive rate\": 1.0, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.96494, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.96494, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.96494, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.1111111111111111, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.96494, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.1111111111111111, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.96494, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.13333333333333333, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.96494, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.13333333333333333, \"True positive rate\": 0.9333333333333333, \"AUC\": 0.96494, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.26666666666666666, \"True positive rate\": 0.9333333333333333, \"AUC\": 0.96494, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.26666666666666666, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.96494, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.37777777777777777, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.96494, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.37777777777777777, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.96494, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.5777777777777777, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.96494, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.5777777777777777, \"True positive rate\": 1.0, \"AUC\": 0.96494, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.96494, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.96346, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.96346, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.8, \"AUC\": 0.96346, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.8, \"AUC\": 0.96346, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.8222222222222222, \"AUC\": 0.96346, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.8222222222222222, \"AUC\": 0.96346, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.8888888888888888, \"AUC\": 0.96346, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.08888888888888889, \"True positive rate\": 0.8888888888888888, \"AUC\": 0.96346, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.08888888888888889, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.96346, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.17777777777777778, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.96346, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.17777777777777778, \"True positive rate\": 0.9333333333333333, \"AUC\": 0.96346, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.26666666666666666, \"True positive rate\": 0.9333333333333333, \"AUC\": 0.96346, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.26666666666666666, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.96346, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.6888888888888889, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.96346, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.6888888888888889, \"True positive rate\": 1.0, \"AUC\": 0.96346, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.96346, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.044444444444444446, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.044444444444444446, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.1111111111111111, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.1111111111111111, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.15555555555555556, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.08888888888888889, \"True positive rate\": 0.15555555555555556, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.08888888888888889, \"True positive rate\": 0.24444444444444444, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.1111111111111111, \"True positive rate\": 0.24444444444444444, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.1111111111111111, \"True positive rate\": 0.28888888888888886, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.15555555555555556, \"True positive rate\": 0.28888888888888886, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.15555555555555556, \"True positive rate\": 0.3333333333333333, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.2, \"True positive rate\": 0.3333333333333333, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.2, \"True positive rate\": 0.37777777777777777, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.2222222222222222, \"True positive rate\": 0.37777777777777777, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.2222222222222222, \"True positive rate\": 0.6, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.28888888888888886, \"True positive rate\": 0.6, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.28888888888888886, \"True positive rate\": 0.7111111111111111, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.37777777777777777, \"True positive rate\": 0.7111111111111111, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.37777777777777777, \"True positive rate\": 0.7333333333333333, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.4, \"True positive rate\": 0.7333333333333333, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.4, \"True positive rate\": 0.8, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.4222222222222222, \"True positive rate\": 0.8, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.4222222222222222, \"True positive rate\": 0.8222222222222222, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.4444444444444444, \"True positive rate\": 0.8222222222222222, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.4444444444444444, \"True positive rate\": 0.8444444444444444, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.5777777777777777, \"True positive rate\": 0.8444444444444444, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.5777777777777777, \"True positive rate\": 0.8888888888888888, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.8, \"True positive rate\": 0.8888888888888888, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.8, \"True positive rate\": 0.9333333333333333, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.8444444444444444, \"True positive rate\": 0.9333333333333333, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.8444444444444444, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.9333333333333333, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.9333333333333333, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.9777777777777777, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.9777777777777777, \"True positive rate\": 1.0, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.06666666666666667, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.06666666666666667, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.15555555555555556, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.15555555555555556, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.2, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.2, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.2222222222222222, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.08888888888888889, \"True positive rate\": 0.2222222222222222, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.08888888888888889, \"True positive rate\": 0.24444444444444444, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.1111111111111111, \"True positive rate\": 0.24444444444444444, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.1111111111111111, \"True positive rate\": 0.26666666666666666, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.13333333333333333, \"True positive rate\": 0.26666666666666666, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.13333333333333333, \"True positive rate\": 0.3111111111111111, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.15555555555555556, \"True positive rate\": 0.3111111111111111, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.15555555555555556, \"True positive rate\": 0.4, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.2222222222222222, \"True positive rate\": 0.4, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.2222222222222222, \"True positive rate\": 0.4666666666666667, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.26666666666666666, \"True positive rate\": 0.4666666666666667, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.26666666666666666, \"True positive rate\": 0.4888888888888889, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.28888888888888886, \"True positive rate\": 0.4888888888888889, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.28888888888888886, \"True positive rate\": 0.5111111111111111, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.3111111111111111, \"True positive rate\": 0.5111111111111111, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.3111111111111111, \"True positive rate\": 0.5333333333333333, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.3333333333333333, \"True positive rate\": 0.5333333333333333, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.3333333333333333, \"True positive rate\": 0.5555555555555556, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.37777777777777777, \"True positive rate\": 0.5555555555555556, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.37777777777777777, \"True positive rate\": 0.6666666666666666, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.4444444444444444, \"True positive rate\": 0.6666666666666666, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.4444444444444444, \"True positive rate\": 0.6888888888888889, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.4888888888888889, \"True positive rate\": 0.6888888888888889, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.4888888888888889, \"True positive rate\": 0.7555555555555555, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.5111111111111111, \"True positive rate\": 0.7555555555555555, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.5111111111111111, \"True positive rate\": 0.8, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.5555555555555556, \"True positive rate\": 0.8, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.5555555555555556, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.6444444444444445, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.6444444444444445, \"True positive rate\": 0.8888888888888888, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.6666666666666666, \"True positive rate\": 0.8888888888888888, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.6666666666666666, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.7555555555555555, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.7555555555555555, \"True positive rate\": 0.9333333333333333, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.9111111111111111, \"True positive rate\": 0.9333333333333333, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.9111111111111111, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.9777777777777777, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.9777777777777777, \"True positive rate\": 1.0, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.15555555555555556, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.15555555555555556, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.2, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.13333333333333333, \"True positive rate\": 0.2, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.13333333333333333, \"True positive rate\": 0.24444444444444444, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.15555555555555556, \"True positive rate\": 0.24444444444444444, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.15555555555555556, \"True positive rate\": 0.28888888888888886, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.2, \"True positive rate\": 0.28888888888888886, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.2, \"True positive rate\": 0.3111111111111111, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.2222222222222222, \"True positive rate\": 0.3111111111111111, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.2222222222222222, \"True positive rate\": 0.35555555555555557, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.24444444444444444, \"True positive rate\": 0.35555555555555557, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.24444444444444444, \"True positive rate\": 0.4444444444444444, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.26666666666666666, \"True positive rate\": 0.4444444444444444, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.26666666666666666, \"True positive rate\": 0.5333333333333333, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.28888888888888886, \"True positive rate\": 0.5333333333333333, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.28888888888888886, \"True positive rate\": 0.5555555555555556, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.3111111111111111, \"True positive rate\": 0.5555555555555556, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.3111111111111111, \"True positive rate\": 0.6, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.3333333333333333, \"True positive rate\": 0.6, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.3333333333333333, \"True positive rate\": 0.6222222222222222, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.4222222222222222, \"True positive rate\": 0.6222222222222222, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.4222222222222222, \"True positive rate\": 0.6444444444444445, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.5777777777777777, \"True positive rate\": 0.6444444444444445, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.5777777777777777, \"True positive rate\": 0.6888888888888889, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.6444444444444445, \"True positive rate\": 0.6888888888888889, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.6444444444444445, \"True positive rate\": 0.7111111111111111, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.6888888888888889, \"True positive rate\": 0.7111111111111111, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.6888888888888889, \"True positive rate\": 0.7555555555555555, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.7333333333333333, \"True positive rate\": 0.7555555555555555, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.7333333333333333, \"True positive rate\": 0.7777777777777778, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.7777777777777778, \"True positive rate\": 0.7777777777777778, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.7777777777777778, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.8222222222222222, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.8222222222222222, \"True positive rate\": 0.8888888888888888, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.9111111111111111, \"True positive rate\": 0.8888888888888888, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.9111111111111111, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.9555555555555556, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.9555555555555556, \"True positive rate\": 1.0, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.0, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.13333333333333333, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.08888888888888889, \"True positive rate\": 0.13333333333333333, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.08888888888888889, \"True positive rate\": 0.17777777777777778, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.1111111111111111, \"True positive rate\": 0.17777777777777778, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.1111111111111111, \"True positive rate\": 0.26666666666666666, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.15555555555555556, \"True positive rate\": 0.26666666666666666, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.15555555555555556, \"True positive rate\": 0.28888888888888886, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.17777777777777778, \"True positive rate\": 0.28888888888888886, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.17777777777777778, \"True positive rate\": 0.3111111111111111, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.2222222222222222, \"True positive rate\": 0.3111111111111111, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.2222222222222222, \"True positive rate\": 0.3333333333333333, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.28888888888888886, \"True positive rate\": 0.3333333333333333, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.28888888888888886, \"True positive rate\": 0.35555555555555557, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.3333333333333333, \"True positive rate\": 0.35555555555555557, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.3333333333333333, \"True positive rate\": 0.37777777777777777, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.35555555555555557, \"True positive rate\": 0.37777777777777777, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.35555555555555557, \"True positive rate\": 0.4888888888888889, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.37777777777777777, \"True positive rate\": 0.4888888888888889, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.37777777777777777, \"True positive rate\": 0.5333333333333333, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.4444444444444444, \"True positive rate\": 0.5333333333333333, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.4444444444444444, \"True positive rate\": 0.5555555555555556, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.4888888888888889, \"True positive rate\": 0.5555555555555556, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.4888888888888889, \"True positive rate\": 0.6, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.5111111111111111, \"True positive rate\": 0.6, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.5111111111111111, \"True positive rate\": 0.6444444444444445, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.5333333333333333, \"True positive rate\": 0.6444444444444445, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.5333333333333333, \"True positive rate\": 0.7111111111111111, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.6, \"True positive rate\": 0.7111111111111111, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.6, \"True positive rate\": 0.7555555555555555, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.7111111111111111, \"True positive rate\": 0.7555555555555555, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.7111111111111111, \"True positive rate\": 0.7777777777777778, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.7333333333333333, \"True positive rate\": 0.7777777777777778, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.7333333333333333, \"True positive rate\": 0.8, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.8, \"True positive rate\": 0.8, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.8, \"True positive rate\": 0.8222222222222222, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.8444444444444444, \"True positive rate\": 0.8222222222222222, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.8444444444444444, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.9333333333333333, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.9333333333333333, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.044444444444444446, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.044444444444444446, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.06666666666666667, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.1111111111111111, \"True positive rate\": 0.06666666666666667, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.1111111111111111, \"True positive rate\": 0.15555555555555556, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.24444444444444444, \"True positive rate\": 0.15555555555555556, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.24444444444444444, \"True positive rate\": 0.17777777777777778, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.26666666666666666, \"True positive rate\": 0.17777777777777778, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.26666666666666666, \"True positive rate\": 0.2222222222222222, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.28888888888888886, \"True positive rate\": 0.2222222222222222, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.28888888888888886, \"True positive rate\": 0.24444444444444444, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.3111111111111111, \"True positive rate\": 0.24444444444444444, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.3111111111111111, \"True positive rate\": 0.37777777777777777, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.3333333333333333, \"True positive rate\": 0.37777777777777777, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.3333333333333333, \"True positive rate\": 0.4444444444444444, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.35555555555555557, \"True positive rate\": 0.4444444444444444, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.35555555555555557, \"True positive rate\": 0.5111111111111111, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.37777777777777777, \"True positive rate\": 0.5111111111111111, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.37777777777777777, \"True positive rate\": 0.6444444444444445, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.4, \"True positive rate\": 0.6444444444444445, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.4, \"True positive rate\": 0.6666666666666666, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.4444444444444444, \"True positive rate\": 0.6666666666666666, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.4444444444444444, \"True positive rate\": 0.7333333333333333, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.4888888888888889, \"True positive rate\": 0.7333333333333333, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.4888888888888889, \"True positive rate\": 0.7555555555555555, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.5777777777777777, \"True positive rate\": 0.7555555555555555, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.5777777777777777, \"True positive rate\": 0.8444444444444444, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.6, \"True positive rate\": 0.8444444444444444, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.6, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.6222222222222222, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.6222222222222222, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.8666666666666667, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.8666666666666667, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.8888888888888888, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.8888888888888888, \"True positive rate\": 1.0, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.044444444444444446, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.044444444444444446, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.08888888888888889, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.08888888888888889, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.13333333333333333, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.13333333333333333, \"True positive rate\": 0.13333333333333333, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.13333333333333333, \"True positive rate\": 0.17777777777777778, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.15555555555555556, \"True positive rate\": 0.17777777777777778, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.15555555555555556, \"True positive rate\": 0.2222222222222222, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.17777777777777778, \"True positive rate\": 0.2222222222222222, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.17777777777777778, \"True positive rate\": 0.24444444444444444, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.2, \"True positive rate\": 0.24444444444444444, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.2, \"True positive rate\": 0.26666666666666666, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.2222222222222222, \"True positive rate\": 0.26666666666666666, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.2222222222222222, \"True positive rate\": 0.28888888888888886, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.24444444444444444, \"True positive rate\": 0.28888888888888886, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.24444444444444444, \"True positive rate\": 0.3111111111111111, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.3111111111111111, \"True positive rate\": 0.3111111111111111, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.3111111111111111, \"True positive rate\": 0.37777777777777777, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.35555555555555557, \"True positive rate\": 0.37777777777777777, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.35555555555555557, \"True positive rate\": 0.4666666666666667, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.37777777777777777, \"True positive rate\": 0.4666666666666667, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.37777777777777777, \"True positive rate\": 0.5333333333333333, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.4, \"True positive rate\": 0.5333333333333333, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.4, \"True positive rate\": 0.6, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.4222222222222222, \"True positive rate\": 0.6, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.4222222222222222, \"True positive rate\": 0.6666666666666666, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.4666666666666667, \"True positive rate\": 0.6666666666666666, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.4666666666666667, \"True positive rate\": 0.7111111111111111, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.4888888888888889, \"True positive rate\": 0.7111111111111111, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.4888888888888889, \"True positive rate\": 0.7333333333333333, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.5111111111111111, \"True positive rate\": 0.7333333333333333, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.5111111111111111, \"True positive rate\": 0.7555555555555555, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.5555555555555556, \"True positive rate\": 0.7555555555555555, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.5555555555555556, \"True positive rate\": 0.8222222222222222, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.6, \"True positive rate\": 0.8222222222222222, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.6, \"True positive rate\": 0.8444444444444444, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.6444444444444445, \"True positive rate\": 0.8444444444444444, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.6444444444444445, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.6666666666666666, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.6666666666666666, \"True positive rate\": 0.8888888888888888, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.7111111111111111, \"True positive rate\": 0.8888888888888888, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.7111111111111111, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.8, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.8, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.8222222222222222, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.8222222222222222, \"True positive rate\": 1.0, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.0, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.044444444444444446, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.044444444444444446, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.08888888888888889, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.08888888888888889, \"True positive rate\": 0.08888888888888889, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.08888888888888889, \"True positive rate\": 0.2, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.13333333333333333, \"True positive rate\": 0.2, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.13333333333333333, \"True positive rate\": 0.24444444444444444, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.15555555555555556, \"True positive rate\": 0.24444444444444444, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.15555555555555556, \"True positive rate\": 0.28888888888888886, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.17777777777777778, \"True positive rate\": 0.28888888888888886, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.17777777777777778, \"True positive rate\": 0.3111111111111111, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.24444444444444444, \"True positive rate\": 0.3111111111111111, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.24444444444444444, \"True positive rate\": 0.35555555555555557, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.3111111111111111, \"True positive rate\": 0.35555555555555557, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.3111111111111111, \"True positive rate\": 0.4, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.3333333333333333, \"True positive rate\": 0.4, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.3333333333333333, \"True positive rate\": 0.4222222222222222, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.37777777777777777, \"True positive rate\": 0.4222222222222222, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.37777777777777777, \"True positive rate\": 0.4666666666666667, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.4, \"True positive rate\": 0.4666666666666667, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.4, \"True positive rate\": 0.5111111111111111, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.4444444444444444, \"True positive rate\": 0.5111111111111111, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.4444444444444444, \"True positive rate\": 0.5333333333333333, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.4666666666666667, \"True positive rate\": 0.5333333333333333, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.4666666666666667, \"True positive rate\": 0.5555555555555556, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.4888888888888889, \"True positive rate\": 0.5555555555555556, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.4888888888888889, \"True positive rate\": 0.6222222222222222, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.5111111111111111, \"True positive rate\": 0.6222222222222222, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.5111111111111111, \"True positive rate\": 0.6444444444444445, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.5333333333333333, \"True positive rate\": 0.6444444444444445, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.5333333333333333, \"True positive rate\": 0.6666666666666666, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.5777777777777777, \"True positive rate\": 0.6666666666666666, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.5777777777777777, \"True positive rate\": 0.7333333333333333, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.6, \"True positive rate\": 0.7333333333333333, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.6, \"True positive rate\": 0.8222222222222222, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.6222222222222222, \"True positive rate\": 0.8222222222222222, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.6222222222222222, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.6444444444444445, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.6444444444444445, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.6888888888888889, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.6888888888888889, \"True positive rate\": 0.9333333333333333, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.7555555555555555, \"True positive rate\": 0.9333333333333333, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.7555555555555555, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.7777777777777778, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.7777777777777778, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.8, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.8, \"True positive rate\": 1.0, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.0, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.0, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.08888888888888889, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.08888888888888889, \"True positive rate\": 0.08888888888888889, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.08888888888888889, \"True positive rate\": 0.1111111111111111, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.13333333333333333, \"True positive rate\": 0.1111111111111111, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.13333333333333333, \"True positive rate\": 0.2222222222222222, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.2, \"True positive rate\": 0.2222222222222222, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.2, \"True positive rate\": 0.24444444444444444, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.2222222222222222, \"True positive rate\": 0.24444444444444444, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.2222222222222222, \"True positive rate\": 0.26666666666666666, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.24444444444444444, \"True positive rate\": 0.26666666666666666, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.24444444444444444, \"True positive rate\": 0.3111111111111111, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.3111111111111111, \"True positive rate\": 0.3111111111111111, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.3111111111111111, \"True positive rate\": 0.37777777777777777, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.3333333333333333, \"True positive rate\": 0.37777777777777777, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.3333333333333333, \"True positive rate\": 0.4, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.35555555555555557, \"True positive rate\": 0.4, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.35555555555555557, \"True positive rate\": 0.4888888888888889, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.37777777777777777, \"True positive rate\": 0.4888888888888889, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.37777777777777777, \"True positive rate\": 0.5111111111111111, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.4, \"True positive rate\": 0.5111111111111111, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.4, \"True positive rate\": 0.5333333333333333, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.4222222222222222, \"True positive rate\": 0.5333333333333333, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.4222222222222222, \"True positive rate\": 0.5555555555555556, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.4444444444444444, \"True positive rate\": 0.5555555555555556, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.4444444444444444, \"True positive rate\": 0.6666666666666666, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.4666666666666667, \"True positive rate\": 0.6666666666666666, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.4666666666666667, \"True positive rate\": 0.8222222222222222, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.4888888888888889, \"True positive rate\": 0.8222222222222222, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.4888888888888889, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.5333333333333333, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.5333333333333333, \"True positive rate\": 0.8888888888888888, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.6, \"True positive rate\": 0.8888888888888888, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.6, \"True positive rate\": 0.9333333333333333, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.8444444444444444, \"True positive rate\": 0.9333333333333333, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.8444444444444444, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.8888888888888888, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.8888888888888888, \"True positive rate\": 1.0, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.0, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.1111111111111111, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.1111111111111111, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.15555555555555556, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.13333333333333333, \"True positive rate\": 0.15555555555555556, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.13333333333333333, \"True positive rate\": 0.17777777777777778, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.15555555555555556, \"True positive rate\": 0.17777777777777778, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.15555555555555556, \"True positive rate\": 0.2222222222222222, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.2, \"True positive rate\": 0.2222222222222222, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.2, \"True positive rate\": 0.26666666666666666, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.26666666666666666, \"True positive rate\": 0.26666666666666666, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.26666666666666666, \"True positive rate\": 0.3333333333333333, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.28888888888888886, \"True positive rate\": 0.3333333333333333, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.28888888888888886, \"True positive rate\": 0.37777777777777777, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.3333333333333333, \"True positive rate\": 0.37777777777777777, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.3333333333333333, \"True positive rate\": 0.4222222222222222, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.35555555555555557, \"True positive rate\": 0.4222222222222222, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.35555555555555557, \"True positive rate\": 0.4888888888888889, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.4, \"True positive rate\": 0.4888888888888889, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.4, \"True positive rate\": 0.5555555555555556, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.4444444444444444, \"True positive rate\": 0.5555555555555556, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.4444444444444444, \"True positive rate\": 0.5777777777777777, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.4666666666666667, \"True positive rate\": 0.5777777777777777, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.4666666666666667, \"True positive rate\": 0.6444444444444445, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.5333333333333333, \"True positive rate\": 0.6444444444444445, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.5333333333333333, \"True positive rate\": 0.7111111111111111, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.6222222222222222, \"True positive rate\": 0.7111111111111111, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.6222222222222222, \"True positive rate\": 0.7333333333333333, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.6444444444444445, \"True positive rate\": 0.7333333333333333, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.6444444444444445, \"True positive rate\": 0.7555555555555555, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.6666666666666666, \"True positive rate\": 0.7555555555555555, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.6666666666666666, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.6888888888888889, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.6888888888888889, \"True positive rate\": 0.8888888888888888, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.7333333333333333, \"True positive rate\": 0.8888888888888888, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.7333333333333333, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.7555555555555555, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.7555555555555555, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.7777777777777778, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.7777777777777778, \"True positive rate\": 1.0, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.044444444444444446, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.044444444444444446, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.06666666666666667, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.08888888888888889, \"True positive rate\": 0.06666666666666667, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.08888888888888889, \"True positive rate\": 0.13333333333333333, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.13333333333333333, \"True positive rate\": 0.13333333333333333, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.13333333333333333, \"True positive rate\": 0.15555555555555556, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.17777777777777778, \"True positive rate\": 0.15555555555555556, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.17777777777777778, \"True positive rate\": 0.17777777777777778, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.35555555555555557, \"True positive rate\": 0.17777777777777778, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.35555555555555557, \"True positive rate\": 0.2, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.37777777777777777, \"True positive rate\": 0.2, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.37777777777777777, \"True positive rate\": 0.26666666666666666, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.4444444444444444, \"True positive rate\": 0.26666666666666666, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.4444444444444444, \"True positive rate\": 0.3333333333333333, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.4666666666666667, \"True positive rate\": 0.3333333333333333, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.4666666666666667, \"True positive rate\": 0.35555555555555557, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.4888888888888889, \"True positive rate\": 0.35555555555555557, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.4888888888888889, \"True positive rate\": 0.4666666666666667, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.5111111111111111, \"True positive rate\": 0.4666666666666667, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.5111111111111111, \"True positive rate\": 0.5777777777777777, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.5333333333333333, \"True positive rate\": 0.5777777777777777, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.5333333333333333, \"True positive rate\": 0.6, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.5555555555555556, \"True positive rate\": 0.6, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.5555555555555556, \"True positive rate\": 0.7111111111111111, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.6, \"True positive rate\": 0.7111111111111111, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.6, \"True positive rate\": 0.7555555555555555, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.6222222222222222, \"True positive rate\": 0.7555555555555555, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.6222222222222222, \"True positive rate\": 0.7777777777777778, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.6444444444444445, \"True positive rate\": 0.7777777777777778, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.6444444444444445, \"True positive rate\": 0.8222222222222222, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.7111111111111111, \"True positive rate\": 0.8222222222222222, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.7111111111111111, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.7333333333333333, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.7333333333333333, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.7555555555555555, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.7555555555555555, \"True positive rate\": 0.9333333333333333, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.8222222222222222, \"True positive rate\": 0.9333333333333333, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.8222222222222222, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.9555555555555556, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.9555555555555556, \"True positive rate\": 1.0, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.FacetChart(...)"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "text/html": [
       "\n",
       "<div id=\"altair-viz-ca6c620be9504fe4ab70a50c6cffc6cd\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-ca6c620be9504fe4ab70a50c6cffc6cd\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-ca6c620be9504fe4ab70a50c6cffc6cd\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm//vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm//vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm//vega-lite@4.8.1?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm//vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function loadScript(lib) {\n",
       "      return new Promise(function(resolve, reject) {\n",
       "        var s = document.createElement('script');\n",
       "        s.src = paths[lib];\n",
       "        s.async = true;\n",
       "        s.onload = () => resolve(paths[lib]);\n",
       "        s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "        document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "      });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else if (typeof vegaEmbed === \"function\") {\n",
       "      displayChart(vegaEmbed);\n",
       "    } else {\n",
       "      loadScript(\"vega\")\n",
       "        .then(() => loadScript(\"vega-lite\"))\n",
       "        .then(() => loadScript(\"vega-embed\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 400, \"continuousHeight\": 300}}, \"data\": {\"name\": \"data-f3f786e8ade191214ad5c94419d47a5b\"}, \"facet\": {\"column\": {\"type\": \"quantitative\", \"field\": \"n_trials\"}, \"row\": {\"type\": \"nominal\", \"field\": \"y\"}}, \"spec\": {\"layer\": [{\"mark\": {\"type\": \"line\", \"opacity\": 0.7, \"size\": 2.6}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"method\"}, \"x\": {\"type\": \"quantitative\", \"field\": \"False positive rate\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"field\": \"True positive rate\"}}, \"selection\": {\"selector001\": {\"type\": \"interval\", \"bind\": \"scales\", \"encodings\": [\"x\", \"y\"]}}}, {\"mark\": {\"type\": \"point\", \"opacity\": 0.7, \"size\": 22.6}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"method\"}, \"x\": {\"type\": \"quantitative\", \"field\": \"False positive rate\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"field\": \"True positive rate\"}}}], \"width\": 150}, \"$schema\": \"https://vega.github.io/schema/vega-lite/v4.8.1.json\", \"datasets\": {\"data-f3f786e8ade191214ad5c94419d47a5b\": [{\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.56667, \"true_slope\": 10.0, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.15555555555555556, \"AUC\": 0.56667, \"true_slope\": 10.0, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.56667, \"true_slope\": 10.0, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.5, \"true_slope\": 10.0, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.5, \"true_slope\": 10.0, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.5, \"true_slope\": 10.0, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.51111, \"true_slope\": 10.0, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.51111, \"true_slope\": 10.0, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.51111, \"true_slope\": 10.0, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.5, \"true_slope\": 10.0, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.5, \"true_slope\": 10.0, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.5, \"true_slope\": 10.0, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.5, \"true_slope\": 10.0, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.5, \"true_slope\": 10.0, \"method\": \"anova\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.4, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.4, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.4222222222222222, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.4222222222222222, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.5555555555555556, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.5555555555555556, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.5777777777777777, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.1111111111111111, \"True positive rate\": 0.5777777777777777, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.1111111111111111, \"True positive rate\": 0.6, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.15555555555555556, \"True positive rate\": 0.6, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.15555555555555556, \"True positive rate\": 0.6222222222222222, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.17777777777777778, \"True positive rate\": 0.6222222222222222, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.17777777777777778, \"True positive rate\": 0.6666666666666666, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.2, \"True positive rate\": 0.6666666666666666, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.2, \"True positive rate\": 0.7333333333333333, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.24444444444444444, \"True positive rate\": 0.7333333333333333, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.24444444444444444, \"True positive rate\": 0.7555555555555555, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.28888888888888886, \"True positive rate\": 0.7555555555555555, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.28888888888888886, \"True positive rate\": 0.7777777777777778, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.37777777777777777, \"True positive rate\": 0.7777777777777778, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.37777777777777777, \"True positive rate\": 0.8222222222222222, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.5333333333333333, \"True positive rate\": 0.8222222222222222, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.5333333333333333, \"True positive rate\": 0.8444444444444444, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.5777777777777777, \"True positive rate\": 0.8444444444444444, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.5777777777777777, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.6444444444444445, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.6444444444444445, \"True positive rate\": 0.8888888888888888, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.7111111111111111, \"True positive rate\": 0.8888888888888888, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.7111111111111111, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.7777777777777778, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.7777777777777778, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.8, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.8, \"True positive rate\": 1.0, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.81136, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.89778, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.89778, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.3333333333333333, \"AUC\": 0.89778, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.3333333333333333, \"AUC\": 0.89778, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.5555555555555556, \"AUC\": 0.89778, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.5555555555555556, \"AUC\": 0.89778, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.6888888888888889, \"AUC\": 0.89778, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.6888888888888889, \"AUC\": 0.89778, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.7111111111111111, \"AUC\": 0.89778, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.1111111111111111, \"True positive rate\": 0.7111111111111111, \"AUC\": 0.89778, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.1111111111111111, \"True positive rate\": 0.7777777777777778, \"AUC\": 0.89778, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.17777777777777778, \"True positive rate\": 0.7777777777777778, \"AUC\": 0.89778, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.17777777777777778, \"True positive rate\": 0.8222222222222222, \"AUC\": 0.89778, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.26666666666666666, \"True positive rate\": 0.8222222222222222, \"AUC\": 0.89778, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.26666666666666666, \"True positive rate\": 0.8444444444444444, \"AUC\": 0.89778, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.28888888888888886, \"True positive rate\": 0.8444444444444444, \"AUC\": 0.89778, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.28888888888888886, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.89778, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.37777777777777777, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.89778, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.37777777777777777, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.89778, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.4666666666666667, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.89778, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.4666666666666667, \"True positive rate\": 0.9333333333333333, \"AUC\": 0.89778, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.5111111111111111, \"True positive rate\": 0.9333333333333333, \"AUC\": 0.89778, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.5111111111111111, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.89778, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.5333333333333333, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.89778, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.5333333333333333, \"True positive rate\": 1.0, \"AUC\": 0.89778, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.89778, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.37777777777777777, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.37777777777777777, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.4222222222222222, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.4222222222222222, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.5333333333333333, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.5333333333333333, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.5555555555555556, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.08888888888888889, \"True positive rate\": 0.5555555555555556, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.08888888888888889, \"True positive rate\": 0.6444444444444445, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.1111111111111111, \"True positive rate\": 0.6444444444444445, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.1111111111111111, \"True positive rate\": 0.6888888888888889, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.13333333333333333, \"True positive rate\": 0.6888888888888889, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.13333333333333333, \"True positive rate\": 0.7555555555555555, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.15555555555555556, \"True positive rate\": 0.7555555555555555, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.15555555555555556, \"True positive rate\": 0.8444444444444444, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.26666666666666666, \"True positive rate\": 0.8444444444444444, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.26666666666666666, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.35555555555555557, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.35555555555555557, \"True positive rate\": 0.8888888888888888, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.4, \"True positive rate\": 0.8888888888888888, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.4, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.4444444444444444, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.4444444444444444, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.5111111111111111, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.5111111111111111, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.8, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.8, \"True positive rate\": 1.0, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.88543, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.96494, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.96494, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.96494, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.1111111111111111, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.96494, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.1111111111111111, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.96494, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.13333333333333333, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.96494, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.13333333333333333, \"True positive rate\": 0.9333333333333333, \"AUC\": 0.96494, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.26666666666666666, \"True positive rate\": 0.9333333333333333, \"AUC\": 0.96494, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.26666666666666666, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.96494, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.37777777777777777, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.96494, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.37777777777777777, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.96494, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.5777777777777777, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.96494, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.5777777777777777, \"True positive rate\": 1.0, \"AUC\": 0.96494, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.96494, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.96346, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.96346, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.8, \"AUC\": 0.96346, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.8, \"AUC\": 0.96346, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.8222222222222222, \"AUC\": 0.96346, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.8222222222222222, \"AUC\": 0.96346, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.8888888888888888, \"AUC\": 0.96346, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.08888888888888889, \"True positive rate\": 0.8888888888888888, \"AUC\": 0.96346, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.08888888888888889, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.96346, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.17777777777777778, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.96346, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.17777777777777778, \"True positive rate\": 0.9333333333333333, \"AUC\": 0.96346, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.26666666666666666, \"True positive rate\": 0.9333333333333333, \"AUC\": 0.96346, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.26666666666666666, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.96346, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.6888888888888889, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.96346, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.6888888888888889, \"True positive rate\": 1.0, \"AUC\": 0.96346, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.96346, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.044444444444444446, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.044444444444444446, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.1111111111111111, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.1111111111111111, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.15555555555555556, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.08888888888888889, \"True positive rate\": 0.15555555555555556, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.08888888888888889, \"True positive rate\": 0.24444444444444444, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.1111111111111111, \"True positive rate\": 0.24444444444444444, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.1111111111111111, \"True positive rate\": 0.28888888888888886, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.15555555555555556, \"True positive rate\": 0.28888888888888886, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.15555555555555556, \"True positive rate\": 0.3333333333333333, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.2, \"True positive rate\": 0.3333333333333333, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.2, \"True positive rate\": 0.37777777777777777, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.2222222222222222, \"True positive rate\": 0.37777777777777777, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.2222222222222222, \"True positive rate\": 0.6, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.28888888888888886, \"True positive rate\": 0.6, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.28888888888888886, \"True positive rate\": 0.7111111111111111, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.37777777777777777, \"True positive rate\": 0.7111111111111111, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.37777777777777777, \"True positive rate\": 0.7333333333333333, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.4, \"True positive rate\": 0.7333333333333333, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.4, \"True positive rate\": 0.8, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.4222222222222222, \"True positive rate\": 0.8, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.4222222222222222, \"True positive rate\": 0.8222222222222222, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.4444444444444444, \"True positive rate\": 0.8222222222222222, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.4444444444444444, \"True positive rate\": 0.8444444444444444, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.5777777777777777, \"True positive rate\": 0.8444444444444444, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.5777777777777777, \"True positive rate\": 0.8888888888888888, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.8, \"True positive rate\": 0.8888888888888888, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.8, \"True positive rate\": 0.9333333333333333, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.8444444444444444, \"True positive rate\": 0.9333333333333333, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.8444444444444444, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.9333333333333333, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.9333333333333333, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.9777777777777777, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.9777777777777777, \"True positive rate\": 1.0, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.70716, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.06666666666666667, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.06666666666666667, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.15555555555555556, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.15555555555555556, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.2, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.2, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.2222222222222222, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.08888888888888889, \"True positive rate\": 0.2222222222222222, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.08888888888888889, \"True positive rate\": 0.24444444444444444, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.1111111111111111, \"True positive rate\": 0.24444444444444444, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.1111111111111111, \"True positive rate\": 0.26666666666666666, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.13333333333333333, \"True positive rate\": 0.26666666666666666, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.13333333333333333, \"True positive rate\": 0.3111111111111111, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.15555555555555556, \"True positive rate\": 0.3111111111111111, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.15555555555555556, \"True positive rate\": 0.4, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.2222222222222222, \"True positive rate\": 0.4, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.2222222222222222, \"True positive rate\": 0.4666666666666667, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.26666666666666666, \"True positive rate\": 0.4666666666666667, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.26666666666666666, \"True positive rate\": 0.4888888888888889, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.28888888888888886, \"True positive rate\": 0.4888888888888889, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.28888888888888886, \"True positive rate\": 0.5111111111111111, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.3111111111111111, \"True positive rate\": 0.5111111111111111, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.3111111111111111, \"True positive rate\": 0.5333333333333333, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.3333333333333333, \"True positive rate\": 0.5333333333333333, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.3333333333333333, \"True positive rate\": 0.5555555555555556, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.37777777777777777, \"True positive rate\": 0.5555555555555556, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.37777777777777777, \"True positive rate\": 0.6666666666666666, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.4444444444444444, \"True positive rate\": 0.6666666666666666, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.4444444444444444, \"True positive rate\": 0.6888888888888889, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.4888888888888889, \"True positive rate\": 0.6888888888888889, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.4888888888888889, \"True positive rate\": 0.7555555555555555, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.5111111111111111, \"True positive rate\": 0.7555555555555555, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.5111111111111111, \"True positive rate\": 0.8, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.5555555555555556, \"True positive rate\": 0.8, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.5555555555555556, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.6444444444444445, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.6444444444444445, \"True positive rate\": 0.8888888888888888, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.6666666666666666, \"True positive rate\": 0.8888888888888888, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.6666666666666666, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.7555555555555555, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.7555555555555555, \"True positive rate\": 0.9333333333333333, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.9111111111111111, \"True positive rate\": 0.9333333333333333, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.9111111111111111, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.9777777777777777, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.9777777777777777, \"True positive rate\": 1.0, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.67506, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.15555555555555556, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.15555555555555556, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.2, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.13333333333333333, \"True positive rate\": 0.2, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.13333333333333333, \"True positive rate\": 0.24444444444444444, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.15555555555555556, \"True positive rate\": 0.24444444444444444, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.15555555555555556, \"True positive rate\": 0.28888888888888886, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.2, \"True positive rate\": 0.28888888888888886, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.2, \"True positive rate\": 0.3111111111111111, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.2222222222222222, \"True positive rate\": 0.3111111111111111, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.2222222222222222, \"True positive rate\": 0.35555555555555557, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.24444444444444444, \"True positive rate\": 0.35555555555555557, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.24444444444444444, \"True positive rate\": 0.4444444444444444, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.26666666666666666, \"True positive rate\": 0.4444444444444444, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.26666666666666666, \"True positive rate\": 0.5333333333333333, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.28888888888888886, \"True positive rate\": 0.5333333333333333, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.28888888888888886, \"True positive rate\": 0.5555555555555556, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.3111111111111111, \"True positive rate\": 0.5555555555555556, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.3111111111111111, \"True positive rate\": 0.6, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.3333333333333333, \"True positive rate\": 0.6, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.3333333333333333, \"True positive rate\": 0.6222222222222222, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.4222222222222222, \"True positive rate\": 0.6222222222222222, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.4222222222222222, \"True positive rate\": 0.6444444444444445, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.5777777777777777, \"True positive rate\": 0.6444444444444445, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.5777777777777777, \"True positive rate\": 0.6888888888888889, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.6444444444444445, \"True positive rate\": 0.6888888888888889, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.6444444444444445, \"True positive rate\": 0.7111111111111111, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.6888888888888889, \"True positive rate\": 0.7111111111111111, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.6888888888888889, \"True positive rate\": 0.7555555555555555, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.7333333333333333, \"True positive rate\": 0.7555555555555555, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.7333333333333333, \"True positive rate\": 0.7777777777777778, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.7777777777777778, \"True positive rate\": 0.7777777777777778, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.7777777777777778, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.8222222222222222, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.8222222222222222, \"True positive rate\": 0.8888888888888888, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.9111111111111111, \"True positive rate\": 0.8888888888888888, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.9111111111111111, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.9555555555555556, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.9555555555555556, \"True positive rate\": 1.0, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.6079, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.0, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.13333333333333333, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.08888888888888889, \"True positive rate\": 0.13333333333333333, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.08888888888888889, \"True positive rate\": 0.17777777777777778, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.1111111111111111, \"True positive rate\": 0.17777777777777778, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.1111111111111111, \"True positive rate\": 0.26666666666666666, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.15555555555555556, \"True positive rate\": 0.26666666666666666, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.15555555555555556, \"True positive rate\": 0.28888888888888886, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.17777777777777778, \"True positive rate\": 0.28888888888888886, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.17777777777777778, \"True positive rate\": 0.3111111111111111, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.2222222222222222, \"True positive rate\": 0.3111111111111111, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.2222222222222222, \"True positive rate\": 0.3333333333333333, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.28888888888888886, \"True positive rate\": 0.3333333333333333, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.28888888888888886, \"True positive rate\": 0.35555555555555557, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.3333333333333333, \"True positive rate\": 0.35555555555555557, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.3333333333333333, \"True positive rate\": 0.37777777777777777, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.35555555555555557, \"True positive rate\": 0.37777777777777777, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.35555555555555557, \"True positive rate\": 0.4888888888888889, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.37777777777777777, \"True positive rate\": 0.4888888888888889, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.37777777777777777, \"True positive rate\": 0.5333333333333333, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.4444444444444444, \"True positive rate\": 0.5333333333333333, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.4444444444444444, \"True positive rate\": 0.5555555555555556, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.4888888888888889, \"True positive rate\": 0.5555555555555556, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.4888888888888889, \"True positive rate\": 0.6, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.5111111111111111, \"True positive rate\": 0.6, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.5111111111111111, \"True positive rate\": 0.6444444444444445, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.5333333333333333, \"True positive rate\": 0.6444444444444445, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.5333333333333333, \"True positive rate\": 0.7111111111111111, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.6, \"True positive rate\": 0.7111111111111111, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.6, \"True positive rate\": 0.7555555555555555, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.7111111111111111, \"True positive rate\": 0.7555555555555555, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.7111111111111111, \"True positive rate\": 0.7777777777777778, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.7333333333333333, \"True positive rate\": 0.7777777777777778, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.7333333333333333, \"True positive rate\": 0.8, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.8, \"True positive rate\": 0.8, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.8, \"True positive rate\": 0.8222222222222222, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.8444444444444444, \"True positive rate\": 0.8222222222222222, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.8444444444444444, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.9333333333333333, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.9333333333333333, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.57333, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.044444444444444446, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.044444444444444446, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.06666666666666667, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.1111111111111111, \"True positive rate\": 0.06666666666666667, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.1111111111111111, \"True positive rate\": 0.15555555555555556, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.24444444444444444, \"True positive rate\": 0.15555555555555556, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.24444444444444444, \"True positive rate\": 0.17777777777777778, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.26666666666666666, \"True positive rate\": 0.17777777777777778, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.26666666666666666, \"True positive rate\": 0.2222222222222222, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.28888888888888886, \"True positive rate\": 0.2222222222222222, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.28888888888888886, \"True positive rate\": 0.24444444444444444, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.3111111111111111, \"True positive rate\": 0.24444444444444444, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.3111111111111111, \"True positive rate\": 0.37777777777777777, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.3333333333333333, \"True positive rate\": 0.37777777777777777, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.3333333333333333, \"True positive rate\": 0.4444444444444444, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.35555555555555557, \"True positive rate\": 0.4444444444444444, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.35555555555555557, \"True positive rate\": 0.5111111111111111, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.37777777777777777, \"True positive rate\": 0.5111111111111111, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.37777777777777777, \"True positive rate\": 0.6444444444444445, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.4, \"True positive rate\": 0.6444444444444445, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.4, \"True positive rate\": 0.6666666666666666, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.4444444444444444, \"True positive rate\": 0.6666666666666666, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.4444444444444444, \"True positive rate\": 0.7333333333333333, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.4888888888888889, \"True positive rate\": 0.7333333333333333, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.4888888888888889, \"True positive rate\": 0.7555555555555555, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.5777777777777777, \"True positive rate\": 0.7555555555555555, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.5777777777777777, \"True positive rate\": 0.8444444444444444, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.6, \"True positive rate\": 0.8444444444444444, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.6, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.6222222222222222, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.6222222222222222, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.8666666666666667, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.8666666666666667, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.8888888888888888, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.8888888888888888, \"True positive rate\": 1.0, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.60691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.044444444444444446, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.044444444444444446, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.08888888888888889, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.08888888888888889, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.13333333333333333, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.13333333333333333, \"True positive rate\": 0.13333333333333333, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.13333333333333333, \"True positive rate\": 0.17777777777777778, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.15555555555555556, \"True positive rate\": 0.17777777777777778, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.15555555555555556, \"True positive rate\": 0.2222222222222222, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.17777777777777778, \"True positive rate\": 0.2222222222222222, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.17777777777777778, \"True positive rate\": 0.24444444444444444, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.2, \"True positive rate\": 0.24444444444444444, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.2, \"True positive rate\": 0.26666666666666666, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.2222222222222222, \"True positive rate\": 0.26666666666666666, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.2222222222222222, \"True positive rate\": 0.28888888888888886, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.24444444444444444, \"True positive rate\": 0.28888888888888886, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.24444444444444444, \"True positive rate\": 0.3111111111111111, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.3111111111111111, \"True positive rate\": 0.3111111111111111, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.3111111111111111, \"True positive rate\": 0.37777777777777777, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.35555555555555557, \"True positive rate\": 0.37777777777777777, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.35555555555555557, \"True positive rate\": 0.4666666666666667, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.37777777777777777, \"True positive rate\": 0.4666666666666667, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.37777777777777777, \"True positive rate\": 0.5333333333333333, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.4, \"True positive rate\": 0.5333333333333333, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.4, \"True positive rate\": 0.6, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.4222222222222222, \"True positive rate\": 0.6, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.4222222222222222, \"True positive rate\": 0.6666666666666666, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.4666666666666667, \"True positive rate\": 0.6666666666666666, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.4666666666666667, \"True positive rate\": 0.7111111111111111, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.4888888888888889, \"True positive rate\": 0.7111111111111111, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.4888888888888889, \"True positive rate\": 0.7333333333333333, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.5111111111111111, \"True positive rate\": 0.7333333333333333, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.5111111111111111, \"True positive rate\": 0.7555555555555555, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.5555555555555556, \"True positive rate\": 0.7555555555555555, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.5555555555555556, \"True positive rate\": 0.8222222222222222, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.6, \"True positive rate\": 0.8222222222222222, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.6, \"True positive rate\": 0.8444444444444444, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.6444444444444445, \"True positive rate\": 0.8444444444444444, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.6444444444444445, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.6666666666666666, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.6666666666666666, \"True positive rate\": 0.8888888888888888, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.7111111111111111, \"True positive rate\": 0.8888888888888888, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.7111111111111111, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.8, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.8, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.8222222222222222, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.8222222222222222, \"True positive rate\": 1.0, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.62716, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.0, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.044444444444444446, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.044444444444444446, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.08888888888888889, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.08888888888888889, \"True positive rate\": 0.08888888888888889, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.08888888888888889, \"True positive rate\": 0.2, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.13333333333333333, \"True positive rate\": 0.2, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.13333333333333333, \"True positive rate\": 0.24444444444444444, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.15555555555555556, \"True positive rate\": 0.24444444444444444, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.15555555555555556, \"True positive rate\": 0.28888888888888886, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.17777777777777778, \"True positive rate\": 0.28888888888888886, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.17777777777777778, \"True positive rate\": 0.3111111111111111, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.24444444444444444, \"True positive rate\": 0.3111111111111111, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.24444444444444444, \"True positive rate\": 0.35555555555555557, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.3111111111111111, \"True positive rate\": 0.35555555555555557, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.3111111111111111, \"True positive rate\": 0.4, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.3333333333333333, \"True positive rate\": 0.4, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.3333333333333333, \"True positive rate\": 0.4222222222222222, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.37777777777777777, \"True positive rate\": 0.4222222222222222, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.37777777777777777, \"True positive rate\": 0.4666666666666667, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.4, \"True positive rate\": 0.4666666666666667, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.4, \"True positive rate\": 0.5111111111111111, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.4444444444444444, \"True positive rate\": 0.5111111111111111, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.4444444444444444, \"True positive rate\": 0.5333333333333333, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.4666666666666667, \"True positive rate\": 0.5333333333333333, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.4666666666666667, \"True positive rate\": 0.5555555555555556, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.4888888888888889, \"True positive rate\": 0.5555555555555556, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.4888888888888889, \"True positive rate\": 0.6222222222222222, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.5111111111111111, \"True positive rate\": 0.6222222222222222, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.5111111111111111, \"True positive rate\": 0.6444444444444445, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.5333333333333333, \"True positive rate\": 0.6444444444444445, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.5333333333333333, \"True positive rate\": 0.6666666666666666, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.5777777777777777, \"True positive rate\": 0.6666666666666666, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.5777777777777777, \"True positive rate\": 0.7333333333333333, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.6, \"True positive rate\": 0.7333333333333333, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.6, \"True positive rate\": 0.8222222222222222, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.6222222222222222, \"True positive rate\": 0.8222222222222222, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.6222222222222222, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.6444444444444445, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.6444444444444445, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.6888888888888889, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.6888888888888889, \"True positive rate\": 0.9333333333333333, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.7555555555555555, \"True positive rate\": 0.9333333333333333, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.7555555555555555, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.7777777777777778, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.7777777777777778, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.8, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.8, \"True positive rate\": 1.0, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.61235, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.0, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.0, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.08888888888888889, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.08888888888888889, \"True positive rate\": 0.08888888888888889, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.08888888888888889, \"True positive rate\": 0.1111111111111111, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.13333333333333333, \"True positive rate\": 0.1111111111111111, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.13333333333333333, \"True positive rate\": 0.2222222222222222, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.2, \"True positive rate\": 0.2222222222222222, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.2, \"True positive rate\": 0.24444444444444444, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.2222222222222222, \"True positive rate\": 0.24444444444444444, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.2222222222222222, \"True positive rate\": 0.26666666666666666, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.24444444444444444, \"True positive rate\": 0.26666666666666666, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.24444444444444444, \"True positive rate\": 0.3111111111111111, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.3111111111111111, \"True positive rate\": 0.3111111111111111, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.3111111111111111, \"True positive rate\": 0.37777777777777777, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.3333333333333333, \"True positive rate\": 0.37777777777777777, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.3333333333333333, \"True positive rate\": 0.4, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.35555555555555557, \"True positive rate\": 0.4, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.35555555555555557, \"True positive rate\": 0.4888888888888889, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.37777777777777777, \"True positive rate\": 0.4888888888888889, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.37777777777777777, \"True positive rate\": 0.5111111111111111, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.4, \"True positive rate\": 0.5111111111111111, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.4, \"True positive rate\": 0.5333333333333333, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.4222222222222222, \"True positive rate\": 0.5333333333333333, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.4222222222222222, \"True positive rate\": 0.5555555555555556, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.4444444444444444, \"True positive rate\": 0.5555555555555556, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.4444444444444444, \"True positive rate\": 0.6666666666666666, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.4666666666666667, \"True positive rate\": 0.6666666666666666, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.4666666666666667, \"True positive rate\": 0.8222222222222222, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.4888888888888889, \"True positive rate\": 0.8222222222222222, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.4888888888888889, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.5333333333333333, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.5333333333333333, \"True positive rate\": 0.8888888888888888, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.6, \"True positive rate\": 0.8888888888888888, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.6, \"True positive rate\": 0.9333333333333333, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.8444444444444444, \"True positive rate\": 0.9333333333333333, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.8444444444444444, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.8888888888888888, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.8888888888888888, \"True positive rate\": 1.0, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.6316, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.0, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.1111111111111111, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.1111111111111111, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.15555555555555556, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.13333333333333333, \"True positive rate\": 0.15555555555555556, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.13333333333333333, \"True positive rate\": 0.17777777777777778, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.15555555555555556, \"True positive rate\": 0.17777777777777778, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.15555555555555556, \"True positive rate\": 0.2222222222222222, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.2, \"True positive rate\": 0.2222222222222222, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.2, \"True positive rate\": 0.26666666666666666, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.26666666666666666, \"True positive rate\": 0.26666666666666666, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.26666666666666666, \"True positive rate\": 0.3333333333333333, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.28888888888888886, \"True positive rate\": 0.3333333333333333, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.28888888888888886, \"True positive rate\": 0.37777777777777777, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.3333333333333333, \"True positive rate\": 0.37777777777777777, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.3333333333333333, \"True positive rate\": 0.4222222222222222, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.35555555555555557, \"True positive rate\": 0.4222222222222222, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.35555555555555557, \"True positive rate\": 0.4888888888888889, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.4, \"True positive rate\": 0.4888888888888889, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.4, \"True positive rate\": 0.5555555555555556, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.4444444444444444, \"True positive rate\": 0.5555555555555556, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.4444444444444444, \"True positive rate\": 0.5777777777777777, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.4666666666666667, \"True positive rate\": 0.5777777777777777, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.4666666666666667, \"True positive rate\": 0.6444444444444445, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.5333333333333333, \"True positive rate\": 0.6444444444444445, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.5333333333333333, \"True positive rate\": 0.7111111111111111, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.6222222222222222, \"True positive rate\": 0.7111111111111111, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.6222222222222222, \"True positive rate\": 0.7333333333333333, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.6444444444444445, \"True positive rate\": 0.7333333333333333, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.6444444444444445, \"True positive rate\": 0.7555555555555555, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.6666666666666666, \"True positive rate\": 0.7555555555555555, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.6666666666666666, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.6888888888888889, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.6888888888888889, \"True positive rate\": 0.8888888888888888, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.7333333333333333, \"True positive rate\": 0.8888888888888888, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.7333333333333333, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.7555555555555555, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.7555555555555555, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.7777777777777778, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.7777777777777778, \"True positive rate\": 1.0, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.59951, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.044444444444444446, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.044444444444444446, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.06666666666666667, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.08888888888888889, \"True positive rate\": 0.06666666666666667, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.08888888888888889, \"True positive rate\": 0.13333333333333333, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.13333333333333333, \"True positive rate\": 0.13333333333333333, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.13333333333333333, \"True positive rate\": 0.15555555555555556, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.17777777777777778, \"True positive rate\": 0.15555555555555556, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.17777777777777778, \"True positive rate\": 0.17777777777777778, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.35555555555555557, \"True positive rate\": 0.17777777777777778, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.35555555555555557, \"True positive rate\": 0.2, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.37777777777777777, \"True positive rate\": 0.2, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.37777777777777777, \"True positive rate\": 0.26666666666666666, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.4444444444444444, \"True positive rate\": 0.26666666666666666, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.4444444444444444, \"True positive rate\": 0.3333333333333333, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.4666666666666667, \"True positive rate\": 0.3333333333333333, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.4666666666666667, \"True positive rate\": 0.35555555555555557, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.4888888888888889, \"True positive rate\": 0.35555555555555557, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.4888888888888889, \"True positive rate\": 0.4666666666666667, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.5111111111111111, \"True positive rate\": 0.4666666666666667, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.5111111111111111, \"True positive rate\": 0.5777777777777777, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.5333333333333333, \"True positive rate\": 0.5777777777777777, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.5333333333333333, \"True positive rate\": 0.6, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.5555555555555556, \"True positive rate\": 0.6, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.5555555555555556, \"True positive rate\": 0.7111111111111111, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.6, \"True positive rate\": 0.7111111111111111, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.6, \"True positive rate\": 0.7555555555555555, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.6222222222222222, \"True positive rate\": 0.7555555555555555, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.6222222222222222, \"True positive rate\": 0.7777777777777778, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.6444444444444445, \"True positive rate\": 0.7777777777777778, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.6444444444444445, \"True positive rate\": 0.8222222222222222, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.7111111111111111, \"True positive rate\": 0.8222222222222222, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.7111111111111111, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.7333333333333333, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.7333333333333333, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.7555555555555555, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.7555555555555555, \"True positive rate\": 0.9333333333333333, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.8222222222222222, \"True positive rate\": 0.9333333333333333, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.8222222222222222, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.9555555555555556, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.9555555555555556, \"True positive rate\": 1.0, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.52099, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Power\", \"n_trials\": 70, \"randomness\": 0.2}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.FacetChart(...)"
      ]
     },
     "execution_count": 5,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "df = model_comparison.make_roc_auc(res, binary=False, groups=('method', 'y', 'n_trials'))\n",
    "\n",
    "bars, roc = model_comparison.plot_roc(df)\n",
    "bars.facet(column='n_trials', row='y').properties().display()\n",
    "roc.facet(column='n_trials', row='y').properties()\n",
    "# NBVAL_SKIP"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Log-transformed"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 6,
   "metadata": {},
   "outputs": [
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "100%|██████████| 450/450 [23:21<00:00,  3.12s/it]\n"
     ]
    }
   ],
   "source": [
    "reslog = model_comparison.run_conditions(true_slopes=np.hstack([np.zeros(15),\n",
    "                                                                np.tile(10, 15)]),\n",
    "                                         #                                                              np.tile(np.linspace(20, 40, 3), 15)]),\n",
    "                                         n_trials=np.linspace(10, 70, 5).astype(int),\n",
    "                                         #                                       trial_baseline_randomness=np.linspace(.2, 11, 3),\n",
    "                                         ys=('Log power',),\n",
    "                                         parallel=True)\n",
    "# NBVAL_SKIP"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### Confusion matrix"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 7,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<div id=\"altair-viz-eb05fda0aee54d99bf33ec56ec1aa3c7\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-eb05fda0aee54d99bf33ec56ec1aa3c7\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-eb05fda0aee54d99bf33ec56ec1aa3c7\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm//vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm//vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm//vega-lite@4.8.1?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm//vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function loadScript(lib) {\n",
       "      return new Promise(function(resolve, reject) {\n",
       "        var s = document.createElement('script');\n",
       "        s.src = paths[lib];\n",
       "        s.async = true;\n",
       "        s.onload = () => resolve(paths[lib]);\n",
       "        s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "        document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "      });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else if (typeof vegaEmbed === \"function\") {\n",
       "      displayChart(vegaEmbed);\n",
       "    } else {\n",
       "      loadScript(\"vega\")\n",
       "        .then(() => loadScript(\"vega-lite\"))\n",
       "        .then(() => loadScript(\"vega-embed\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 400, \"continuousHeight\": 300}}, \"data\": {\"name\": \"data-272328fd967ceefbcb4985949367bd45\"}, \"facet\": {\"column\": {\"type\": \"quantitative\", \"field\": \"n_trials\"}, \"row\": {\"type\": \"nominal\", \"field\": \"method\"}}, \"spec\": {\"mark\": \"rect\", \"encoding\": {\"color\": {\"type\": \"ordinal\", \"field\": \"Occurences\"}, \"x\": {\"type\": \"nominal\", \"field\": \"predicted\"}, \"y\": {\"type\": \"nominal\", \"field\": \"actual\"}}, \"height\": 180, \"width\": 140}, \"$schema\": \"https://vega.github.io/schema/vega-lite/v4.8.1.json\", \"datasets\": {\"data-272328fd967ceefbcb4985949367bd45\": [{\"actual\": false, \"predicted\": false, \"Occurences\": 15, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": true, \"Occurences\": 0, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": false, \"Occurences\": 14, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": true, \"Occurences\": 1, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": false, \"Occurences\": 15, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": true, \"Occurences\": 0, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": false, \"Occurences\": 15, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": true, \"Occurences\": 0, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": false, \"Occurences\": 15, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": true, \"Occurences\": 0, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": false, \"Occurences\": 14, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": true, \"Occurences\": 1, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": false, \"Occurences\": 15, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": true, \"Occurences\": 0, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": false, \"Occurences\": 15, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": true, \"Occurences\": 0, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": false, \"Occurences\": 15, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": true, \"Occurences\": 0, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": false, \"Occurences\": 15, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": true, \"Occurences\": 0, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": false, \"Occurences\": 15, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": true, \"Occurences\": 0, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": false, \"Occurences\": 11, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": true, \"Occurences\": 4, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": false, \"Occurences\": 15, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": true, \"Occurences\": 0, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": false, \"Occurences\": 14, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": true, \"Occurences\": 1, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": false, \"Occurences\": 15, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": true, \"Occurences\": 0, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": false, \"Occurences\": 15, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": true, \"Occurences\": 0, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": false, \"Occurences\": 15, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": true, \"Occurences\": 0, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": false, \"Occurences\": 15, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": true, \"Occurences\": 0, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": false, \"Occurences\": 15, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": true, \"Occurences\": 0, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": false, \"Occurences\": 15, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": true, \"Occurences\": 0, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": false, \"Occurences\": 15, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": true, \"Occurences\": 0, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": false, \"Occurences\": 13, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": true, \"Occurences\": 2, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": false, \"Occurences\": 15, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": true, \"Occurences\": 0, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": false, \"Occurences\": 13, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": true, \"Occurences\": 2, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": false, \"Occurences\": 15, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": true, \"Occurences\": 0, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": false, \"Occurences\": 15, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": true, \"Occurences\": 0, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": false, \"Occurences\": 15, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": true, \"Occurences\": 0, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": false, \"Occurences\": 15, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": true, \"Occurences\": 0, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": false, \"Occurences\": 15, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": true, \"Occurences\": 0, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": false, \"Occurences\": 14, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": true, \"Occurences\": 1, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": false, \"Occurences\": 15, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": true, \"Occurences\": 0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": false, \"Occurences\": 12, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": true, \"Occurences\": 3, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": false, \"Occurences\": 14, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": true, \"Occurences\": 1, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": false, \"Occurences\": 1, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": true, \"Occurences\": 14, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": false, \"Occurences\": 15, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": true, \"Occurences\": 0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": false, \"Occurences\": 0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": true, \"Occurences\": 15, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": false, \"Occurences\": 14, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": true, \"Occurences\": 1, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": false, \"Occurences\": 0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": true, \"Occurences\": 15, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": false, \"Occurences\": 15, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": true, \"Occurences\": 0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": false, \"Occurences\": 0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": true, \"Occurences\": 15, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": false, \"Occurences\": 15, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": true, \"Occurences\": 0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": false, \"Occurences\": 4, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": true, \"Occurences\": 11, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": false, \"Occurences\": 14, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": true, \"Occurences\": 1, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": false, \"Occurences\": 0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": true, \"Occurences\": 15, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": false, \"Occurences\": 15, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": true, \"Occurences\": 0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": false, \"Occurences\": 0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": true, \"Occurences\": 15, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": false, \"Occurences\": 14, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": true, \"Occurences\": 1, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": false, \"Occurences\": 0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": true, \"Occurences\": 15, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": false, \"Occurences\": 15, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": true, \"Occurences\": 0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": false, \"Occurences\": 0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": true, \"Occurences\": 15, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": false, \"Occurences\": 14, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": true, \"Occurences\": 1, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": false, \"Occurences\": 8, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": true, \"Occurences\": 7, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": false, \"Occurences\": 14, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": true, \"Occurences\": 1, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": false, \"Occurences\": 2, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": true, \"Occurences\": 13, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": false, \"Occurences\": 11, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": true, \"Occurences\": 4, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": false, \"Occurences\": 0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": true, \"Occurences\": 15, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": false, \"Occurences\": 11, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": true, \"Occurences\": 4, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": false, \"Occurences\": 0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": true, \"Occurences\": 15, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": false, \"Occurences\": 13, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": true, \"Occurences\": 2, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": false, \"Occurences\": 0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": true, \"Occurences\": 15, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": false, \"Occurences\": 15, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": true, \"Occurences\": 0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": false, \"Occurences\": 8, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": true, \"Occurences\": 7, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": false, \"Occurences\": 14, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": true, \"Occurences\": 1, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": false, \"Occurences\": 2, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": true, \"Occurences\": 13, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": false, \"Occurences\": 15, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": true, \"Occurences\": 0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": false, \"Occurences\": 0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": true, \"Occurences\": 15, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": false, \"Occurences\": 15, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": true, \"Occurences\": 0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": false, \"Occurences\": 0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": true, \"Occurences\": 15, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": false, \"Occurences\": 15, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": true, \"Occurences\": 0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": false, \"Occurences\": 0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": true, \"Occurences\": 15, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": false, \"Occurences\": 15, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": true, \"Occurences\": 0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": false, \"Occurences\": 3, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": true, \"Occurences\": 12, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": false, \"Occurences\": 13, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": true, \"Occurences\": 2, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": false, \"Occurences\": 1, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": true, \"Occurences\": 14, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": false, \"Occurences\": 14, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": true, \"Occurences\": 1, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": false, \"Occurences\": 0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": true, \"Occurences\": 15, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": false, \"Occurences\": 14, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": true, \"Occurences\": 1, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": false, \"Occurences\": 0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": true, \"Occurences\": 15, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": false, \"Occurences\": 15, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": true, \"Occurences\": 0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": false, \"Occurences\": 0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": true, \"Occurences\": 15, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": false, \"Occurences\": 14, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": true, \"Occurences\": 1, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": false, \"Occurences\": 5, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": true, \"Occurences\": 10, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": false, \"Occurences\": 13, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": true, \"Occurences\": 2, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": false, \"Occurences\": 3, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": true, \"Occurences\": 12, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": false, \"Occurences\": 10, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": true, \"Occurences\": 5, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": false, \"Occurences\": 0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": true, \"Occurences\": 15, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": false, \"Occurences\": 11, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": true, \"Occurences\": 4, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": false, \"Occurences\": 0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": true, \"Occurences\": 15, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": false, \"Occurences\": 14, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": true, \"Occurences\": 1, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": false, \"Occurences\": 0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": true, \"Occurences\": 15, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": false, \"Occurences\": 1, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": true, \"Occurences\": 14, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": false, \"Occurences\": 0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": true, \"Occurences\": 15, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": false, \"Occurences\": 0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": true, \"Occurences\": 15, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": false, \"Occurences\": 0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": true, \"Occurences\": 15, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": false, \"Occurences\": 0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": true, \"Occurences\": 15, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": false, \"Occurences\": 0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": true, \"Occurences\": 15, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": false, \"Occurences\": 0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": true, \"Occurences\": 15, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": false, \"Occurences\": 0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": true, \"Occurences\": 15, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": false, \"Occurences\": 0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": true, \"Occurences\": 15, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": false, \"Occurences\": 0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"actual\": true, \"predicted\": true, \"Occurences\": 15, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"actual\": false, \"predicted\": false, \"Occurences\": 1, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": true, \"Occurences\": 14, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": false, \"Occurences\": 0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": true, \"Occurences\": 15, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": false, \"Occurences\": 0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": true, \"Occurences\": 15, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": false, \"Occurences\": 0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": true, \"Occurences\": 15, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": false, \"Occurences\": 0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": true, \"Occurences\": 15, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": false, \"Occurences\": 0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": true, \"Occurences\": 15, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": false, \"Occurences\": 0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": true, \"Occurences\": 15, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": false, \"Occurences\": 0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": true, \"Occurences\": 15, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": false, \"Occurences\": 0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": true, \"Occurences\": 15, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": false, \"Occurences\": 0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.4}, {\"actual\": true, \"predicted\": true, \"Occurences\": 15, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.4}, {\"actual\": false, \"predicted\": false, \"Occurences\": 0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": true, \"Occurences\": 15, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": false, \"Occurences\": 0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": true, \"Occurences\": 15, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": false, \"Occurences\": 0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": true, \"Occurences\": 15, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": false, \"Occurences\": 0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": true, \"Occurences\": 15, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": false, \"Occurences\": 0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": true, \"Occurences\": 15, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": false, \"Occurences\": 0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": true, \"Occurences\": 15, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": false, \"Occurences\": 0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": true, \"Occurences\": 15, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": false, \"Occurences\": 0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": true, \"Occurences\": 15, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": false, \"Occurences\": 0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 1.8}, {\"actual\": false, \"predicted\": true, \"Occurences\": 15, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": false, \"Occurences\": 0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 1.8}, {\"actual\": true, \"predicted\": true, \"Occurences\": 15, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 1.8}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.FacetChart(...)"
      ]
     },
     "execution_count": 7,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "model_comparison.plot_confusion(\n",
    "    model_comparison.make_confusion_matrix(reslog, ('method', 'y', 'randomness', 'n_trials')\n",
    "                                           )).properties(width=140).facet(row='method', column='n_trials')\n",
    "# NBVAL_SKIP"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "slideshow": {
     "slide_type": "slide"
    }
   },
   "source": [
    "### ROC curve"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 8,
   "metadata": {
    "scrolled": false
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<div id=\"altair-viz-7d793285ed4241ddb7be48e9140853e3\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-7d793285ed4241ddb7be48e9140853e3\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-7d793285ed4241ddb7be48e9140853e3\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm//vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm//vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm//vega-lite@4.8.1?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm//vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function loadScript(lib) {\n",
       "      return new Promise(function(resolve, reject) {\n",
       "        var s = document.createElement('script');\n",
       "        s.src = paths[lib];\n",
       "        s.async = true;\n",
       "        s.onload = () => resolve(paths[lib]);\n",
       "        s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "        document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "      });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else if (typeof vegaEmbed === \"function\") {\n",
       "      displayChart(vegaEmbed);\n",
       "    } else {\n",
       "      loadScript(\"vega\")\n",
       "        .then(() => loadScript(\"vega-lite\"))\n",
       "        .then(() => loadScript(\"vega-embed\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 400, \"continuousHeight\": 300}}, \"data\": {\"name\": \"data-bd9ddff88500ea10b6bbc737a36d9615\"}, \"facet\": {\"column\": {\"type\": \"quantitative\", \"field\": \"n_trials\"}, \"row\": {\"type\": \"nominal\", \"field\": \"y\"}}, \"spec\": {\"mark\": \"bar\", \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"method\"}, \"x\": {\"type\": \"nominal\", \"field\": \"method\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"AUC\"}}, \"selection\": {\"selector004\": {\"type\": \"interval\", \"bind\": \"scales\", \"encodings\": [\"x\", \"y\"]}}}, \"$schema\": \"https://vega.github.io/schema/vega-lite/v4.8.1.json\", \"datasets\": {\"data-bd9ddff88500ea10b6bbc737a36d9615\": [{\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.57778, \"true_slope\": 10.0, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.15555555555555556, \"AUC\": 0.57778, \"true_slope\": 10.0, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.57778, \"true_slope\": 10.0, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.53333, \"true_slope\": 10.0, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.06666666666666667, \"AUC\": 0.53333, \"true_slope\": 10.0, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.53333, \"true_slope\": 10.0, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.51111, \"true_slope\": 10.0, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.51111, \"true_slope\": 10.0, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.51111, \"true_slope\": 10.0, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.5, \"true_slope\": 10.0, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.5, \"true_slope\": 10.0, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.51111, \"true_slope\": 10.0, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.51111, \"true_slope\": 10.0, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.51111, \"true_slope\": 10.0, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.93284, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.93284, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.4, \"AUC\": 0.93284, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.4, \"AUC\": 0.93284, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.93284, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.17777777777777778, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.93284, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.17777777777777778, \"True positive rate\": 0.8888888888888888, \"AUC\": 0.93284, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.2, \"True positive rate\": 0.8888888888888888, \"AUC\": 0.93284, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.2, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.93284, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.26666666666666666, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.93284, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.26666666666666666, \"True positive rate\": 0.9333333333333333, \"AUC\": 0.93284, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.4444444444444444, \"True positive rate\": 0.9333333333333333, \"AUC\": 0.93284, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.4444444444444444, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.93284, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.5777777777777777, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.93284, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.5777777777777777, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.93284, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.8888888888888888, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.93284, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.8888888888888888, \"True positive rate\": 1.0, \"AUC\": 0.93284, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.93284, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.98469, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.98469, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.8, \"AUC\": 0.98469, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.8, \"AUC\": 0.98469, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.8888888888888888, \"AUC\": 0.98469, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.8888888888888888, \"AUC\": 0.98469, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.98469, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.1111111111111111, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.98469, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.1111111111111111, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.98469, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.28888888888888886, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.98469, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.28888888888888886, \"True positive rate\": 1.0, \"AUC\": 0.98469, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.98469, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.99407, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.99407, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.99407, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.99407, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.99407, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.99407, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.99407, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.99407, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 1.0, \"AUC\": 0.99407, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.99407, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.99704, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.99704, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.9333333333333333, \"AUC\": 0.99704, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.9333333333333333, \"AUC\": 0.99704, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.99704, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.99704, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.99704, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.99704, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 1.0, \"AUC\": 0.99704, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.99704, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.022222222222222223, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 1.0, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.92691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.92691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.37777777777777777, \"AUC\": 0.92691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.37777777777777777, \"AUC\": 0.92691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.7111111111111111, \"AUC\": 0.92691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.7111111111111111, \"AUC\": 0.92691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.8, \"AUC\": 0.92691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.8, \"AUC\": 0.92691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.8222222222222222, \"AUC\": 0.92691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.13333333333333333, \"True positive rate\": 0.8222222222222222, \"AUC\": 0.92691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.13333333333333333, \"True positive rate\": 0.8444444444444444, \"AUC\": 0.92691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.15555555555555556, \"True positive rate\": 0.8444444444444444, \"AUC\": 0.92691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.15555555555555556, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.92691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.17777777777777778, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.92691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.17777777777777778, \"True positive rate\": 0.8888888888888888, \"AUC\": 0.92691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.2, \"True positive rate\": 0.8888888888888888, \"AUC\": 0.92691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.2, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.92691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.24444444444444444, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.92691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.24444444444444444, \"True positive rate\": 0.9333333333333333, \"AUC\": 0.92691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.26666666666666666, \"True positive rate\": 0.9333333333333333, \"AUC\": 0.92691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.26666666666666666, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.92691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.6666666666666666, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.92691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.6666666666666666, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.92691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.8666666666666667, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.92691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.8666666666666667, \"True positive rate\": 1.0, \"AUC\": 0.92691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.92691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.9684, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.9684, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.7333333333333333, \"AUC\": 0.9684, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.7333333333333333, \"AUC\": 0.9684, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.8, \"AUC\": 0.9684, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.8, \"AUC\": 0.9684, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.8222222222222222, \"AUC\": 0.9684, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.1111111111111111, \"True positive rate\": 0.8222222222222222, \"AUC\": 0.9684, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.1111111111111111, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.9684, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.17777777777777778, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.9684, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.17777777777777778, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.9684, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.2, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.9684, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.2, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.9684, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.28888888888888886, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.9684, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.28888888888888886, \"True positive rate\": 1.0, \"AUC\": 0.9684, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.9684, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.98864, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.98864, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.7777777777777778, \"AUC\": 0.98864, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.7777777777777778, \"AUC\": 0.98864, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.8, \"AUC\": 0.98864, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.8, \"AUC\": 0.98864, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.98864, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.98864, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.98864, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.1111111111111111, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.98864, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.1111111111111111, \"True positive rate\": 1.0, \"AUC\": 0.98864, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.98864, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.99259, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.99259, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.7777777777777778, \"AUC\": 0.99259, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.7777777777777778, \"AUC\": 0.99259, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.99259, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.99259, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.99259, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.08888888888888889, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.99259, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.08888888888888889, \"True positive rate\": 1.0, \"AUC\": 0.99259, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.99259, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.022222222222222223, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 1.0, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.24444444444444444, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.26666666666666666, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.37777777777777777, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.4222222222222222, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.4444444444444444, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.4888888888888889, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.5111111111111111, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.5111111111111111, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.6, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.6, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.6222222222222222, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.6666666666666666, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.7111111111111111, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.08888888888888889, \"True positive rate\": 0.7333333333333333, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.08888888888888889, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.1111111111111111, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.17777777777777778, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.17777777777777778, \"True positive rate\": 0.9333333333333333, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.2, \"True positive rate\": 0.9333333333333333, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.2, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.24444444444444444, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.3111111111111111, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.3333333333333333, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.5333333333333333, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.5777777777777777, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.6222222222222222, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.6666666666666666, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.8222222222222222, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.8222222222222222, \"True positive rate\": 1.0, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.28888888888888886, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.3333333333333333, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.5111111111111111, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.5555555555555556, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.6, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.6222222222222222, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.6888888888888889, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.7333333333333333, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.7555555555555555, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.8, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.8444444444444444, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.9333333333333333, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.1111111111111111, \"True positive rate\": 0.9333333333333333, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.1111111111111111, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.13333333333333333, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.13333333333333333, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.15555555555555556, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.2, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.26666666666666666, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.26666666666666666, \"True positive rate\": 1.0, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.4444444444444444, \"True positive rate\": 1.0, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.4888888888888889, \"True positive rate\": 1.0, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.5777777777777777, \"True positive rate\": 1.0, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.6222222222222222, \"True positive rate\": 1.0, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.7333333333333333, \"True positive rate\": 1.0, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.7777777777777778, \"True positive rate\": 1.0, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.8222222222222222, \"True positive rate\": 1.0, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.8666666666666667, \"True positive rate\": 1.0, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.9111111111111111, \"True positive rate\": 1.0, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.9555555555555556, \"True positive rate\": 1.0, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.99086, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.99086, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.13333333333333333, \"AUC\": 0.99086, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.17777777777777778, \"AUC\": 0.99086, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.24444444444444444, \"AUC\": 0.99086, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.3333333333333333, \"AUC\": 0.99086, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.4444444444444444, \"AUC\": 0.99086, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.4888888888888889, \"AUC\": 0.99086, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.5555555555555556, \"AUC\": 0.99086, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.6, \"AUC\": 0.99086, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.7333333333333333, \"AUC\": 0.99086, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.7555555555555555, \"AUC\": 0.99086, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.8888888888888888, \"AUC\": 0.99086, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.8888888888888888, \"AUC\": 0.99086, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.99086, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.99086, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.99086, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 1.0, \"AUC\": 0.99086, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.2, \"True positive rate\": 1.0, \"AUC\": 0.99086, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.24444444444444444, \"True positive rate\": 1.0, \"AUC\": 0.99086, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.5111111111111111, \"True positive rate\": 1.0, \"AUC\": 0.99086, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.5777777777777777, \"True positive rate\": 1.0, \"AUC\": 0.99086, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.8, \"True positive rate\": 1.0, \"AUC\": 0.99086, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.8444444444444444, \"True positive rate\": 1.0, \"AUC\": 0.99086, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.99086, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.99556, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.99556, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.08888888888888889, \"AUC\": 0.99556, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.13333333333333333, \"AUC\": 0.99556, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.2, \"AUC\": 0.99556, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.26666666666666666, \"AUC\": 0.99556, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.28888888888888886, \"AUC\": 0.99556, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.3333333333333333, \"AUC\": 0.99556, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.35555555555555557, \"AUC\": 0.99556, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.4, \"AUC\": 0.99556, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.4222222222222222, \"AUC\": 0.99556, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.5555555555555556, \"AUC\": 0.99556, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.6444444444444445, \"AUC\": 0.99556, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.7555555555555555, \"AUC\": 0.99556, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.8444444444444444, \"AUC\": 0.99556, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.99556, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.99556, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.99556, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 1.0, \"AUC\": 0.99556, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.4888888888888889, \"True positive rate\": 1.0, \"AUC\": 0.99556, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.5333333333333333, \"True positive rate\": 1.0, \"AUC\": 0.99556, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.7333333333333333, \"True positive rate\": 1.0, \"AUC\": 0.99556, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.7777777777777778, \"True positive rate\": 1.0, \"AUC\": 0.99556, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.8444444444444444, \"True positive rate\": 1.0, \"AUC\": 0.99556, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.8888888888888888, \"True positive rate\": 1.0, \"AUC\": 0.99556, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.9333333333333333, \"True positive rate\": 1.0, \"AUC\": 0.99556, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.9777777777777777, \"True positive rate\": 1.0, \"AUC\": 0.99556, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.99556, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.022222222222222223, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.08888888888888889, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.13333333333333333, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.2, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.28888888888888886, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.3111111111111111, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.35555555555555557, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.5111111111111111, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.5555555555555556, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.7555555555555555, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.8444444444444444, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 1.0, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.13333333333333333, \"True positive rate\": 1.0, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.17777777777777778, \"True positive rate\": 1.0, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.28888888888888886, \"True positive rate\": 1.0, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.3333333333333333, \"True positive rate\": 1.0, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.37777777777777777, \"True positive rate\": 1.0, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.4222222222222222, \"True positive rate\": 1.0, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.4666666666666667, \"True positive rate\": 1.0, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.5555555555555556, \"True positive rate\": 1.0, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.6444444444444445, \"True positive rate\": 1.0, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.6888888888888889, \"True positive rate\": 1.0, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.FacetChart(...)"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "text/html": [
       "\n",
       "<div id=\"altair-viz-2d2bc67a08fd4e8eaea9981e273d6e9a\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-2d2bc67a08fd4e8eaea9981e273d6e9a\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-2d2bc67a08fd4e8eaea9981e273d6e9a\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm//vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm//vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm//vega-lite@4.8.1?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm//vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function loadScript(lib) {\n",
       "      return new Promise(function(resolve, reject) {\n",
       "        var s = document.createElement('script');\n",
       "        s.src = paths[lib];\n",
       "        s.async = true;\n",
       "        s.onload = () => resolve(paths[lib]);\n",
       "        s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "        document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "      });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else if (typeof vegaEmbed === \"function\") {\n",
       "      displayChart(vegaEmbed);\n",
       "    } else {\n",
       "      loadScript(\"vega\")\n",
       "        .then(() => loadScript(\"vega-lite\"))\n",
       "        .then(() => loadScript(\"vega-embed\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 400, \"continuousHeight\": 300}}, \"data\": {\"name\": \"data-bd9ddff88500ea10b6bbc737a36d9615\"}, \"facet\": {\"column\": {\"type\": \"quantitative\", \"field\": \"n_trials\"}, \"row\": {\"type\": \"nominal\", \"field\": \"y\"}}, \"spec\": {\"layer\": [{\"mark\": {\"type\": \"line\", \"opacity\": 0.7, \"size\": 2.6}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"method\"}, \"x\": {\"type\": \"quantitative\", \"field\": \"False positive rate\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"field\": \"True positive rate\"}}, \"selection\": {\"selector003\": {\"type\": \"interval\", \"bind\": \"scales\", \"encodings\": [\"x\", \"y\"]}}}, {\"mark\": {\"type\": \"point\", \"opacity\": 0.7, \"size\": 22.6}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"method\"}, \"x\": {\"type\": \"quantitative\", \"field\": \"False positive rate\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"field\": \"True positive rate\"}}}], \"width\": 150}, \"$schema\": \"https://vega.github.io/schema/vega-lite/v4.8.1.json\", \"datasets\": {\"data-bd9ddff88500ea10b6bbc737a36d9615\": [{\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.57778, \"true_slope\": 10.0, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.15555555555555556, \"AUC\": 0.57778, \"true_slope\": 10.0, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.57778, \"true_slope\": 10.0, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.53333, \"true_slope\": 10.0, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.06666666666666667, \"AUC\": 0.53333, \"true_slope\": 10.0, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.53333, \"true_slope\": 10.0, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.51111, \"true_slope\": 10.0, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.51111, \"true_slope\": 10.0, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.51111, \"true_slope\": 10.0, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.5, \"true_slope\": 10.0, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.5, \"true_slope\": 10.0, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.51111, \"true_slope\": 10.0, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.51111, \"true_slope\": 10.0, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.51111, \"true_slope\": 10.0, \"method\": \"anova\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.93284, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.93284, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.4, \"AUC\": 0.93284, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.4, \"AUC\": 0.93284, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.93284, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.17777777777777778, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.93284, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.17777777777777778, \"True positive rate\": 0.8888888888888888, \"AUC\": 0.93284, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.2, \"True positive rate\": 0.8888888888888888, \"AUC\": 0.93284, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.2, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.93284, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.26666666666666666, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.93284, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.26666666666666666, \"True positive rate\": 0.9333333333333333, \"AUC\": 0.93284, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.4444444444444444, \"True positive rate\": 0.9333333333333333, \"AUC\": 0.93284, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.4444444444444444, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.93284, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.5777777777777777, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.93284, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.5777777777777777, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.93284, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.8888888888888888, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.93284, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.8888888888888888, \"True positive rate\": 1.0, \"AUC\": 0.93284, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.93284, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.98469, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.98469, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.8, \"AUC\": 0.98469, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.8, \"AUC\": 0.98469, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.8888888888888888, \"AUC\": 0.98469, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.8888888888888888, \"AUC\": 0.98469, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.98469, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.1111111111111111, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.98469, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.1111111111111111, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.98469, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.28888888888888886, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.98469, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.28888888888888886, \"True positive rate\": 1.0, \"AUC\": 0.98469, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.98469, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.99407, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.99407, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.99407, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.99407, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.99407, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.99407, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.99407, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.99407, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 1.0, \"AUC\": 0.99407, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.99407, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.99704, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.99704, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.9333333333333333, \"AUC\": 0.99704, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.9333333333333333, \"AUC\": 0.99704, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.99704, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.99704, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.99704, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.99704, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 1.0, \"AUC\": 0.99704, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.99704, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.022222222222222223, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 1.0, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"bw_gamma\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.92691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.92691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.37777777777777777, \"AUC\": 0.92691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.37777777777777777, \"AUC\": 0.92691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.7111111111111111, \"AUC\": 0.92691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.7111111111111111, \"AUC\": 0.92691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.8, \"AUC\": 0.92691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.8, \"AUC\": 0.92691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.8222222222222222, \"AUC\": 0.92691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.13333333333333333, \"True positive rate\": 0.8222222222222222, \"AUC\": 0.92691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.13333333333333333, \"True positive rate\": 0.8444444444444444, \"AUC\": 0.92691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.15555555555555556, \"True positive rate\": 0.8444444444444444, \"AUC\": 0.92691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.15555555555555556, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.92691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.17777777777777778, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.92691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.17777777777777778, \"True positive rate\": 0.8888888888888888, \"AUC\": 0.92691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.2, \"True positive rate\": 0.8888888888888888, \"AUC\": 0.92691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.2, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.92691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.24444444444444444, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.92691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.24444444444444444, \"True positive rate\": 0.9333333333333333, \"AUC\": 0.92691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.26666666666666666, \"True positive rate\": 0.9333333333333333, \"AUC\": 0.92691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.26666666666666666, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.92691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.6666666666666666, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.92691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.6666666666666666, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.92691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.8666666666666667, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.92691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.8666666666666667, \"True positive rate\": 1.0, \"AUC\": 0.92691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.92691, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.9684, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.9684, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.7333333333333333, \"AUC\": 0.9684, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.7333333333333333, \"AUC\": 0.9684, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.8, \"AUC\": 0.9684, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.8, \"AUC\": 0.9684, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.8222222222222222, \"AUC\": 0.9684, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.1111111111111111, \"True positive rate\": 0.8222222222222222, \"AUC\": 0.9684, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.1111111111111111, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.9684, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.17777777777777778, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.9684, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.17777777777777778, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.9684, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.2, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.9684, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.2, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.9684, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.28888888888888886, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.9684, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.28888888888888886, \"True positive rate\": 1.0, \"AUC\": 0.9684, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.9684, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.98864, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.98864, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.7777777777777778, \"AUC\": 0.98864, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.7777777777777778, \"AUC\": 0.98864, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.8, \"AUC\": 0.98864, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.8, \"AUC\": 0.98864, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.98864, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.98864, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.98864, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.1111111111111111, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.98864, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.1111111111111111, \"True positive rate\": 1.0, \"AUC\": 0.98864, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.98864, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.99259, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.99259, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.7777777777777778, \"AUC\": 0.99259, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.7777777777777778, \"AUC\": 0.99259, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.99259, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.99259, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.99259, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.08888888888888889, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.99259, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.08888888888888889, \"True positive rate\": 1.0, \"AUC\": 0.99259, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.99259, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.022222222222222223, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 1.0, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"bw_normal\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.24444444444444444, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.26666666666666666, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.37777777777777777, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.4222222222222222, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.4444444444444444, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.4888888888888889, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.5111111111111111, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.5111111111111111, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.6, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.6, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.6222222222222222, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.6666666666666666, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.7111111111111111, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.08888888888888889, \"True positive rate\": 0.7333333333333333, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.08888888888888889, \"True positive rate\": 0.8666666666666667, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.1111111111111111, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.17777777777777778, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.17777777777777778, \"True positive rate\": 0.9333333333333333, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.2, \"True positive rate\": 0.9333333333333333, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.2, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.24444444444444444, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.3111111111111111, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.3333333333333333, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.5333333333333333, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.5777777777777777, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.6222222222222222, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.6666666666666666, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.8222222222222222, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.8222222222222222, \"True positive rate\": 1.0, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.93111, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 10, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.28888888888888886, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.3333333333333333, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.5111111111111111, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.5555555555555556, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.6, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.6222222222222222, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.6888888888888889, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.7333333333333333, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.7555555555555555, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.8, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.8444444444444444, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.9333333333333333, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.1111111111111111, \"True positive rate\": 0.9333333333333333, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.1111111111111111, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.13333333333333333, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.13333333333333333, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.15555555555555556, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.2, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.26666666666666666, \"True positive rate\": 0.9777777777777777, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.26666666666666666, \"True positive rate\": 1.0, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.4444444444444444, \"True positive rate\": 1.0, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.4888888888888889, \"True positive rate\": 1.0, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.5777777777777777, \"True positive rate\": 1.0, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.6222222222222222, \"True positive rate\": 1.0, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.7333333333333333, \"True positive rate\": 1.0, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.7777777777777778, \"True positive rate\": 1.0, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.8222222222222222, \"True positive rate\": 1.0, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.8666666666666667, \"True positive rate\": 1.0, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.9111111111111111, \"True positive rate\": 1.0, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.9555555555555556, \"True positive rate\": 1.0, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.97679, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 25, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.99086, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.99086, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.13333333333333333, \"AUC\": 0.99086, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.17777777777777778, \"AUC\": 0.99086, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.24444444444444444, \"AUC\": 0.99086, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.3333333333333333, \"AUC\": 0.99086, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.4444444444444444, \"AUC\": 0.99086, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.4888888888888889, \"AUC\": 0.99086, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.5555555555555556, \"AUC\": 0.99086, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.6, \"AUC\": 0.99086, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.7333333333333333, \"AUC\": 0.99086, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.7555555555555555, \"AUC\": 0.99086, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.022222222222222223, \"True positive rate\": 0.8888888888888888, \"AUC\": 0.99086, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.8888888888888888, \"AUC\": 0.99086, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.99086, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.99086, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.99086, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 1.0, \"AUC\": 0.99086, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.2, \"True positive rate\": 1.0, \"AUC\": 0.99086, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.24444444444444444, \"True positive rate\": 1.0, \"AUC\": 0.99086, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.5111111111111111, \"True positive rate\": 1.0, \"AUC\": 0.99086, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.5777777777777777, \"True positive rate\": 1.0, \"AUC\": 0.99086, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.8, \"True positive rate\": 1.0, \"AUC\": 0.99086, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.8444444444444444, \"True positive rate\": 1.0, \"AUC\": 0.99086, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.99086, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 40, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 0.99556, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.022222222222222223, \"AUC\": 0.99556, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.08888888888888889, \"AUC\": 0.99556, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.13333333333333333, \"AUC\": 0.99556, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.2, \"AUC\": 0.99556, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.26666666666666666, \"AUC\": 0.99556, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.28888888888888886, \"AUC\": 0.99556, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.3333333333333333, \"AUC\": 0.99556, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.35555555555555557, \"AUC\": 0.99556, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.4, \"AUC\": 0.99556, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.4222222222222222, \"AUC\": 0.99556, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.5555555555555556, \"AUC\": 0.99556, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.6444444444444445, \"AUC\": 0.99556, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.7555555555555555, \"AUC\": 0.99556, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.8444444444444444, \"AUC\": 0.99556, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.99556, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.9111111111111111, \"AUC\": 0.99556, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.044444444444444446, \"True positive rate\": 0.9555555555555556, \"AUC\": 0.99556, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.06666666666666667, \"True positive rate\": 1.0, \"AUC\": 0.99556, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.4888888888888889, \"True positive rate\": 1.0, \"AUC\": 0.99556, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.5333333333333333, \"True positive rate\": 1.0, \"AUC\": 0.99556, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.7333333333333333, \"True positive rate\": 1.0, \"AUC\": 0.99556, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.7777777777777778, \"True positive rate\": 1.0, \"AUC\": 0.99556, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.8444444444444444, \"True positive rate\": 1.0, \"AUC\": 0.99556, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.8888888888888888, \"True positive rate\": 1.0, \"AUC\": 0.99556, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.9333333333333333, \"True positive rate\": 1.0, \"AUC\": 0.99556, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.9777777777777777, \"True positive rate\": 1.0, \"AUC\": 0.99556, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 0.99556, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 55, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.0, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.022222222222222223, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.08888888888888889, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.13333333333333333, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.2, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.28888888888888886, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.3111111111111111, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.35555555555555557, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.5111111111111111, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.5555555555555556, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.7555555555555555, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 0.8444444444444444, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.0, \"True positive rate\": 1.0, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.13333333333333333, \"True positive rate\": 1.0, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.17777777777777778, \"True positive rate\": 1.0, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.28888888888888886, \"True positive rate\": 1.0, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.3333333333333333, \"True positive rate\": 1.0, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.37777777777777777, \"True positive rate\": 1.0, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.4222222222222222, \"True positive rate\": 1.0, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.4666666666666667, \"True positive rate\": 1.0, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.5555555555555556, \"True positive rate\": 1.0, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.6444444444444445, \"True positive rate\": 1.0, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 0.6888888888888889, \"True positive rate\": 1.0, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}, {\"False positive rate\": 1.0, \"True positive rate\": 1.0, \"AUC\": 1.0, \"true_slope\": 10.0, \"method\": \"mlm\", \"y\": \"Log power\", \"n_trials\": 70, \"randomness\": 0.2}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.FacetChart(...)"
      ]
     },
     "execution_count": 8,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "df = model_comparison.make_roc_auc(reslog, binary=False, groups=('method', 'y', 'n_trials'))\n",
    "\n",
    "bars, roc = model_comparison.plot_roc(df)\n",
    "bars.facet(column='n_trials', row='y').properties().display()\n",
    "roc.facet(column='n_trials', row='y').properties()\n",
    "# NBVAL_SKIP\n"
   ]
  }
 ],
 "metadata": {
  "celltoolbar": "Slideshow",
  "hide_input": false,
  "jupytext": {
   "formats": "ipynb,py:light"
  },
  "kernelspec": {
   "display_name": "PyCharm (jup)",
   "language": "python",
   "name": "pycharm-d5912792"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.8.5"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 4
}
